""" Cisco_IOS_XR_ipv6_ospfv3_oper 

This module contains a collection of YANG definitions
for Cisco IOS\-XR ipv6\-ospfv3 package operational data.

This module contains definitions
for the following management objects\:
  ospfv3\: OSPFv3 operational information 

Copyright (c) 2013\-2016 by Cisco Systems, Inc.
All rights reserved.

"""


import re
import collections

from enum import Enum

from ydk.types import Empty, YList, YLeafList, DELETE, Decimal64, FixedBitsDict

from ydk.errors import YPYError, YPYModelError



class ImStateEnumEnum(Enum):
    """
    ImStateEnumEnum

    Im state enum

    .. data:: im_state_not_ready = 0

    	im state not ready

    .. data:: im_state_admin_down = 1

    	im state admin down

    .. data:: im_state_down = 2

    	im state down

    .. data:: im_state_up = 3

    	im state up

    .. data:: im_state_shutdown = 4

    	im state shutdown

    .. data:: im_state_err_disable = 5

    	im state err disable

    .. data:: im_state_down_immediate = 6

    	im state down immediate

    .. data:: im_state_down_immediate_admin = 7

    	im state down immediate admin

    .. data:: im_state_down_graceful = 8

    	im state down graceful

    .. data:: im_state_begin_shutdown = 9

    	im state begin shutdown

    .. data:: im_state_end_shutdown = 10

    	im state end shutdown

    .. data:: im_state_begin_error_disable = 11

    	im state begin error disable

    .. data:: im_state_end_error_disable = 12

    	im state end error disable

    .. data:: im_state_begin_down_graceful = 13

    	im state begin down graceful

    .. data:: im_state_reset = 14

    	im state reset

    .. data:: im_state_operational = 15

    	im state operational

    .. data:: im_state_not_operational = 16

    	im state not operational

    .. data:: im_state_unknown = 17

    	im state unknown

    .. data:: im_state_last = 18

    	im state last

    """

    im_state_not_ready = 0

    im_state_admin_down = 1

    im_state_down = 2

    im_state_up = 3

    im_state_shutdown = 4

    im_state_err_disable = 5

    im_state_down_immediate = 6

    im_state_down_immediate_admin = 7

    im_state_down_graceful = 8

    im_state_begin_shutdown = 9

    im_state_end_shutdown = 10

    im_state_begin_error_disable = 11

    im_state_end_error_disable = 12

    im_state_begin_down_graceful = 13

    im_state_reset = 14

    im_state_operational = 15

    im_state_not_operational = 16

    im_state_unknown = 17

    im_state_last = 18


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
        return meta._meta_table['ImStateEnumEnum']


class IpfrrTbrkrEnum(Enum):
    """
    IpfrrTbrkrEnum

    FRR Tiebreakers

    .. data:: downstream = 0

    	Downsteram

    .. data:: line_card_disjoint = 1

    	LC Disjoint

    .. data:: backup_metric = 2

    	Backup metric

    .. data:: node_protect = 3

    	Node protection

    .. data:: primary_path = 4

    	Primary path

    .. data:: secondary_path = 5

    	Secondary path

    .. data:: srlg_disjoint = 6

    	SRLG disjoint

    .. data:: tunnel = 7

    	Tunnel

    """

    downstream = 0

    line_card_disjoint = 1

    backup_metric = 2

    node_protect = 3

    primary_path = 4

    secondary_path = 5

    srlg_disjoint = 6

    tunnel = 7


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
        return meta._meta_table['IpfrrTbrkrEnum']


class OspfLsaSyncStateEnum(Enum):
    """
    OspfLsaSyncStateEnum

    LSA synchronization states

    .. data:: none = 0

    	State not set

    .. data:: out_of_sync = 1

    	LSA out of sync with active

    .. data:: in_sync = 2

    	LSA in sync with active

    .. data:: nsr_ack_pending = 3

    	NSR ack pending for LSA sync

    """

    none = 0

    out_of_sync = 1

    in_sync = 2

    nsr_ack_pending = 3


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
        return meta._meta_table['OspfLsaSyncStateEnum']


class OspfNsrSchedPriEnum(Enum):
    """
    OspfNsrSchedPriEnum

    Ospf nsr sched pri

    .. data:: ospf_nsr_stats_sched_pri_hi = 0

    	ospf nsr stats sched pri hi

    .. data:: ospf_nsr_stats_sched_pri_med = 1

    	ospf nsr stats sched pri med

    .. data:: ospf_nsr_stats_sched_pri_low = 2

    	ospf nsr stats sched pri low

    .. data:: ospf_nsr_stats_sched_pri_max = 3

    	ospf nsr stats sched pri max

    """

    ospf_nsr_stats_sched_pri_hi = 0

    ospf_nsr_stats_sched_pri_med = 1

    ospf_nsr_stats_sched_pri_low = 2

    ospf_nsr_stats_sched_pri_max = 3


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
        return meta._meta_table['OspfNsrSchedPriEnum']


class Ospfv3AreaRangeStatusEnum(Enum):
    """
    Ospfv3AreaRangeStatusEnum

    Ospfv3 area range status

    .. data:: advertise = 1

    	Advertise this range

    .. data:: do_not_advertise = 2

    	Do not advertise this range

    """

    advertise = 1

    do_not_advertise = 2


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
        return meta._meta_table['Ospfv3AreaRangeStatusEnum']


class Ospfv3BorderRouteEnum(Enum):
    """
    Ospfv3BorderRouteEnum

    OSPFv3 border route destination types

    .. data:: abr = 1

    	Area border router

    .. data:: asbr = 2

    	Area system boundary router

    .. data:: abr_asbr = 3

    	Area border router and area system boundary

    	router

    """

    abr = 1

    asbr = 2

    abr_asbr = 3


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
        return meta._meta_table['Ospfv3BorderRouteEnum']


class Ospfv3DefaultMetricEnum(Enum):
    """
    Ospfv3DefaultMetricEnum

    OSPFv3 default metric types 

    .. data:: type_none = 0

    	OSPFv3 default metric type None 

    .. data:: type1 = 1

    	OSPFv3 default metric type 1 

    .. data:: type2 = 2

    	OSPFv3 default metric type 2 

    """

    type_none = 0

    type1 = 1

    type2 = 2


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
        return meta._meta_table['Ospfv3DefaultMetricEnum']


class Ospfv3GracefulRestartReasonEnum(Enum):
    """
    Ospfv3GracefulRestartReasonEnum

    Reason for router restart

    .. data:: grace_reason_unknown = 0

    	Grace reason unknown

    .. data:: grace_reason_software_restart = 1

    	Grace reason software restart

    .. data:: grace_reason_software_upgrade = 2

    	Software reload/upgrade, RFC 3623

    .. data:: grace_reason_switchover = 3

    	Switch to redundant control processor

    """

    grace_reason_unknown = 0

    grace_reason_software_restart = 1

    grace_reason_software_upgrade = 2

    grace_reason_switchover = 3


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
        return meta._meta_table['Ospfv3GracefulRestartReasonEnum']


class Ospfv3GracefulShutdownStateEnum(Enum):
    """
    Ospfv3GracefulShutdownStateEnum

    Graceful Shutdown state

    .. data:: init = 0

    	Init

    .. data:: normal = 1

    	Normal

    .. data:: flushing = 2

    	Flushing

    .. data:: empty_hellos = 3

    	Empty Hellos

    .. data:: quiet = 4

    	Quiet

    """

    init = 0

    normal = 1

    flushing = 2

    empty_hellos = 3

    quiet = 4


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
        return meta._meta_table['Ospfv3GracefulShutdownStateEnum']


class Ospfv3InterfaceEnum(Enum):
    """
    Ospfv3InterfaceEnum

    OSPFv3 neighbor interface types

    .. data:: none = 0

    	None

    .. data:: broadcast = 1

    	Broadcast

    .. data:: non_broadcast = 2

    	Non broadcast

    .. data:: point_to_point = 3

    	Point To Point

    .. data:: point_to_multipoint = 4

    	Point To Multipoint

    .. data:: point_to_multipoint_non_broadcast = 5

    	Point-To-Multipoint Non broadcast

    .. data:: virtual_link = 6

    	Virtual link

    .. data:: loopback_interface = 7

    	Loopback

    .. data:: mpls_traffic_engineering = 8

    	MPLS traffic engineering

    .. data:: sham_link = 9

    	Sham link

    """

    none = 0

    broadcast = 1

    non_broadcast = 2

    point_to_point = 3

    point_to_multipoint = 4

    point_to_multipoint_non_broadcast = 5

    virtual_link = 6

    loopback_interface = 7

    mpls_traffic_engineering = 8

    sham_link = 9


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
        return meta._meta_table['Ospfv3InterfaceEnum']


class Ospfv3InterfaceStateEnum(Enum):
    """
    Ospfv3InterfaceStateEnum

    OSPFv3 interface states

    .. data:: down = 0

    	Down

    .. data:: loopback = 1

    	Loopback

    .. data:: waiting = 2

    	Waiting

    .. data:: point_to_multipoint = 3

    	Point To Multipoint

    .. data:: point_to_point = 4

    	Point To Point

    .. data:: designated_router = 5

    	Designated router

    .. data:: backup_designated_router = 6

    	Backup designated router

    .. data:: other_designated_router = 7

    	Other designated router

    """

    down = 0

    loopback = 1

    waiting = 2

    point_to_multipoint = 3

    point_to_point = 4

    designated_router = 5

    backup_designated_router = 6

    other_designated_router = 7


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
        return meta._meta_table['Ospfv3InterfaceStateEnum']


class Ospfv3LinkEnum(Enum):
    """
    Ospfv3LinkEnum

    OSPFV3 Link type

    .. data:: link_router = 1

    	Router link

    .. data:: link_trans_net = 2

    	Transit network link

    .. data:: link_virtual_link = 4

    	Virutal link

    """

    link_router = 1

    link_trans_net = 2

    link_virtual_link = 4


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
        return meta._meta_table['Ospfv3LinkEnum']


class Ospfv3Lsa1Enum(Enum):
    """
    Ospfv3Lsa1Enum

    OSPFv3 LSA types

    .. data:: link = 8

    	Link LSA

    .. data:: grace = 11

    	Grace LSA

    .. data:: router = 8193

    	Router LSA

    .. data:: network = 8194

    	Network LSA

    .. data:: inter_area_prefix = 8195

    	Inter area prefix LSA

    .. data:: inter_area_router = 8196

    	Inter area router LSA

    .. data:: mospf = 8198

    	MOSPF LSA

    .. data:: type7_external = 8199

    	Type-7 External LSA

    .. data:: lsa_prefix = 8201

    	Prefix LSA

    .. data:: as_external = 16389

    	AS external LSA

    .. data:: unknown_link = 32768

    	Unknown link LSA

    .. data:: unknown_area = 40960

    	Unknown area LSA

    .. data:: unknown_as = 49152

    	Unknown AS LSA

    .. data:: unknown_type = 57344

    	Unknown type LSA

    """

    link = 8

    grace = 11

    router = 8193

    network = 8194

    inter_area_prefix = 8195

    inter_area_router = 8196

    mospf = 8198

    type7_external = 8199

    lsa_prefix = 8201

    as_external = 16389

    unknown_link = 32768

    unknown_area = 40960

    unknown_as = 49152

    unknown_type = 57344


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
        return meta._meta_table['Ospfv3Lsa1Enum']


class Ospfv3LsaEnum(Enum):
    """
    Ospfv3LsaEnum

    Ospfv3 lsa

    .. data:: link_lsa = 8

    	Link LSA

    .. data:: grace_lsa = 11

    	Grace LSA

    .. data:: router = 8193

    	Router LSA

    .. data:: network = 8194

    	Network LSA

    .. data:: inter_area_prefix = 8195

    	Inter-Area Prefix LSA

    .. data:: inter_area_router = 8196

    	Inter-Area Router LSA

    .. data:: nssa_external = 8199

    	NSSA External LSA

    .. data:: intra_area_prefix = 8201

    	Intra-Area Prefix LSA

    .. data:: external = 16389

    	External LSA

    .. data:: opaque_link = 32768

    	Opaque LSALink Scope

    .. data:: opaque_area = 40960

    	Opaque LSA Area Scope

    .. data:: opaque_as = 49152

    	Opaque LSA AS Scope

    .. data:: unknown = 57344

    	Unknown Reserved Scope LSAs

    """

    link_lsa = 8

    grace_lsa = 11

    router = 8193

    network = 8194

    inter_area_prefix = 8195

    inter_area_router = 8196

    nssa_external = 8199

    intra_area_prefix = 8201

    external = 16389

    opaque_link = 32768

    opaque_area = 40960

    opaque_as = 49152

    unknown = 57344


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
        return meta._meta_table['Ospfv3LsaEnum']


class Ospfv3LsaInfoTypesEnum(Enum):
    """
    Ospfv3LsaInfoTypesEnum

    OSPFv3 LSA format types

    .. data:: mgmt_lsa_lsasum_type = 0

    	Summary information of LSAs

    .. data:: mgmt_lsa_link_type = 8

    	Link LSA

    .. data:: mgmt_lsa_gr_type = 11

    	Grace LSA

    .. data:: mgmt_lsa_rtr_type = 8193

    	Router LSA

    .. data:: mgmt_lsa_net_type = 8194

    	Network LSA

    .. data:: mgmt_lsa_iapfx_type = 8195

    	Inter Area Prefix Summary LSA

    .. data:: mgmt_lsa_iartr_type = 8196

    	Inter Area Router Summay LSA

    .. data:: mgmt_lsa_nssaext_type = 8199

    	NSSA external LSA

    .. data:: mgmt_lsa_prefix_type = 8201

    	Intra Area Prefix LSA

    .. data:: mgmt_lsa_ext_type = 16389

    	Type 5 External LSA

    .. data:: mgmt_lsa_unk_link_type = 32768

    	Opaque Link scope LSA

    .. data:: mgmt_lsa_unk_area_type = 40960

    	Opaque Area scope LSA

    .. data:: mgmt_lsa_unk_as_type = 49152

    	Opaque AS scope LSA

    .. data:: mgmt_lsa_unk_type = 57344

    	Opaque Reserved scope LSA

    """

    mgmt_lsa_lsasum_type = 0

    mgmt_lsa_link_type = 8

    mgmt_lsa_gr_type = 11

    mgmt_lsa_rtr_type = 8193

    mgmt_lsa_net_type = 8194

    mgmt_lsa_iapfx_type = 8195

    mgmt_lsa_iartr_type = 8196

    mgmt_lsa_nssaext_type = 8199

    mgmt_lsa_prefix_type = 8201

    mgmt_lsa_ext_type = 16389

    mgmt_lsa_unk_link_type = 32768

    mgmt_lsa_unk_area_type = 40960

    mgmt_lsa_unk_as_type = 49152

    mgmt_lsa_unk_type = 57344


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
        return meta._meta_table['Ospfv3LsaInfoTypesEnum']


class Ospfv3NeighborStateEnum(Enum):
    """
    Ospfv3NeighborStateEnum

    OSPFv3 neighbor states

    .. data:: neigbhor_down = 0

    	Down

    .. data:: attempt = 1

    	Attempting

    .. data:: init = 2

    	Initializing

    .. data:: two_way = 3

    	2 Way

    .. data:: exstart = 4

    	Exstart

    .. data:: exchange = 5

    	Exchange

    .. data:: loading = 6

    	Loading

    .. data:: full = 7

    	Full

    .. data:: sc_virtual = 8

    	SCVirtual

    """

    neigbhor_down = 0

    attempt = 1

    init = 2

    two_way = 3

    exstart = 4

    exchange = 5

    loading = 6

    full = 7

    sc_virtual = 8


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
        return meta._meta_table['Ospfv3NeighborStateEnum']


class PrefixPriorityEnum(Enum):
    """
    PrefixPriorityEnum

    Prefix priority

    .. data:: critical = 0

    	Critical priority

    .. data:: high = 1

    	High priority

    .. data:: medium = 2

    	Medium priority

    .. data:: low = 3

    	Low priority

    """

    critical = 0

    high = 1

    medium = 2

    low = 3


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
        return meta._meta_table['PrefixPriorityEnum']


class StubRouterAbrOffReasonEnum(Enum):
    """
    StubRouterAbrOffReasonEnum

    Reason to exiting stub router mode

    .. data:: init_delay = 2

    	Initial delay when stub router mode is

    	activated

    .. data:: no_neighbor = 3

    	No neighbor present

    .. data:: no_full_neighbor = 4

    	No neighbor in FULL state present

    .. data:: new_neighbor = 5

    	A new neighbor discovered less than 60 seconds

    	ago

    .. data:: full_neighbor = 6

    	A neighbor transitioned to FULL state less than

    	60 seconds ago

    """

    init_delay = 2

    no_neighbor = 3

    no_full_neighbor = 4

    new_neighbor = 5

    full_neighbor = 6


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
        return meta._meta_table['StubRouterAbrOffReasonEnum']


class StubRouterExitReasonEnum(Enum):
    """
    StubRouterExitReasonEnum

    Reason to exiting stub router mode

    .. data:: none = 0

    	No reason

    .. data:: bgp = 1

    	BGP has converged

    .. data:: timer = 2

    	Stub Router timer has expired

    .. data:: configuration = 3

    	Configuration has changed

    .. data:: cleared = 4

    	Process has been cleared

    .. data:: override = 5

    	Preempted by always

    """

    none = 0

    bgp = 1

    timer = 2

    configuration = 3

    cleared = 4

    override = 5


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
        return meta._meta_table['StubRouterExitReasonEnum']


class StubRouterModeEnum(Enum):
    """
    StubRouterModeEnum

    Stub Router mode

    .. data:: rbit = 0

    	Stub Router mode r-bit

    .. data:: v6bit = 1

    	Stub Router mode v6-bit

    .. data:: max_metric = 2

    	Stub Router mode max-metric

    .. data:: none = 3

    	Stub Router not configured

    """

    rbit = 0

    v6bit = 1

    max_metric = 2

    none = 3


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
        return meta._meta_table['StubRouterModeEnum']


class StubRouterTriggerEnum(Enum):
    """
    StubRouterTriggerEnum

    Trigger for entering stub router mode

    .. data:: on_proc_migration = 0

    	Process migration

    .. data:: on_proc_restart = 1

    	Process restart

    .. data:: on_switchover = 2

    	RP switchover

    .. data:: on_startup = 3

    	Router startup

    .. data:: always = 4

    	Always on

    .. data:: none = 5

    	No trigger

    """

    on_proc_migration = 0

    on_proc_restart = 1

    on_switchover = 2

    on_startup = 3

    always = 4

    none = 5


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
        return meta._meta_table['StubRouterTriggerEnum']



class Ospfv3(object):
    """
    OSPFv3 operational information 
    
    .. attribute:: processes
    
    	OSPFv3 Process Table
    	**type**\:   :py:class:`Processes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes>`
    
    

    """

    _prefix = 'ipv6-ospfv3-oper'
    _revision = '2015-11-09'

    def __init__(self):
        self.processes = Ospfv3.Processes()
        self.processes.parent = self


    class Processes(object):
        """
        OSPFv3 Process Table
        
        .. attribute:: process
        
        	OSPFv3 Operational data for a particular OSPFv3 process 
        	**type**\: list of    :py:class:`Process <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process>`
        
        

        """

        _prefix = 'ipv6-ospfv3-oper'
        _revision = '2015-11-09'

        def __init__(self):
            self.parent = None
            self.process = YList()
            self.process.parent = self
            self.process.name = 'process'


        class Process(object):
            """
            OSPFv3 Operational data for a particular OSPFv3
            process 
            
            .. attribute:: process_name  <key>
            
            	Particular OSPFv3 process
            	**type**\:  str
            
            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
            
            .. attribute:: default_vrf
            
            	Operational data for the default VRF (instance) in the OSPFv3 process
            	**type**\:   :py:class:`DefaultVrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf>`
            
            .. attribute:: statistics
            
            	Container for Statistics
            	**type**\:   :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Statistics>`
            
            .. attribute:: vrfs
            
            	Table for each VRF
            	**type**\:   :py:class:`Vrfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs>`
            
            

            """

            _prefix = 'ipv6-ospfv3-oper'
            _revision = '2015-11-09'

            def __init__(self):
                self.parent = None
                self.process_name = None
                self.default_vrf = Ospfv3.Processes.Process.DefaultVrf()
                self.default_vrf.parent = self
                self.statistics = Ospfv3.Processes.Process.Statistics()
                self.statistics.parent = self
                self.vrfs = Ospfv3.Processes.Process.Vrfs()
                self.vrfs.parent = self


            class Vrfs(object):
                """
                Table for each VRF
                
                .. attribute:: vrf
                
                	Operational data for a particular VRF (instance) in the OSPFv3 process
                	**type**\: list of    :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf>`
                
                

                """

                _prefix = 'ipv6-ospfv3-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.vrf = YList()
                    self.vrf.parent = self
                    self.vrf.name = 'vrf'


                class Vrf(object):
                    """
                    Operational data for a particular VRF
                    (instance) in the OSPFv3 process
                    
                    .. attribute:: vrf_name  <key>
                    
                    	VRF Name
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    .. attribute:: area_informations
                    
                    	OSPFv3 area information table
                    	**type**\:   :py:class:`AreaInformations <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.AreaInformations>`
                    
                    .. attribute:: areas
                    
                    	OSPFv3 area table
                    	**type**\:   :py:class:`Areas <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas>`
                    
                    .. attribute:: bad_checksums
                    
                    	Bad Checksum Packets information table
                    	**type**\:   :py:class:`BadChecksums <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.BadChecksums>`
                    
                    .. attribute:: border_routers
                    
                    	OSPFv3 border router information table
                    	**type**\:   :py:class:`BorderRouters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.BorderRouters>`
                    
                    .. attribute:: connected_routes
                    
                    	OSPFv3 connected route information table
                    	**type**\:   :py:class:`ConnectedRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.ConnectedRoutes>`
                    
                    .. attribute:: database_summary_table
                    
                    	Database summary table
                    	**type**\:   :py:class:`DatabaseSummaryTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseSummaryTable>`
                    
                    .. attribute:: database_table
                    
                    	OSPF Link State Database
                    	**type**\:   :py:class:`DatabaseTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable>`
                    
                    .. attribute:: external_routes
                    
                    	OSPFv3 external route information table
                    	**type**\:   :py:class:`ExternalRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.ExternalRoutes>`
                    
                    .. attribute:: fast_reroutes
                    
                    	OSPFv3 fast reroute topology information table
                    	**type**\:   :py:class:`FastReroutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.FastReroutes>`
                    
                    .. attribute:: flood_list_process_table
                    
                    	OSPFv3 flood list information table for all areas
                    	**type**\:   :py:class:`FloodListProcessTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.FloodListProcessTable>`
                    
                    .. attribute:: interface_brief_process_table
                    
                    	OSPFv3 interface brief information table for all areas
                    	**type**\:   :py:class:`InterfaceBriefProcessTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.InterfaceBriefProcessTable>`
                    
                    .. attribute:: interface_process_table
                    
                    	OSPFv3 interface information table for all areas
                    	**type**\:   :py:class:`InterfaceProcessTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.InterfaceProcessTable>`
                    
                    .. attribute:: internal_routes
                    
                    	OSPFv3 internal route information table
                    	**type**\:   :py:class:`InternalRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.InternalRoutes>`
                    
                    .. attribute:: neighbor_detail_process_table
                    
                    	OSPFv3 neighbor information table for all areas
                    	**type**\:   :py:class:`NeighborDetailProcessTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.NeighborDetailProcessTable>`
                    
                    .. attribute:: neighbor_process_table
                    
                    	OSPFv3 neighbor information table for all areas
                    	**type**\:   :py:class:`NeighborProcessTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.NeighborProcessTable>`
                    
                    .. attribute:: protocol_areas
                    
                    	Protocol area table 
                    	**type**\:   :py:class:`ProtocolAreas <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.ProtocolAreas>`
                    
                    .. attribute:: redistributions
                    
                    	Redistribution information table
                    	**type**\:   :py:class:`Redistributions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Redistributions>`
                    
                    .. attribute:: request_list_process_table
                    
                    	OSPFv3 request list information for all areas
                    	**type**\:   :py:class:`RequestListProcessTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.RequestListProcessTable>`
                    
                    .. attribute:: retransmission_list_process_table
                    
                    	OSPFv3 retransmission list information table for all areas
                    	**type**\:   :py:class:`RetransmissionListProcessTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.RetransmissionListProcessTable>`
                    
                    .. attribute:: route_summary
                    
                    	Summarize OSPFv3 local RIB tables
                    	**type**\:   :py:class:`RouteSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.RouteSummary>`
                    
                    .. attribute:: sham_link_table
                    
                    	Sham link information
                    	**type**\:   :py:class:`ShamLinkTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.ShamLinkTable>`
                    
                    .. attribute:: summary
                    
                    	OSPFv3 summary
                    	**type**\:   :py:class:`Summary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Summary>`
                    
                    .. attribute:: summary_prefixes
                    
                    	Summary prefix information table
                    	**type**\:   :py:class:`SummaryPrefixes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.SummaryPrefixes>`
                    
                    .. attribute:: virtual_link
                    
                    	Virtual link information
                    	**type**\:   :py:class:`VirtualLink <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.VirtualLink>`
                    
                    .. attribute:: vrf_statistics
                    
                    	Container for Statistics
                    	**type**\:   :py:class:`VrfStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics>`
                    
                    

                    """

                    _prefix = 'ipv6-ospfv3-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.vrf_name = None
                        self.area_informations = Ospfv3.Processes.Process.Vrfs.Vrf.AreaInformations()
                        self.area_informations.parent = self
                        self.areas = Ospfv3.Processes.Process.Vrfs.Vrf.Areas()
                        self.areas.parent = self
                        self.bad_checksums = Ospfv3.Processes.Process.Vrfs.Vrf.BadChecksums()
                        self.bad_checksums.parent = self
                        self.border_routers = Ospfv3.Processes.Process.Vrfs.Vrf.BorderRouters()
                        self.border_routers.parent = self
                        self.connected_routes = Ospfv3.Processes.Process.Vrfs.Vrf.ConnectedRoutes()
                        self.connected_routes.parent = self
                        self.database_summary_table = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseSummaryTable()
                        self.database_summary_table.parent = self
                        self.database_table = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable()
                        self.database_table.parent = self
                        self.external_routes = Ospfv3.Processes.Process.Vrfs.Vrf.ExternalRoutes()
                        self.external_routes.parent = self
                        self.fast_reroutes = Ospfv3.Processes.Process.Vrfs.Vrf.FastReroutes()
                        self.fast_reroutes.parent = self
                        self.flood_list_process_table = Ospfv3.Processes.Process.Vrfs.Vrf.FloodListProcessTable()
                        self.flood_list_process_table.parent = self
                        self.interface_brief_process_table = Ospfv3.Processes.Process.Vrfs.Vrf.InterfaceBriefProcessTable()
                        self.interface_brief_process_table.parent = self
                        self.interface_process_table = Ospfv3.Processes.Process.Vrfs.Vrf.InterfaceProcessTable()
                        self.interface_process_table.parent = self
                        self.internal_routes = Ospfv3.Processes.Process.Vrfs.Vrf.InternalRoutes()
                        self.internal_routes.parent = self
                        self.neighbor_detail_process_table = Ospfv3.Processes.Process.Vrfs.Vrf.NeighborDetailProcessTable()
                        self.neighbor_detail_process_table.parent = self
                        self.neighbor_process_table = Ospfv3.Processes.Process.Vrfs.Vrf.NeighborProcessTable()
                        self.neighbor_process_table.parent = self
                        self.protocol_areas = Ospfv3.Processes.Process.Vrfs.Vrf.ProtocolAreas()
                        self.protocol_areas.parent = self
                        self.redistributions = Ospfv3.Processes.Process.Vrfs.Vrf.Redistributions()
                        self.redistributions.parent = self
                        self.request_list_process_table = Ospfv3.Processes.Process.Vrfs.Vrf.RequestListProcessTable()
                        self.request_list_process_table.parent = self
                        self.retransmission_list_process_table = Ospfv3.Processes.Process.Vrfs.Vrf.RetransmissionListProcessTable()
                        self.retransmission_list_process_table.parent = self
                        self.route_summary = Ospfv3.Processes.Process.Vrfs.Vrf.RouteSummary()
                        self.route_summary.parent = self
                        self.sham_link_table = Ospfv3.Processes.Process.Vrfs.Vrf.ShamLinkTable()
                        self.sham_link_table.parent = self
                        self.summary = Ospfv3.Processes.Process.Vrfs.Vrf.Summary()
                        self.summary.parent = self
                        self.summary_prefixes = Ospfv3.Processes.Process.Vrfs.Vrf.SummaryPrefixes()
                        self.summary_prefixes.parent = self
                        self.virtual_link = Ospfv3.Processes.Process.Vrfs.Vrf.VirtualLink()
                        self.virtual_link.parent = self
                        self.vrf_statistics = Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics()
                        self.vrf_statistics.parent = self


                    class SummaryPrefixes(object):
                        """
                        Summary prefix information table
                        
                        .. attribute:: summary_prefix
                        
                        	Summary prefix information
                        	**type**\: list of    :py:class:`SummaryPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.SummaryPrefixes.SummaryPrefix>`
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.summary_prefix = YList()
                            self.summary_prefix.parent = self
                            self.summary_prefix.name = 'summary_prefix'


                        class SummaryPrefix(object):
                            """
                            Summary prefix information
                            
                            .. attribute:: prefix
                            
                            	Summary prefix
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: prefix_length
                            
                            	Prefix length
                            	**type**\:  int
                            
                            	**range:** 0..128
                            
                            .. attribute:: prefix_metric
                            
                            	Prefix metric
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: prefix_metric_type
                            
                            	Prefix metric type
                            	**type**\:   :py:class:`Ospfv3DefaultMetricEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3DefaultMetricEnum>`
                            
                            .. attribute:: tag
                            
                            	Tag
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.prefix = None
                                self.prefix_length = None
                                self.prefix_metric = None
                                self.prefix_metric_type = None
                                self.tag = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:summary-prefix'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.prefix is not None:
                                    return True

                                if self.prefix_length is not None:
                                    return True

                                if self.prefix_metric is not None:
                                    return True

                                if self.prefix_metric_type is not None:
                                    return True

                                if self.tag is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.SummaryPrefixes.SummaryPrefix']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:summary-prefixes'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.summary_prefix is not None:
                                for child_ref in self.summary_prefix:
                                    if child_ref._has_data():
                                        return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                            return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.SummaryPrefixes']['meta_info']


                    class BorderRouters(object):
                        """
                        OSPFv3 border router information table
                        
                        .. attribute:: border_router
                        
                        	OSPFv3 border router information
                        	**type**\: list of    :py:class:`BorderRouter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.BorderRouters.BorderRouter>`
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.border_router = YList()
                            self.border_router.parent = self
                            self.border_router.name = 'border_router'


                        class BorderRouter(object):
                            """
                            OSPFv3 border router information
                            
                            .. attribute:: border_router_id  <key>
                            
                            	Router address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: border_router_path
                            
                            	List of border router paths
                            	**type**\: list of    :py:class:`BorderRouterPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.BorderRouters.BorderRouter.BorderRouterPath>`
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.border_router_id = None
                                self.border_router_path = YList()
                                self.border_router_path.parent = self
                                self.border_router_path.name = 'border_router_path'


                            class BorderRouterPath(object):
                                """
                                List of border router paths
                                
                                .. attribute:: border_router_area_id
                                
                                	Area string in decimal or dotted\-decimal format 
                                	**type**\:  str
                                
                                	**length:** 0..16
                                
                                .. attribute:: border_router_next_hop
                                
                                	Next hop address 
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: border_router_route_metric
                                
                                	Metric
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: border_router_type
                                
                                	Border router type 
                                	**type**\:   :py:class:`Ospfv3BorderRouteEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3BorderRouteEnum>`
                                
                                .. attribute:: interface_name
                                
                                	Next hop interface name
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: is_intra_area_router
                                
                                	If true, intra\-area router else inter\-area router
                                	**type**\:  bool
                                
                                .. attribute:: spf_version
                                
                                	SPF version
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.border_router_area_id = None
                                    self.border_router_next_hop = None
                                    self.border_router_route_metric = None
                                    self.border_router_type = None
                                    self.interface_name = None
                                    self.is_intra_area_router = None
                                    self.spf_version = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:border-router-path'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.border_router_area_id is not None:
                                        return True

                                    if self.border_router_next_hop is not None:
                                        return True

                                    if self.border_router_route_metric is not None:
                                        return True

                                    if self.border_router_type is not None:
                                        return True

                                    if self.interface_name is not None:
                                        return True

                                    if self.is_intra_area_router is not None:
                                        return True

                                    if self.spf_version is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                    return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.BorderRouters.BorderRouter.BorderRouterPath']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')
                                if self.border_router_id is None:
                                    raise YPYModelError('Key property border_router_id is None')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:border-router[Cisco-IOS-XR-ipv6-ospfv3-oper:border-router-id = ' + str(self.border_router_id) + ']'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.border_router_id is not None:
                                    return True

                                if self.border_router_path is not None:
                                    for child_ref in self.border_router_path:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.BorderRouters.BorderRouter']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:border-routers'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.border_router is not None:
                                for child_ref in self.border_router:
                                    if child_ref._has_data():
                                        return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                            return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.BorderRouters']['meta_info']


                    class ShamLinkTable(object):
                        """
                        Sham link information
                        
                        .. attribute:: is_sham_link_authentication_enabled
                        
                        	If true, sham link authentication is enabled 
                        	**type**\:  bool
                        
                        .. attribute:: is_sham_link_encryption_enabled
                        
                        	If true, sham link encryption is enabled 
                        	**type**\:  bool
                        
                        .. attribute:: is_sham_link_ip_security_active
                        
                        	If true, Sham link IP security is active 
                        	**type**\:  bool
                        
                        .. attribute:: is_sham_link_ip_security_required
                        
                        	If true, sham link IP security is required 
                        	**type**\:  bool
                        
                        .. attribute:: sham_link_area
                        
                        	Area id
                        	**type**\:  str
                        
                        .. attribute:: sham_link_authentication_transmit
                        
                        	Sham link authentication transmit 
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: sham_link_cost
                        
                        	Cost of the sham link
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: sham_link_dc_bitless_lsa
                        
                        	Number of LSA's with demand circuit bit not set
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: sham_link_dead_interval
                        
                        	Dead interval (s)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: sham_link_demand_circuit
                        
                        	If true, the link runs as demand circuit
                        	**type**\:  bool
                        
                        .. attribute:: sham_link_dest_address
                        
                        	Sham\-link dest
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: sham_link_encrypted_authentication_transmitted
                        
                        	Sham link encrypted authentication transmitted 
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: sham_link_encryption_spi
                        
                        	Sham link encryption spi
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: sham_link_encryption_transmitted
                        
                        	Sham link encryption transmitted 
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: sham_link_gr
                        
                        	If true, Gracefule restart in progress
                        	**type**\:  bool
                        
                        .. attribute:: sham_link_gr_enabled
                        
                        	If true,  enabled
                        	**type**\:  bool
                        
                        .. attribute:: sham_link_hello_interval
                        
                        	Hello interval (s)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: sham_link_ifindex
                        
                        	Sham\-link ifindex
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: sham_link_last_gr
                        
                        	Time in seconds since last GR
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: sham_link_neighbor
                        
                        	Neighbor information
                        	**type**\:   :py:class:`ShamLinkNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.ShamLinkTable.ShamLinkNeighbor>`
                        
                        .. attribute:: sham_link_neighbor_id
                        
                        	Neighbor on other end of this sham link
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: sham_link_next_hello
                        
                        	Time until next hello (s)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: sham_link_passive
                        
                        	If true, interface is passive
                        	**type**\:  bool
                        
                        .. attribute:: sham_link_retransmission_interval
                        
                        	Retransmission interval (s)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: sham_link_source_address
                        
                        	Sham\-link source
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: sham_link_state
                        
                        	OSPF interface state for the sham link
                        	**type**\:   :py:class:`Ospfv3InterfaceStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3InterfaceStateEnum>`
                        
                        .. attribute:: sham_link_transmission_delay
                        
                        	Transmission delay in seconds
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        	**units**\: second
                        
                        .. attribute:: sham_link_wait_interval
                        
                        	Wait interval (s)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: virtual_link_authentication_spi
                        
                        	Sham link authentication spi 
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.is_sham_link_authentication_enabled = None
                            self.is_sham_link_encryption_enabled = None
                            self.is_sham_link_ip_security_active = None
                            self.is_sham_link_ip_security_required = None
                            self.sham_link_area = None
                            self.sham_link_authentication_transmit = None
                            self.sham_link_cost = None
                            self.sham_link_dc_bitless_lsa = None
                            self.sham_link_dead_interval = None
                            self.sham_link_demand_circuit = None
                            self.sham_link_dest_address = None
                            self.sham_link_encrypted_authentication_transmitted = None
                            self.sham_link_encryption_spi = None
                            self.sham_link_encryption_transmitted = None
                            self.sham_link_gr = None
                            self.sham_link_gr_enabled = None
                            self.sham_link_hello_interval = None
                            self.sham_link_ifindex = None
                            self.sham_link_last_gr = None
                            self.sham_link_neighbor = Ospfv3.Processes.Process.Vrfs.Vrf.ShamLinkTable.ShamLinkNeighbor()
                            self.sham_link_neighbor.parent = self
                            self.sham_link_neighbor_id = None
                            self.sham_link_next_hello = None
                            self.sham_link_passive = None
                            self.sham_link_retransmission_interval = None
                            self.sham_link_source_address = None
                            self.sham_link_state = None
                            self.sham_link_transmission_delay = None
                            self.sham_link_wait_interval = None
                            self.virtual_link_authentication_spi = None


                        class ShamLinkNeighbor(object):
                            """
                            Neighbor information
                            
                            .. attribute:: sham_link_retransmission
                            
                            	Neighbor retransmission info
                            	**type**\:   :py:class:`ShamLinkRetransmission <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.ShamLinkTable.ShamLinkNeighbor.ShamLinkRetransmission>`
                            
                            .. attribute:: sham_link_state
                            
                            	Adjacency state
                            	**type**\:   :py:class:`Ospfv3NeighborStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3NeighborStateEnum>`
                            
                            .. attribute:: sham_link_suppress_hello
                            
                            	If true Hellos suppressed
                            	**type**\:  bool
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.sham_link_retransmission = Ospfv3.Processes.Process.Vrfs.Vrf.ShamLinkTable.ShamLinkNeighbor.ShamLinkRetransmission()
                                self.sham_link_retransmission.parent = self
                                self.sham_link_state = None
                                self.sham_link_suppress_hello = None


                            class ShamLinkRetransmission(object):
                                """
                                Neighbor retransmission info
                                
                                .. attribute:: area_first_flood
                                
                                	First flood item for area scope LSAs
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: area_first_flood_index
                                
                                	Index of the first flood item for area scope LSAs
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: area_flood_index
                                
                                	Area scope LSA's flood index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: area_next_flood
                                
                                	Next flood item for area scope LSAs
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: area_next_flood_index
                                
                                	Index of next flood item for Area scope LSAs
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: as_first_flood
                                
                                	First flood item for AS scope LSAs
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: as_first_flood_index
                                
                                	Index for first flood item for AS scope LSAs
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: as_flood_index
                                
                                	AS scope LSA's flood index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: as_next_flood
                                
                                	Next flood item for AS scope LSAs
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: as_next_flood_index
                                
                                	Index of next flood item for AS scope LSAs
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: database_descriptor_retransmissions
                                
                                	Number of database descriptor retransmissions during last exchange
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: last_retransmission_length
                                
                                	Number of LSAs sent in last retransmission
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: last_retransmission_time
                                
                                	Last retransmission scan time (ms)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: link_first_flood
                                
                                	Link first flood information 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: link_first_flood_index
                                
                                	Link first flood information index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: link_flood_index
                                
                                	Link flood index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: link_next_flood
                                
                                	Link next flood information 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: link_next_flood_index
                                
                                	Link next flood information index 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: lsa_retransmission_timer
                                
                                	Time until next LSA retransmission (ms)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: maximum_retransmission_length
                                
                                	Maximum number of LSAs sent in a retransmission
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: maximum_retransmission_time
                                
                                	Maximum retransmission scan time (ms)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: neighbor_retransmissions
                                
                                	Number of neighbor retransmissions 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: retransmissions
                                
                                	Number of retransmissions for this neighbor
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.area_first_flood = None
                                    self.area_first_flood_index = None
                                    self.area_flood_index = None
                                    self.area_next_flood = None
                                    self.area_next_flood_index = None
                                    self.as_first_flood = None
                                    self.as_first_flood_index = None
                                    self.as_flood_index = None
                                    self.as_next_flood = None
                                    self.as_next_flood_index = None
                                    self.database_descriptor_retransmissions = None
                                    self.last_retransmission_length = None
                                    self.last_retransmission_time = None
                                    self.link_first_flood = None
                                    self.link_first_flood_index = None
                                    self.link_flood_index = None
                                    self.link_next_flood = None
                                    self.link_next_flood_index = None
                                    self.lsa_retransmission_timer = None
                                    self.maximum_retransmission_length = None
                                    self.maximum_retransmission_time = None
                                    self.neighbor_retransmissions = None
                                    self.retransmissions = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:sham-link-retransmission'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.area_first_flood is not None:
                                        return True

                                    if self.area_first_flood_index is not None:
                                        return True

                                    if self.area_flood_index is not None:
                                        return True

                                    if self.area_next_flood is not None:
                                        return True

                                    if self.area_next_flood_index is not None:
                                        return True

                                    if self.as_first_flood is not None:
                                        return True

                                    if self.as_first_flood_index is not None:
                                        return True

                                    if self.as_flood_index is not None:
                                        return True

                                    if self.as_next_flood is not None:
                                        return True

                                    if self.as_next_flood_index is not None:
                                        return True

                                    if self.database_descriptor_retransmissions is not None:
                                        return True

                                    if self.last_retransmission_length is not None:
                                        return True

                                    if self.last_retransmission_time is not None:
                                        return True

                                    if self.link_first_flood is not None:
                                        return True

                                    if self.link_first_flood_index is not None:
                                        return True

                                    if self.link_flood_index is not None:
                                        return True

                                    if self.link_next_flood is not None:
                                        return True

                                    if self.link_next_flood_index is not None:
                                        return True

                                    if self.lsa_retransmission_timer is not None:
                                        return True

                                    if self.maximum_retransmission_length is not None:
                                        return True

                                    if self.maximum_retransmission_time is not None:
                                        return True

                                    if self.neighbor_retransmissions is not None:
                                        return True

                                    if self.retransmissions is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                    return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.ShamLinkTable.ShamLinkNeighbor.ShamLinkRetransmission']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:sham-link-neighbor'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.sham_link_retransmission is not None and self.sham_link_retransmission._has_data():
                                    return True

                                if self.sham_link_state is not None:
                                    return True

                                if self.sham_link_suppress_hello is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.ShamLinkTable.ShamLinkNeighbor']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:sham-link-table'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.is_sham_link_authentication_enabled is not None:
                                return True

                            if self.is_sham_link_encryption_enabled is not None:
                                return True

                            if self.is_sham_link_ip_security_active is not None:
                                return True

                            if self.is_sham_link_ip_security_required is not None:
                                return True

                            if self.sham_link_area is not None:
                                return True

                            if self.sham_link_authentication_transmit is not None:
                                return True

                            if self.sham_link_cost is not None:
                                return True

                            if self.sham_link_dc_bitless_lsa is not None:
                                return True

                            if self.sham_link_dead_interval is not None:
                                return True

                            if self.sham_link_demand_circuit is not None:
                                return True

                            if self.sham_link_dest_address is not None:
                                return True

                            if self.sham_link_encrypted_authentication_transmitted is not None:
                                return True

                            if self.sham_link_encryption_spi is not None:
                                return True

                            if self.sham_link_encryption_transmitted is not None:
                                return True

                            if self.sham_link_gr is not None:
                                return True

                            if self.sham_link_gr_enabled is not None:
                                return True

                            if self.sham_link_hello_interval is not None:
                                return True

                            if self.sham_link_ifindex is not None:
                                return True

                            if self.sham_link_last_gr is not None:
                                return True

                            if self.sham_link_neighbor is not None and self.sham_link_neighbor._has_data():
                                return True

                            if self.sham_link_neighbor_id is not None:
                                return True

                            if self.sham_link_next_hello is not None:
                                return True

                            if self.sham_link_passive is not None:
                                return True

                            if self.sham_link_retransmission_interval is not None:
                                return True

                            if self.sham_link_source_address is not None:
                                return True

                            if self.sham_link_state is not None:
                                return True

                            if self.sham_link_transmission_delay is not None:
                                return True

                            if self.sham_link_wait_interval is not None:
                                return True

                            if self.virtual_link_authentication_spi is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                            return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.ShamLinkTable']['meta_info']


                    class AreaInformations(object):
                        """
                        OSPFv3 area information table
                        
                        .. attribute:: area_information
                        
                        	OSPFv3 area information
                        	**type**\: list of    :py:class:`AreaInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.AreaInformations.AreaInformation>`
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.area_information = YList()
                            self.area_information.parent = self
                            self.area_information.name = 'area_information'


                        class AreaInformation(object):
                            """
                            OSPFv3 area information
                            
                            .. attribute:: area_id  <key>
                            
                            	Area ID
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: area_dc_bitless_ls_as
                            
                            	Number of LSA with demand circuit bit not set
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: area_interfaces
                            
                            	Number of interfaces in the area
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: area_lfa_interface_count
                            
                            	Number of LFA enabled interfaces
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: area_lfa_revision
                            
                            	Area LFA revision
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: area_opaque_lsa_checksum
                            
                            	Sum of opaque LSA checksums
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: area_opaque_lsas
                            
                            	Number of opaque LSAs in the area
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: area_per_prefix_lfa_interface_count
                            
                            	Number of Per Prefix LFA enabled interfaces
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: area_range
                            
                            	List of ranges to summarize
                            	**type**\: list of    :py:class:`AreaRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.AreaInformations.AreaInformation.AreaRange>`
                            
                            .. attribute:: do_not_age_ls_as
                            
                            	Number of do not age LSAs
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: flood_list_length
                            
                            	Number of LSAs which need to be flooded
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: indication_ls_as
                            
                            	Number of indication LSAs
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: is_area_nssa
                            
                            	If true, area is a NSSA
                            	**type**\:  bool
                            
                            .. attribute:: is_area_stubbed
                            
                            	If true, stub area
                            	**type**\:  bool
                            
                            .. attribute:: is_area_total_stubbed
                            
                            	If true, totally stubby area
                            	**type**\:  bool
                            
                            .. attribute:: is_backbone_area_active
                            
                            	If true, Backbone area is active
                            	**type**\:  bool
                            
                            .. attribute:: is_nssa_default
                            
                            	If true, generate NSSA default route
                            	**type**\:  bool
                            
                            .. attribute:: is_nssa_translated
                            
                            	If true, perform 7/5 translation
                            	**type**\:  bool
                            
                            .. attribute:: is_rrr_enabled
                            
                            	If true, RRR is enabled
                            	**type**\:  bool
                            
                            .. attribute:: nssa_no_redistribution
                            
                            	If true, No redistribution into this NSSA area
                            	**type**\:  bool
                            
                            .. attribute:: sp_fs
                            
                            	Number of SPF calculations run
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: stub_default_cost
                            
                            	Default cost for Stub or NSSA area
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.area_id = None
                                self.area_dc_bitless_ls_as = None
                                self.area_interfaces = None
                                self.area_lfa_interface_count = None
                                self.area_lfa_revision = None
                                self.area_opaque_lsa_checksum = None
                                self.area_opaque_lsas = None
                                self.area_per_prefix_lfa_interface_count = None
                                self.area_range = YList()
                                self.area_range.parent = self
                                self.area_range.name = 'area_range'
                                self.do_not_age_ls_as = None
                                self.flood_list_length = None
                                self.indication_ls_as = None
                                self.is_area_nssa = None
                                self.is_area_stubbed = None
                                self.is_area_total_stubbed = None
                                self.is_backbone_area_active = None
                                self.is_nssa_default = None
                                self.is_nssa_translated = None
                                self.is_rrr_enabled = None
                                self.nssa_no_redistribution = None
                                self.sp_fs = None
                                self.stub_default_cost = None


                            class AreaRange(object):
                                """
                                List of ranges to summarize
                                
                                .. attribute:: is_cost_configured
                                
                                	If true, cost is configured 
                                	**type**\:  bool
                                
                                .. attribute:: net_cost
                                
                                	Net cost 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: range_prefix
                                
                                	IP prefix for summarization
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: range_prefix_length
                                
                                	IP prefix length for summarization
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: status
                                
                                	Area range status 
                                	**type**\:   :py:class:`Ospfv3AreaRangeStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3AreaRangeStatusEnum>`
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.is_cost_configured = None
                                    self.net_cost = None
                                    self.range_prefix = None
                                    self.range_prefix_length = None
                                    self.status = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:area-range'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.is_cost_configured is not None:
                                        return True

                                    if self.net_cost is not None:
                                        return True

                                    if self.range_prefix is not None:
                                        return True

                                    if self.range_prefix_length is not None:
                                        return True

                                    if self.status is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                    return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.AreaInformations.AreaInformation.AreaRange']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')
                                if self.area_id is None:
                                    raise YPYModelError('Key property area_id is None')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:area-information[Cisco-IOS-XR-ipv6-ospfv3-oper:area-id = ' + str(self.area_id) + ']'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.area_id is not None:
                                    return True

                                if self.area_dc_bitless_ls_as is not None:
                                    return True

                                if self.area_interfaces is not None:
                                    return True

                                if self.area_lfa_interface_count is not None:
                                    return True

                                if self.area_lfa_revision is not None:
                                    return True

                                if self.area_opaque_lsa_checksum is not None:
                                    return True

                                if self.area_opaque_lsas is not None:
                                    return True

                                if self.area_per_prefix_lfa_interface_count is not None:
                                    return True

                                if self.area_range is not None:
                                    for child_ref in self.area_range:
                                        if child_ref._has_data():
                                            return True

                                if self.do_not_age_ls_as is not None:
                                    return True

                                if self.flood_list_length is not None:
                                    return True

                                if self.indication_ls_as is not None:
                                    return True

                                if self.is_area_nssa is not None:
                                    return True

                                if self.is_area_stubbed is not None:
                                    return True

                                if self.is_area_total_stubbed is not None:
                                    return True

                                if self.is_backbone_area_active is not None:
                                    return True

                                if self.is_nssa_default is not None:
                                    return True

                                if self.is_nssa_translated is not None:
                                    return True

                                if self.is_rrr_enabled is not None:
                                    return True

                                if self.nssa_no_redistribution is not None:
                                    return True

                                if self.sp_fs is not None:
                                    return True

                                if self.stub_default_cost is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.AreaInformations.AreaInformation']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:area-informations'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.area_information is not None:
                                for child_ref in self.area_information:
                                    if child_ref._has_data():
                                        return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                            return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.AreaInformations']['meta_info']


                    class DatabaseTable(object):
                        """
                        OSPF Link State Database
                        
                        .. attribute:: lsa_internal_table
                        
                        	Database LSA information
                        	**type**\:   :py:class:`LsaInternalTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable>`
                        
                        .. attribute:: lsa_table
                        
                        	Database LSA information
                        	**type**\:   :py:class:`LsaTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable>`
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.lsa_internal_table = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable()
                            self.lsa_internal_table.parent = self
                            self.lsa_table = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable()
                            self.lsa_table.parent = self


                        class LsaTable(object):
                            """
                            Database LSA information
                            
                            .. attribute:: lsa
                            
                            	Database LSA information
                            	**type**\: list of    :py:class:`Lsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa>`
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.lsa = YList()
                                self.lsa.parent = self
                                self.lsa.name = 'lsa'


                            class Lsa(object):
                                """
                                Database LSA information
                                
                                .. attribute:: advertising_router
                                
                                	Advertising Router ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: area_id
                                
                                	Area ID
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: interface_name
                                
                                	InterfaceName
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: ls_id
                                
                                	Link state ID
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: ls_type
                                
                                	LSA type
                                	**type**\:   :py:class:`Ospfv3LsaEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3LsaEnum>`
                                
                                .. attribute:: lsa_info
                                
                                	Summary of all LSAs or LSA specific information 
                                	**type**\:   :py:class:`LsaInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo>`
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.advertising_router = None
                                    self.area_id = None
                                    self.interface_name = None
                                    self.ls_id = None
                                    self.ls_type = None
                                    self.lsa_info = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo()
                                    self.lsa_info.parent = self


                                class LsaInfo(object):
                                    """
                                    Summary of all LSAs or LSA specific information 
                                    
                                    .. attribute:: external_lsa_type
                                    
                                    	External LSA
                                    	**type**\:   :py:class:`ExternalLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType>`
                                    
                                    .. attribute:: grace_lsa
                                    
                                    	Grace LSA
                                    	**type**\:   :py:class:`GraceLsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa>`
                                    
                                    .. attribute:: inter_area_prefix_lsa_type
                                    
                                    	Inter Area Prefix LSA
                                    	**type**\:   :py:class:`InterAreaPrefixLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType>`
                                    
                                    .. attribute:: inter_area_router_lsa_type
                                    
                                    	Inter Area Router LSA
                                    	**type**\:   :py:class:`InterAreaRouterLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType>`
                                    
                                    .. attribute:: intra_area_prefix_lsa_type
                                    
                                    	Intra Area Prefix LSA
                                    	**type**\:   :py:class:`IntraAreaPrefixLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType>`
                                    
                                    .. attribute:: link_lsa_type
                                    
                                    	Link LSA
                                    	**type**\:   :py:class:`LinkLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType>`
                                    
                                    .. attribute:: lsa_info_type
                                    
                                    	LSAInfoType
                                    	**type**\:   :py:class:`Ospfv3LsaInfoTypesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3LsaInfoTypesEnum>`
                                    
                                    .. attribute:: lsa_summary_info
                                    
                                    	Summary information of LSAs
                                    	**type**\:   :py:class:`LsaSummaryInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo>`
                                    
                                    .. attribute:: network_lsa_type
                                    
                                    	Network LSA
                                    	**type**\:   :py:class:`NetworkLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType>`
                                    
                                    .. attribute:: nssalsa_type
                                    
                                    	NSSA External LSA
                                    	**type**\:   :py:class:`NssalsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType>`
                                    
                                    .. attribute:: router_lsa_type
                                    
                                    	Router LSA
                                    	**type**\:   :py:class:`RouterLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType>`
                                    
                                    .. attribute:: unknown_area_lsa_type
                                    
                                    	Unknown\-Area scope LSA
                                    	**type**\:   :py:class:`UnknownAreaLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType>`
                                    
                                    .. attribute:: unknown_aslsa_type
                                    
                                    	Unknown\-AS scope LSA
                                    	**type**\:   :py:class:`UnknownAslsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType>`
                                    
                                    .. attribute:: unknown_link_lsa_type
                                    
                                    	Unknown Link Scope LSA
                                    	**type**\:   :py:class:`UnknownLinkLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType>`
                                    
                                    .. attribute:: unknown_lsa_type
                                    
                                    	Unknown LSA
                                    	**type**\:   :py:class:`UnknownLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType>`
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.external_lsa_type = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType()
                                        self.external_lsa_type.parent = self
                                        self.grace_lsa = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa()
                                        self.grace_lsa.parent = self
                                        self.inter_area_prefix_lsa_type = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType()
                                        self.inter_area_prefix_lsa_type.parent = self
                                        self.inter_area_router_lsa_type = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType()
                                        self.inter_area_router_lsa_type.parent = self
                                        self.intra_area_prefix_lsa_type = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType()
                                        self.intra_area_prefix_lsa_type.parent = self
                                        self.link_lsa_type = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType()
                                        self.link_lsa_type.parent = self
                                        self.lsa_info_type = None
                                        self.lsa_summary_info = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo()
                                        self.lsa_summary_info.parent = self
                                        self.network_lsa_type = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType()
                                        self.network_lsa_type.parent = self
                                        self.nssalsa_type = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType()
                                        self.nssalsa_type.parent = self
                                        self.router_lsa_type = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType()
                                        self.router_lsa_type.parent = self
                                        self.unknown_area_lsa_type = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType()
                                        self.unknown_area_lsa_type.parent = self
                                        self.unknown_aslsa_type = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType()
                                        self.unknown_aslsa_type.parent = self
                                        self.unknown_link_lsa_type = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType()
                                        self.unknown_link_lsa_type.parent = self
                                        self.unknown_lsa_type = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType()
                                        self.unknown_lsa_type.parent = self


                                    class LsaSummaryInfo(object):
                                        """
                                        Summary information of LSAs
                                        
                                        .. attribute:: interface_name
                                        
                                        	LSA interface name 
                                        	**type**\:  str
                                        
                                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                        
                                        .. attribute:: is_sham_link
                                        
                                        	If true, it is a sham link 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_virtual_link
                                        
                                        	If true, it is a virtual link 
                                        	**type**\:  bool
                                        
                                        .. attribute:: links
                                        
                                        	Number of links
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_detail
                                        
                                        	Detailed LSA information
                                        	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo.LsaDetail>`
                                        
                                        .. attribute:: lsa_header
                                        
                                        	Header information 
                                        	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo.LsaHeader>`
                                        
                                        .. attribute:: lsa_router_id
                                        
                                        	LSA router ID 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: prefix
                                        
                                        	OSPFv3 address Prefix 
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: prefix_length
                                        
                                        	Prefix length 
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: reference_lsa_id
                                        
                                        	Reference LSA ID 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: reference_type
                                        
                                        	Reference type 
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: router_la_bits
                                        
                                        	Router LA bits 
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: sham_link_id
                                        
                                        	Sham link ID 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: virtual_link_id
                                        
                                        	Virtual link ID 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface_name = None
                                            self.is_sham_link = None
                                            self.is_virtual_link = None
                                            self.links = None
                                            self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo.LsaDetail()
                                            self.lsa_detail.parent = self
                                            self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo.LsaHeader()
                                            self.lsa_header.parent = self
                                            self.lsa_router_id = None
                                            self.prefix = None
                                            self.prefix_length = None
                                            self.reference_lsa_id = None
                                            self.reference_type = None
                                            self.router_la_bits = None
                                            self.sham_link_id = None
                                            self.virtual_link_id = None


                                        class LsaHeader(object):
                                            """
                                            Header information 
                                            
                                            .. attribute:: advertising_router
                                            
                                            	Router ID of Advertising Router
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: checksum
                                            
                                            	Checksum value
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: is_do_not_age_lsa
                                            
                                            	If true, Do Not Age this LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_graceful_restart_active
                                            
                                            	If true, if grace restart is active 
                                            	**type**\:  bool
                                            
                                            .. attribute:: ls_id
                                            
                                            	LS ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: lsa_age
                                            
                                            	LSA's Age (s)
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_area_id
                                            
                                            	Area ID in decimal or dotted\-decimal format
                                            	**type**\:  str
                                            
                                            	**length:** 0..16
                                            
                                            .. attribute:: lsa_type
                                            
                                            	LSA type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: sequence_number
                                            
                                            	Current Sequence number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.advertising_router = None
                                                self.checksum = None
                                                self.is_do_not_age_lsa = None
                                                self.is_graceful_restart_active = None
                                                self.ls_id = None
                                                self.lsa_age = None
                                                self.lsa_area_id = None
                                                self.lsa_type = None
                                                self.sequence_number = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-header'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.advertising_router is not None:
                                                    return True

                                                if self.checksum is not None:
                                                    return True

                                                if self.is_do_not_age_lsa is not None:
                                                    return True

                                                if self.is_graceful_restart_active is not None:
                                                    return True

                                                if self.ls_id is not None:
                                                    return True

                                                if self.lsa_age is not None:
                                                    return True

                                                if self.lsa_area_id is not None:
                                                    return True

                                                if self.lsa_type is not None:
                                                    return True

                                                if self.sequence_number is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo.LsaHeader']['meta_info']


                                        class LsaDetail(object):
                                            """
                                            Detailed LSA information
                                            
                                            .. attribute:: free_time
                                            
                                            	The amount of time since the last check was made to free this LSA (s)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_acknowledged
                                            
                                            	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_advertising_router_reachable
                                            
                                            	If true, Advertising Router is reachable
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_deleted
                                            
                                            	If true, flag is set to delete this LSA 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_flood_pending
                                            
                                            	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_maximum_aged
                                            
                                            	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_neighbor_exchange
                                            
                                            	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_no_delete
                                            
                                            	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_nsr_ack_pending
                                            
                                            	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_partial_spf
                                            
                                            	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_routing_bit
                                            
                                            	If true, Routing Bit set on the LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_routing_table
                                            
                                            	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                            	**type**\:  bool
                                            
                                            .. attribute:: lsa_flood_required_post_fail_over
                                            
                                            	LSA flood required after FO
                                            	**type**\:  bool
                                            
                                            .. attribute:: lsa_length
                                            
                                            	Length of the LSA
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_sync_state
                                            
                                            	State of LSA sync with active
                                            	**type**\:   :py:class:`OspfLsaSyncStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncStateEnum>`
                                            
                                            .. attribute:: minute_table_index
                                            
                                            	Minute table index
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: nsr_flood_required
                                            
                                            	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                            	**type**\:  bool
                                            
                                            .. attribute:: rate_limit
                                            
                                            	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                            	**type**\:  bool
                                            
                                            .. attribute:: second_table_index
                                            
                                            	Second table index
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.free_time = None
                                                self.is_acknowledged = None
                                                self.is_advertising_router_reachable = None
                                                self.is_deleted = None
                                                self.is_flood_pending = None
                                                self.is_maximum_aged = None
                                                self.is_neighbor_exchange = None
                                                self.is_no_delete = None
                                                self.is_nsr_ack_pending = None
                                                self.is_partial_spf = None
                                                self.is_routing_bit = None
                                                self.is_routing_table = None
                                                self.lsa_flood_required_post_fail_over = None
                                                self.lsa_length = None
                                                self.lsa_sync_state = None
                                                self.minute_table_index = None
                                                self.nsr_flood_required = None
                                                self.rate_limit = None
                                                self.second_table_index = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-detail'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.free_time is not None:
                                                    return True

                                                if self.is_acknowledged is not None:
                                                    return True

                                                if self.is_advertising_router_reachable is not None:
                                                    return True

                                                if self.is_deleted is not None:
                                                    return True

                                                if self.is_flood_pending is not None:
                                                    return True

                                                if self.is_maximum_aged is not None:
                                                    return True

                                                if self.is_neighbor_exchange is not None:
                                                    return True

                                                if self.is_no_delete is not None:
                                                    return True

                                                if self.is_nsr_ack_pending is not None:
                                                    return True

                                                if self.is_partial_spf is not None:
                                                    return True

                                                if self.is_routing_bit is not None:
                                                    return True

                                                if self.is_routing_table is not None:
                                                    return True

                                                if self.lsa_flood_required_post_fail_over is not None:
                                                    return True

                                                if self.lsa_length is not None:
                                                    return True

                                                if self.lsa_sync_state is not None:
                                                    return True

                                                if self.minute_table_index is not None:
                                                    return True

                                                if self.nsr_flood_required is not None:
                                                    return True

                                                if self.rate_limit is not None:
                                                    return True

                                                if self.second_table_index is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo.LsaDetail']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-summary-info'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface_name is not None:
                                                return True

                                            if self.is_sham_link is not None:
                                                return True

                                            if self.is_virtual_link is not None:
                                                return True

                                            if self.links is not None:
                                                return True

                                            if self.lsa_detail is not None and self.lsa_detail._has_data():
                                                return True

                                            if self.lsa_header is not None and self.lsa_header._has_data():
                                                return True

                                            if self.lsa_router_id is not None:
                                                return True

                                            if self.prefix is not None:
                                                return True

                                            if self.prefix_length is not None:
                                                return True

                                            if self.reference_lsa_id is not None:
                                                return True

                                            if self.reference_type is not None:
                                                return True

                                            if self.router_la_bits is not None:
                                                return True

                                            if self.sham_link_id is not None:
                                                return True

                                            if self.virtual_link_id is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo']['meta_info']


                                    class RouterLsaType(object):
                                        """
                                        Router LSA
                                        
                                        .. attribute:: link
                                        
                                        	List of links in this LSA
                                        	**type**\: list of    :py:class:`Link <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.Link>`
                                        
                                        .. attribute:: lsa_detail
                                        
                                        	Detailed LSA information
                                        	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.LsaDetail>`
                                        
                                        .. attribute:: lsa_header
                                        
                                        	Header information 
                                        	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.LsaHeader>`
                                        
                                        .. attribute:: router_la_bits
                                        
                                        	Router LA bits 
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: rpf_path
                                        
                                        	Router LSA Reverse\-Path Forwarding information 
                                        	**type**\:   :py:class:`RpfPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.RpfPath>`
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.link = YList()
                                            self.link.parent = self
                                            self.link.name = 'link'
                                            self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.LsaDetail()
                                            self.lsa_detail.parent = self
                                            self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.LsaHeader()
                                            self.lsa_header.parent = self
                                            self.router_la_bits = None
                                            self.rpf_path = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.RpfPath()
                                            self.rpf_path.parent = self


                                        class LsaHeader(object):
                                            """
                                            Header information 
                                            
                                            .. attribute:: advertising_router
                                            
                                            	Router ID of Advertising Router
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: checksum
                                            
                                            	Checksum value
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: is_do_not_age_lsa
                                            
                                            	If true, Do Not Age this LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_graceful_restart_active
                                            
                                            	If true, if grace restart is active 
                                            	**type**\:  bool
                                            
                                            .. attribute:: ls_id
                                            
                                            	LS ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: lsa_age
                                            
                                            	LSA's Age (s)
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_area_id
                                            
                                            	Area ID in decimal or dotted\-decimal format
                                            	**type**\:  str
                                            
                                            	**length:** 0..16
                                            
                                            .. attribute:: lsa_type
                                            
                                            	LSA type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: sequence_number
                                            
                                            	Current Sequence number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.advertising_router = None
                                                self.checksum = None
                                                self.is_do_not_age_lsa = None
                                                self.is_graceful_restart_active = None
                                                self.ls_id = None
                                                self.lsa_age = None
                                                self.lsa_area_id = None
                                                self.lsa_type = None
                                                self.sequence_number = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-header'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.advertising_router is not None:
                                                    return True

                                                if self.checksum is not None:
                                                    return True

                                                if self.is_do_not_age_lsa is not None:
                                                    return True

                                                if self.is_graceful_restart_active is not None:
                                                    return True

                                                if self.ls_id is not None:
                                                    return True

                                                if self.lsa_age is not None:
                                                    return True

                                                if self.lsa_area_id is not None:
                                                    return True

                                                if self.lsa_type is not None:
                                                    return True

                                                if self.sequence_number is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.LsaHeader']['meta_info']


                                        class LsaDetail(object):
                                            """
                                            Detailed LSA information
                                            
                                            .. attribute:: free_time
                                            
                                            	The amount of time since the last check was made to free this LSA (s)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_acknowledged
                                            
                                            	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_advertising_router_reachable
                                            
                                            	If true, Advertising Router is reachable
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_deleted
                                            
                                            	If true, flag is set to delete this LSA 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_flood_pending
                                            
                                            	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_maximum_aged
                                            
                                            	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_neighbor_exchange
                                            
                                            	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_no_delete
                                            
                                            	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_nsr_ack_pending
                                            
                                            	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_partial_spf
                                            
                                            	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_routing_bit
                                            
                                            	If true, Routing Bit set on the LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_routing_table
                                            
                                            	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                            	**type**\:  bool
                                            
                                            .. attribute:: lsa_flood_required_post_fail_over
                                            
                                            	LSA flood required after FO
                                            	**type**\:  bool
                                            
                                            .. attribute:: lsa_length
                                            
                                            	Length of the LSA
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_sync_state
                                            
                                            	State of LSA sync with active
                                            	**type**\:   :py:class:`OspfLsaSyncStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncStateEnum>`
                                            
                                            .. attribute:: minute_table_index
                                            
                                            	Minute table index
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: nsr_flood_required
                                            
                                            	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                            	**type**\:  bool
                                            
                                            .. attribute:: rate_limit
                                            
                                            	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                            	**type**\:  bool
                                            
                                            .. attribute:: second_table_index
                                            
                                            	Second table index
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.free_time = None
                                                self.is_acknowledged = None
                                                self.is_advertising_router_reachable = None
                                                self.is_deleted = None
                                                self.is_flood_pending = None
                                                self.is_maximum_aged = None
                                                self.is_neighbor_exchange = None
                                                self.is_no_delete = None
                                                self.is_nsr_ack_pending = None
                                                self.is_partial_spf = None
                                                self.is_routing_bit = None
                                                self.is_routing_table = None
                                                self.lsa_flood_required_post_fail_over = None
                                                self.lsa_length = None
                                                self.lsa_sync_state = None
                                                self.minute_table_index = None
                                                self.nsr_flood_required = None
                                                self.rate_limit = None
                                                self.second_table_index = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-detail'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.free_time is not None:
                                                    return True

                                                if self.is_acknowledged is not None:
                                                    return True

                                                if self.is_advertising_router_reachable is not None:
                                                    return True

                                                if self.is_deleted is not None:
                                                    return True

                                                if self.is_flood_pending is not None:
                                                    return True

                                                if self.is_maximum_aged is not None:
                                                    return True

                                                if self.is_neighbor_exchange is not None:
                                                    return True

                                                if self.is_no_delete is not None:
                                                    return True

                                                if self.is_nsr_ack_pending is not None:
                                                    return True

                                                if self.is_partial_spf is not None:
                                                    return True

                                                if self.is_routing_bit is not None:
                                                    return True

                                                if self.is_routing_table is not None:
                                                    return True

                                                if self.lsa_flood_required_post_fail_over is not None:
                                                    return True

                                                if self.lsa_length is not None:
                                                    return True

                                                if self.lsa_sync_state is not None:
                                                    return True

                                                if self.minute_table_index is not None:
                                                    return True

                                                if self.nsr_flood_required is not None:
                                                    return True

                                                if self.rate_limit is not None:
                                                    return True

                                                if self.second_table_index is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.LsaDetail']['meta_info']


                                        class RpfPath(object):
                                            """
                                            Router LSA Reverse\-Path Forwarding information 
                                            
                                            .. attribute:: interface_name
                                            
                                            	RPF multicast IDB 
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                            
                                            .. attribute:: rpf_multicast_next_hop
                                            
                                            	RPF multicast next hop 
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface_name = None
                                                self.rpf_multicast_next_hop = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:rpf-path'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface_name is not None:
                                                    return True

                                                if self.rpf_multicast_next_hop is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.RpfPath']['meta_info']


                                        class Link(object):
                                            """
                                            List of links in this LSA
                                            
                                            .. attribute:: link_interface_id
                                            
                                            	LSA link interface ID 
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: link_metric
                                            
                                            	LSA link metric 
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: link_neighbor_interface_id
                                            
                                            	LSA link neighbor interface ID 
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: link_neighbor_router_id
                                            
                                            	LSA link neigbhor router id 
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: link_type
                                            
                                            	Type of link
                                            	**type**\:   :py:class:`Ospfv3LinkEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3LinkEnum>`
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.link_interface_id = None
                                                self.link_metric = None
                                                self.link_neighbor_interface_id = None
                                                self.link_neighbor_router_id = None
                                                self.link_type = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:link'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.link_interface_id is not None:
                                                    return True

                                                if self.link_metric is not None:
                                                    return True

                                                if self.link_neighbor_interface_id is not None:
                                                    return True

                                                if self.link_neighbor_router_id is not None:
                                                    return True

                                                if self.link_type is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.Link']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:router-lsa-type'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.link is not None:
                                                for child_ref in self.link:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.lsa_detail is not None and self.lsa_detail._has_data():
                                                return True

                                            if self.lsa_header is not None and self.lsa_header._has_data():
                                                return True

                                            if self.router_la_bits is not None:
                                                return True

                                            if self.rpf_path is not None and self.rpf_path._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType']['meta_info']


                                    class NetworkLsaType(object):
                                        """
                                        Network LSA
                                        
                                        .. attribute:: lsa_detail
                                        
                                        	Detailed LSA information
                                        	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType.LsaDetail>`
                                        
                                        .. attribute:: lsa_header
                                        
                                        	Header information 
                                        	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType.LsaHeader>`
                                        
                                        .. attribute:: neighbor_router
                                        
                                        	Neighbor router list
                                        	**type**\:  list of str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType.LsaDetail()
                                            self.lsa_detail.parent = self
                                            self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType.LsaHeader()
                                            self.lsa_header.parent = self
                                            self.neighbor_router = YLeafList()
                                            self.neighbor_router.parent = self
                                            self.neighbor_router.name = 'neighbor_router'


                                        class LsaHeader(object):
                                            """
                                            Header information 
                                            
                                            .. attribute:: advertising_router
                                            
                                            	Router ID of Advertising Router
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: checksum
                                            
                                            	Checksum value
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: is_do_not_age_lsa
                                            
                                            	If true, Do Not Age this LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_graceful_restart_active
                                            
                                            	If true, if grace restart is active 
                                            	**type**\:  bool
                                            
                                            .. attribute:: ls_id
                                            
                                            	LS ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: lsa_age
                                            
                                            	LSA's Age (s)
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_area_id
                                            
                                            	Area ID in decimal or dotted\-decimal format
                                            	**type**\:  str
                                            
                                            	**length:** 0..16
                                            
                                            .. attribute:: lsa_type
                                            
                                            	LSA type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: sequence_number
                                            
                                            	Current Sequence number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.advertising_router = None
                                                self.checksum = None
                                                self.is_do_not_age_lsa = None
                                                self.is_graceful_restart_active = None
                                                self.ls_id = None
                                                self.lsa_age = None
                                                self.lsa_area_id = None
                                                self.lsa_type = None
                                                self.sequence_number = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-header'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.advertising_router is not None:
                                                    return True

                                                if self.checksum is not None:
                                                    return True

                                                if self.is_do_not_age_lsa is not None:
                                                    return True

                                                if self.is_graceful_restart_active is not None:
                                                    return True

                                                if self.ls_id is not None:
                                                    return True

                                                if self.lsa_age is not None:
                                                    return True

                                                if self.lsa_area_id is not None:
                                                    return True

                                                if self.lsa_type is not None:
                                                    return True

                                                if self.sequence_number is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType.LsaHeader']['meta_info']


                                        class LsaDetail(object):
                                            """
                                            Detailed LSA information
                                            
                                            .. attribute:: free_time
                                            
                                            	The amount of time since the last check was made to free this LSA (s)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_acknowledged
                                            
                                            	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_advertising_router_reachable
                                            
                                            	If true, Advertising Router is reachable
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_deleted
                                            
                                            	If true, flag is set to delete this LSA 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_flood_pending
                                            
                                            	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_maximum_aged
                                            
                                            	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_neighbor_exchange
                                            
                                            	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_no_delete
                                            
                                            	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_nsr_ack_pending
                                            
                                            	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_partial_spf
                                            
                                            	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_routing_bit
                                            
                                            	If true, Routing Bit set on the LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_routing_table
                                            
                                            	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                            	**type**\:  bool
                                            
                                            .. attribute:: lsa_flood_required_post_fail_over
                                            
                                            	LSA flood required after FO
                                            	**type**\:  bool
                                            
                                            .. attribute:: lsa_length
                                            
                                            	Length of the LSA
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_sync_state
                                            
                                            	State of LSA sync with active
                                            	**type**\:   :py:class:`OspfLsaSyncStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncStateEnum>`
                                            
                                            .. attribute:: minute_table_index
                                            
                                            	Minute table index
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: nsr_flood_required
                                            
                                            	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                            	**type**\:  bool
                                            
                                            .. attribute:: rate_limit
                                            
                                            	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                            	**type**\:  bool
                                            
                                            .. attribute:: second_table_index
                                            
                                            	Second table index
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.free_time = None
                                                self.is_acknowledged = None
                                                self.is_advertising_router_reachable = None
                                                self.is_deleted = None
                                                self.is_flood_pending = None
                                                self.is_maximum_aged = None
                                                self.is_neighbor_exchange = None
                                                self.is_no_delete = None
                                                self.is_nsr_ack_pending = None
                                                self.is_partial_spf = None
                                                self.is_routing_bit = None
                                                self.is_routing_table = None
                                                self.lsa_flood_required_post_fail_over = None
                                                self.lsa_length = None
                                                self.lsa_sync_state = None
                                                self.minute_table_index = None
                                                self.nsr_flood_required = None
                                                self.rate_limit = None
                                                self.second_table_index = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-detail'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.free_time is not None:
                                                    return True

                                                if self.is_acknowledged is not None:
                                                    return True

                                                if self.is_advertising_router_reachable is not None:
                                                    return True

                                                if self.is_deleted is not None:
                                                    return True

                                                if self.is_flood_pending is not None:
                                                    return True

                                                if self.is_maximum_aged is not None:
                                                    return True

                                                if self.is_neighbor_exchange is not None:
                                                    return True

                                                if self.is_no_delete is not None:
                                                    return True

                                                if self.is_nsr_ack_pending is not None:
                                                    return True

                                                if self.is_partial_spf is not None:
                                                    return True

                                                if self.is_routing_bit is not None:
                                                    return True

                                                if self.is_routing_table is not None:
                                                    return True

                                                if self.lsa_flood_required_post_fail_over is not None:
                                                    return True

                                                if self.lsa_length is not None:
                                                    return True

                                                if self.lsa_sync_state is not None:
                                                    return True

                                                if self.minute_table_index is not None:
                                                    return True

                                                if self.nsr_flood_required is not None:
                                                    return True

                                                if self.rate_limit is not None:
                                                    return True

                                                if self.second_table_index is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType.LsaDetail']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:network-lsa-type'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.lsa_detail is not None and self.lsa_detail._has_data():
                                                return True

                                            if self.lsa_header is not None and self.lsa_header._has_data():
                                                return True

                                            if self.neighbor_router is not None:
                                                for child in self.neighbor_router:
                                                    if child is not None:
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType']['meta_info']


                                    class InterAreaPrefixLsaType(object):
                                        """
                                        Inter Area Prefix LSA
                                        
                                        .. attribute:: lsa_detail
                                        
                                        	Detailed LSA Information
                                        	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaDetail>`
                                        
                                        .. attribute:: lsa_header
                                        
                                        	Header information 
                                        	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaHeader>`
                                        
                                        .. attribute:: prefix
                                        
                                        	LSA address prefix 
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: prefix_length
                                        
                                        	Prefix length 
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: priority
                                        
                                        	Prefix priority
                                        	**type**\:   :py:class:`PrefixPriorityEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.PrefixPriorityEnum>`
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaDetail()
                                            self.lsa_detail.parent = self
                                            self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaHeader()
                                            self.lsa_header.parent = self
                                            self.prefix = None
                                            self.prefix_length = None
                                            self.priority = None


                                        class LsaHeader(object):
                                            """
                                            Header information 
                                            
                                            .. attribute:: advertising_router
                                            
                                            	Router ID of Advertising Router
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: checksum
                                            
                                            	Checksum value
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: is_do_not_age_lsa
                                            
                                            	If true, Do Not Age this LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_graceful_restart_active
                                            
                                            	If true, if grace restart is active 
                                            	**type**\:  bool
                                            
                                            .. attribute:: ls_id
                                            
                                            	LS ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: lsa_age
                                            
                                            	LSA's Age (s)
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_area_id
                                            
                                            	Area ID in decimal or dotted\-decimal format
                                            	**type**\:  str
                                            
                                            	**length:** 0..16
                                            
                                            .. attribute:: lsa_type
                                            
                                            	LSA type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: sequence_number
                                            
                                            	Current Sequence number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.advertising_router = None
                                                self.checksum = None
                                                self.is_do_not_age_lsa = None
                                                self.is_graceful_restart_active = None
                                                self.ls_id = None
                                                self.lsa_age = None
                                                self.lsa_area_id = None
                                                self.lsa_type = None
                                                self.sequence_number = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-header'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.advertising_router is not None:
                                                    return True

                                                if self.checksum is not None:
                                                    return True

                                                if self.is_do_not_age_lsa is not None:
                                                    return True

                                                if self.is_graceful_restart_active is not None:
                                                    return True

                                                if self.ls_id is not None:
                                                    return True

                                                if self.lsa_age is not None:
                                                    return True

                                                if self.lsa_area_id is not None:
                                                    return True

                                                if self.lsa_type is not None:
                                                    return True

                                                if self.sequence_number is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaHeader']['meta_info']


                                        class LsaDetail(object):
                                            """
                                            Detailed LSA Information
                                            
                                            .. attribute:: free_time
                                            
                                            	The amount of time since the last check was made to free this LSA (s)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_acknowledged
                                            
                                            	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_advertising_router_reachable
                                            
                                            	If true, Advertising Router is reachable
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_deleted
                                            
                                            	If true, flag is set to delete this LSA 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_flood_pending
                                            
                                            	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_maximum_aged
                                            
                                            	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_neighbor_exchange
                                            
                                            	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_no_delete
                                            
                                            	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_nsr_ack_pending
                                            
                                            	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_partial_spf
                                            
                                            	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_routing_bit
                                            
                                            	If true, Routing Bit set on the LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_routing_table
                                            
                                            	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                            	**type**\:  bool
                                            
                                            .. attribute:: lsa_flood_required_post_fail_over
                                            
                                            	LSA flood required after FO
                                            	**type**\:  bool
                                            
                                            .. attribute:: lsa_length
                                            
                                            	Length of the LSA
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_sync_state
                                            
                                            	State of LSA sync with active
                                            	**type**\:   :py:class:`OspfLsaSyncStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncStateEnum>`
                                            
                                            .. attribute:: minute_table_index
                                            
                                            	Minute table index
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: nsr_flood_required
                                            
                                            	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                            	**type**\:  bool
                                            
                                            .. attribute:: rate_limit
                                            
                                            	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                            	**type**\:  bool
                                            
                                            .. attribute:: second_table_index
                                            
                                            	Second table index
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.free_time = None
                                                self.is_acknowledged = None
                                                self.is_advertising_router_reachable = None
                                                self.is_deleted = None
                                                self.is_flood_pending = None
                                                self.is_maximum_aged = None
                                                self.is_neighbor_exchange = None
                                                self.is_no_delete = None
                                                self.is_nsr_ack_pending = None
                                                self.is_partial_spf = None
                                                self.is_routing_bit = None
                                                self.is_routing_table = None
                                                self.lsa_flood_required_post_fail_over = None
                                                self.lsa_length = None
                                                self.lsa_sync_state = None
                                                self.minute_table_index = None
                                                self.nsr_flood_required = None
                                                self.rate_limit = None
                                                self.second_table_index = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-detail'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.free_time is not None:
                                                    return True

                                                if self.is_acknowledged is not None:
                                                    return True

                                                if self.is_advertising_router_reachable is not None:
                                                    return True

                                                if self.is_deleted is not None:
                                                    return True

                                                if self.is_flood_pending is not None:
                                                    return True

                                                if self.is_maximum_aged is not None:
                                                    return True

                                                if self.is_neighbor_exchange is not None:
                                                    return True

                                                if self.is_no_delete is not None:
                                                    return True

                                                if self.is_nsr_ack_pending is not None:
                                                    return True

                                                if self.is_partial_spf is not None:
                                                    return True

                                                if self.is_routing_bit is not None:
                                                    return True

                                                if self.is_routing_table is not None:
                                                    return True

                                                if self.lsa_flood_required_post_fail_over is not None:
                                                    return True

                                                if self.lsa_length is not None:
                                                    return True

                                                if self.lsa_sync_state is not None:
                                                    return True

                                                if self.minute_table_index is not None:
                                                    return True

                                                if self.nsr_flood_required is not None:
                                                    return True

                                                if self.rate_limit is not None:
                                                    return True

                                                if self.second_table_index is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaDetail']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:inter-area-prefix-lsa-type'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.lsa_detail is not None and self.lsa_detail._has_data():
                                                return True

                                            if self.lsa_header is not None and self.lsa_header._has_data():
                                                return True

                                            if self.prefix is not None:
                                                return True

                                            if self.prefix_length is not None:
                                                return True

                                            if self.priority is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType']['meta_info']


                                    class InterAreaRouterLsaType(object):
                                        """
                                        Inter Area Router LSA
                                        
                                        .. attribute:: lsa_detail
                                        
                                        	Detailed LSA information
                                        	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaDetail>`
                                        
                                        .. attribute:: lsa_header
                                        
                                        	Header information 
                                        	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaHeader>`
                                        
                                        .. attribute:: lsa_router_id
                                        
                                        	LSA router ID 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaDetail()
                                            self.lsa_detail.parent = self
                                            self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaHeader()
                                            self.lsa_header.parent = self
                                            self.lsa_router_id = None


                                        class LsaHeader(object):
                                            """
                                            Header information 
                                            
                                            .. attribute:: advertising_router
                                            
                                            	Router ID of Advertising Router
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: checksum
                                            
                                            	Checksum value
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: is_do_not_age_lsa
                                            
                                            	If true, Do Not Age this LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_graceful_restart_active
                                            
                                            	If true, if grace restart is active 
                                            	**type**\:  bool
                                            
                                            .. attribute:: ls_id
                                            
                                            	LS ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: lsa_age
                                            
                                            	LSA's Age (s)
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_area_id
                                            
                                            	Area ID in decimal or dotted\-decimal format
                                            	**type**\:  str
                                            
                                            	**length:** 0..16
                                            
                                            .. attribute:: lsa_type
                                            
                                            	LSA type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: sequence_number
                                            
                                            	Current Sequence number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.advertising_router = None
                                                self.checksum = None
                                                self.is_do_not_age_lsa = None
                                                self.is_graceful_restart_active = None
                                                self.ls_id = None
                                                self.lsa_age = None
                                                self.lsa_area_id = None
                                                self.lsa_type = None
                                                self.sequence_number = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-header'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.advertising_router is not None:
                                                    return True

                                                if self.checksum is not None:
                                                    return True

                                                if self.is_do_not_age_lsa is not None:
                                                    return True

                                                if self.is_graceful_restart_active is not None:
                                                    return True

                                                if self.ls_id is not None:
                                                    return True

                                                if self.lsa_age is not None:
                                                    return True

                                                if self.lsa_area_id is not None:
                                                    return True

                                                if self.lsa_type is not None:
                                                    return True

                                                if self.sequence_number is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaHeader']['meta_info']


                                        class LsaDetail(object):
                                            """
                                            Detailed LSA information
                                            
                                            .. attribute:: free_time
                                            
                                            	The amount of time since the last check was made to free this LSA (s)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_acknowledged
                                            
                                            	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_advertising_router_reachable
                                            
                                            	If true, Advertising Router is reachable
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_deleted
                                            
                                            	If true, flag is set to delete this LSA 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_flood_pending
                                            
                                            	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_maximum_aged
                                            
                                            	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_neighbor_exchange
                                            
                                            	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_no_delete
                                            
                                            	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_nsr_ack_pending
                                            
                                            	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_partial_spf
                                            
                                            	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_routing_bit
                                            
                                            	If true, Routing Bit set on the LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_routing_table
                                            
                                            	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                            	**type**\:  bool
                                            
                                            .. attribute:: lsa_flood_required_post_fail_over
                                            
                                            	LSA flood required after FO
                                            	**type**\:  bool
                                            
                                            .. attribute:: lsa_length
                                            
                                            	Length of the LSA
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_sync_state
                                            
                                            	State of LSA sync with active
                                            	**type**\:   :py:class:`OspfLsaSyncStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncStateEnum>`
                                            
                                            .. attribute:: minute_table_index
                                            
                                            	Minute table index
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: nsr_flood_required
                                            
                                            	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                            	**type**\:  bool
                                            
                                            .. attribute:: rate_limit
                                            
                                            	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                            	**type**\:  bool
                                            
                                            .. attribute:: second_table_index
                                            
                                            	Second table index
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.free_time = None
                                                self.is_acknowledged = None
                                                self.is_advertising_router_reachable = None
                                                self.is_deleted = None
                                                self.is_flood_pending = None
                                                self.is_maximum_aged = None
                                                self.is_neighbor_exchange = None
                                                self.is_no_delete = None
                                                self.is_nsr_ack_pending = None
                                                self.is_partial_spf = None
                                                self.is_routing_bit = None
                                                self.is_routing_table = None
                                                self.lsa_flood_required_post_fail_over = None
                                                self.lsa_length = None
                                                self.lsa_sync_state = None
                                                self.minute_table_index = None
                                                self.nsr_flood_required = None
                                                self.rate_limit = None
                                                self.second_table_index = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-detail'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.free_time is not None:
                                                    return True

                                                if self.is_acknowledged is not None:
                                                    return True

                                                if self.is_advertising_router_reachable is not None:
                                                    return True

                                                if self.is_deleted is not None:
                                                    return True

                                                if self.is_flood_pending is not None:
                                                    return True

                                                if self.is_maximum_aged is not None:
                                                    return True

                                                if self.is_neighbor_exchange is not None:
                                                    return True

                                                if self.is_no_delete is not None:
                                                    return True

                                                if self.is_nsr_ack_pending is not None:
                                                    return True

                                                if self.is_partial_spf is not None:
                                                    return True

                                                if self.is_routing_bit is not None:
                                                    return True

                                                if self.is_routing_table is not None:
                                                    return True

                                                if self.lsa_flood_required_post_fail_over is not None:
                                                    return True

                                                if self.lsa_length is not None:
                                                    return True

                                                if self.lsa_sync_state is not None:
                                                    return True

                                                if self.minute_table_index is not None:
                                                    return True

                                                if self.nsr_flood_required is not None:
                                                    return True

                                                if self.rate_limit is not None:
                                                    return True

                                                if self.second_table_index is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaDetail']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:inter-area-router-lsa-type'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.lsa_detail is not None and self.lsa_detail._has_data():
                                                return True

                                            if self.lsa_header is not None and self.lsa_header._has_data():
                                                return True

                                            if self.lsa_router_id is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType']['meta_info']


                                    class ExternalLsaType(object):
                                        """
                                        External LSA
                                        
                                        .. attribute:: external_tag
                                        
                                        	Route Tag
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: forwarding_address
                                        
                                        	Forwarding Address
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: is_forwarding_address_set
                                        
                                        	If true, forwarding address is set 
                                        	**type**\:  bool
                                        
                                        .. attribute:: lsa_detail
                                        
                                        	Detailed LSA Information
                                        	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType.LsaDetail>`
                                        
                                        .. attribute:: lsa_header
                                        
                                        	Header information 
                                        	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType.LsaHeader>`
                                        
                                        .. attribute:: metric_type
                                        
                                        	Metric type 
                                        	**type**\:   :py:class:`Ospfv3DefaultMetricEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3DefaultMetricEnum>`
                                        
                                        .. attribute:: prefix
                                        
                                        	IPV6 address prefix 
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: prefix_length
                                        
                                        	Prefix length 
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: priority
                                        
                                        	Prefix priority
                                        	**type**\:   :py:class:`PrefixPriorityEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.PrefixPriorityEnum>`
                                        
                                        .. attribute:: tos_cost
                                        
                                        	Type of service cost metric 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.external_tag = None
                                            self.forwarding_address = None
                                            self.is_forwarding_address_set = None
                                            self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType.LsaDetail()
                                            self.lsa_detail.parent = self
                                            self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType.LsaHeader()
                                            self.lsa_header.parent = self
                                            self.metric_type = None
                                            self.prefix = None
                                            self.prefix_length = None
                                            self.priority = None
                                            self.tos_cost = None


                                        class LsaHeader(object):
                                            """
                                            Header information 
                                            
                                            .. attribute:: advertising_router
                                            
                                            	Router ID of Advertising Router
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: checksum
                                            
                                            	Checksum value
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: is_do_not_age_lsa
                                            
                                            	If true, Do Not Age this LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_graceful_restart_active
                                            
                                            	If true, if grace restart is active 
                                            	**type**\:  bool
                                            
                                            .. attribute:: ls_id
                                            
                                            	LS ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: lsa_age
                                            
                                            	LSA's Age (s)
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_area_id
                                            
                                            	Area ID in decimal or dotted\-decimal format
                                            	**type**\:  str
                                            
                                            	**length:** 0..16
                                            
                                            .. attribute:: lsa_type
                                            
                                            	LSA type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: sequence_number
                                            
                                            	Current Sequence number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.advertising_router = None
                                                self.checksum = None
                                                self.is_do_not_age_lsa = None
                                                self.is_graceful_restart_active = None
                                                self.ls_id = None
                                                self.lsa_age = None
                                                self.lsa_area_id = None
                                                self.lsa_type = None
                                                self.sequence_number = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-header'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.advertising_router is not None:
                                                    return True

                                                if self.checksum is not None:
                                                    return True

                                                if self.is_do_not_age_lsa is not None:
                                                    return True

                                                if self.is_graceful_restart_active is not None:
                                                    return True

                                                if self.ls_id is not None:
                                                    return True

                                                if self.lsa_age is not None:
                                                    return True

                                                if self.lsa_area_id is not None:
                                                    return True

                                                if self.lsa_type is not None:
                                                    return True

                                                if self.sequence_number is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType.LsaHeader']['meta_info']


                                        class LsaDetail(object):
                                            """
                                            Detailed LSA Information
                                            
                                            .. attribute:: free_time
                                            
                                            	The amount of time since the last check was made to free this LSA (s)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_acknowledged
                                            
                                            	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_advertising_router_reachable
                                            
                                            	If true, Advertising Router is reachable
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_deleted
                                            
                                            	If true, flag is set to delete this LSA 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_flood_pending
                                            
                                            	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_maximum_aged
                                            
                                            	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_neighbor_exchange
                                            
                                            	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_no_delete
                                            
                                            	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_nsr_ack_pending
                                            
                                            	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_partial_spf
                                            
                                            	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_routing_bit
                                            
                                            	If true, Routing Bit set on the LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_routing_table
                                            
                                            	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                            	**type**\:  bool
                                            
                                            .. attribute:: lsa_flood_required_post_fail_over
                                            
                                            	LSA flood required after FO
                                            	**type**\:  bool
                                            
                                            .. attribute:: lsa_length
                                            
                                            	Length of the LSA
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_sync_state
                                            
                                            	State of LSA sync with active
                                            	**type**\:   :py:class:`OspfLsaSyncStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncStateEnum>`
                                            
                                            .. attribute:: minute_table_index
                                            
                                            	Minute table index
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: nsr_flood_required
                                            
                                            	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                            	**type**\:  bool
                                            
                                            .. attribute:: rate_limit
                                            
                                            	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                            	**type**\:  bool
                                            
                                            .. attribute:: second_table_index
                                            
                                            	Second table index
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.free_time = None
                                                self.is_acknowledged = None
                                                self.is_advertising_router_reachable = None
                                                self.is_deleted = None
                                                self.is_flood_pending = None
                                                self.is_maximum_aged = None
                                                self.is_neighbor_exchange = None
                                                self.is_no_delete = None
                                                self.is_nsr_ack_pending = None
                                                self.is_partial_spf = None
                                                self.is_routing_bit = None
                                                self.is_routing_table = None
                                                self.lsa_flood_required_post_fail_over = None
                                                self.lsa_length = None
                                                self.lsa_sync_state = None
                                                self.minute_table_index = None
                                                self.nsr_flood_required = None
                                                self.rate_limit = None
                                                self.second_table_index = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-detail'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.free_time is not None:
                                                    return True

                                                if self.is_acknowledged is not None:
                                                    return True

                                                if self.is_advertising_router_reachable is not None:
                                                    return True

                                                if self.is_deleted is not None:
                                                    return True

                                                if self.is_flood_pending is not None:
                                                    return True

                                                if self.is_maximum_aged is not None:
                                                    return True

                                                if self.is_neighbor_exchange is not None:
                                                    return True

                                                if self.is_no_delete is not None:
                                                    return True

                                                if self.is_nsr_ack_pending is not None:
                                                    return True

                                                if self.is_partial_spf is not None:
                                                    return True

                                                if self.is_routing_bit is not None:
                                                    return True

                                                if self.is_routing_table is not None:
                                                    return True

                                                if self.lsa_flood_required_post_fail_over is not None:
                                                    return True

                                                if self.lsa_length is not None:
                                                    return True

                                                if self.lsa_sync_state is not None:
                                                    return True

                                                if self.minute_table_index is not None:
                                                    return True

                                                if self.nsr_flood_required is not None:
                                                    return True

                                                if self.rate_limit is not None:
                                                    return True

                                                if self.second_table_index is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType.LsaDetail']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:external-lsa-type'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.external_tag is not None:
                                                return True

                                            if self.forwarding_address is not None:
                                                return True

                                            if self.is_forwarding_address_set is not None:
                                                return True

                                            if self.lsa_detail is not None and self.lsa_detail._has_data():
                                                return True

                                            if self.lsa_header is not None and self.lsa_header._has_data():
                                                return True

                                            if self.metric_type is not None:
                                                return True

                                            if self.prefix is not None:
                                                return True

                                            if self.prefix_length is not None:
                                                return True

                                            if self.priority is not None:
                                                return True

                                            if self.tos_cost is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType']['meta_info']


                                    class NssalsaType(object):
                                        """
                                        NSSA External LSA
                                        
                                        .. attribute:: external_tag
                                        
                                        	Route Tag
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: forwarding_address
                                        
                                        	Forwarding Address
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: is_forwarding_address_set
                                        
                                        	If true, forwarding address is set 
                                        	**type**\:  bool
                                        
                                        .. attribute:: lsa_detail
                                        
                                        	Detailed LSA Information
                                        	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType.LsaDetail>`
                                        
                                        .. attribute:: lsa_header
                                        
                                        	Header information 
                                        	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType.LsaHeader>`
                                        
                                        .. attribute:: metric_type
                                        
                                        	Metric type 
                                        	**type**\:   :py:class:`Ospfv3DefaultMetricEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3DefaultMetricEnum>`
                                        
                                        .. attribute:: prefix
                                        
                                        	IPV6 address prefix 
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: prefix_length
                                        
                                        	Prefix length 
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: priority
                                        
                                        	Prefix priority
                                        	**type**\:   :py:class:`PrefixPriorityEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.PrefixPriorityEnum>`
                                        
                                        .. attribute:: tos_cost
                                        
                                        	Type of service cost metric 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.external_tag = None
                                            self.forwarding_address = None
                                            self.is_forwarding_address_set = None
                                            self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType.LsaDetail()
                                            self.lsa_detail.parent = self
                                            self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType.LsaHeader()
                                            self.lsa_header.parent = self
                                            self.metric_type = None
                                            self.prefix = None
                                            self.prefix_length = None
                                            self.priority = None
                                            self.tos_cost = None


                                        class LsaHeader(object):
                                            """
                                            Header information 
                                            
                                            .. attribute:: advertising_router
                                            
                                            	Router ID of Advertising Router
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: checksum
                                            
                                            	Checksum value
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: is_do_not_age_lsa
                                            
                                            	If true, Do Not Age this LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_graceful_restart_active
                                            
                                            	If true, if grace restart is active 
                                            	**type**\:  bool
                                            
                                            .. attribute:: ls_id
                                            
                                            	LS ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: lsa_age
                                            
                                            	LSA's Age (s)
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_area_id
                                            
                                            	Area ID in decimal or dotted\-decimal format
                                            	**type**\:  str
                                            
                                            	**length:** 0..16
                                            
                                            .. attribute:: lsa_type
                                            
                                            	LSA type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: sequence_number
                                            
                                            	Current Sequence number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.advertising_router = None
                                                self.checksum = None
                                                self.is_do_not_age_lsa = None
                                                self.is_graceful_restart_active = None
                                                self.ls_id = None
                                                self.lsa_age = None
                                                self.lsa_area_id = None
                                                self.lsa_type = None
                                                self.sequence_number = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-header'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.advertising_router is not None:
                                                    return True

                                                if self.checksum is not None:
                                                    return True

                                                if self.is_do_not_age_lsa is not None:
                                                    return True

                                                if self.is_graceful_restart_active is not None:
                                                    return True

                                                if self.ls_id is not None:
                                                    return True

                                                if self.lsa_age is not None:
                                                    return True

                                                if self.lsa_area_id is not None:
                                                    return True

                                                if self.lsa_type is not None:
                                                    return True

                                                if self.sequence_number is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType.LsaHeader']['meta_info']


                                        class LsaDetail(object):
                                            """
                                            Detailed LSA Information
                                            
                                            .. attribute:: free_time
                                            
                                            	The amount of time since the last check was made to free this LSA (s)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_acknowledged
                                            
                                            	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_advertising_router_reachable
                                            
                                            	If true, Advertising Router is reachable
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_deleted
                                            
                                            	If true, flag is set to delete this LSA 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_flood_pending
                                            
                                            	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_maximum_aged
                                            
                                            	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_neighbor_exchange
                                            
                                            	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_no_delete
                                            
                                            	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_nsr_ack_pending
                                            
                                            	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_partial_spf
                                            
                                            	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_routing_bit
                                            
                                            	If true, Routing Bit set on the LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_routing_table
                                            
                                            	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                            	**type**\:  bool
                                            
                                            .. attribute:: lsa_flood_required_post_fail_over
                                            
                                            	LSA flood required after FO
                                            	**type**\:  bool
                                            
                                            .. attribute:: lsa_length
                                            
                                            	Length of the LSA
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_sync_state
                                            
                                            	State of LSA sync with active
                                            	**type**\:   :py:class:`OspfLsaSyncStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncStateEnum>`
                                            
                                            .. attribute:: minute_table_index
                                            
                                            	Minute table index
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: nsr_flood_required
                                            
                                            	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                            	**type**\:  bool
                                            
                                            .. attribute:: rate_limit
                                            
                                            	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                            	**type**\:  bool
                                            
                                            .. attribute:: second_table_index
                                            
                                            	Second table index
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.free_time = None
                                                self.is_acknowledged = None
                                                self.is_advertising_router_reachable = None
                                                self.is_deleted = None
                                                self.is_flood_pending = None
                                                self.is_maximum_aged = None
                                                self.is_neighbor_exchange = None
                                                self.is_no_delete = None
                                                self.is_nsr_ack_pending = None
                                                self.is_partial_spf = None
                                                self.is_routing_bit = None
                                                self.is_routing_table = None
                                                self.lsa_flood_required_post_fail_over = None
                                                self.lsa_length = None
                                                self.lsa_sync_state = None
                                                self.minute_table_index = None
                                                self.nsr_flood_required = None
                                                self.rate_limit = None
                                                self.second_table_index = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-detail'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.free_time is not None:
                                                    return True

                                                if self.is_acknowledged is not None:
                                                    return True

                                                if self.is_advertising_router_reachable is not None:
                                                    return True

                                                if self.is_deleted is not None:
                                                    return True

                                                if self.is_flood_pending is not None:
                                                    return True

                                                if self.is_maximum_aged is not None:
                                                    return True

                                                if self.is_neighbor_exchange is not None:
                                                    return True

                                                if self.is_no_delete is not None:
                                                    return True

                                                if self.is_nsr_ack_pending is not None:
                                                    return True

                                                if self.is_partial_spf is not None:
                                                    return True

                                                if self.is_routing_bit is not None:
                                                    return True

                                                if self.is_routing_table is not None:
                                                    return True

                                                if self.lsa_flood_required_post_fail_over is not None:
                                                    return True

                                                if self.lsa_length is not None:
                                                    return True

                                                if self.lsa_sync_state is not None:
                                                    return True

                                                if self.minute_table_index is not None:
                                                    return True

                                                if self.nsr_flood_required is not None:
                                                    return True

                                                if self.rate_limit is not None:
                                                    return True

                                                if self.second_table_index is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType.LsaDetail']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:nssalsa-type'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.external_tag is not None:
                                                return True

                                            if self.forwarding_address is not None:
                                                return True

                                            if self.is_forwarding_address_set is not None:
                                                return True

                                            if self.lsa_detail is not None and self.lsa_detail._has_data():
                                                return True

                                            if self.lsa_header is not None and self.lsa_header._has_data():
                                                return True

                                            if self.metric_type is not None:
                                                return True

                                            if self.prefix is not None:
                                                return True

                                            if self.prefix_length is not None:
                                                return True

                                            if self.priority is not None:
                                                return True

                                            if self.tos_cost is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType']['meta_info']


                                    class LinkLsaType(object):
                                        """
                                        Link LSA
                                        
                                        .. attribute:: interface_name
                                        
                                        	LSA interface handle
                                        	**type**\:  str
                                        
                                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                        
                                        .. attribute:: is_sham_link
                                        
                                        	If true, it is a sham link
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_virtual_link
                                        
                                        	If true, it is a virtual link
                                        	**type**\:  bool
                                        
                                        .. attribute:: lsa_detail
                                        
                                        	Detailed LSA information
                                        	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType.LsaDetail>`
                                        
                                        .. attribute:: lsa_header
                                        
                                        	Header information 
                                        	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType.LsaHeader>`
                                        
                                        .. attribute:: lsa_link_local
                                        
                                        	LSA link local 
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: prefix
                                        
                                        	OSPFv3 prefix 
                                        	**type**\: list of    :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType.Prefix>`
                                        
                                        .. attribute:: router_priority
                                        
                                        	Router priority 
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: sham_link_id
                                        
                                        	Sham link ID 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: virtual_link_id
                                        
                                        	Virtual link ID 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface_name = None
                                            self.is_sham_link = None
                                            self.is_virtual_link = None
                                            self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType.LsaDetail()
                                            self.lsa_detail.parent = self
                                            self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType.LsaHeader()
                                            self.lsa_header.parent = self
                                            self.lsa_link_local = None
                                            self.prefix = YList()
                                            self.prefix.parent = self
                                            self.prefix.name = 'prefix'
                                            self.router_priority = None
                                            self.sham_link_id = None
                                            self.virtual_link_id = None


                                        class LsaHeader(object):
                                            """
                                            Header information 
                                            
                                            .. attribute:: advertising_router
                                            
                                            	Router ID of Advertising Router
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: checksum
                                            
                                            	Checksum value
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: is_do_not_age_lsa
                                            
                                            	If true, Do Not Age this LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_graceful_restart_active
                                            
                                            	If true, if grace restart is active 
                                            	**type**\:  bool
                                            
                                            .. attribute:: ls_id
                                            
                                            	LS ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: lsa_age
                                            
                                            	LSA's Age (s)
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_area_id
                                            
                                            	Area ID in decimal or dotted\-decimal format
                                            	**type**\:  str
                                            
                                            	**length:** 0..16
                                            
                                            .. attribute:: lsa_type
                                            
                                            	LSA type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: sequence_number
                                            
                                            	Current Sequence number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.advertising_router = None
                                                self.checksum = None
                                                self.is_do_not_age_lsa = None
                                                self.is_graceful_restart_active = None
                                                self.ls_id = None
                                                self.lsa_age = None
                                                self.lsa_area_id = None
                                                self.lsa_type = None
                                                self.sequence_number = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-header'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.advertising_router is not None:
                                                    return True

                                                if self.checksum is not None:
                                                    return True

                                                if self.is_do_not_age_lsa is not None:
                                                    return True

                                                if self.is_graceful_restart_active is not None:
                                                    return True

                                                if self.ls_id is not None:
                                                    return True

                                                if self.lsa_age is not None:
                                                    return True

                                                if self.lsa_area_id is not None:
                                                    return True

                                                if self.lsa_type is not None:
                                                    return True

                                                if self.sequence_number is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType.LsaHeader']['meta_info']


                                        class LsaDetail(object):
                                            """
                                            Detailed LSA information
                                            
                                            .. attribute:: free_time
                                            
                                            	The amount of time since the last check was made to free this LSA (s)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_acknowledged
                                            
                                            	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_advertising_router_reachable
                                            
                                            	If true, Advertising Router is reachable
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_deleted
                                            
                                            	If true, flag is set to delete this LSA 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_flood_pending
                                            
                                            	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_maximum_aged
                                            
                                            	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_neighbor_exchange
                                            
                                            	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_no_delete
                                            
                                            	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_nsr_ack_pending
                                            
                                            	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_partial_spf
                                            
                                            	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_routing_bit
                                            
                                            	If true, Routing Bit set on the LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_routing_table
                                            
                                            	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                            	**type**\:  bool
                                            
                                            .. attribute:: lsa_flood_required_post_fail_over
                                            
                                            	LSA flood required after FO
                                            	**type**\:  bool
                                            
                                            .. attribute:: lsa_length
                                            
                                            	Length of the LSA
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_sync_state
                                            
                                            	State of LSA sync with active
                                            	**type**\:   :py:class:`OspfLsaSyncStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncStateEnum>`
                                            
                                            .. attribute:: minute_table_index
                                            
                                            	Minute table index
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: nsr_flood_required
                                            
                                            	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                            	**type**\:  bool
                                            
                                            .. attribute:: rate_limit
                                            
                                            	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                            	**type**\:  bool
                                            
                                            .. attribute:: second_table_index
                                            
                                            	Second table index
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.free_time = None
                                                self.is_acknowledged = None
                                                self.is_advertising_router_reachable = None
                                                self.is_deleted = None
                                                self.is_flood_pending = None
                                                self.is_maximum_aged = None
                                                self.is_neighbor_exchange = None
                                                self.is_no_delete = None
                                                self.is_nsr_ack_pending = None
                                                self.is_partial_spf = None
                                                self.is_routing_bit = None
                                                self.is_routing_table = None
                                                self.lsa_flood_required_post_fail_over = None
                                                self.lsa_length = None
                                                self.lsa_sync_state = None
                                                self.minute_table_index = None
                                                self.nsr_flood_required = None
                                                self.rate_limit = None
                                                self.second_table_index = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-detail'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.free_time is not None:
                                                    return True

                                                if self.is_acknowledged is not None:
                                                    return True

                                                if self.is_advertising_router_reachable is not None:
                                                    return True

                                                if self.is_deleted is not None:
                                                    return True

                                                if self.is_flood_pending is not None:
                                                    return True

                                                if self.is_maximum_aged is not None:
                                                    return True

                                                if self.is_neighbor_exchange is not None:
                                                    return True

                                                if self.is_no_delete is not None:
                                                    return True

                                                if self.is_nsr_ack_pending is not None:
                                                    return True

                                                if self.is_partial_spf is not None:
                                                    return True

                                                if self.is_routing_bit is not None:
                                                    return True

                                                if self.is_routing_table is not None:
                                                    return True

                                                if self.lsa_flood_required_post_fail_over is not None:
                                                    return True

                                                if self.lsa_length is not None:
                                                    return True

                                                if self.lsa_sync_state is not None:
                                                    return True

                                                if self.minute_table_index is not None:
                                                    return True

                                                if self.nsr_flood_required is not None:
                                                    return True

                                                if self.rate_limit is not None:
                                                    return True

                                                if self.second_table_index is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType.LsaDetail']['meta_info']


                                        class Prefix(object):
                                            """
                                            OSPFv3 prefix 
                                            
                                            .. attribute:: ospfv3_prefix_length
                                            
                                            	OSPFv3 prefix length 
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ospfv3_prefix_metric
                                            
                                            	OSPFv3 prefix metric 
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: ospfv3_prefix_options
                                            
                                            	OSPFv3 prefix options 
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: prefix
                                            
                                            	OSPFv3 prefix 
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: priority
                                            
                                            	Prefix priority
                                            	**type**\:   :py:class:`PrefixPriorityEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.PrefixPriorityEnum>`
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.ospfv3_prefix_length = None
                                                self.ospfv3_prefix_metric = None
                                                self.ospfv3_prefix_options = None
                                                self.prefix = None
                                                self.priority = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:prefix'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.ospfv3_prefix_length is not None:
                                                    return True

                                                if self.ospfv3_prefix_metric is not None:
                                                    return True

                                                if self.ospfv3_prefix_options is not None:
                                                    return True

                                                if self.prefix is not None:
                                                    return True

                                                if self.priority is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType.Prefix']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:link-lsa-type'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface_name is not None:
                                                return True

                                            if self.is_sham_link is not None:
                                                return True

                                            if self.is_virtual_link is not None:
                                                return True

                                            if self.lsa_detail is not None and self.lsa_detail._has_data():
                                                return True

                                            if self.lsa_header is not None and self.lsa_header._has_data():
                                                return True

                                            if self.lsa_link_local is not None:
                                                return True

                                            if self.prefix is not None:
                                                for child_ref in self.prefix:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.router_priority is not None:
                                                return True

                                            if self.sham_link_id is not None:
                                                return True

                                            if self.virtual_link_id is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType']['meta_info']


                                    class IntraAreaPrefixLsaType(object):
                                        """
                                        Intra Area Prefix LSA
                                        
                                        .. attribute:: lsa_detail
                                        
                                        	Detailed LSA information
                                        	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaDetail>`
                                        
                                        .. attribute:: lsa_header
                                        
                                        	Header information 
                                        	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaHeader>`
                                        
                                        .. attribute:: prefix
                                        
                                        	OSPFv3 prefix 
                                        	**type**\: list of    :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.Prefix>`
                                        
                                        .. attribute:: reference_advertised_router
                                        
                                        	Reference advertised router 
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: reference_lsa_id
                                        
                                        	Reference LSA ID 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: reference_type
                                        
                                        	Reference type 
                                        	**type**\:   :py:class:`Ospfv3Lsa1Enum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Lsa1Enum>`
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaDetail()
                                            self.lsa_detail.parent = self
                                            self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaHeader()
                                            self.lsa_header.parent = self
                                            self.prefix = YList()
                                            self.prefix.parent = self
                                            self.prefix.name = 'prefix'
                                            self.reference_advertised_router = None
                                            self.reference_lsa_id = None
                                            self.reference_type = None


                                        class LsaHeader(object):
                                            """
                                            Header information 
                                            
                                            .. attribute:: advertising_router
                                            
                                            	Router ID of Advertising Router
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: checksum
                                            
                                            	Checksum value
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: is_do_not_age_lsa
                                            
                                            	If true, Do Not Age this LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_graceful_restart_active
                                            
                                            	If true, if grace restart is active 
                                            	**type**\:  bool
                                            
                                            .. attribute:: ls_id
                                            
                                            	LS ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: lsa_age
                                            
                                            	LSA's Age (s)
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_area_id
                                            
                                            	Area ID in decimal or dotted\-decimal format
                                            	**type**\:  str
                                            
                                            	**length:** 0..16
                                            
                                            .. attribute:: lsa_type
                                            
                                            	LSA type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: sequence_number
                                            
                                            	Current Sequence number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.advertising_router = None
                                                self.checksum = None
                                                self.is_do_not_age_lsa = None
                                                self.is_graceful_restart_active = None
                                                self.ls_id = None
                                                self.lsa_age = None
                                                self.lsa_area_id = None
                                                self.lsa_type = None
                                                self.sequence_number = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-header'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.advertising_router is not None:
                                                    return True

                                                if self.checksum is not None:
                                                    return True

                                                if self.is_do_not_age_lsa is not None:
                                                    return True

                                                if self.is_graceful_restart_active is not None:
                                                    return True

                                                if self.ls_id is not None:
                                                    return True

                                                if self.lsa_age is not None:
                                                    return True

                                                if self.lsa_area_id is not None:
                                                    return True

                                                if self.lsa_type is not None:
                                                    return True

                                                if self.sequence_number is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaHeader']['meta_info']


                                        class LsaDetail(object):
                                            """
                                            Detailed LSA information
                                            
                                            .. attribute:: free_time
                                            
                                            	The amount of time since the last check was made to free this LSA (s)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_acknowledged
                                            
                                            	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_advertising_router_reachable
                                            
                                            	If true, Advertising Router is reachable
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_deleted
                                            
                                            	If true, flag is set to delete this LSA 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_flood_pending
                                            
                                            	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_maximum_aged
                                            
                                            	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_neighbor_exchange
                                            
                                            	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_no_delete
                                            
                                            	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_nsr_ack_pending
                                            
                                            	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_partial_spf
                                            
                                            	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_routing_bit
                                            
                                            	If true, Routing Bit set on the LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_routing_table
                                            
                                            	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                            	**type**\:  bool
                                            
                                            .. attribute:: lsa_flood_required_post_fail_over
                                            
                                            	LSA flood required after FO
                                            	**type**\:  bool
                                            
                                            .. attribute:: lsa_length
                                            
                                            	Length of the LSA
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_sync_state
                                            
                                            	State of LSA sync with active
                                            	**type**\:   :py:class:`OspfLsaSyncStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncStateEnum>`
                                            
                                            .. attribute:: minute_table_index
                                            
                                            	Minute table index
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: nsr_flood_required
                                            
                                            	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                            	**type**\:  bool
                                            
                                            .. attribute:: rate_limit
                                            
                                            	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                            	**type**\:  bool
                                            
                                            .. attribute:: second_table_index
                                            
                                            	Second table index
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.free_time = None
                                                self.is_acknowledged = None
                                                self.is_advertising_router_reachable = None
                                                self.is_deleted = None
                                                self.is_flood_pending = None
                                                self.is_maximum_aged = None
                                                self.is_neighbor_exchange = None
                                                self.is_no_delete = None
                                                self.is_nsr_ack_pending = None
                                                self.is_partial_spf = None
                                                self.is_routing_bit = None
                                                self.is_routing_table = None
                                                self.lsa_flood_required_post_fail_over = None
                                                self.lsa_length = None
                                                self.lsa_sync_state = None
                                                self.minute_table_index = None
                                                self.nsr_flood_required = None
                                                self.rate_limit = None
                                                self.second_table_index = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-detail'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.free_time is not None:
                                                    return True

                                                if self.is_acknowledged is not None:
                                                    return True

                                                if self.is_advertising_router_reachable is not None:
                                                    return True

                                                if self.is_deleted is not None:
                                                    return True

                                                if self.is_flood_pending is not None:
                                                    return True

                                                if self.is_maximum_aged is not None:
                                                    return True

                                                if self.is_neighbor_exchange is not None:
                                                    return True

                                                if self.is_no_delete is not None:
                                                    return True

                                                if self.is_nsr_ack_pending is not None:
                                                    return True

                                                if self.is_partial_spf is not None:
                                                    return True

                                                if self.is_routing_bit is not None:
                                                    return True

                                                if self.is_routing_table is not None:
                                                    return True

                                                if self.lsa_flood_required_post_fail_over is not None:
                                                    return True

                                                if self.lsa_length is not None:
                                                    return True

                                                if self.lsa_sync_state is not None:
                                                    return True

                                                if self.minute_table_index is not None:
                                                    return True

                                                if self.nsr_flood_required is not None:
                                                    return True

                                                if self.rate_limit is not None:
                                                    return True

                                                if self.second_table_index is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaDetail']['meta_info']


                                        class Prefix(object):
                                            """
                                            OSPFv3 prefix 
                                            
                                            .. attribute:: ospfv3_prefix_length
                                            
                                            	OSPFv3 prefix length 
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ospfv3_prefix_metric
                                            
                                            	OSPFv3 prefix metric 
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: ospfv3_prefix_options
                                            
                                            	OSPFv3 prefix options 
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: prefix
                                            
                                            	OSPFv3 prefix 
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: priority
                                            
                                            	Prefix priority
                                            	**type**\:   :py:class:`PrefixPriorityEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.PrefixPriorityEnum>`
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.ospfv3_prefix_length = None
                                                self.ospfv3_prefix_metric = None
                                                self.ospfv3_prefix_options = None
                                                self.prefix = None
                                                self.priority = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:prefix'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.ospfv3_prefix_length is not None:
                                                    return True

                                                if self.ospfv3_prefix_metric is not None:
                                                    return True

                                                if self.ospfv3_prefix_options is not None:
                                                    return True

                                                if self.prefix is not None:
                                                    return True

                                                if self.priority is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.Prefix']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:intra-area-prefix-lsa-type'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.lsa_detail is not None and self.lsa_detail._has_data():
                                                return True

                                            if self.lsa_header is not None and self.lsa_header._has_data():
                                                return True

                                            if self.prefix is not None:
                                                for child_ref in self.prefix:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.reference_advertised_router is not None:
                                                return True

                                            if self.reference_lsa_id is not None:
                                                return True

                                            if self.reference_type is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType']['meta_info']


                                    class GraceLsa(object):
                                        """
                                        Grace LSA
                                        
                                        .. attribute:: grace_period
                                        
                                        	The grace periord where helper routers should wait before advertising it fully adjacent(s) 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: grace_reason
                                        
                                        	Reason for router restart
                                        	**type**\:   :py:class:`Ospfv3GracefulRestartReasonEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3GracefulRestartReasonEnum>`
                                        
                                        .. attribute:: lsa_detail
                                        
                                        	Detailed LSA information
                                        	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa.LsaDetail>`
                                        
                                        .. attribute:: lsa_header
                                        
                                        	Header information 
                                        	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa.LsaHeader>`
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.grace_period = None
                                            self.grace_reason = None
                                            self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa.LsaDetail()
                                            self.lsa_detail.parent = self
                                            self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa.LsaHeader()
                                            self.lsa_header.parent = self


                                        class LsaHeader(object):
                                            """
                                            Header information 
                                            
                                            .. attribute:: advertising_router
                                            
                                            	Router ID of Advertising Router
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: checksum
                                            
                                            	Checksum value
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: is_do_not_age_lsa
                                            
                                            	If true, Do Not Age this LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_graceful_restart_active
                                            
                                            	If true, if grace restart is active 
                                            	**type**\:  bool
                                            
                                            .. attribute:: ls_id
                                            
                                            	LS ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: lsa_age
                                            
                                            	LSA's Age (s)
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_area_id
                                            
                                            	Area ID in decimal or dotted\-decimal format
                                            	**type**\:  str
                                            
                                            	**length:** 0..16
                                            
                                            .. attribute:: lsa_type
                                            
                                            	LSA type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: sequence_number
                                            
                                            	Current Sequence number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.advertising_router = None
                                                self.checksum = None
                                                self.is_do_not_age_lsa = None
                                                self.is_graceful_restart_active = None
                                                self.ls_id = None
                                                self.lsa_age = None
                                                self.lsa_area_id = None
                                                self.lsa_type = None
                                                self.sequence_number = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-header'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.advertising_router is not None:
                                                    return True

                                                if self.checksum is not None:
                                                    return True

                                                if self.is_do_not_age_lsa is not None:
                                                    return True

                                                if self.is_graceful_restart_active is not None:
                                                    return True

                                                if self.ls_id is not None:
                                                    return True

                                                if self.lsa_age is not None:
                                                    return True

                                                if self.lsa_area_id is not None:
                                                    return True

                                                if self.lsa_type is not None:
                                                    return True

                                                if self.sequence_number is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa.LsaHeader']['meta_info']


                                        class LsaDetail(object):
                                            """
                                            Detailed LSA information
                                            
                                            .. attribute:: free_time
                                            
                                            	The amount of time since the last check was made to free this LSA (s)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_acknowledged
                                            
                                            	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_advertising_router_reachable
                                            
                                            	If true, Advertising Router is reachable
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_deleted
                                            
                                            	If true, flag is set to delete this LSA 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_flood_pending
                                            
                                            	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_maximum_aged
                                            
                                            	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_neighbor_exchange
                                            
                                            	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_no_delete
                                            
                                            	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_nsr_ack_pending
                                            
                                            	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_partial_spf
                                            
                                            	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_routing_bit
                                            
                                            	If true, Routing Bit set on the LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_routing_table
                                            
                                            	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                            	**type**\:  bool
                                            
                                            .. attribute:: lsa_flood_required_post_fail_over
                                            
                                            	LSA flood required after FO
                                            	**type**\:  bool
                                            
                                            .. attribute:: lsa_length
                                            
                                            	Length of the LSA
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_sync_state
                                            
                                            	State of LSA sync with active
                                            	**type**\:   :py:class:`OspfLsaSyncStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncStateEnum>`
                                            
                                            .. attribute:: minute_table_index
                                            
                                            	Minute table index
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: nsr_flood_required
                                            
                                            	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                            	**type**\:  bool
                                            
                                            .. attribute:: rate_limit
                                            
                                            	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                            	**type**\:  bool
                                            
                                            .. attribute:: second_table_index
                                            
                                            	Second table index
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.free_time = None
                                                self.is_acknowledged = None
                                                self.is_advertising_router_reachable = None
                                                self.is_deleted = None
                                                self.is_flood_pending = None
                                                self.is_maximum_aged = None
                                                self.is_neighbor_exchange = None
                                                self.is_no_delete = None
                                                self.is_nsr_ack_pending = None
                                                self.is_partial_spf = None
                                                self.is_routing_bit = None
                                                self.is_routing_table = None
                                                self.lsa_flood_required_post_fail_over = None
                                                self.lsa_length = None
                                                self.lsa_sync_state = None
                                                self.minute_table_index = None
                                                self.nsr_flood_required = None
                                                self.rate_limit = None
                                                self.second_table_index = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-detail'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.free_time is not None:
                                                    return True

                                                if self.is_acknowledged is not None:
                                                    return True

                                                if self.is_advertising_router_reachable is not None:
                                                    return True

                                                if self.is_deleted is not None:
                                                    return True

                                                if self.is_flood_pending is not None:
                                                    return True

                                                if self.is_maximum_aged is not None:
                                                    return True

                                                if self.is_neighbor_exchange is not None:
                                                    return True

                                                if self.is_no_delete is not None:
                                                    return True

                                                if self.is_nsr_ack_pending is not None:
                                                    return True

                                                if self.is_partial_spf is not None:
                                                    return True

                                                if self.is_routing_bit is not None:
                                                    return True

                                                if self.is_routing_table is not None:
                                                    return True

                                                if self.lsa_flood_required_post_fail_over is not None:
                                                    return True

                                                if self.lsa_length is not None:
                                                    return True

                                                if self.lsa_sync_state is not None:
                                                    return True

                                                if self.minute_table_index is not None:
                                                    return True

                                                if self.nsr_flood_required is not None:
                                                    return True

                                                if self.rate_limit is not None:
                                                    return True

                                                if self.second_table_index is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa.LsaDetail']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:grace-lsa'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.grace_period is not None:
                                                return True

                                            if self.grace_reason is not None:
                                                return True

                                            if self.lsa_detail is not None and self.lsa_detail._has_data():
                                                return True

                                            if self.lsa_header is not None and self.lsa_header._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa']['meta_info']


                                    class UnknownLinkLsaType(object):
                                        """
                                        Unknown Link Scope LSA
                                        
                                        .. attribute:: interface_name
                                        
                                        	LSA interface name 
                                        	**type**\:  str
                                        
                                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                        
                                        .. attribute:: is_sham_link
                                        
                                        	If true, it is a sham link 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_virtual_link
                                        
                                        	If true, it is a virtual link 
                                        	**type**\:  bool
                                        
                                        .. attribute:: lsa_detail
                                        
                                        	Detailed LSA information
                                        	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaDetail>`
                                        
                                        .. attribute:: lsa_header
                                        
                                        	Header information 
                                        	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaHeader>`
                                        
                                        .. attribute:: sham_link_id
                                        
                                        	Shamlink ID 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: virtual_link_id
                                        
                                        	Virtual link ID 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface_name = None
                                            self.is_sham_link = None
                                            self.is_virtual_link = None
                                            self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaDetail()
                                            self.lsa_detail.parent = self
                                            self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaHeader()
                                            self.lsa_header.parent = self
                                            self.sham_link_id = None
                                            self.virtual_link_id = None


                                        class LsaHeader(object):
                                            """
                                            Header information 
                                            
                                            .. attribute:: advertising_router
                                            
                                            	Router ID of Advertising Router
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: checksum
                                            
                                            	Checksum value
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: is_do_not_age_lsa
                                            
                                            	If true, Do Not Age this LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_graceful_restart_active
                                            
                                            	If true, if grace restart is active 
                                            	**type**\:  bool
                                            
                                            .. attribute:: ls_id
                                            
                                            	LS ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: lsa_age
                                            
                                            	LSA's Age (s)
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_area_id
                                            
                                            	Area ID in decimal or dotted\-decimal format
                                            	**type**\:  str
                                            
                                            	**length:** 0..16
                                            
                                            .. attribute:: lsa_type
                                            
                                            	LSA type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: sequence_number
                                            
                                            	Current Sequence number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.advertising_router = None
                                                self.checksum = None
                                                self.is_do_not_age_lsa = None
                                                self.is_graceful_restart_active = None
                                                self.ls_id = None
                                                self.lsa_age = None
                                                self.lsa_area_id = None
                                                self.lsa_type = None
                                                self.sequence_number = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-header'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.advertising_router is not None:
                                                    return True

                                                if self.checksum is not None:
                                                    return True

                                                if self.is_do_not_age_lsa is not None:
                                                    return True

                                                if self.is_graceful_restart_active is not None:
                                                    return True

                                                if self.ls_id is not None:
                                                    return True

                                                if self.lsa_age is not None:
                                                    return True

                                                if self.lsa_area_id is not None:
                                                    return True

                                                if self.lsa_type is not None:
                                                    return True

                                                if self.sequence_number is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaHeader']['meta_info']


                                        class LsaDetail(object):
                                            """
                                            Detailed LSA information
                                            
                                            .. attribute:: free_time
                                            
                                            	The amount of time since the last check was made to free this LSA (s)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_acknowledged
                                            
                                            	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_advertising_router_reachable
                                            
                                            	If true, Advertising Router is reachable
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_deleted
                                            
                                            	If true, flag is set to delete this LSA 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_flood_pending
                                            
                                            	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_maximum_aged
                                            
                                            	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_neighbor_exchange
                                            
                                            	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_no_delete
                                            
                                            	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_nsr_ack_pending
                                            
                                            	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_partial_spf
                                            
                                            	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_routing_bit
                                            
                                            	If true, Routing Bit set on the LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_routing_table
                                            
                                            	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                            	**type**\:  bool
                                            
                                            .. attribute:: lsa_flood_required_post_fail_over
                                            
                                            	LSA flood required after FO
                                            	**type**\:  bool
                                            
                                            .. attribute:: lsa_length
                                            
                                            	Length of the LSA
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_sync_state
                                            
                                            	State of LSA sync with active
                                            	**type**\:   :py:class:`OspfLsaSyncStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncStateEnum>`
                                            
                                            .. attribute:: minute_table_index
                                            
                                            	Minute table index
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: nsr_flood_required
                                            
                                            	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                            	**type**\:  bool
                                            
                                            .. attribute:: rate_limit
                                            
                                            	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                            	**type**\:  bool
                                            
                                            .. attribute:: second_table_index
                                            
                                            	Second table index
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.free_time = None
                                                self.is_acknowledged = None
                                                self.is_advertising_router_reachable = None
                                                self.is_deleted = None
                                                self.is_flood_pending = None
                                                self.is_maximum_aged = None
                                                self.is_neighbor_exchange = None
                                                self.is_no_delete = None
                                                self.is_nsr_ack_pending = None
                                                self.is_partial_spf = None
                                                self.is_routing_bit = None
                                                self.is_routing_table = None
                                                self.lsa_flood_required_post_fail_over = None
                                                self.lsa_length = None
                                                self.lsa_sync_state = None
                                                self.minute_table_index = None
                                                self.nsr_flood_required = None
                                                self.rate_limit = None
                                                self.second_table_index = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-detail'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.free_time is not None:
                                                    return True

                                                if self.is_acknowledged is not None:
                                                    return True

                                                if self.is_advertising_router_reachable is not None:
                                                    return True

                                                if self.is_deleted is not None:
                                                    return True

                                                if self.is_flood_pending is not None:
                                                    return True

                                                if self.is_maximum_aged is not None:
                                                    return True

                                                if self.is_neighbor_exchange is not None:
                                                    return True

                                                if self.is_no_delete is not None:
                                                    return True

                                                if self.is_nsr_ack_pending is not None:
                                                    return True

                                                if self.is_partial_spf is not None:
                                                    return True

                                                if self.is_routing_bit is not None:
                                                    return True

                                                if self.is_routing_table is not None:
                                                    return True

                                                if self.lsa_flood_required_post_fail_over is not None:
                                                    return True

                                                if self.lsa_length is not None:
                                                    return True

                                                if self.lsa_sync_state is not None:
                                                    return True

                                                if self.minute_table_index is not None:
                                                    return True

                                                if self.nsr_flood_required is not None:
                                                    return True

                                                if self.rate_limit is not None:
                                                    return True

                                                if self.second_table_index is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaDetail']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:unknown-link-lsa-type'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface_name is not None:
                                                return True

                                            if self.is_sham_link is not None:
                                                return True

                                            if self.is_virtual_link is not None:
                                                return True

                                            if self.lsa_detail is not None and self.lsa_detail._has_data():
                                                return True

                                            if self.lsa_header is not None and self.lsa_header._has_data():
                                                return True

                                            if self.sham_link_id is not None:
                                                return True

                                            if self.virtual_link_id is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType']['meta_info']


                                    class UnknownAreaLsaType(object):
                                        """
                                        Unknown\-Area scope LSA
                                        
                                        .. attribute:: interface_name
                                        
                                        	LSA interface name 
                                        	**type**\:  str
                                        
                                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                        
                                        .. attribute:: is_sham_link
                                        
                                        	If true, it is a sham link 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_virtual_link
                                        
                                        	If true, it is a virtual link 
                                        	**type**\:  bool
                                        
                                        .. attribute:: lsa_detail
                                        
                                        	Detailed LSA information
                                        	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaDetail>`
                                        
                                        .. attribute:: lsa_header
                                        
                                        	Header information 
                                        	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaHeader>`
                                        
                                        .. attribute:: sham_link_id
                                        
                                        	Shamlink ID 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: virtual_link_id
                                        
                                        	Virtual link ID 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface_name = None
                                            self.is_sham_link = None
                                            self.is_virtual_link = None
                                            self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaDetail()
                                            self.lsa_detail.parent = self
                                            self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaHeader()
                                            self.lsa_header.parent = self
                                            self.sham_link_id = None
                                            self.virtual_link_id = None


                                        class LsaHeader(object):
                                            """
                                            Header information 
                                            
                                            .. attribute:: advertising_router
                                            
                                            	Router ID of Advertising Router
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: checksum
                                            
                                            	Checksum value
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: is_do_not_age_lsa
                                            
                                            	If true, Do Not Age this LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_graceful_restart_active
                                            
                                            	If true, if grace restart is active 
                                            	**type**\:  bool
                                            
                                            .. attribute:: ls_id
                                            
                                            	LS ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: lsa_age
                                            
                                            	LSA's Age (s)
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_area_id
                                            
                                            	Area ID in decimal or dotted\-decimal format
                                            	**type**\:  str
                                            
                                            	**length:** 0..16
                                            
                                            .. attribute:: lsa_type
                                            
                                            	LSA type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: sequence_number
                                            
                                            	Current Sequence number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.advertising_router = None
                                                self.checksum = None
                                                self.is_do_not_age_lsa = None
                                                self.is_graceful_restart_active = None
                                                self.ls_id = None
                                                self.lsa_age = None
                                                self.lsa_area_id = None
                                                self.lsa_type = None
                                                self.sequence_number = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-header'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.advertising_router is not None:
                                                    return True

                                                if self.checksum is not None:
                                                    return True

                                                if self.is_do_not_age_lsa is not None:
                                                    return True

                                                if self.is_graceful_restart_active is not None:
                                                    return True

                                                if self.ls_id is not None:
                                                    return True

                                                if self.lsa_age is not None:
                                                    return True

                                                if self.lsa_area_id is not None:
                                                    return True

                                                if self.lsa_type is not None:
                                                    return True

                                                if self.sequence_number is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaHeader']['meta_info']


                                        class LsaDetail(object):
                                            """
                                            Detailed LSA information
                                            
                                            .. attribute:: free_time
                                            
                                            	The amount of time since the last check was made to free this LSA (s)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_acknowledged
                                            
                                            	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_advertising_router_reachable
                                            
                                            	If true, Advertising Router is reachable
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_deleted
                                            
                                            	If true, flag is set to delete this LSA 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_flood_pending
                                            
                                            	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_maximum_aged
                                            
                                            	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_neighbor_exchange
                                            
                                            	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_no_delete
                                            
                                            	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_nsr_ack_pending
                                            
                                            	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_partial_spf
                                            
                                            	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_routing_bit
                                            
                                            	If true, Routing Bit set on the LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_routing_table
                                            
                                            	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                            	**type**\:  bool
                                            
                                            .. attribute:: lsa_flood_required_post_fail_over
                                            
                                            	LSA flood required after FO
                                            	**type**\:  bool
                                            
                                            .. attribute:: lsa_length
                                            
                                            	Length of the LSA
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_sync_state
                                            
                                            	State of LSA sync with active
                                            	**type**\:   :py:class:`OspfLsaSyncStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncStateEnum>`
                                            
                                            .. attribute:: minute_table_index
                                            
                                            	Minute table index
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: nsr_flood_required
                                            
                                            	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                            	**type**\:  bool
                                            
                                            .. attribute:: rate_limit
                                            
                                            	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                            	**type**\:  bool
                                            
                                            .. attribute:: second_table_index
                                            
                                            	Second table index
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.free_time = None
                                                self.is_acknowledged = None
                                                self.is_advertising_router_reachable = None
                                                self.is_deleted = None
                                                self.is_flood_pending = None
                                                self.is_maximum_aged = None
                                                self.is_neighbor_exchange = None
                                                self.is_no_delete = None
                                                self.is_nsr_ack_pending = None
                                                self.is_partial_spf = None
                                                self.is_routing_bit = None
                                                self.is_routing_table = None
                                                self.lsa_flood_required_post_fail_over = None
                                                self.lsa_length = None
                                                self.lsa_sync_state = None
                                                self.minute_table_index = None
                                                self.nsr_flood_required = None
                                                self.rate_limit = None
                                                self.second_table_index = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-detail'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.free_time is not None:
                                                    return True

                                                if self.is_acknowledged is not None:
                                                    return True

                                                if self.is_advertising_router_reachable is not None:
                                                    return True

                                                if self.is_deleted is not None:
                                                    return True

                                                if self.is_flood_pending is not None:
                                                    return True

                                                if self.is_maximum_aged is not None:
                                                    return True

                                                if self.is_neighbor_exchange is not None:
                                                    return True

                                                if self.is_no_delete is not None:
                                                    return True

                                                if self.is_nsr_ack_pending is not None:
                                                    return True

                                                if self.is_partial_spf is not None:
                                                    return True

                                                if self.is_routing_bit is not None:
                                                    return True

                                                if self.is_routing_table is not None:
                                                    return True

                                                if self.lsa_flood_required_post_fail_over is not None:
                                                    return True

                                                if self.lsa_length is not None:
                                                    return True

                                                if self.lsa_sync_state is not None:
                                                    return True

                                                if self.minute_table_index is not None:
                                                    return True

                                                if self.nsr_flood_required is not None:
                                                    return True

                                                if self.rate_limit is not None:
                                                    return True

                                                if self.second_table_index is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaDetail']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:unknown-area-lsa-type'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface_name is not None:
                                                return True

                                            if self.is_sham_link is not None:
                                                return True

                                            if self.is_virtual_link is not None:
                                                return True

                                            if self.lsa_detail is not None and self.lsa_detail._has_data():
                                                return True

                                            if self.lsa_header is not None and self.lsa_header._has_data():
                                                return True

                                            if self.sham_link_id is not None:
                                                return True

                                            if self.virtual_link_id is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType']['meta_info']


                                    class UnknownAslsaType(object):
                                        """
                                        Unknown\-AS scope LSA
                                        
                                        .. attribute:: interface_name
                                        
                                        	LSA interface name 
                                        	**type**\:  str
                                        
                                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                        
                                        .. attribute:: is_sham_link
                                        
                                        	If true, it is a sham link 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_virtual_link
                                        
                                        	If true, it is a virtual link 
                                        	**type**\:  bool
                                        
                                        .. attribute:: lsa_detail
                                        
                                        	Detailed LSA information
                                        	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType.LsaDetail>`
                                        
                                        .. attribute:: lsa_header
                                        
                                        	Header information 
                                        	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType.LsaHeader>`
                                        
                                        .. attribute:: sham_link_id
                                        
                                        	Shamlink ID 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: virtual_link_id
                                        
                                        	Virtual link ID 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface_name = None
                                            self.is_sham_link = None
                                            self.is_virtual_link = None
                                            self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType.LsaDetail()
                                            self.lsa_detail.parent = self
                                            self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType.LsaHeader()
                                            self.lsa_header.parent = self
                                            self.sham_link_id = None
                                            self.virtual_link_id = None


                                        class LsaHeader(object):
                                            """
                                            Header information 
                                            
                                            .. attribute:: advertising_router
                                            
                                            	Router ID of Advertising Router
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: checksum
                                            
                                            	Checksum value
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: is_do_not_age_lsa
                                            
                                            	If true, Do Not Age this LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_graceful_restart_active
                                            
                                            	If true, if grace restart is active 
                                            	**type**\:  bool
                                            
                                            .. attribute:: ls_id
                                            
                                            	LS ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: lsa_age
                                            
                                            	LSA's Age (s)
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_area_id
                                            
                                            	Area ID in decimal or dotted\-decimal format
                                            	**type**\:  str
                                            
                                            	**length:** 0..16
                                            
                                            .. attribute:: lsa_type
                                            
                                            	LSA type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: sequence_number
                                            
                                            	Current Sequence number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.advertising_router = None
                                                self.checksum = None
                                                self.is_do_not_age_lsa = None
                                                self.is_graceful_restart_active = None
                                                self.ls_id = None
                                                self.lsa_age = None
                                                self.lsa_area_id = None
                                                self.lsa_type = None
                                                self.sequence_number = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-header'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.advertising_router is not None:
                                                    return True

                                                if self.checksum is not None:
                                                    return True

                                                if self.is_do_not_age_lsa is not None:
                                                    return True

                                                if self.is_graceful_restart_active is not None:
                                                    return True

                                                if self.ls_id is not None:
                                                    return True

                                                if self.lsa_age is not None:
                                                    return True

                                                if self.lsa_area_id is not None:
                                                    return True

                                                if self.lsa_type is not None:
                                                    return True

                                                if self.sequence_number is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType.LsaHeader']['meta_info']


                                        class LsaDetail(object):
                                            """
                                            Detailed LSA information
                                            
                                            .. attribute:: free_time
                                            
                                            	The amount of time since the last check was made to free this LSA (s)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_acknowledged
                                            
                                            	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_advertising_router_reachable
                                            
                                            	If true, Advertising Router is reachable
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_deleted
                                            
                                            	If true, flag is set to delete this LSA 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_flood_pending
                                            
                                            	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_maximum_aged
                                            
                                            	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_neighbor_exchange
                                            
                                            	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_no_delete
                                            
                                            	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_nsr_ack_pending
                                            
                                            	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_partial_spf
                                            
                                            	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_routing_bit
                                            
                                            	If true, Routing Bit set on the LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_routing_table
                                            
                                            	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                            	**type**\:  bool
                                            
                                            .. attribute:: lsa_flood_required_post_fail_over
                                            
                                            	LSA flood required after FO
                                            	**type**\:  bool
                                            
                                            .. attribute:: lsa_length
                                            
                                            	Length of the LSA
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_sync_state
                                            
                                            	State of LSA sync with active
                                            	**type**\:   :py:class:`OspfLsaSyncStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncStateEnum>`
                                            
                                            .. attribute:: minute_table_index
                                            
                                            	Minute table index
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: nsr_flood_required
                                            
                                            	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                            	**type**\:  bool
                                            
                                            .. attribute:: rate_limit
                                            
                                            	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                            	**type**\:  bool
                                            
                                            .. attribute:: second_table_index
                                            
                                            	Second table index
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.free_time = None
                                                self.is_acknowledged = None
                                                self.is_advertising_router_reachable = None
                                                self.is_deleted = None
                                                self.is_flood_pending = None
                                                self.is_maximum_aged = None
                                                self.is_neighbor_exchange = None
                                                self.is_no_delete = None
                                                self.is_nsr_ack_pending = None
                                                self.is_partial_spf = None
                                                self.is_routing_bit = None
                                                self.is_routing_table = None
                                                self.lsa_flood_required_post_fail_over = None
                                                self.lsa_length = None
                                                self.lsa_sync_state = None
                                                self.minute_table_index = None
                                                self.nsr_flood_required = None
                                                self.rate_limit = None
                                                self.second_table_index = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-detail'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.free_time is not None:
                                                    return True

                                                if self.is_acknowledged is not None:
                                                    return True

                                                if self.is_advertising_router_reachable is not None:
                                                    return True

                                                if self.is_deleted is not None:
                                                    return True

                                                if self.is_flood_pending is not None:
                                                    return True

                                                if self.is_maximum_aged is not None:
                                                    return True

                                                if self.is_neighbor_exchange is not None:
                                                    return True

                                                if self.is_no_delete is not None:
                                                    return True

                                                if self.is_nsr_ack_pending is not None:
                                                    return True

                                                if self.is_partial_spf is not None:
                                                    return True

                                                if self.is_routing_bit is not None:
                                                    return True

                                                if self.is_routing_table is not None:
                                                    return True

                                                if self.lsa_flood_required_post_fail_over is not None:
                                                    return True

                                                if self.lsa_length is not None:
                                                    return True

                                                if self.lsa_sync_state is not None:
                                                    return True

                                                if self.minute_table_index is not None:
                                                    return True

                                                if self.nsr_flood_required is not None:
                                                    return True

                                                if self.rate_limit is not None:
                                                    return True

                                                if self.second_table_index is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType.LsaDetail']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:unknown-aslsa-type'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface_name is not None:
                                                return True

                                            if self.is_sham_link is not None:
                                                return True

                                            if self.is_virtual_link is not None:
                                                return True

                                            if self.lsa_detail is not None and self.lsa_detail._has_data():
                                                return True

                                            if self.lsa_header is not None and self.lsa_header._has_data():
                                                return True

                                            if self.sham_link_id is not None:
                                                return True

                                            if self.virtual_link_id is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType']['meta_info']


                                    class UnknownLsaType(object):
                                        """
                                        Unknown LSA
                                        
                                        .. attribute:: interface_name
                                        
                                        	LSA interface name 
                                        	**type**\:  str
                                        
                                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                        
                                        .. attribute:: is_sham_link
                                        
                                        	If true, it is a sham link 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_virtual_link
                                        
                                        	If true, it is a virtual link 
                                        	**type**\:  bool
                                        
                                        .. attribute:: lsa_detail
                                        
                                        	Detailed LSA information
                                        	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType.LsaDetail>`
                                        
                                        .. attribute:: lsa_header
                                        
                                        	Header information 
                                        	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType.LsaHeader>`
                                        
                                        .. attribute:: sham_link_id
                                        
                                        	Shamlink ID 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: virtual_link_id
                                        
                                        	Virtual link ID 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface_name = None
                                            self.is_sham_link = None
                                            self.is_virtual_link = None
                                            self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType.LsaDetail()
                                            self.lsa_detail.parent = self
                                            self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType.LsaHeader()
                                            self.lsa_header.parent = self
                                            self.sham_link_id = None
                                            self.virtual_link_id = None


                                        class LsaHeader(object):
                                            """
                                            Header information 
                                            
                                            .. attribute:: advertising_router
                                            
                                            	Router ID of Advertising Router
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: checksum
                                            
                                            	Checksum value
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: is_do_not_age_lsa
                                            
                                            	If true, Do Not Age this LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_graceful_restart_active
                                            
                                            	If true, if grace restart is active 
                                            	**type**\:  bool
                                            
                                            .. attribute:: ls_id
                                            
                                            	LS ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: lsa_age
                                            
                                            	LSA's Age (s)
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_area_id
                                            
                                            	Area ID in decimal or dotted\-decimal format
                                            	**type**\:  str
                                            
                                            	**length:** 0..16
                                            
                                            .. attribute:: lsa_type
                                            
                                            	LSA type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: sequence_number
                                            
                                            	Current Sequence number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.advertising_router = None
                                                self.checksum = None
                                                self.is_do_not_age_lsa = None
                                                self.is_graceful_restart_active = None
                                                self.ls_id = None
                                                self.lsa_age = None
                                                self.lsa_area_id = None
                                                self.lsa_type = None
                                                self.sequence_number = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-header'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.advertising_router is not None:
                                                    return True

                                                if self.checksum is not None:
                                                    return True

                                                if self.is_do_not_age_lsa is not None:
                                                    return True

                                                if self.is_graceful_restart_active is not None:
                                                    return True

                                                if self.ls_id is not None:
                                                    return True

                                                if self.lsa_age is not None:
                                                    return True

                                                if self.lsa_area_id is not None:
                                                    return True

                                                if self.lsa_type is not None:
                                                    return True

                                                if self.sequence_number is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType.LsaHeader']['meta_info']


                                        class LsaDetail(object):
                                            """
                                            Detailed LSA information
                                            
                                            .. attribute:: free_time
                                            
                                            	The amount of time since the last check was made to free this LSA (s)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_acknowledged
                                            
                                            	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_advertising_router_reachable
                                            
                                            	If true, Advertising Router is reachable
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_deleted
                                            
                                            	If true, flag is set to delete this LSA 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_flood_pending
                                            
                                            	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_maximum_aged
                                            
                                            	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_neighbor_exchange
                                            
                                            	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_no_delete
                                            
                                            	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_nsr_ack_pending
                                            
                                            	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_partial_spf
                                            
                                            	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_routing_bit
                                            
                                            	If true, Routing Bit set on the LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_routing_table
                                            
                                            	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                            	**type**\:  bool
                                            
                                            .. attribute:: lsa_flood_required_post_fail_over
                                            
                                            	LSA flood required after FO
                                            	**type**\:  bool
                                            
                                            .. attribute:: lsa_length
                                            
                                            	Length of the LSA
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_sync_state
                                            
                                            	State of LSA sync with active
                                            	**type**\:   :py:class:`OspfLsaSyncStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncStateEnum>`
                                            
                                            .. attribute:: minute_table_index
                                            
                                            	Minute table index
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: nsr_flood_required
                                            
                                            	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                            	**type**\:  bool
                                            
                                            .. attribute:: rate_limit
                                            
                                            	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                            	**type**\:  bool
                                            
                                            .. attribute:: second_table_index
                                            
                                            	Second table index
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.free_time = None
                                                self.is_acknowledged = None
                                                self.is_advertising_router_reachable = None
                                                self.is_deleted = None
                                                self.is_flood_pending = None
                                                self.is_maximum_aged = None
                                                self.is_neighbor_exchange = None
                                                self.is_no_delete = None
                                                self.is_nsr_ack_pending = None
                                                self.is_partial_spf = None
                                                self.is_routing_bit = None
                                                self.is_routing_table = None
                                                self.lsa_flood_required_post_fail_over = None
                                                self.lsa_length = None
                                                self.lsa_sync_state = None
                                                self.minute_table_index = None
                                                self.nsr_flood_required = None
                                                self.rate_limit = None
                                                self.second_table_index = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-detail'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.free_time is not None:
                                                    return True

                                                if self.is_acknowledged is not None:
                                                    return True

                                                if self.is_advertising_router_reachable is not None:
                                                    return True

                                                if self.is_deleted is not None:
                                                    return True

                                                if self.is_flood_pending is not None:
                                                    return True

                                                if self.is_maximum_aged is not None:
                                                    return True

                                                if self.is_neighbor_exchange is not None:
                                                    return True

                                                if self.is_no_delete is not None:
                                                    return True

                                                if self.is_nsr_ack_pending is not None:
                                                    return True

                                                if self.is_partial_spf is not None:
                                                    return True

                                                if self.is_routing_bit is not None:
                                                    return True

                                                if self.is_routing_table is not None:
                                                    return True

                                                if self.lsa_flood_required_post_fail_over is not None:
                                                    return True

                                                if self.lsa_length is not None:
                                                    return True

                                                if self.lsa_sync_state is not None:
                                                    return True

                                                if self.minute_table_index is not None:
                                                    return True

                                                if self.nsr_flood_required is not None:
                                                    return True

                                                if self.rate_limit is not None:
                                                    return True

                                                if self.second_table_index is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType.LsaDetail']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:unknown-lsa-type'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface_name is not None:
                                                return True

                                            if self.is_sham_link is not None:
                                                return True

                                            if self.is_virtual_link is not None:
                                                return True

                                            if self.lsa_detail is not None and self.lsa_detail._has_data():
                                                return True

                                            if self.lsa_header is not None and self.lsa_header._has_data():
                                                return True

                                            if self.sham_link_id is not None:
                                                return True

                                            if self.virtual_link_id is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-info'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.external_lsa_type is not None and self.external_lsa_type._has_data():
                                            return True

                                        if self.grace_lsa is not None and self.grace_lsa._has_data():
                                            return True

                                        if self.inter_area_prefix_lsa_type is not None and self.inter_area_prefix_lsa_type._has_data():
                                            return True

                                        if self.inter_area_router_lsa_type is not None and self.inter_area_router_lsa_type._has_data():
                                            return True

                                        if self.intra_area_prefix_lsa_type is not None and self.intra_area_prefix_lsa_type._has_data():
                                            return True

                                        if self.link_lsa_type is not None and self.link_lsa_type._has_data():
                                            return True

                                        if self.lsa_info_type is not None:
                                            return True

                                        if self.lsa_summary_info is not None and self.lsa_summary_info._has_data():
                                            return True

                                        if self.network_lsa_type is not None and self.network_lsa_type._has_data():
                                            return True

                                        if self.nssalsa_type is not None and self.nssalsa_type._has_data():
                                            return True

                                        if self.router_lsa_type is not None and self.router_lsa_type._has_data():
                                            return True

                                        if self.unknown_area_lsa_type is not None and self.unknown_area_lsa_type._has_data():
                                            return True

                                        if self.unknown_aslsa_type is not None and self.unknown_aslsa_type._has_data():
                                            return True

                                        if self.unknown_link_lsa_type is not None and self.unknown_link_lsa_type._has_data():
                                            return True

                                        if self.unknown_lsa_type is not None and self.unknown_lsa_type._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                        return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.advertising_router is not None:
                                        return True

                                    if self.area_id is not None:
                                        return True

                                    if self.interface_name is not None:
                                        return True

                                    if self.ls_id is not None:
                                        return True

                                    if self.ls_type is not None:
                                        return True

                                    if self.lsa_info is not None and self.lsa_info._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                    return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-table'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.lsa is not None:
                                    for child_ref in self.lsa:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable']['meta_info']


                        class LsaInternalTable(object):
                            """
                            Database LSA information
                            
                            .. attribute:: lsa
                            
                            	Database LSA information
                            	**type**\: list of    :py:class:`Lsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa>`
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.lsa = YList()
                                self.lsa.parent = self
                                self.lsa.name = 'lsa'


                            class Lsa(object):
                                """
                                Database LSA information
                                
                                .. attribute:: advertising_router
                                
                                	Advertising Router ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: area_id
                                
                                	Area ID
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: interface_name
                                
                                	InterfaceName
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: ls_id
                                
                                	Link state ID
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: ls_type
                                
                                	LSA type
                                	**type**\:   :py:class:`Ospfv3LsaEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3LsaEnum>`
                                
                                .. attribute:: lsa_info
                                
                                	Summary of all LSAs or LSA specific information 
                                	**type**\:   :py:class:`LsaInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo>`
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.advertising_router = None
                                    self.area_id = None
                                    self.interface_name = None
                                    self.ls_id = None
                                    self.ls_type = None
                                    self.lsa_info = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo()
                                    self.lsa_info.parent = self


                                class LsaInfo(object):
                                    """
                                    Summary of all LSAs or LSA specific information 
                                    
                                    .. attribute:: external_lsa_type
                                    
                                    	External LSA
                                    	**type**\:   :py:class:`ExternalLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType>`
                                    
                                    .. attribute:: grace_lsa
                                    
                                    	Grace LSA
                                    	**type**\:   :py:class:`GraceLsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa>`
                                    
                                    .. attribute:: inter_area_prefix_lsa_type
                                    
                                    	Inter Area Prefix LSA
                                    	**type**\:   :py:class:`InterAreaPrefixLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType>`
                                    
                                    .. attribute:: inter_area_router_lsa_type
                                    
                                    	Inter Area Router LSA
                                    	**type**\:   :py:class:`InterAreaRouterLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType>`
                                    
                                    .. attribute:: intra_area_prefix_lsa_type
                                    
                                    	Intra Area Prefix LSA
                                    	**type**\:   :py:class:`IntraAreaPrefixLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType>`
                                    
                                    .. attribute:: link_lsa_type
                                    
                                    	Link LSA
                                    	**type**\:   :py:class:`LinkLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType>`
                                    
                                    .. attribute:: lsa_info_type
                                    
                                    	LSAInfoType
                                    	**type**\:   :py:class:`Ospfv3LsaInfoTypesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3LsaInfoTypesEnum>`
                                    
                                    .. attribute:: lsa_summary_info
                                    
                                    	Summary information of LSAs
                                    	**type**\:   :py:class:`LsaSummaryInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo>`
                                    
                                    .. attribute:: network_lsa_type
                                    
                                    	Network LSA
                                    	**type**\:   :py:class:`NetworkLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType>`
                                    
                                    .. attribute:: nssalsa_type
                                    
                                    	NSSA External LSA
                                    	**type**\:   :py:class:`NssalsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType>`
                                    
                                    .. attribute:: router_lsa_type
                                    
                                    	Router LSA
                                    	**type**\:   :py:class:`RouterLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType>`
                                    
                                    .. attribute:: unknown_area_lsa_type
                                    
                                    	Unknown\-Area scope LSA
                                    	**type**\:   :py:class:`UnknownAreaLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType>`
                                    
                                    .. attribute:: unknown_aslsa_type
                                    
                                    	Unknown\-AS scope LSA
                                    	**type**\:   :py:class:`UnknownAslsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType>`
                                    
                                    .. attribute:: unknown_link_lsa_type
                                    
                                    	Unknown Link Scope LSA
                                    	**type**\:   :py:class:`UnknownLinkLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType>`
                                    
                                    .. attribute:: unknown_lsa_type
                                    
                                    	Unknown LSA
                                    	**type**\:   :py:class:`UnknownLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType>`
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.external_lsa_type = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType()
                                        self.external_lsa_type.parent = self
                                        self.grace_lsa = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa()
                                        self.grace_lsa.parent = self
                                        self.inter_area_prefix_lsa_type = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType()
                                        self.inter_area_prefix_lsa_type.parent = self
                                        self.inter_area_router_lsa_type = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType()
                                        self.inter_area_router_lsa_type.parent = self
                                        self.intra_area_prefix_lsa_type = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType()
                                        self.intra_area_prefix_lsa_type.parent = self
                                        self.link_lsa_type = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType()
                                        self.link_lsa_type.parent = self
                                        self.lsa_info_type = None
                                        self.lsa_summary_info = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo()
                                        self.lsa_summary_info.parent = self
                                        self.network_lsa_type = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType()
                                        self.network_lsa_type.parent = self
                                        self.nssalsa_type = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType()
                                        self.nssalsa_type.parent = self
                                        self.router_lsa_type = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType()
                                        self.router_lsa_type.parent = self
                                        self.unknown_area_lsa_type = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType()
                                        self.unknown_area_lsa_type.parent = self
                                        self.unknown_aslsa_type = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType()
                                        self.unknown_aslsa_type.parent = self
                                        self.unknown_link_lsa_type = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType()
                                        self.unknown_link_lsa_type.parent = self
                                        self.unknown_lsa_type = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType()
                                        self.unknown_lsa_type.parent = self


                                    class LsaSummaryInfo(object):
                                        """
                                        Summary information of LSAs
                                        
                                        .. attribute:: interface_name
                                        
                                        	LSA interface name 
                                        	**type**\:  str
                                        
                                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                        
                                        .. attribute:: is_sham_link
                                        
                                        	If true, it is a sham link 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_virtual_link
                                        
                                        	If true, it is a virtual link 
                                        	**type**\:  bool
                                        
                                        .. attribute:: links
                                        
                                        	Number of links
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_detail
                                        
                                        	Detailed LSA information
                                        	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo.LsaDetail>`
                                        
                                        .. attribute:: lsa_header
                                        
                                        	Header information 
                                        	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo.LsaHeader>`
                                        
                                        .. attribute:: lsa_router_id
                                        
                                        	LSA router ID 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: prefix
                                        
                                        	OSPFv3 address Prefix 
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: prefix_length
                                        
                                        	Prefix length 
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: reference_lsa_id
                                        
                                        	Reference LSA ID 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: reference_type
                                        
                                        	Reference type 
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: router_la_bits
                                        
                                        	Router LA bits 
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: sham_link_id
                                        
                                        	Sham link ID 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: virtual_link_id
                                        
                                        	Virtual link ID 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface_name = None
                                            self.is_sham_link = None
                                            self.is_virtual_link = None
                                            self.links = None
                                            self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo.LsaDetail()
                                            self.lsa_detail.parent = self
                                            self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo.LsaHeader()
                                            self.lsa_header.parent = self
                                            self.lsa_router_id = None
                                            self.prefix = None
                                            self.prefix_length = None
                                            self.reference_lsa_id = None
                                            self.reference_type = None
                                            self.router_la_bits = None
                                            self.sham_link_id = None
                                            self.virtual_link_id = None


                                        class LsaHeader(object):
                                            """
                                            Header information 
                                            
                                            .. attribute:: advertising_router
                                            
                                            	Router ID of Advertising Router
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: checksum
                                            
                                            	Checksum value
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: is_do_not_age_lsa
                                            
                                            	If true, Do Not Age this LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_graceful_restart_active
                                            
                                            	If true, if grace restart is active 
                                            	**type**\:  bool
                                            
                                            .. attribute:: ls_id
                                            
                                            	LS ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: lsa_age
                                            
                                            	LSA's Age (s)
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_area_id
                                            
                                            	Area ID in decimal or dotted\-decimal format
                                            	**type**\:  str
                                            
                                            	**length:** 0..16
                                            
                                            .. attribute:: lsa_type
                                            
                                            	LSA type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: sequence_number
                                            
                                            	Current Sequence number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.advertising_router = None
                                                self.checksum = None
                                                self.is_do_not_age_lsa = None
                                                self.is_graceful_restart_active = None
                                                self.ls_id = None
                                                self.lsa_age = None
                                                self.lsa_area_id = None
                                                self.lsa_type = None
                                                self.sequence_number = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-header'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.advertising_router is not None:
                                                    return True

                                                if self.checksum is not None:
                                                    return True

                                                if self.is_do_not_age_lsa is not None:
                                                    return True

                                                if self.is_graceful_restart_active is not None:
                                                    return True

                                                if self.ls_id is not None:
                                                    return True

                                                if self.lsa_age is not None:
                                                    return True

                                                if self.lsa_area_id is not None:
                                                    return True

                                                if self.lsa_type is not None:
                                                    return True

                                                if self.sequence_number is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo.LsaHeader']['meta_info']


                                        class LsaDetail(object):
                                            """
                                            Detailed LSA information
                                            
                                            .. attribute:: free_time
                                            
                                            	The amount of time since the last check was made to free this LSA (s)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_acknowledged
                                            
                                            	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_advertising_router_reachable
                                            
                                            	If true, Advertising Router is reachable
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_deleted
                                            
                                            	If true, flag is set to delete this LSA 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_flood_pending
                                            
                                            	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_maximum_aged
                                            
                                            	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_neighbor_exchange
                                            
                                            	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_no_delete
                                            
                                            	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_nsr_ack_pending
                                            
                                            	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_partial_spf
                                            
                                            	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_routing_bit
                                            
                                            	If true, Routing Bit set on the LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_routing_table
                                            
                                            	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                            	**type**\:  bool
                                            
                                            .. attribute:: lsa_flood_required_post_fail_over
                                            
                                            	LSA flood required after FO
                                            	**type**\:  bool
                                            
                                            .. attribute:: lsa_length
                                            
                                            	Length of the LSA
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_sync_state
                                            
                                            	State of LSA sync with active
                                            	**type**\:   :py:class:`OspfLsaSyncStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncStateEnum>`
                                            
                                            .. attribute:: minute_table_index
                                            
                                            	Minute table index
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: nsr_flood_required
                                            
                                            	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                            	**type**\:  bool
                                            
                                            .. attribute:: rate_limit
                                            
                                            	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                            	**type**\:  bool
                                            
                                            .. attribute:: second_table_index
                                            
                                            	Second table index
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.free_time = None
                                                self.is_acknowledged = None
                                                self.is_advertising_router_reachable = None
                                                self.is_deleted = None
                                                self.is_flood_pending = None
                                                self.is_maximum_aged = None
                                                self.is_neighbor_exchange = None
                                                self.is_no_delete = None
                                                self.is_nsr_ack_pending = None
                                                self.is_partial_spf = None
                                                self.is_routing_bit = None
                                                self.is_routing_table = None
                                                self.lsa_flood_required_post_fail_over = None
                                                self.lsa_length = None
                                                self.lsa_sync_state = None
                                                self.minute_table_index = None
                                                self.nsr_flood_required = None
                                                self.rate_limit = None
                                                self.second_table_index = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-detail'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.free_time is not None:
                                                    return True

                                                if self.is_acknowledged is not None:
                                                    return True

                                                if self.is_advertising_router_reachable is not None:
                                                    return True

                                                if self.is_deleted is not None:
                                                    return True

                                                if self.is_flood_pending is not None:
                                                    return True

                                                if self.is_maximum_aged is not None:
                                                    return True

                                                if self.is_neighbor_exchange is not None:
                                                    return True

                                                if self.is_no_delete is not None:
                                                    return True

                                                if self.is_nsr_ack_pending is not None:
                                                    return True

                                                if self.is_partial_spf is not None:
                                                    return True

                                                if self.is_routing_bit is not None:
                                                    return True

                                                if self.is_routing_table is not None:
                                                    return True

                                                if self.lsa_flood_required_post_fail_over is not None:
                                                    return True

                                                if self.lsa_length is not None:
                                                    return True

                                                if self.lsa_sync_state is not None:
                                                    return True

                                                if self.minute_table_index is not None:
                                                    return True

                                                if self.nsr_flood_required is not None:
                                                    return True

                                                if self.rate_limit is not None:
                                                    return True

                                                if self.second_table_index is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo.LsaDetail']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-summary-info'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface_name is not None:
                                                return True

                                            if self.is_sham_link is not None:
                                                return True

                                            if self.is_virtual_link is not None:
                                                return True

                                            if self.links is not None:
                                                return True

                                            if self.lsa_detail is not None and self.lsa_detail._has_data():
                                                return True

                                            if self.lsa_header is not None and self.lsa_header._has_data():
                                                return True

                                            if self.lsa_router_id is not None:
                                                return True

                                            if self.prefix is not None:
                                                return True

                                            if self.prefix_length is not None:
                                                return True

                                            if self.reference_lsa_id is not None:
                                                return True

                                            if self.reference_type is not None:
                                                return True

                                            if self.router_la_bits is not None:
                                                return True

                                            if self.sham_link_id is not None:
                                                return True

                                            if self.virtual_link_id is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo']['meta_info']


                                    class RouterLsaType(object):
                                        """
                                        Router LSA
                                        
                                        .. attribute:: link
                                        
                                        	List of links in this LSA
                                        	**type**\: list of    :py:class:`Link <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.Link>`
                                        
                                        .. attribute:: lsa_detail
                                        
                                        	Detailed LSA information
                                        	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.LsaDetail>`
                                        
                                        .. attribute:: lsa_header
                                        
                                        	Header information 
                                        	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.LsaHeader>`
                                        
                                        .. attribute:: router_la_bits
                                        
                                        	Router LA bits 
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: rpf_path
                                        
                                        	Router LSA Reverse\-Path Forwarding information 
                                        	**type**\:   :py:class:`RpfPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.RpfPath>`
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.link = YList()
                                            self.link.parent = self
                                            self.link.name = 'link'
                                            self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.LsaDetail()
                                            self.lsa_detail.parent = self
                                            self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.LsaHeader()
                                            self.lsa_header.parent = self
                                            self.router_la_bits = None
                                            self.rpf_path = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.RpfPath()
                                            self.rpf_path.parent = self


                                        class LsaHeader(object):
                                            """
                                            Header information 
                                            
                                            .. attribute:: advertising_router
                                            
                                            	Router ID of Advertising Router
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: checksum
                                            
                                            	Checksum value
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: is_do_not_age_lsa
                                            
                                            	If true, Do Not Age this LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_graceful_restart_active
                                            
                                            	If true, if grace restart is active 
                                            	**type**\:  bool
                                            
                                            .. attribute:: ls_id
                                            
                                            	LS ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: lsa_age
                                            
                                            	LSA's Age (s)
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_area_id
                                            
                                            	Area ID in decimal or dotted\-decimal format
                                            	**type**\:  str
                                            
                                            	**length:** 0..16
                                            
                                            .. attribute:: lsa_type
                                            
                                            	LSA type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: sequence_number
                                            
                                            	Current Sequence number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.advertising_router = None
                                                self.checksum = None
                                                self.is_do_not_age_lsa = None
                                                self.is_graceful_restart_active = None
                                                self.ls_id = None
                                                self.lsa_age = None
                                                self.lsa_area_id = None
                                                self.lsa_type = None
                                                self.sequence_number = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-header'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.advertising_router is not None:
                                                    return True

                                                if self.checksum is not None:
                                                    return True

                                                if self.is_do_not_age_lsa is not None:
                                                    return True

                                                if self.is_graceful_restart_active is not None:
                                                    return True

                                                if self.ls_id is not None:
                                                    return True

                                                if self.lsa_age is not None:
                                                    return True

                                                if self.lsa_area_id is not None:
                                                    return True

                                                if self.lsa_type is not None:
                                                    return True

                                                if self.sequence_number is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.LsaHeader']['meta_info']


                                        class LsaDetail(object):
                                            """
                                            Detailed LSA information
                                            
                                            .. attribute:: free_time
                                            
                                            	The amount of time since the last check was made to free this LSA (s)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_acknowledged
                                            
                                            	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_advertising_router_reachable
                                            
                                            	If true, Advertising Router is reachable
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_deleted
                                            
                                            	If true, flag is set to delete this LSA 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_flood_pending
                                            
                                            	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_maximum_aged
                                            
                                            	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_neighbor_exchange
                                            
                                            	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_no_delete
                                            
                                            	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_nsr_ack_pending
                                            
                                            	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_partial_spf
                                            
                                            	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_routing_bit
                                            
                                            	If true, Routing Bit set on the LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_routing_table
                                            
                                            	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                            	**type**\:  bool
                                            
                                            .. attribute:: lsa_flood_required_post_fail_over
                                            
                                            	LSA flood required after FO
                                            	**type**\:  bool
                                            
                                            .. attribute:: lsa_length
                                            
                                            	Length of the LSA
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_sync_state
                                            
                                            	State of LSA sync with active
                                            	**type**\:   :py:class:`OspfLsaSyncStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncStateEnum>`
                                            
                                            .. attribute:: minute_table_index
                                            
                                            	Minute table index
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: nsr_flood_required
                                            
                                            	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                            	**type**\:  bool
                                            
                                            .. attribute:: rate_limit
                                            
                                            	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                            	**type**\:  bool
                                            
                                            .. attribute:: second_table_index
                                            
                                            	Second table index
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.free_time = None
                                                self.is_acknowledged = None
                                                self.is_advertising_router_reachable = None
                                                self.is_deleted = None
                                                self.is_flood_pending = None
                                                self.is_maximum_aged = None
                                                self.is_neighbor_exchange = None
                                                self.is_no_delete = None
                                                self.is_nsr_ack_pending = None
                                                self.is_partial_spf = None
                                                self.is_routing_bit = None
                                                self.is_routing_table = None
                                                self.lsa_flood_required_post_fail_over = None
                                                self.lsa_length = None
                                                self.lsa_sync_state = None
                                                self.minute_table_index = None
                                                self.nsr_flood_required = None
                                                self.rate_limit = None
                                                self.second_table_index = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-detail'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.free_time is not None:
                                                    return True

                                                if self.is_acknowledged is not None:
                                                    return True

                                                if self.is_advertising_router_reachable is not None:
                                                    return True

                                                if self.is_deleted is not None:
                                                    return True

                                                if self.is_flood_pending is not None:
                                                    return True

                                                if self.is_maximum_aged is not None:
                                                    return True

                                                if self.is_neighbor_exchange is not None:
                                                    return True

                                                if self.is_no_delete is not None:
                                                    return True

                                                if self.is_nsr_ack_pending is not None:
                                                    return True

                                                if self.is_partial_spf is not None:
                                                    return True

                                                if self.is_routing_bit is not None:
                                                    return True

                                                if self.is_routing_table is not None:
                                                    return True

                                                if self.lsa_flood_required_post_fail_over is not None:
                                                    return True

                                                if self.lsa_length is not None:
                                                    return True

                                                if self.lsa_sync_state is not None:
                                                    return True

                                                if self.minute_table_index is not None:
                                                    return True

                                                if self.nsr_flood_required is not None:
                                                    return True

                                                if self.rate_limit is not None:
                                                    return True

                                                if self.second_table_index is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.LsaDetail']['meta_info']


                                        class RpfPath(object):
                                            """
                                            Router LSA Reverse\-Path Forwarding information 
                                            
                                            .. attribute:: interface_name
                                            
                                            	RPF multicast IDB 
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                            
                                            .. attribute:: rpf_multicast_next_hop
                                            
                                            	RPF multicast next hop 
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface_name = None
                                                self.rpf_multicast_next_hop = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:rpf-path'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface_name is not None:
                                                    return True

                                                if self.rpf_multicast_next_hop is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.RpfPath']['meta_info']


                                        class Link(object):
                                            """
                                            List of links in this LSA
                                            
                                            .. attribute:: link_interface_id
                                            
                                            	LSA link interface ID 
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: link_metric
                                            
                                            	LSA link metric 
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: link_neighbor_interface_id
                                            
                                            	LSA link neighbor interface ID 
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: link_neighbor_router_id
                                            
                                            	LSA link neigbhor router id 
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: link_type
                                            
                                            	Type of link
                                            	**type**\:   :py:class:`Ospfv3LinkEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3LinkEnum>`
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.link_interface_id = None
                                                self.link_metric = None
                                                self.link_neighbor_interface_id = None
                                                self.link_neighbor_router_id = None
                                                self.link_type = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:link'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.link_interface_id is not None:
                                                    return True

                                                if self.link_metric is not None:
                                                    return True

                                                if self.link_neighbor_interface_id is not None:
                                                    return True

                                                if self.link_neighbor_router_id is not None:
                                                    return True

                                                if self.link_type is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.Link']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:router-lsa-type'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.link is not None:
                                                for child_ref in self.link:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.lsa_detail is not None and self.lsa_detail._has_data():
                                                return True

                                            if self.lsa_header is not None and self.lsa_header._has_data():
                                                return True

                                            if self.router_la_bits is not None:
                                                return True

                                            if self.rpf_path is not None and self.rpf_path._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType']['meta_info']


                                    class NetworkLsaType(object):
                                        """
                                        Network LSA
                                        
                                        .. attribute:: lsa_detail
                                        
                                        	Detailed LSA information
                                        	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType.LsaDetail>`
                                        
                                        .. attribute:: lsa_header
                                        
                                        	Header information 
                                        	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType.LsaHeader>`
                                        
                                        .. attribute:: neighbor_router
                                        
                                        	Neighbor router list
                                        	**type**\:  list of str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType.LsaDetail()
                                            self.lsa_detail.parent = self
                                            self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType.LsaHeader()
                                            self.lsa_header.parent = self
                                            self.neighbor_router = YLeafList()
                                            self.neighbor_router.parent = self
                                            self.neighbor_router.name = 'neighbor_router'


                                        class LsaHeader(object):
                                            """
                                            Header information 
                                            
                                            .. attribute:: advertising_router
                                            
                                            	Router ID of Advertising Router
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: checksum
                                            
                                            	Checksum value
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: is_do_not_age_lsa
                                            
                                            	If true, Do Not Age this LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_graceful_restart_active
                                            
                                            	If true, if grace restart is active 
                                            	**type**\:  bool
                                            
                                            .. attribute:: ls_id
                                            
                                            	LS ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: lsa_age
                                            
                                            	LSA's Age (s)
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_area_id
                                            
                                            	Area ID in decimal or dotted\-decimal format
                                            	**type**\:  str
                                            
                                            	**length:** 0..16
                                            
                                            .. attribute:: lsa_type
                                            
                                            	LSA type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: sequence_number
                                            
                                            	Current Sequence number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.advertising_router = None
                                                self.checksum = None
                                                self.is_do_not_age_lsa = None
                                                self.is_graceful_restart_active = None
                                                self.ls_id = None
                                                self.lsa_age = None
                                                self.lsa_area_id = None
                                                self.lsa_type = None
                                                self.sequence_number = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-header'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.advertising_router is not None:
                                                    return True

                                                if self.checksum is not None:
                                                    return True

                                                if self.is_do_not_age_lsa is not None:
                                                    return True

                                                if self.is_graceful_restart_active is not None:
                                                    return True

                                                if self.ls_id is not None:
                                                    return True

                                                if self.lsa_age is not None:
                                                    return True

                                                if self.lsa_area_id is not None:
                                                    return True

                                                if self.lsa_type is not None:
                                                    return True

                                                if self.sequence_number is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType.LsaHeader']['meta_info']


                                        class LsaDetail(object):
                                            """
                                            Detailed LSA information
                                            
                                            .. attribute:: free_time
                                            
                                            	The amount of time since the last check was made to free this LSA (s)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_acknowledged
                                            
                                            	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_advertising_router_reachable
                                            
                                            	If true, Advertising Router is reachable
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_deleted
                                            
                                            	If true, flag is set to delete this LSA 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_flood_pending
                                            
                                            	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_maximum_aged
                                            
                                            	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_neighbor_exchange
                                            
                                            	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_no_delete
                                            
                                            	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_nsr_ack_pending
                                            
                                            	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_partial_spf
                                            
                                            	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_routing_bit
                                            
                                            	If true, Routing Bit set on the LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_routing_table
                                            
                                            	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                            	**type**\:  bool
                                            
                                            .. attribute:: lsa_flood_required_post_fail_over
                                            
                                            	LSA flood required after FO
                                            	**type**\:  bool
                                            
                                            .. attribute:: lsa_length
                                            
                                            	Length of the LSA
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_sync_state
                                            
                                            	State of LSA sync with active
                                            	**type**\:   :py:class:`OspfLsaSyncStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncStateEnum>`
                                            
                                            .. attribute:: minute_table_index
                                            
                                            	Minute table index
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: nsr_flood_required
                                            
                                            	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                            	**type**\:  bool
                                            
                                            .. attribute:: rate_limit
                                            
                                            	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                            	**type**\:  bool
                                            
                                            .. attribute:: second_table_index
                                            
                                            	Second table index
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.free_time = None
                                                self.is_acknowledged = None
                                                self.is_advertising_router_reachable = None
                                                self.is_deleted = None
                                                self.is_flood_pending = None
                                                self.is_maximum_aged = None
                                                self.is_neighbor_exchange = None
                                                self.is_no_delete = None
                                                self.is_nsr_ack_pending = None
                                                self.is_partial_spf = None
                                                self.is_routing_bit = None
                                                self.is_routing_table = None
                                                self.lsa_flood_required_post_fail_over = None
                                                self.lsa_length = None
                                                self.lsa_sync_state = None
                                                self.minute_table_index = None
                                                self.nsr_flood_required = None
                                                self.rate_limit = None
                                                self.second_table_index = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-detail'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.free_time is not None:
                                                    return True

                                                if self.is_acknowledged is not None:
                                                    return True

                                                if self.is_advertising_router_reachable is not None:
                                                    return True

                                                if self.is_deleted is not None:
                                                    return True

                                                if self.is_flood_pending is not None:
                                                    return True

                                                if self.is_maximum_aged is not None:
                                                    return True

                                                if self.is_neighbor_exchange is not None:
                                                    return True

                                                if self.is_no_delete is not None:
                                                    return True

                                                if self.is_nsr_ack_pending is not None:
                                                    return True

                                                if self.is_partial_spf is not None:
                                                    return True

                                                if self.is_routing_bit is not None:
                                                    return True

                                                if self.is_routing_table is not None:
                                                    return True

                                                if self.lsa_flood_required_post_fail_over is not None:
                                                    return True

                                                if self.lsa_length is not None:
                                                    return True

                                                if self.lsa_sync_state is not None:
                                                    return True

                                                if self.minute_table_index is not None:
                                                    return True

                                                if self.nsr_flood_required is not None:
                                                    return True

                                                if self.rate_limit is not None:
                                                    return True

                                                if self.second_table_index is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType.LsaDetail']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:network-lsa-type'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.lsa_detail is not None and self.lsa_detail._has_data():
                                                return True

                                            if self.lsa_header is not None and self.lsa_header._has_data():
                                                return True

                                            if self.neighbor_router is not None:
                                                for child in self.neighbor_router:
                                                    if child is not None:
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType']['meta_info']


                                    class InterAreaPrefixLsaType(object):
                                        """
                                        Inter Area Prefix LSA
                                        
                                        .. attribute:: lsa_detail
                                        
                                        	Detailed LSA Information
                                        	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaDetail>`
                                        
                                        .. attribute:: lsa_header
                                        
                                        	Header information 
                                        	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaHeader>`
                                        
                                        .. attribute:: prefix
                                        
                                        	LSA address prefix 
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: prefix_length
                                        
                                        	Prefix length 
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: priority
                                        
                                        	Prefix priority
                                        	**type**\:   :py:class:`PrefixPriorityEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.PrefixPriorityEnum>`
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaDetail()
                                            self.lsa_detail.parent = self
                                            self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaHeader()
                                            self.lsa_header.parent = self
                                            self.prefix = None
                                            self.prefix_length = None
                                            self.priority = None


                                        class LsaHeader(object):
                                            """
                                            Header information 
                                            
                                            .. attribute:: advertising_router
                                            
                                            	Router ID of Advertising Router
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: checksum
                                            
                                            	Checksum value
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: is_do_not_age_lsa
                                            
                                            	If true, Do Not Age this LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_graceful_restart_active
                                            
                                            	If true, if grace restart is active 
                                            	**type**\:  bool
                                            
                                            .. attribute:: ls_id
                                            
                                            	LS ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: lsa_age
                                            
                                            	LSA's Age (s)
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_area_id
                                            
                                            	Area ID in decimal or dotted\-decimal format
                                            	**type**\:  str
                                            
                                            	**length:** 0..16
                                            
                                            .. attribute:: lsa_type
                                            
                                            	LSA type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: sequence_number
                                            
                                            	Current Sequence number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.advertising_router = None
                                                self.checksum = None
                                                self.is_do_not_age_lsa = None
                                                self.is_graceful_restart_active = None
                                                self.ls_id = None
                                                self.lsa_age = None
                                                self.lsa_area_id = None
                                                self.lsa_type = None
                                                self.sequence_number = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-header'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.advertising_router is not None:
                                                    return True

                                                if self.checksum is not None:
                                                    return True

                                                if self.is_do_not_age_lsa is not None:
                                                    return True

                                                if self.is_graceful_restart_active is not None:
                                                    return True

                                                if self.ls_id is not None:
                                                    return True

                                                if self.lsa_age is not None:
                                                    return True

                                                if self.lsa_area_id is not None:
                                                    return True

                                                if self.lsa_type is not None:
                                                    return True

                                                if self.sequence_number is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaHeader']['meta_info']


                                        class LsaDetail(object):
                                            """
                                            Detailed LSA Information
                                            
                                            .. attribute:: free_time
                                            
                                            	The amount of time since the last check was made to free this LSA (s)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_acknowledged
                                            
                                            	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_advertising_router_reachable
                                            
                                            	If true, Advertising Router is reachable
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_deleted
                                            
                                            	If true, flag is set to delete this LSA 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_flood_pending
                                            
                                            	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_maximum_aged
                                            
                                            	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_neighbor_exchange
                                            
                                            	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_no_delete
                                            
                                            	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_nsr_ack_pending
                                            
                                            	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_partial_spf
                                            
                                            	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_routing_bit
                                            
                                            	If true, Routing Bit set on the LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_routing_table
                                            
                                            	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                            	**type**\:  bool
                                            
                                            .. attribute:: lsa_flood_required_post_fail_over
                                            
                                            	LSA flood required after FO
                                            	**type**\:  bool
                                            
                                            .. attribute:: lsa_length
                                            
                                            	Length of the LSA
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_sync_state
                                            
                                            	State of LSA sync with active
                                            	**type**\:   :py:class:`OspfLsaSyncStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncStateEnum>`
                                            
                                            .. attribute:: minute_table_index
                                            
                                            	Minute table index
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: nsr_flood_required
                                            
                                            	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                            	**type**\:  bool
                                            
                                            .. attribute:: rate_limit
                                            
                                            	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                            	**type**\:  bool
                                            
                                            .. attribute:: second_table_index
                                            
                                            	Second table index
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.free_time = None
                                                self.is_acknowledged = None
                                                self.is_advertising_router_reachable = None
                                                self.is_deleted = None
                                                self.is_flood_pending = None
                                                self.is_maximum_aged = None
                                                self.is_neighbor_exchange = None
                                                self.is_no_delete = None
                                                self.is_nsr_ack_pending = None
                                                self.is_partial_spf = None
                                                self.is_routing_bit = None
                                                self.is_routing_table = None
                                                self.lsa_flood_required_post_fail_over = None
                                                self.lsa_length = None
                                                self.lsa_sync_state = None
                                                self.minute_table_index = None
                                                self.nsr_flood_required = None
                                                self.rate_limit = None
                                                self.second_table_index = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-detail'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.free_time is not None:
                                                    return True

                                                if self.is_acknowledged is not None:
                                                    return True

                                                if self.is_advertising_router_reachable is not None:
                                                    return True

                                                if self.is_deleted is not None:
                                                    return True

                                                if self.is_flood_pending is not None:
                                                    return True

                                                if self.is_maximum_aged is not None:
                                                    return True

                                                if self.is_neighbor_exchange is not None:
                                                    return True

                                                if self.is_no_delete is not None:
                                                    return True

                                                if self.is_nsr_ack_pending is not None:
                                                    return True

                                                if self.is_partial_spf is not None:
                                                    return True

                                                if self.is_routing_bit is not None:
                                                    return True

                                                if self.is_routing_table is not None:
                                                    return True

                                                if self.lsa_flood_required_post_fail_over is not None:
                                                    return True

                                                if self.lsa_length is not None:
                                                    return True

                                                if self.lsa_sync_state is not None:
                                                    return True

                                                if self.minute_table_index is not None:
                                                    return True

                                                if self.nsr_flood_required is not None:
                                                    return True

                                                if self.rate_limit is not None:
                                                    return True

                                                if self.second_table_index is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaDetail']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:inter-area-prefix-lsa-type'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.lsa_detail is not None and self.lsa_detail._has_data():
                                                return True

                                            if self.lsa_header is not None and self.lsa_header._has_data():
                                                return True

                                            if self.prefix is not None:
                                                return True

                                            if self.prefix_length is not None:
                                                return True

                                            if self.priority is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType']['meta_info']


                                    class InterAreaRouterLsaType(object):
                                        """
                                        Inter Area Router LSA
                                        
                                        .. attribute:: lsa_detail
                                        
                                        	Detailed LSA information
                                        	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaDetail>`
                                        
                                        .. attribute:: lsa_header
                                        
                                        	Header information 
                                        	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaHeader>`
                                        
                                        .. attribute:: lsa_router_id
                                        
                                        	LSA router ID 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaDetail()
                                            self.lsa_detail.parent = self
                                            self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaHeader()
                                            self.lsa_header.parent = self
                                            self.lsa_router_id = None


                                        class LsaHeader(object):
                                            """
                                            Header information 
                                            
                                            .. attribute:: advertising_router
                                            
                                            	Router ID of Advertising Router
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: checksum
                                            
                                            	Checksum value
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: is_do_not_age_lsa
                                            
                                            	If true, Do Not Age this LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_graceful_restart_active
                                            
                                            	If true, if grace restart is active 
                                            	**type**\:  bool
                                            
                                            .. attribute:: ls_id
                                            
                                            	LS ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: lsa_age
                                            
                                            	LSA's Age (s)
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_area_id
                                            
                                            	Area ID in decimal or dotted\-decimal format
                                            	**type**\:  str
                                            
                                            	**length:** 0..16
                                            
                                            .. attribute:: lsa_type
                                            
                                            	LSA type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: sequence_number
                                            
                                            	Current Sequence number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.advertising_router = None
                                                self.checksum = None
                                                self.is_do_not_age_lsa = None
                                                self.is_graceful_restart_active = None
                                                self.ls_id = None
                                                self.lsa_age = None
                                                self.lsa_area_id = None
                                                self.lsa_type = None
                                                self.sequence_number = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-header'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.advertising_router is not None:
                                                    return True

                                                if self.checksum is not None:
                                                    return True

                                                if self.is_do_not_age_lsa is not None:
                                                    return True

                                                if self.is_graceful_restart_active is not None:
                                                    return True

                                                if self.ls_id is not None:
                                                    return True

                                                if self.lsa_age is not None:
                                                    return True

                                                if self.lsa_area_id is not None:
                                                    return True

                                                if self.lsa_type is not None:
                                                    return True

                                                if self.sequence_number is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaHeader']['meta_info']


                                        class LsaDetail(object):
                                            """
                                            Detailed LSA information
                                            
                                            .. attribute:: free_time
                                            
                                            	The amount of time since the last check was made to free this LSA (s)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_acknowledged
                                            
                                            	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_advertising_router_reachable
                                            
                                            	If true, Advertising Router is reachable
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_deleted
                                            
                                            	If true, flag is set to delete this LSA 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_flood_pending
                                            
                                            	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_maximum_aged
                                            
                                            	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_neighbor_exchange
                                            
                                            	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_no_delete
                                            
                                            	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_nsr_ack_pending
                                            
                                            	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_partial_spf
                                            
                                            	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_routing_bit
                                            
                                            	If true, Routing Bit set on the LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_routing_table
                                            
                                            	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                            	**type**\:  bool
                                            
                                            .. attribute:: lsa_flood_required_post_fail_over
                                            
                                            	LSA flood required after FO
                                            	**type**\:  bool
                                            
                                            .. attribute:: lsa_length
                                            
                                            	Length of the LSA
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_sync_state
                                            
                                            	State of LSA sync with active
                                            	**type**\:   :py:class:`OspfLsaSyncStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncStateEnum>`
                                            
                                            .. attribute:: minute_table_index
                                            
                                            	Minute table index
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: nsr_flood_required
                                            
                                            	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                            	**type**\:  bool
                                            
                                            .. attribute:: rate_limit
                                            
                                            	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                            	**type**\:  bool
                                            
                                            .. attribute:: second_table_index
                                            
                                            	Second table index
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.free_time = None
                                                self.is_acknowledged = None
                                                self.is_advertising_router_reachable = None
                                                self.is_deleted = None
                                                self.is_flood_pending = None
                                                self.is_maximum_aged = None
                                                self.is_neighbor_exchange = None
                                                self.is_no_delete = None
                                                self.is_nsr_ack_pending = None
                                                self.is_partial_spf = None
                                                self.is_routing_bit = None
                                                self.is_routing_table = None
                                                self.lsa_flood_required_post_fail_over = None
                                                self.lsa_length = None
                                                self.lsa_sync_state = None
                                                self.minute_table_index = None
                                                self.nsr_flood_required = None
                                                self.rate_limit = None
                                                self.second_table_index = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-detail'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.free_time is not None:
                                                    return True

                                                if self.is_acknowledged is not None:
                                                    return True

                                                if self.is_advertising_router_reachable is not None:
                                                    return True

                                                if self.is_deleted is not None:
                                                    return True

                                                if self.is_flood_pending is not None:
                                                    return True

                                                if self.is_maximum_aged is not None:
                                                    return True

                                                if self.is_neighbor_exchange is not None:
                                                    return True

                                                if self.is_no_delete is not None:
                                                    return True

                                                if self.is_nsr_ack_pending is not None:
                                                    return True

                                                if self.is_partial_spf is not None:
                                                    return True

                                                if self.is_routing_bit is not None:
                                                    return True

                                                if self.is_routing_table is not None:
                                                    return True

                                                if self.lsa_flood_required_post_fail_over is not None:
                                                    return True

                                                if self.lsa_length is not None:
                                                    return True

                                                if self.lsa_sync_state is not None:
                                                    return True

                                                if self.minute_table_index is not None:
                                                    return True

                                                if self.nsr_flood_required is not None:
                                                    return True

                                                if self.rate_limit is not None:
                                                    return True

                                                if self.second_table_index is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaDetail']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:inter-area-router-lsa-type'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.lsa_detail is not None and self.lsa_detail._has_data():
                                                return True

                                            if self.lsa_header is not None and self.lsa_header._has_data():
                                                return True

                                            if self.lsa_router_id is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType']['meta_info']


                                    class ExternalLsaType(object):
                                        """
                                        External LSA
                                        
                                        .. attribute:: external_tag
                                        
                                        	Route Tag
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: forwarding_address
                                        
                                        	Forwarding Address
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: is_forwarding_address_set
                                        
                                        	If true, forwarding address is set 
                                        	**type**\:  bool
                                        
                                        .. attribute:: lsa_detail
                                        
                                        	Detailed LSA Information
                                        	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType.LsaDetail>`
                                        
                                        .. attribute:: lsa_header
                                        
                                        	Header information 
                                        	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType.LsaHeader>`
                                        
                                        .. attribute:: metric_type
                                        
                                        	Metric type 
                                        	**type**\:   :py:class:`Ospfv3DefaultMetricEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3DefaultMetricEnum>`
                                        
                                        .. attribute:: prefix
                                        
                                        	IPV6 address prefix 
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: prefix_length
                                        
                                        	Prefix length 
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: priority
                                        
                                        	Prefix priority
                                        	**type**\:   :py:class:`PrefixPriorityEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.PrefixPriorityEnum>`
                                        
                                        .. attribute:: tos_cost
                                        
                                        	Type of service cost metric 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.external_tag = None
                                            self.forwarding_address = None
                                            self.is_forwarding_address_set = None
                                            self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType.LsaDetail()
                                            self.lsa_detail.parent = self
                                            self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType.LsaHeader()
                                            self.lsa_header.parent = self
                                            self.metric_type = None
                                            self.prefix = None
                                            self.prefix_length = None
                                            self.priority = None
                                            self.tos_cost = None


                                        class LsaHeader(object):
                                            """
                                            Header information 
                                            
                                            .. attribute:: advertising_router
                                            
                                            	Router ID of Advertising Router
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: checksum
                                            
                                            	Checksum value
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: is_do_not_age_lsa
                                            
                                            	If true, Do Not Age this LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_graceful_restart_active
                                            
                                            	If true, if grace restart is active 
                                            	**type**\:  bool
                                            
                                            .. attribute:: ls_id
                                            
                                            	LS ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: lsa_age
                                            
                                            	LSA's Age (s)
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_area_id
                                            
                                            	Area ID in decimal or dotted\-decimal format
                                            	**type**\:  str
                                            
                                            	**length:** 0..16
                                            
                                            .. attribute:: lsa_type
                                            
                                            	LSA type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: sequence_number
                                            
                                            	Current Sequence number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.advertising_router = None
                                                self.checksum = None
                                                self.is_do_not_age_lsa = None
                                                self.is_graceful_restart_active = None
                                                self.ls_id = None
                                                self.lsa_age = None
                                                self.lsa_area_id = None
                                                self.lsa_type = None
                                                self.sequence_number = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-header'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.advertising_router is not None:
                                                    return True

                                                if self.checksum is not None:
                                                    return True

                                                if self.is_do_not_age_lsa is not None:
                                                    return True

                                                if self.is_graceful_restart_active is not None:
                                                    return True

                                                if self.ls_id is not None:
                                                    return True

                                                if self.lsa_age is not None:
                                                    return True

                                                if self.lsa_area_id is not None:
                                                    return True

                                                if self.lsa_type is not None:
                                                    return True

                                                if self.sequence_number is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType.LsaHeader']['meta_info']


                                        class LsaDetail(object):
                                            """
                                            Detailed LSA Information
                                            
                                            .. attribute:: free_time
                                            
                                            	The amount of time since the last check was made to free this LSA (s)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_acknowledged
                                            
                                            	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_advertising_router_reachable
                                            
                                            	If true, Advertising Router is reachable
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_deleted
                                            
                                            	If true, flag is set to delete this LSA 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_flood_pending
                                            
                                            	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_maximum_aged
                                            
                                            	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_neighbor_exchange
                                            
                                            	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_no_delete
                                            
                                            	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_nsr_ack_pending
                                            
                                            	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_partial_spf
                                            
                                            	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_routing_bit
                                            
                                            	If true, Routing Bit set on the LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_routing_table
                                            
                                            	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                            	**type**\:  bool
                                            
                                            .. attribute:: lsa_flood_required_post_fail_over
                                            
                                            	LSA flood required after FO
                                            	**type**\:  bool
                                            
                                            .. attribute:: lsa_length
                                            
                                            	Length of the LSA
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_sync_state
                                            
                                            	State of LSA sync with active
                                            	**type**\:   :py:class:`OspfLsaSyncStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncStateEnum>`
                                            
                                            .. attribute:: minute_table_index
                                            
                                            	Minute table index
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: nsr_flood_required
                                            
                                            	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                            	**type**\:  bool
                                            
                                            .. attribute:: rate_limit
                                            
                                            	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                            	**type**\:  bool
                                            
                                            .. attribute:: second_table_index
                                            
                                            	Second table index
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.free_time = None
                                                self.is_acknowledged = None
                                                self.is_advertising_router_reachable = None
                                                self.is_deleted = None
                                                self.is_flood_pending = None
                                                self.is_maximum_aged = None
                                                self.is_neighbor_exchange = None
                                                self.is_no_delete = None
                                                self.is_nsr_ack_pending = None
                                                self.is_partial_spf = None
                                                self.is_routing_bit = None
                                                self.is_routing_table = None
                                                self.lsa_flood_required_post_fail_over = None
                                                self.lsa_length = None
                                                self.lsa_sync_state = None
                                                self.minute_table_index = None
                                                self.nsr_flood_required = None
                                                self.rate_limit = None
                                                self.second_table_index = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-detail'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.free_time is not None:
                                                    return True

                                                if self.is_acknowledged is not None:
                                                    return True

                                                if self.is_advertising_router_reachable is not None:
                                                    return True

                                                if self.is_deleted is not None:
                                                    return True

                                                if self.is_flood_pending is not None:
                                                    return True

                                                if self.is_maximum_aged is not None:
                                                    return True

                                                if self.is_neighbor_exchange is not None:
                                                    return True

                                                if self.is_no_delete is not None:
                                                    return True

                                                if self.is_nsr_ack_pending is not None:
                                                    return True

                                                if self.is_partial_spf is not None:
                                                    return True

                                                if self.is_routing_bit is not None:
                                                    return True

                                                if self.is_routing_table is not None:
                                                    return True

                                                if self.lsa_flood_required_post_fail_over is not None:
                                                    return True

                                                if self.lsa_length is not None:
                                                    return True

                                                if self.lsa_sync_state is not None:
                                                    return True

                                                if self.minute_table_index is not None:
                                                    return True

                                                if self.nsr_flood_required is not None:
                                                    return True

                                                if self.rate_limit is not None:
                                                    return True

                                                if self.second_table_index is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType.LsaDetail']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:external-lsa-type'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.external_tag is not None:
                                                return True

                                            if self.forwarding_address is not None:
                                                return True

                                            if self.is_forwarding_address_set is not None:
                                                return True

                                            if self.lsa_detail is not None and self.lsa_detail._has_data():
                                                return True

                                            if self.lsa_header is not None and self.lsa_header._has_data():
                                                return True

                                            if self.metric_type is not None:
                                                return True

                                            if self.prefix is not None:
                                                return True

                                            if self.prefix_length is not None:
                                                return True

                                            if self.priority is not None:
                                                return True

                                            if self.tos_cost is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType']['meta_info']


                                    class NssalsaType(object):
                                        """
                                        NSSA External LSA
                                        
                                        .. attribute:: external_tag
                                        
                                        	Route Tag
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: forwarding_address
                                        
                                        	Forwarding Address
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: is_forwarding_address_set
                                        
                                        	If true, forwarding address is set 
                                        	**type**\:  bool
                                        
                                        .. attribute:: lsa_detail
                                        
                                        	Detailed LSA Information
                                        	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType.LsaDetail>`
                                        
                                        .. attribute:: lsa_header
                                        
                                        	Header information 
                                        	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType.LsaHeader>`
                                        
                                        .. attribute:: metric_type
                                        
                                        	Metric type 
                                        	**type**\:   :py:class:`Ospfv3DefaultMetricEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3DefaultMetricEnum>`
                                        
                                        .. attribute:: prefix
                                        
                                        	IPV6 address prefix 
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: prefix_length
                                        
                                        	Prefix length 
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: priority
                                        
                                        	Prefix priority
                                        	**type**\:   :py:class:`PrefixPriorityEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.PrefixPriorityEnum>`
                                        
                                        .. attribute:: tos_cost
                                        
                                        	Type of service cost metric 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.external_tag = None
                                            self.forwarding_address = None
                                            self.is_forwarding_address_set = None
                                            self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType.LsaDetail()
                                            self.lsa_detail.parent = self
                                            self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType.LsaHeader()
                                            self.lsa_header.parent = self
                                            self.metric_type = None
                                            self.prefix = None
                                            self.prefix_length = None
                                            self.priority = None
                                            self.tos_cost = None


                                        class LsaHeader(object):
                                            """
                                            Header information 
                                            
                                            .. attribute:: advertising_router
                                            
                                            	Router ID of Advertising Router
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: checksum
                                            
                                            	Checksum value
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: is_do_not_age_lsa
                                            
                                            	If true, Do Not Age this LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_graceful_restart_active
                                            
                                            	If true, if grace restart is active 
                                            	**type**\:  bool
                                            
                                            .. attribute:: ls_id
                                            
                                            	LS ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: lsa_age
                                            
                                            	LSA's Age (s)
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_area_id
                                            
                                            	Area ID in decimal or dotted\-decimal format
                                            	**type**\:  str
                                            
                                            	**length:** 0..16
                                            
                                            .. attribute:: lsa_type
                                            
                                            	LSA type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: sequence_number
                                            
                                            	Current Sequence number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.advertising_router = None
                                                self.checksum = None
                                                self.is_do_not_age_lsa = None
                                                self.is_graceful_restart_active = None
                                                self.ls_id = None
                                                self.lsa_age = None
                                                self.lsa_area_id = None
                                                self.lsa_type = None
                                                self.sequence_number = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-header'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.advertising_router is not None:
                                                    return True

                                                if self.checksum is not None:
                                                    return True

                                                if self.is_do_not_age_lsa is not None:
                                                    return True

                                                if self.is_graceful_restart_active is not None:
                                                    return True

                                                if self.ls_id is not None:
                                                    return True

                                                if self.lsa_age is not None:
                                                    return True

                                                if self.lsa_area_id is not None:
                                                    return True

                                                if self.lsa_type is not None:
                                                    return True

                                                if self.sequence_number is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType.LsaHeader']['meta_info']


                                        class LsaDetail(object):
                                            """
                                            Detailed LSA Information
                                            
                                            .. attribute:: free_time
                                            
                                            	The amount of time since the last check was made to free this LSA (s)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_acknowledged
                                            
                                            	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_advertising_router_reachable
                                            
                                            	If true, Advertising Router is reachable
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_deleted
                                            
                                            	If true, flag is set to delete this LSA 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_flood_pending
                                            
                                            	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_maximum_aged
                                            
                                            	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_neighbor_exchange
                                            
                                            	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_no_delete
                                            
                                            	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_nsr_ack_pending
                                            
                                            	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_partial_spf
                                            
                                            	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_routing_bit
                                            
                                            	If true, Routing Bit set on the LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_routing_table
                                            
                                            	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                            	**type**\:  bool
                                            
                                            .. attribute:: lsa_flood_required_post_fail_over
                                            
                                            	LSA flood required after FO
                                            	**type**\:  bool
                                            
                                            .. attribute:: lsa_length
                                            
                                            	Length of the LSA
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_sync_state
                                            
                                            	State of LSA sync with active
                                            	**type**\:   :py:class:`OspfLsaSyncStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncStateEnum>`
                                            
                                            .. attribute:: minute_table_index
                                            
                                            	Minute table index
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: nsr_flood_required
                                            
                                            	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                            	**type**\:  bool
                                            
                                            .. attribute:: rate_limit
                                            
                                            	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                            	**type**\:  bool
                                            
                                            .. attribute:: second_table_index
                                            
                                            	Second table index
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.free_time = None
                                                self.is_acknowledged = None
                                                self.is_advertising_router_reachable = None
                                                self.is_deleted = None
                                                self.is_flood_pending = None
                                                self.is_maximum_aged = None
                                                self.is_neighbor_exchange = None
                                                self.is_no_delete = None
                                                self.is_nsr_ack_pending = None
                                                self.is_partial_spf = None
                                                self.is_routing_bit = None
                                                self.is_routing_table = None
                                                self.lsa_flood_required_post_fail_over = None
                                                self.lsa_length = None
                                                self.lsa_sync_state = None
                                                self.minute_table_index = None
                                                self.nsr_flood_required = None
                                                self.rate_limit = None
                                                self.second_table_index = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-detail'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.free_time is not None:
                                                    return True

                                                if self.is_acknowledged is not None:
                                                    return True

                                                if self.is_advertising_router_reachable is not None:
                                                    return True

                                                if self.is_deleted is not None:
                                                    return True

                                                if self.is_flood_pending is not None:
                                                    return True

                                                if self.is_maximum_aged is not None:
                                                    return True

                                                if self.is_neighbor_exchange is not None:
                                                    return True

                                                if self.is_no_delete is not None:
                                                    return True

                                                if self.is_nsr_ack_pending is not None:
                                                    return True

                                                if self.is_partial_spf is not None:
                                                    return True

                                                if self.is_routing_bit is not None:
                                                    return True

                                                if self.is_routing_table is not None:
                                                    return True

                                                if self.lsa_flood_required_post_fail_over is not None:
                                                    return True

                                                if self.lsa_length is not None:
                                                    return True

                                                if self.lsa_sync_state is not None:
                                                    return True

                                                if self.minute_table_index is not None:
                                                    return True

                                                if self.nsr_flood_required is not None:
                                                    return True

                                                if self.rate_limit is not None:
                                                    return True

                                                if self.second_table_index is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType.LsaDetail']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:nssalsa-type'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.external_tag is not None:
                                                return True

                                            if self.forwarding_address is not None:
                                                return True

                                            if self.is_forwarding_address_set is not None:
                                                return True

                                            if self.lsa_detail is not None and self.lsa_detail._has_data():
                                                return True

                                            if self.lsa_header is not None and self.lsa_header._has_data():
                                                return True

                                            if self.metric_type is not None:
                                                return True

                                            if self.prefix is not None:
                                                return True

                                            if self.prefix_length is not None:
                                                return True

                                            if self.priority is not None:
                                                return True

                                            if self.tos_cost is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType']['meta_info']


                                    class LinkLsaType(object):
                                        """
                                        Link LSA
                                        
                                        .. attribute:: interface_name
                                        
                                        	LSA interface handle
                                        	**type**\:  str
                                        
                                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                        
                                        .. attribute:: is_sham_link
                                        
                                        	If true, it is a sham link
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_virtual_link
                                        
                                        	If true, it is a virtual link
                                        	**type**\:  bool
                                        
                                        .. attribute:: lsa_detail
                                        
                                        	Detailed LSA information
                                        	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType.LsaDetail>`
                                        
                                        .. attribute:: lsa_header
                                        
                                        	Header information 
                                        	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType.LsaHeader>`
                                        
                                        .. attribute:: lsa_link_local
                                        
                                        	LSA link local 
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: prefix
                                        
                                        	OSPFv3 prefix 
                                        	**type**\: list of    :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType.Prefix>`
                                        
                                        .. attribute:: router_priority
                                        
                                        	Router priority 
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: sham_link_id
                                        
                                        	Sham link ID 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: virtual_link_id
                                        
                                        	Virtual link ID 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface_name = None
                                            self.is_sham_link = None
                                            self.is_virtual_link = None
                                            self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType.LsaDetail()
                                            self.lsa_detail.parent = self
                                            self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType.LsaHeader()
                                            self.lsa_header.parent = self
                                            self.lsa_link_local = None
                                            self.prefix = YList()
                                            self.prefix.parent = self
                                            self.prefix.name = 'prefix'
                                            self.router_priority = None
                                            self.sham_link_id = None
                                            self.virtual_link_id = None


                                        class LsaHeader(object):
                                            """
                                            Header information 
                                            
                                            .. attribute:: advertising_router
                                            
                                            	Router ID of Advertising Router
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: checksum
                                            
                                            	Checksum value
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: is_do_not_age_lsa
                                            
                                            	If true, Do Not Age this LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_graceful_restart_active
                                            
                                            	If true, if grace restart is active 
                                            	**type**\:  bool
                                            
                                            .. attribute:: ls_id
                                            
                                            	LS ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: lsa_age
                                            
                                            	LSA's Age (s)
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_area_id
                                            
                                            	Area ID in decimal or dotted\-decimal format
                                            	**type**\:  str
                                            
                                            	**length:** 0..16
                                            
                                            .. attribute:: lsa_type
                                            
                                            	LSA type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: sequence_number
                                            
                                            	Current Sequence number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.advertising_router = None
                                                self.checksum = None
                                                self.is_do_not_age_lsa = None
                                                self.is_graceful_restart_active = None
                                                self.ls_id = None
                                                self.lsa_age = None
                                                self.lsa_area_id = None
                                                self.lsa_type = None
                                                self.sequence_number = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-header'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.advertising_router is not None:
                                                    return True

                                                if self.checksum is not None:
                                                    return True

                                                if self.is_do_not_age_lsa is not None:
                                                    return True

                                                if self.is_graceful_restart_active is not None:
                                                    return True

                                                if self.ls_id is not None:
                                                    return True

                                                if self.lsa_age is not None:
                                                    return True

                                                if self.lsa_area_id is not None:
                                                    return True

                                                if self.lsa_type is not None:
                                                    return True

                                                if self.sequence_number is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType.LsaHeader']['meta_info']


                                        class LsaDetail(object):
                                            """
                                            Detailed LSA information
                                            
                                            .. attribute:: free_time
                                            
                                            	The amount of time since the last check was made to free this LSA (s)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_acknowledged
                                            
                                            	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_advertising_router_reachable
                                            
                                            	If true, Advertising Router is reachable
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_deleted
                                            
                                            	If true, flag is set to delete this LSA 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_flood_pending
                                            
                                            	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_maximum_aged
                                            
                                            	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_neighbor_exchange
                                            
                                            	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_no_delete
                                            
                                            	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_nsr_ack_pending
                                            
                                            	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_partial_spf
                                            
                                            	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_routing_bit
                                            
                                            	If true, Routing Bit set on the LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_routing_table
                                            
                                            	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                            	**type**\:  bool
                                            
                                            .. attribute:: lsa_flood_required_post_fail_over
                                            
                                            	LSA flood required after FO
                                            	**type**\:  bool
                                            
                                            .. attribute:: lsa_length
                                            
                                            	Length of the LSA
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_sync_state
                                            
                                            	State of LSA sync with active
                                            	**type**\:   :py:class:`OspfLsaSyncStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncStateEnum>`
                                            
                                            .. attribute:: minute_table_index
                                            
                                            	Minute table index
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: nsr_flood_required
                                            
                                            	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                            	**type**\:  bool
                                            
                                            .. attribute:: rate_limit
                                            
                                            	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                            	**type**\:  bool
                                            
                                            .. attribute:: second_table_index
                                            
                                            	Second table index
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.free_time = None
                                                self.is_acknowledged = None
                                                self.is_advertising_router_reachable = None
                                                self.is_deleted = None
                                                self.is_flood_pending = None
                                                self.is_maximum_aged = None
                                                self.is_neighbor_exchange = None
                                                self.is_no_delete = None
                                                self.is_nsr_ack_pending = None
                                                self.is_partial_spf = None
                                                self.is_routing_bit = None
                                                self.is_routing_table = None
                                                self.lsa_flood_required_post_fail_over = None
                                                self.lsa_length = None
                                                self.lsa_sync_state = None
                                                self.minute_table_index = None
                                                self.nsr_flood_required = None
                                                self.rate_limit = None
                                                self.second_table_index = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-detail'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.free_time is not None:
                                                    return True

                                                if self.is_acknowledged is not None:
                                                    return True

                                                if self.is_advertising_router_reachable is not None:
                                                    return True

                                                if self.is_deleted is not None:
                                                    return True

                                                if self.is_flood_pending is not None:
                                                    return True

                                                if self.is_maximum_aged is not None:
                                                    return True

                                                if self.is_neighbor_exchange is not None:
                                                    return True

                                                if self.is_no_delete is not None:
                                                    return True

                                                if self.is_nsr_ack_pending is not None:
                                                    return True

                                                if self.is_partial_spf is not None:
                                                    return True

                                                if self.is_routing_bit is not None:
                                                    return True

                                                if self.is_routing_table is not None:
                                                    return True

                                                if self.lsa_flood_required_post_fail_over is not None:
                                                    return True

                                                if self.lsa_length is not None:
                                                    return True

                                                if self.lsa_sync_state is not None:
                                                    return True

                                                if self.minute_table_index is not None:
                                                    return True

                                                if self.nsr_flood_required is not None:
                                                    return True

                                                if self.rate_limit is not None:
                                                    return True

                                                if self.second_table_index is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType.LsaDetail']['meta_info']


                                        class Prefix(object):
                                            """
                                            OSPFv3 prefix 
                                            
                                            .. attribute:: ospfv3_prefix_length
                                            
                                            	OSPFv3 prefix length 
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ospfv3_prefix_metric
                                            
                                            	OSPFv3 prefix metric 
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: ospfv3_prefix_options
                                            
                                            	OSPFv3 prefix options 
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: prefix
                                            
                                            	OSPFv3 prefix 
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: priority
                                            
                                            	Prefix priority
                                            	**type**\:   :py:class:`PrefixPriorityEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.PrefixPriorityEnum>`
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.ospfv3_prefix_length = None
                                                self.ospfv3_prefix_metric = None
                                                self.ospfv3_prefix_options = None
                                                self.prefix = None
                                                self.priority = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:prefix'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.ospfv3_prefix_length is not None:
                                                    return True

                                                if self.ospfv3_prefix_metric is not None:
                                                    return True

                                                if self.ospfv3_prefix_options is not None:
                                                    return True

                                                if self.prefix is not None:
                                                    return True

                                                if self.priority is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType.Prefix']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:link-lsa-type'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface_name is not None:
                                                return True

                                            if self.is_sham_link is not None:
                                                return True

                                            if self.is_virtual_link is not None:
                                                return True

                                            if self.lsa_detail is not None and self.lsa_detail._has_data():
                                                return True

                                            if self.lsa_header is not None and self.lsa_header._has_data():
                                                return True

                                            if self.lsa_link_local is not None:
                                                return True

                                            if self.prefix is not None:
                                                for child_ref in self.prefix:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.router_priority is not None:
                                                return True

                                            if self.sham_link_id is not None:
                                                return True

                                            if self.virtual_link_id is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType']['meta_info']


                                    class IntraAreaPrefixLsaType(object):
                                        """
                                        Intra Area Prefix LSA
                                        
                                        .. attribute:: lsa_detail
                                        
                                        	Detailed LSA information
                                        	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaDetail>`
                                        
                                        .. attribute:: lsa_header
                                        
                                        	Header information 
                                        	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaHeader>`
                                        
                                        .. attribute:: prefix
                                        
                                        	OSPFv3 prefix 
                                        	**type**\: list of    :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.Prefix>`
                                        
                                        .. attribute:: reference_advertised_router
                                        
                                        	Reference advertised router 
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: reference_lsa_id
                                        
                                        	Reference LSA ID 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: reference_type
                                        
                                        	Reference type 
                                        	**type**\:   :py:class:`Ospfv3Lsa1Enum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Lsa1Enum>`
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaDetail()
                                            self.lsa_detail.parent = self
                                            self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaHeader()
                                            self.lsa_header.parent = self
                                            self.prefix = YList()
                                            self.prefix.parent = self
                                            self.prefix.name = 'prefix'
                                            self.reference_advertised_router = None
                                            self.reference_lsa_id = None
                                            self.reference_type = None


                                        class LsaHeader(object):
                                            """
                                            Header information 
                                            
                                            .. attribute:: advertising_router
                                            
                                            	Router ID of Advertising Router
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: checksum
                                            
                                            	Checksum value
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: is_do_not_age_lsa
                                            
                                            	If true, Do Not Age this LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_graceful_restart_active
                                            
                                            	If true, if grace restart is active 
                                            	**type**\:  bool
                                            
                                            .. attribute:: ls_id
                                            
                                            	LS ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: lsa_age
                                            
                                            	LSA's Age (s)
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_area_id
                                            
                                            	Area ID in decimal or dotted\-decimal format
                                            	**type**\:  str
                                            
                                            	**length:** 0..16
                                            
                                            .. attribute:: lsa_type
                                            
                                            	LSA type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: sequence_number
                                            
                                            	Current Sequence number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.advertising_router = None
                                                self.checksum = None
                                                self.is_do_not_age_lsa = None
                                                self.is_graceful_restart_active = None
                                                self.ls_id = None
                                                self.lsa_age = None
                                                self.lsa_area_id = None
                                                self.lsa_type = None
                                                self.sequence_number = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-header'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.advertising_router is not None:
                                                    return True

                                                if self.checksum is not None:
                                                    return True

                                                if self.is_do_not_age_lsa is not None:
                                                    return True

                                                if self.is_graceful_restart_active is not None:
                                                    return True

                                                if self.ls_id is not None:
                                                    return True

                                                if self.lsa_age is not None:
                                                    return True

                                                if self.lsa_area_id is not None:
                                                    return True

                                                if self.lsa_type is not None:
                                                    return True

                                                if self.sequence_number is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaHeader']['meta_info']


                                        class LsaDetail(object):
                                            """
                                            Detailed LSA information
                                            
                                            .. attribute:: free_time
                                            
                                            	The amount of time since the last check was made to free this LSA (s)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_acknowledged
                                            
                                            	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_advertising_router_reachable
                                            
                                            	If true, Advertising Router is reachable
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_deleted
                                            
                                            	If true, flag is set to delete this LSA 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_flood_pending
                                            
                                            	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_maximum_aged
                                            
                                            	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_neighbor_exchange
                                            
                                            	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_no_delete
                                            
                                            	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_nsr_ack_pending
                                            
                                            	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_partial_spf
                                            
                                            	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_routing_bit
                                            
                                            	If true, Routing Bit set on the LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_routing_table
                                            
                                            	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                            	**type**\:  bool
                                            
                                            .. attribute:: lsa_flood_required_post_fail_over
                                            
                                            	LSA flood required after FO
                                            	**type**\:  bool
                                            
                                            .. attribute:: lsa_length
                                            
                                            	Length of the LSA
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_sync_state
                                            
                                            	State of LSA sync with active
                                            	**type**\:   :py:class:`OspfLsaSyncStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncStateEnum>`
                                            
                                            .. attribute:: minute_table_index
                                            
                                            	Minute table index
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: nsr_flood_required
                                            
                                            	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                            	**type**\:  bool
                                            
                                            .. attribute:: rate_limit
                                            
                                            	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                            	**type**\:  bool
                                            
                                            .. attribute:: second_table_index
                                            
                                            	Second table index
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.free_time = None
                                                self.is_acknowledged = None
                                                self.is_advertising_router_reachable = None
                                                self.is_deleted = None
                                                self.is_flood_pending = None
                                                self.is_maximum_aged = None
                                                self.is_neighbor_exchange = None
                                                self.is_no_delete = None
                                                self.is_nsr_ack_pending = None
                                                self.is_partial_spf = None
                                                self.is_routing_bit = None
                                                self.is_routing_table = None
                                                self.lsa_flood_required_post_fail_over = None
                                                self.lsa_length = None
                                                self.lsa_sync_state = None
                                                self.minute_table_index = None
                                                self.nsr_flood_required = None
                                                self.rate_limit = None
                                                self.second_table_index = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-detail'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.free_time is not None:
                                                    return True

                                                if self.is_acknowledged is not None:
                                                    return True

                                                if self.is_advertising_router_reachable is not None:
                                                    return True

                                                if self.is_deleted is not None:
                                                    return True

                                                if self.is_flood_pending is not None:
                                                    return True

                                                if self.is_maximum_aged is not None:
                                                    return True

                                                if self.is_neighbor_exchange is not None:
                                                    return True

                                                if self.is_no_delete is not None:
                                                    return True

                                                if self.is_nsr_ack_pending is not None:
                                                    return True

                                                if self.is_partial_spf is not None:
                                                    return True

                                                if self.is_routing_bit is not None:
                                                    return True

                                                if self.is_routing_table is not None:
                                                    return True

                                                if self.lsa_flood_required_post_fail_over is not None:
                                                    return True

                                                if self.lsa_length is not None:
                                                    return True

                                                if self.lsa_sync_state is not None:
                                                    return True

                                                if self.minute_table_index is not None:
                                                    return True

                                                if self.nsr_flood_required is not None:
                                                    return True

                                                if self.rate_limit is not None:
                                                    return True

                                                if self.second_table_index is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaDetail']['meta_info']


                                        class Prefix(object):
                                            """
                                            OSPFv3 prefix 
                                            
                                            .. attribute:: ospfv3_prefix_length
                                            
                                            	OSPFv3 prefix length 
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ospfv3_prefix_metric
                                            
                                            	OSPFv3 prefix metric 
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: ospfv3_prefix_options
                                            
                                            	OSPFv3 prefix options 
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: prefix
                                            
                                            	OSPFv3 prefix 
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: priority
                                            
                                            	Prefix priority
                                            	**type**\:   :py:class:`PrefixPriorityEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.PrefixPriorityEnum>`
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.ospfv3_prefix_length = None
                                                self.ospfv3_prefix_metric = None
                                                self.ospfv3_prefix_options = None
                                                self.prefix = None
                                                self.priority = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:prefix'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.ospfv3_prefix_length is not None:
                                                    return True

                                                if self.ospfv3_prefix_metric is not None:
                                                    return True

                                                if self.ospfv3_prefix_options is not None:
                                                    return True

                                                if self.prefix is not None:
                                                    return True

                                                if self.priority is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.Prefix']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:intra-area-prefix-lsa-type'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.lsa_detail is not None and self.lsa_detail._has_data():
                                                return True

                                            if self.lsa_header is not None and self.lsa_header._has_data():
                                                return True

                                            if self.prefix is not None:
                                                for child_ref in self.prefix:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.reference_advertised_router is not None:
                                                return True

                                            if self.reference_lsa_id is not None:
                                                return True

                                            if self.reference_type is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType']['meta_info']


                                    class GraceLsa(object):
                                        """
                                        Grace LSA
                                        
                                        .. attribute:: grace_period
                                        
                                        	The grace periord where helper routers should wait before advertising it fully adjacent(s) 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: grace_reason
                                        
                                        	Reason for router restart
                                        	**type**\:   :py:class:`Ospfv3GracefulRestartReasonEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3GracefulRestartReasonEnum>`
                                        
                                        .. attribute:: lsa_detail
                                        
                                        	Detailed LSA information
                                        	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa.LsaDetail>`
                                        
                                        .. attribute:: lsa_header
                                        
                                        	Header information 
                                        	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa.LsaHeader>`
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.grace_period = None
                                            self.grace_reason = None
                                            self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa.LsaDetail()
                                            self.lsa_detail.parent = self
                                            self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa.LsaHeader()
                                            self.lsa_header.parent = self


                                        class LsaHeader(object):
                                            """
                                            Header information 
                                            
                                            .. attribute:: advertising_router
                                            
                                            	Router ID of Advertising Router
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: checksum
                                            
                                            	Checksum value
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: is_do_not_age_lsa
                                            
                                            	If true, Do Not Age this LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_graceful_restart_active
                                            
                                            	If true, if grace restart is active 
                                            	**type**\:  bool
                                            
                                            .. attribute:: ls_id
                                            
                                            	LS ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: lsa_age
                                            
                                            	LSA's Age (s)
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_area_id
                                            
                                            	Area ID in decimal or dotted\-decimal format
                                            	**type**\:  str
                                            
                                            	**length:** 0..16
                                            
                                            .. attribute:: lsa_type
                                            
                                            	LSA type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: sequence_number
                                            
                                            	Current Sequence number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.advertising_router = None
                                                self.checksum = None
                                                self.is_do_not_age_lsa = None
                                                self.is_graceful_restart_active = None
                                                self.ls_id = None
                                                self.lsa_age = None
                                                self.lsa_area_id = None
                                                self.lsa_type = None
                                                self.sequence_number = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-header'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.advertising_router is not None:
                                                    return True

                                                if self.checksum is not None:
                                                    return True

                                                if self.is_do_not_age_lsa is not None:
                                                    return True

                                                if self.is_graceful_restart_active is not None:
                                                    return True

                                                if self.ls_id is not None:
                                                    return True

                                                if self.lsa_age is not None:
                                                    return True

                                                if self.lsa_area_id is not None:
                                                    return True

                                                if self.lsa_type is not None:
                                                    return True

                                                if self.sequence_number is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa.LsaHeader']['meta_info']


                                        class LsaDetail(object):
                                            """
                                            Detailed LSA information
                                            
                                            .. attribute:: free_time
                                            
                                            	The amount of time since the last check was made to free this LSA (s)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_acknowledged
                                            
                                            	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_advertising_router_reachable
                                            
                                            	If true, Advertising Router is reachable
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_deleted
                                            
                                            	If true, flag is set to delete this LSA 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_flood_pending
                                            
                                            	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_maximum_aged
                                            
                                            	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_neighbor_exchange
                                            
                                            	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_no_delete
                                            
                                            	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_nsr_ack_pending
                                            
                                            	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_partial_spf
                                            
                                            	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_routing_bit
                                            
                                            	If true, Routing Bit set on the LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_routing_table
                                            
                                            	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                            	**type**\:  bool
                                            
                                            .. attribute:: lsa_flood_required_post_fail_over
                                            
                                            	LSA flood required after FO
                                            	**type**\:  bool
                                            
                                            .. attribute:: lsa_length
                                            
                                            	Length of the LSA
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_sync_state
                                            
                                            	State of LSA sync with active
                                            	**type**\:   :py:class:`OspfLsaSyncStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncStateEnum>`
                                            
                                            .. attribute:: minute_table_index
                                            
                                            	Minute table index
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: nsr_flood_required
                                            
                                            	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                            	**type**\:  bool
                                            
                                            .. attribute:: rate_limit
                                            
                                            	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                            	**type**\:  bool
                                            
                                            .. attribute:: second_table_index
                                            
                                            	Second table index
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.free_time = None
                                                self.is_acknowledged = None
                                                self.is_advertising_router_reachable = None
                                                self.is_deleted = None
                                                self.is_flood_pending = None
                                                self.is_maximum_aged = None
                                                self.is_neighbor_exchange = None
                                                self.is_no_delete = None
                                                self.is_nsr_ack_pending = None
                                                self.is_partial_spf = None
                                                self.is_routing_bit = None
                                                self.is_routing_table = None
                                                self.lsa_flood_required_post_fail_over = None
                                                self.lsa_length = None
                                                self.lsa_sync_state = None
                                                self.minute_table_index = None
                                                self.nsr_flood_required = None
                                                self.rate_limit = None
                                                self.second_table_index = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-detail'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.free_time is not None:
                                                    return True

                                                if self.is_acknowledged is not None:
                                                    return True

                                                if self.is_advertising_router_reachable is not None:
                                                    return True

                                                if self.is_deleted is not None:
                                                    return True

                                                if self.is_flood_pending is not None:
                                                    return True

                                                if self.is_maximum_aged is not None:
                                                    return True

                                                if self.is_neighbor_exchange is not None:
                                                    return True

                                                if self.is_no_delete is not None:
                                                    return True

                                                if self.is_nsr_ack_pending is not None:
                                                    return True

                                                if self.is_partial_spf is not None:
                                                    return True

                                                if self.is_routing_bit is not None:
                                                    return True

                                                if self.is_routing_table is not None:
                                                    return True

                                                if self.lsa_flood_required_post_fail_over is not None:
                                                    return True

                                                if self.lsa_length is not None:
                                                    return True

                                                if self.lsa_sync_state is not None:
                                                    return True

                                                if self.minute_table_index is not None:
                                                    return True

                                                if self.nsr_flood_required is not None:
                                                    return True

                                                if self.rate_limit is not None:
                                                    return True

                                                if self.second_table_index is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa.LsaDetail']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:grace-lsa'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.grace_period is not None:
                                                return True

                                            if self.grace_reason is not None:
                                                return True

                                            if self.lsa_detail is not None and self.lsa_detail._has_data():
                                                return True

                                            if self.lsa_header is not None and self.lsa_header._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa']['meta_info']


                                    class UnknownLinkLsaType(object):
                                        """
                                        Unknown Link Scope LSA
                                        
                                        .. attribute:: interface_name
                                        
                                        	LSA interface name 
                                        	**type**\:  str
                                        
                                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                        
                                        .. attribute:: is_sham_link
                                        
                                        	If true, it is a sham link 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_virtual_link
                                        
                                        	If true, it is a virtual link 
                                        	**type**\:  bool
                                        
                                        .. attribute:: lsa_detail
                                        
                                        	Detailed LSA information
                                        	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaDetail>`
                                        
                                        .. attribute:: lsa_header
                                        
                                        	Header information 
                                        	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaHeader>`
                                        
                                        .. attribute:: sham_link_id
                                        
                                        	Shamlink ID 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: virtual_link_id
                                        
                                        	Virtual link ID 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface_name = None
                                            self.is_sham_link = None
                                            self.is_virtual_link = None
                                            self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaDetail()
                                            self.lsa_detail.parent = self
                                            self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaHeader()
                                            self.lsa_header.parent = self
                                            self.sham_link_id = None
                                            self.virtual_link_id = None


                                        class LsaHeader(object):
                                            """
                                            Header information 
                                            
                                            .. attribute:: advertising_router
                                            
                                            	Router ID of Advertising Router
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: checksum
                                            
                                            	Checksum value
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: is_do_not_age_lsa
                                            
                                            	If true, Do Not Age this LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_graceful_restart_active
                                            
                                            	If true, if grace restart is active 
                                            	**type**\:  bool
                                            
                                            .. attribute:: ls_id
                                            
                                            	LS ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: lsa_age
                                            
                                            	LSA's Age (s)
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_area_id
                                            
                                            	Area ID in decimal or dotted\-decimal format
                                            	**type**\:  str
                                            
                                            	**length:** 0..16
                                            
                                            .. attribute:: lsa_type
                                            
                                            	LSA type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: sequence_number
                                            
                                            	Current Sequence number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.advertising_router = None
                                                self.checksum = None
                                                self.is_do_not_age_lsa = None
                                                self.is_graceful_restart_active = None
                                                self.ls_id = None
                                                self.lsa_age = None
                                                self.lsa_area_id = None
                                                self.lsa_type = None
                                                self.sequence_number = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-header'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.advertising_router is not None:
                                                    return True

                                                if self.checksum is not None:
                                                    return True

                                                if self.is_do_not_age_lsa is not None:
                                                    return True

                                                if self.is_graceful_restart_active is not None:
                                                    return True

                                                if self.ls_id is not None:
                                                    return True

                                                if self.lsa_age is not None:
                                                    return True

                                                if self.lsa_area_id is not None:
                                                    return True

                                                if self.lsa_type is not None:
                                                    return True

                                                if self.sequence_number is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaHeader']['meta_info']


                                        class LsaDetail(object):
                                            """
                                            Detailed LSA information
                                            
                                            .. attribute:: free_time
                                            
                                            	The amount of time since the last check was made to free this LSA (s)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_acknowledged
                                            
                                            	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_advertising_router_reachable
                                            
                                            	If true, Advertising Router is reachable
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_deleted
                                            
                                            	If true, flag is set to delete this LSA 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_flood_pending
                                            
                                            	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_maximum_aged
                                            
                                            	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_neighbor_exchange
                                            
                                            	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_no_delete
                                            
                                            	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_nsr_ack_pending
                                            
                                            	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_partial_spf
                                            
                                            	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_routing_bit
                                            
                                            	If true, Routing Bit set on the LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_routing_table
                                            
                                            	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                            	**type**\:  bool
                                            
                                            .. attribute:: lsa_flood_required_post_fail_over
                                            
                                            	LSA flood required after FO
                                            	**type**\:  bool
                                            
                                            .. attribute:: lsa_length
                                            
                                            	Length of the LSA
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_sync_state
                                            
                                            	State of LSA sync with active
                                            	**type**\:   :py:class:`OspfLsaSyncStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncStateEnum>`
                                            
                                            .. attribute:: minute_table_index
                                            
                                            	Minute table index
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: nsr_flood_required
                                            
                                            	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                            	**type**\:  bool
                                            
                                            .. attribute:: rate_limit
                                            
                                            	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                            	**type**\:  bool
                                            
                                            .. attribute:: second_table_index
                                            
                                            	Second table index
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.free_time = None
                                                self.is_acknowledged = None
                                                self.is_advertising_router_reachable = None
                                                self.is_deleted = None
                                                self.is_flood_pending = None
                                                self.is_maximum_aged = None
                                                self.is_neighbor_exchange = None
                                                self.is_no_delete = None
                                                self.is_nsr_ack_pending = None
                                                self.is_partial_spf = None
                                                self.is_routing_bit = None
                                                self.is_routing_table = None
                                                self.lsa_flood_required_post_fail_over = None
                                                self.lsa_length = None
                                                self.lsa_sync_state = None
                                                self.minute_table_index = None
                                                self.nsr_flood_required = None
                                                self.rate_limit = None
                                                self.second_table_index = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-detail'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.free_time is not None:
                                                    return True

                                                if self.is_acknowledged is not None:
                                                    return True

                                                if self.is_advertising_router_reachable is not None:
                                                    return True

                                                if self.is_deleted is not None:
                                                    return True

                                                if self.is_flood_pending is not None:
                                                    return True

                                                if self.is_maximum_aged is not None:
                                                    return True

                                                if self.is_neighbor_exchange is not None:
                                                    return True

                                                if self.is_no_delete is not None:
                                                    return True

                                                if self.is_nsr_ack_pending is not None:
                                                    return True

                                                if self.is_partial_spf is not None:
                                                    return True

                                                if self.is_routing_bit is not None:
                                                    return True

                                                if self.is_routing_table is not None:
                                                    return True

                                                if self.lsa_flood_required_post_fail_over is not None:
                                                    return True

                                                if self.lsa_length is not None:
                                                    return True

                                                if self.lsa_sync_state is not None:
                                                    return True

                                                if self.minute_table_index is not None:
                                                    return True

                                                if self.nsr_flood_required is not None:
                                                    return True

                                                if self.rate_limit is not None:
                                                    return True

                                                if self.second_table_index is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaDetail']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:unknown-link-lsa-type'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface_name is not None:
                                                return True

                                            if self.is_sham_link is not None:
                                                return True

                                            if self.is_virtual_link is not None:
                                                return True

                                            if self.lsa_detail is not None and self.lsa_detail._has_data():
                                                return True

                                            if self.lsa_header is not None and self.lsa_header._has_data():
                                                return True

                                            if self.sham_link_id is not None:
                                                return True

                                            if self.virtual_link_id is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType']['meta_info']


                                    class UnknownAreaLsaType(object):
                                        """
                                        Unknown\-Area scope LSA
                                        
                                        .. attribute:: interface_name
                                        
                                        	LSA interface name 
                                        	**type**\:  str
                                        
                                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                        
                                        .. attribute:: is_sham_link
                                        
                                        	If true, it is a sham link 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_virtual_link
                                        
                                        	If true, it is a virtual link 
                                        	**type**\:  bool
                                        
                                        .. attribute:: lsa_detail
                                        
                                        	Detailed LSA information
                                        	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaDetail>`
                                        
                                        .. attribute:: lsa_header
                                        
                                        	Header information 
                                        	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaHeader>`
                                        
                                        .. attribute:: sham_link_id
                                        
                                        	Shamlink ID 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: virtual_link_id
                                        
                                        	Virtual link ID 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface_name = None
                                            self.is_sham_link = None
                                            self.is_virtual_link = None
                                            self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaDetail()
                                            self.lsa_detail.parent = self
                                            self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaHeader()
                                            self.lsa_header.parent = self
                                            self.sham_link_id = None
                                            self.virtual_link_id = None


                                        class LsaHeader(object):
                                            """
                                            Header information 
                                            
                                            .. attribute:: advertising_router
                                            
                                            	Router ID of Advertising Router
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: checksum
                                            
                                            	Checksum value
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: is_do_not_age_lsa
                                            
                                            	If true, Do Not Age this LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_graceful_restart_active
                                            
                                            	If true, if grace restart is active 
                                            	**type**\:  bool
                                            
                                            .. attribute:: ls_id
                                            
                                            	LS ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: lsa_age
                                            
                                            	LSA's Age (s)
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_area_id
                                            
                                            	Area ID in decimal or dotted\-decimal format
                                            	**type**\:  str
                                            
                                            	**length:** 0..16
                                            
                                            .. attribute:: lsa_type
                                            
                                            	LSA type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: sequence_number
                                            
                                            	Current Sequence number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.advertising_router = None
                                                self.checksum = None
                                                self.is_do_not_age_lsa = None
                                                self.is_graceful_restart_active = None
                                                self.ls_id = None
                                                self.lsa_age = None
                                                self.lsa_area_id = None
                                                self.lsa_type = None
                                                self.sequence_number = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-header'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.advertising_router is not None:
                                                    return True

                                                if self.checksum is not None:
                                                    return True

                                                if self.is_do_not_age_lsa is not None:
                                                    return True

                                                if self.is_graceful_restart_active is not None:
                                                    return True

                                                if self.ls_id is not None:
                                                    return True

                                                if self.lsa_age is not None:
                                                    return True

                                                if self.lsa_area_id is not None:
                                                    return True

                                                if self.lsa_type is not None:
                                                    return True

                                                if self.sequence_number is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaHeader']['meta_info']


                                        class LsaDetail(object):
                                            """
                                            Detailed LSA information
                                            
                                            .. attribute:: free_time
                                            
                                            	The amount of time since the last check was made to free this LSA (s)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_acknowledged
                                            
                                            	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_advertising_router_reachable
                                            
                                            	If true, Advertising Router is reachable
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_deleted
                                            
                                            	If true, flag is set to delete this LSA 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_flood_pending
                                            
                                            	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_maximum_aged
                                            
                                            	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_neighbor_exchange
                                            
                                            	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_no_delete
                                            
                                            	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_nsr_ack_pending
                                            
                                            	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_partial_spf
                                            
                                            	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_routing_bit
                                            
                                            	If true, Routing Bit set on the LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_routing_table
                                            
                                            	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                            	**type**\:  bool
                                            
                                            .. attribute:: lsa_flood_required_post_fail_over
                                            
                                            	LSA flood required after FO
                                            	**type**\:  bool
                                            
                                            .. attribute:: lsa_length
                                            
                                            	Length of the LSA
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_sync_state
                                            
                                            	State of LSA sync with active
                                            	**type**\:   :py:class:`OspfLsaSyncStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncStateEnum>`
                                            
                                            .. attribute:: minute_table_index
                                            
                                            	Minute table index
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: nsr_flood_required
                                            
                                            	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                            	**type**\:  bool
                                            
                                            .. attribute:: rate_limit
                                            
                                            	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                            	**type**\:  bool
                                            
                                            .. attribute:: second_table_index
                                            
                                            	Second table index
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.free_time = None
                                                self.is_acknowledged = None
                                                self.is_advertising_router_reachable = None
                                                self.is_deleted = None
                                                self.is_flood_pending = None
                                                self.is_maximum_aged = None
                                                self.is_neighbor_exchange = None
                                                self.is_no_delete = None
                                                self.is_nsr_ack_pending = None
                                                self.is_partial_spf = None
                                                self.is_routing_bit = None
                                                self.is_routing_table = None
                                                self.lsa_flood_required_post_fail_over = None
                                                self.lsa_length = None
                                                self.lsa_sync_state = None
                                                self.minute_table_index = None
                                                self.nsr_flood_required = None
                                                self.rate_limit = None
                                                self.second_table_index = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-detail'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.free_time is not None:
                                                    return True

                                                if self.is_acknowledged is not None:
                                                    return True

                                                if self.is_advertising_router_reachable is not None:
                                                    return True

                                                if self.is_deleted is not None:
                                                    return True

                                                if self.is_flood_pending is not None:
                                                    return True

                                                if self.is_maximum_aged is not None:
                                                    return True

                                                if self.is_neighbor_exchange is not None:
                                                    return True

                                                if self.is_no_delete is not None:
                                                    return True

                                                if self.is_nsr_ack_pending is not None:
                                                    return True

                                                if self.is_partial_spf is not None:
                                                    return True

                                                if self.is_routing_bit is not None:
                                                    return True

                                                if self.is_routing_table is not None:
                                                    return True

                                                if self.lsa_flood_required_post_fail_over is not None:
                                                    return True

                                                if self.lsa_length is not None:
                                                    return True

                                                if self.lsa_sync_state is not None:
                                                    return True

                                                if self.minute_table_index is not None:
                                                    return True

                                                if self.nsr_flood_required is not None:
                                                    return True

                                                if self.rate_limit is not None:
                                                    return True

                                                if self.second_table_index is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaDetail']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:unknown-area-lsa-type'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface_name is not None:
                                                return True

                                            if self.is_sham_link is not None:
                                                return True

                                            if self.is_virtual_link is not None:
                                                return True

                                            if self.lsa_detail is not None and self.lsa_detail._has_data():
                                                return True

                                            if self.lsa_header is not None and self.lsa_header._has_data():
                                                return True

                                            if self.sham_link_id is not None:
                                                return True

                                            if self.virtual_link_id is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType']['meta_info']


                                    class UnknownAslsaType(object):
                                        """
                                        Unknown\-AS scope LSA
                                        
                                        .. attribute:: interface_name
                                        
                                        	LSA interface name 
                                        	**type**\:  str
                                        
                                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                        
                                        .. attribute:: is_sham_link
                                        
                                        	If true, it is a sham link 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_virtual_link
                                        
                                        	If true, it is a virtual link 
                                        	**type**\:  bool
                                        
                                        .. attribute:: lsa_detail
                                        
                                        	Detailed LSA information
                                        	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType.LsaDetail>`
                                        
                                        .. attribute:: lsa_header
                                        
                                        	Header information 
                                        	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType.LsaHeader>`
                                        
                                        .. attribute:: sham_link_id
                                        
                                        	Shamlink ID 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: virtual_link_id
                                        
                                        	Virtual link ID 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface_name = None
                                            self.is_sham_link = None
                                            self.is_virtual_link = None
                                            self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType.LsaDetail()
                                            self.lsa_detail.parent = self
                                            self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType.LsaHeader()
                                            self.lsa_header.parent = self
                                            self.sham_link_id = None
                                            self.virtual_link_id = None


                                        class LsaHeader(object):
                                            """
                                            Header information 
                                            
                                            .. attribute:: advertising_router
                                            
                                            	Router ID of Advertising Router
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: checksum
                                            
                                            	Checksum value
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: is_do_not_age_lsa
                                            
                                            	If true, Do Not Age this LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_graceful_restart_active
                                            
                                            	If true, if grace restart is active 
                                            	**type**\:  bool
                                            
                                            .. attribute:: ls_id
                                            
                                            	LS ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: lsa_age
                                            
                                            	LSA's Age (s)
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_area_id
                                            
                                            	Area ID in decimal or dotted\-decimal format
                                            	**type**\:  str
                                            
                                            	**length:** 0..16
                                            
                                            .. attribute:: lsa_type
                                            
                                            	LSA type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: sequence_number
                                            
                                            	Current Sequence number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.advertising_router = None
                                                self.checksum = None
                                                self.is_do_not_age_lsa = None
                                                self.is_graceful_restart_active = None
                                                self.ls_id = None
                                                self.lsa_age = None
                                                self.lsa_area_id = None
                                                self.lsa_type = None
                                                self.sequence_number = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-header'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.advertising_router is not None:
                                                    return True

                                                if self.checksum is not None:
                                                    return True

                                                if self.is_do_not_age_lsa is not None:
                                                    return True

                                                if self.is_graceful_restart_active is not None:
                                                    return True

                                                if self.ls_id is not None:
                                                    return True

                                                if self.lsa_age is not None:
                                                    return True

                                                if self.lsa_area_id is not None:
                                                    return True

                                                if self.lsa_type is not None:
                                                    return True

                                                if self.sequence_number is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType.LsaHeader']['meta_info']


                                        class LsaDetail(object):
                                            """
                                            Detailed LSA information
                                            
                                            .. attribute:: free_time
                                            
                                            	The amount of time since the last check was made to free this LSA (s)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_acknowledged
                                            
                                            	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_advertising_router_reachable
                                            
                                            	If true, Advertising Router is reachable
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_deleted
                                            
                                            	If true, flag is set to delete this LSA 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_flood_pending
                                            
                                            	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_maximum_aged
                                            
                                            	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_neighbor_exchange
                                            
                                            	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_no_delete
                                            
                                            	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_nsr_ack_pending
                                            
                                            	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_partial_spf
                                            
                                            	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_routing_bit
                                            
                                            	If true, Routing Bit set on the LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_routing_table
                                            
                                            	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                            	**type**\:  bool
                                            
                                            .. attribute:: lsa_flood_required_post_fail_over
                                            
                                            	LSA flood required after FO
                                            	**type**\:  bool
                                            
                                            .. attribute:: lsa_length
                                            
                                            	Length of the LSA
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_sync_state
                                            
                                            	State of LSA sync with active
                                            	**type**\:   :py:class:`OspfLsaSyncStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncStateEnum>`
                                            
                                            .. attribute:: minute_table_index
                                            
                                            	Minute table index
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: nsr_flood_required
                                            
                                            	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                            	**type**\:  bool
                                            
                                            .. attribute:: rate_limit
                                            
                                            	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                            	**type**\:  bool
                                            
                                            .. attribute:: second_table_index
                                            
                                            	Second table index
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.free_time = None
                                                self.is_acknowledged = None
                                                self.is_advertising_router_reachable = None
                                                self.is_deleted = None
                                                self.is_flood_pending = None
                                                self.is_maximum_aged = None
                                                self.is_neighbor_exchange = None
                                                self.is_no_delete = None
                                                self.is_nsr_ack_pending = None
                                                self.is_partial_spf = None
                                                self.is_routing_bit = None
                                                self.is_routing_table = None
                                                self.lsa_flood_required_post_fail_over = None
                                                self.lsa_length = None
                                                self.lsa_sync_state = None
                                                self.minute_table_index = None
                                                self.nsr_flood_required = None
                                                self.rate_limit = None
                                                self.second_table_index = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-detail'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.free_time is not None:
                                                    return True

                                                if self.is_acknowledged is not None:
                                                    return True

                                                if self.is_advertising_router_reachable is not None:
                                                    return True

                                                if self.is_deleted is not None:
                                                    return True

                                                if self.is_flood_pending is not None:
                                                    return True

                                                if self.is_maximum_aged is not None:
                                                    return True

                                                if self.is_neighbor_exchange is not None:
                                                    return True

                                                if self.is_no_delete is not None:
                                                    return True

                                                if self.is_nsr_ack_pending is not None:
                                                    return True

                                                if self.is_partial_spf is not None:
                                                    return True

                                                if self.is_routing_bit is not None:
                                                    return True

                                                if self.is_routing_table is not None:
                                                    return True

                                                if self.lsa_flood_required_post_fail_over is not None:
                                                    return True

                                                if self.lsa_length is not None:
                                                    return True

                                                if self.lsa_sync_state is not None:
                                                    return True

                                                if self.minute_table_index is not None:
                                                    return True

                                                if self.nsr_flood_required is not None:
                                                    return True

                                                if self.rate_limit is not None:
                                                    return True

                                                if self.second_table_index is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType.LsaDetail']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:unknown-aslsa-type'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface_name is not None:
                                                return True

                                            if self.is_sham_link is not None:
                                                return True

                                            if self.is_virtual_link is not None:
                                                return True

                                            if self.lsa_detail is not None and self.lsa_detail._has_data():
                                                return True

                                            if self.lsa_header is not None and self.lsa_header._has_data():
                                                return True

                                            if self.sham_link_id is not None:
                                                return True

                                            if self.virtual_link_id is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType']['meta_info']


                                    class UnknownLsaType(object):
                                        """
                                        Unknown LSA
                                        
                                        .. attribute:: interface_name
                                        
                                        	LSA interface name 
                                        	**type**\:  str
                                        
                                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                        
                                        .. attribute:: is_sham_link
                                        
                                        	If true, it is a sham link 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_virtual_link
                                        
                                        	If true, it is a virtual link 
                                        	**type**\:  bool
                                        
                                        .. attribute:: lsa_detail
                                        
                                        	Detailed LSA information
                                        	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType.LsaDetail>`
                                        
                                        .. attribute:: lsa_header
                                        
                                        	Header information 
                                        	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType.LsaHeader>`
                                        
                                        .. attribute:: sham_link_id
                                        
                                        	Shamlink ID 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: virtual_link_id
                                        
                                        	Virtual link ID 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface_name = None
                                            self.is_sham_link = None
                                            self.is_virtual_link = None
                                            self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType.LsaDetail()
                                            self.lsa_detail.parent = self
                                            self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType.LsaHeader()
                                            self.lsa_header.parent = self
                                            self.sham_link_id = None
                                            self.virtual_link_id = None


                                        class LsaHeader(object):
                                            """
                                            Header information 
                                            
                                            .. attribute:: advertising_router
                                            
                                            	Router ID of Advertising Router
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: checksum
                                            
                                            	Checksum value
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: is_do_not_age_lsa
                                            
                                            	If true, Do Not Age this LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_graceful_restart_active
                                            
                                            	If true, if grace restart is active 
                                            	**type**\:  bool
                                            
                                            .. attribute:: ls_id
                                            
                                            	LS ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: lsa_age
                                            
                                            	LSA's Age (s)
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_area_id
                                            
                                            	Area ID in decimal or dotted\-decimal format
                                            	**type**\:  str
                                            
                                            	**length:** 0..16
                                            
                                            .. attribute:: lsa_type
                                            
                                            	LSA type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: sequence_number
                                            
                                            	Current Sequence number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.advertising_router = None
                                                self.checksum = None
                                                self.is_do_not_age_lsa = None
                                                self.is_graceful_restart_active = None
                                                self.ls_id = None
                                                self.lsa_age = None
                                                self.lsa_area_id = None
                                                self.lsa_type = None
                                                self.sequence_number = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-header'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.advertising_router is not None:
                                                    return True

                                                if self.checksum is not None:
                                                    return True

                                                if self.is_do_not_age_lsa is not None:
                                                    return True

                                                if self.is_graceful_restart_active is not None:
                                                    return True

                                                if self.ls_id is not None:
                                                    return True

                                                if self.lsa_age is not None:
                                                    return True

                                                if self.lsa_area_id is not None:
                                                    return True

                                                if self.lsa_type is not None:
                                                    return True

                                                if self.sequence_number is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType.LsaHeader']['meta_info']


                                        class LsaDetail(object):
                                            """
                                            Detailed LSA information
                                            
                                            .. attribute:: free_time
                                            
                                            	The amount of time since the last check was made to free this LSA (s)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_acknowledged
                                            
                                            	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_advertising_router_reachable
                                            
                                            	If true, Advertising Router is reachable
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_deleted
                                            
                                            	If true, flag is set to delete this LSA 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_flood_pending
                                            
                                            	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_maximum_aged
                                            
                                            	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_neighbor_exchange
                                            
                                            	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_no_delete
                                            
                                            	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_nsr_ack_pending
                                            
                                            	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_partial_spf
                                            
                                            	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_routing_bit
                                            
                                            	If true, Routing Bit set on the LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_routing_table
                                            
                                            	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                            	**type**\:  bool
                                            
                                            .. attribute:: lsa_flood_required_post_fail_over
                                            
                                            	LSA flood required after FO
                                            	**type**\:  bool
                                            
                                            .. attribute:: lsa_length
                                            
                                            	Length of the LSA
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_sync_state
                                            
                                            	State of LSA sync with active
                                            	**type**\:   :py:class:`OspfLsaSyncStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncStateEnum>`
                                            
                                            .. attribute:: minute_table_index
                                            
                                            	Minute table index
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: nsr_flood_required
                                            
                                            	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                            	**type**\:  bool
                                            
                                            .. attribute:: rate_limit
                                            
                                            	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                            	**type**\:  bool
                                            
                                            .. attribute:: second_table_index
                                            
                                            	Second table index
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.free_time = None
                                                self.is_acknowledged = None
                                                self.is_advertising_router_reachable = None
                                                self.is_deleted = None
                                                self.is_flood_pending = None
                                                self.is_maximum_aged = None
                                                self.is_neighbor_exchange = None
                                                self.is_no_delete = None
                                                self.is_nsr_ack_pending = None
                                                self.is_partial_spf = None
                                                self.is_routing_bit = None
                                                self.is_routing_table = None
                                                self.lsa_flood_required_post_fail_over = None
                                                self.lsa_length = None
                                                self.lsa_sync_state = None
                                                self.minute_table_index = None
                                                self.nsr_flood_required = None
                                                self.rate_limit = None
                                                self.second_table_index = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-detail'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.free_time is not None:
                                                    return True

                                                if self.is_acknowledged is not None:
                                                    return True

                                                if self.is_advertising_router_reachable is not None:
                                                    return True

                                                if self.is_deleted is not None:
                                                    return True

                                                if self.is_flood_pending is not None:
                                                    return True

                                                if self.is_maximum_aged is not None:
                                                    return True

                                                if self.is_neighbor_exchange is not None:
                                                    return True

                                                if self.is_no_delete is not None:
                                                    return True

                                                if self.is_nsr_ack_pending is not None:
                                                    return True

                                                if self.is_partial_spf is not None:
                                                    return True

                                                if self.is_routing_bit is not None:
                                                    return True

                                                if self.is_routing_table is not None:
                                                    return True

                                                if self.lsa_flood_required_post_fail_over is not None:
                                                    return True

                                                if self.lsa_length is not None:
                                                    return True

                                                if self.lsa_sync_state is not None:
                                                    return True

                                                if self.minute_table_index is not None:
                                                    return True

                                                if self.nsr_flood_required is not None:
                                                    return True

                                                if self.rate_limit is not None:
                                                    return True

                                                if self.second_table_index is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType.LsaDetail']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:unknown-lsa-type'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface_name is not None:
                                                return True

                                            if self.is_sham_link is not None:
                                                return True

                                            if self.is_virtual_link is not None:
                                                return True

                                            if self.lsa_detail is not None and self.lsa_detail._has_data():
                                                return True

                                            if self.lsa_header is not None and self.lsa_header._has_data():
                                                return True

                                            if self.sham_link_id is not None:
                                                return True

                                            if self.virtual_link_id is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-info'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.external_lsa_type is not None and self.external_lsa_type._has_data():
                                            return True

                                        if self.grace_lsa is not None and self.grace_lsa._has_data():
                                            return True

                                        if self.inter_area_prefix_lsa_type is not None and self.inter_area_prefix_lsa_type._has_data():
                                            return True

                                        if self.inter_area_router_lsa_type is not None and self.inter_area_router_lsa_type._has_data():
                                            return True

                                        if self.intra_area_prefix_lsa_type is not None and self.intra_area_prefix_lsa_type._has_data():
                                            return True

                                        if self.link_lsa_type is not None and self.link_lsa_type._has_data():
                                            return True

                                        if self.lsa_info_type is not None:
                                            return True

                                        if self.lsa_summary_info is not None and self.lsa_summary_info._has_data():
                                            return True

                                        if self.network_lsa_type is not None and self.network_lsa_type._has_data():
                                            return True

                                        if self.nssalsa_type is not None and self.nssalsa_type._has_data():
                                            return True

                                        if self.router_lsa_type is not None and self.router_lsa_type._has_data():
                                            return True

                                        if self.unknown_area_lsa_type is not None and self.unknown_area_lsa_type._has_data():
                                            return True

                                        if self.unknown_aslsa_type is not None and self.unknown_aslsa_type._has_data():
                                            return True

                                        if self.unknown_link_lsa_type is not None and self.unknown_link_lsa_type._has_data():
                                            return True

                                        if self.unknown_lsa_type is not None and self.unknown_lsa_type._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                        return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.advertising_router is not None:
                                        return True

                                    if self.area_id is not None:
                                        return True

                                    if self.interface_name is not None:
                                        return True

                                    if self.ls_id is not None:
                                        return True

                                    if self.ls_type is not None:
                                        return True

                                    if self.lsa_info is not None and self.lsa_info._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                    return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-internal-table'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.lsa is not None:
                                    for child_ref in self.lsa:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:database-table'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.lsa_internal_table is not None and self.lsa_internal_table._has_data():
                                return True

                            if self.lsa_table is not None and self.lsa_table._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                            return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable']['meta_info']


                    class InterfaceProcessTable(object):
                        """
                        OSPFv3 interface information table for all areas
                        
                        .. attribute:: interface
                        
                        	OSPFv3 interface information
                        	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.InterfaceProcessTable.Interface>`
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.interface = YList()
                            self.interface.parent = self
                            self.interface.name = 'interface'


                        class Interface(object):
                            """
                            OSPFv3 interface information
                            
                            .. attribute:: interface_name  <key>
                            
                            	Interface name
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: active_interface
                            
                            	Active interface details 
                            	**type**\:   :py:class:`ActiveInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.InterfaceProcessTable.Interface.ActiveInterface>`
                            
                            .. attribute:: adjacent_neighbor
                            
                            	Number of adjacent neighbors
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: backup_designated_router_address
                            
                            	Backup designated router interface address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: backup_designated_router_id
                            
                            	Backup designated router ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: configured_ldp_sync
                            
                            	If true, configured as LDP sync
                            	**type**\:  bool
                            
                            .. attribute:: dead_interval
                            
                            	Configured dead interval (s) 
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: designated_router_address
                            
                            	Designated router interface address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: designated_router_id
                            
                            	Designated router ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: hello_interval
                            
                            	Configured hello interval (s)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: interface_address
                            
                            	Interface IPv6 address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: interface_authentication_spi
                            
                            	Interface authentication spi 
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: interface_authentication_transmit
                            
                            	Interface authentication transmit 
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: interface_bfd
                            
                            	BFD information 
                            	**type**\:   :py:class:`InterfaceBfd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.InterfaceProcessTable.Interface.InterfaceBfd>`
                            
                            .. attribute:: interface_dc_bitless_ls_as
                            
                            	Number of LSAs with demand circuit bit not set for the area in which the interface is running
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: interface_encrypted_authentication_transmitted
                            
                            	Interface encrypted authentication transmitted 
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: interface_encryption_spi
                            
                            	Interface encryption spi
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: interface_encryption_transmitted
                            
                            	Interface encryption transmitted 
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: interface_ldp_sync
                            
                            	If true, interface LDP sync is achieved
                            	**type**\:  bool
                            
                            .. attribute:: interface_link_cost
                            
                            	Interface link cost
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: interface_neighbor
                            
                            	Information for neighbors on the interface
                            	**type**\: list of    :py:class:`InterfaceNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.InterfaceProcessTable.Interface.InterfaceNeighbor>`
                            
                            .. attribute:: interface_number
                            
                            	Interface number 
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: interface_priority
                            
                            	Interface priority
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: interface_references
                            
                            	Interface reference count 
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: interface_retransmission_interval
                            
                            	Configured retransmit interval (s) 
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: interface_router_id
                            
                            	Interface router ID 
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: interface_state
                            
                            	Interface state
                            	**type**\:   :py:class:`ImStateEnumEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.ImStateEnumEnum>`
                            
                            .. attribute:: is_demand_circuit_configured
                            
                            	If true, configured as demand circuit 
                            	**type**\:  bool
                            
                            .. attribute:: is_designated_router
                            
                            	If true, designated router
                            	**type**\:  bool
                            
                            .. attribute:: is_interface_demand_circuit
                            
                            	If true, interface running as demand circuit
                            	**type**\:  bool
                            
                            .. attribute:: is_interface_encryption_enabled
                            
                            	If true, interface encryption is enabled 
                            	**type**\:  bool
                            
                            .. attribute:: is_interface_flood_reduction
                            
                            	If true, interface flood reduction is active 
                            	**type**\:  bool
                            
                            .. attribute:: is_interface_ip_security_active
                            
                            	If true, interface IP security is active 
                            	**type**\:  bool
                            
                            .. attribute:: is_interface_ip_security_required
                            
                            	If true, interface IP security is required 
                            	**type**\:  bool
                            
                            .. attribute:: is_interface_line_up
                            
                            	If true, line protocol is up 
                            	**type**\:  bool
                            
                            .. attribute:: is_interface_lsa_filtered
                            
                            	Filter is configured for out going LSAs 
                            	**type**\:  bool
                            
                            .. attribute:: is_prefix_suppress
                            
                            	If true prefix suppression is enabled
                            	**type**\:  bool
                            
                            .. attribute:: network_lsa_flush_timer
                            
                            	The amount of time in seconds before flush timer for old network LSA expires 
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: network_type
                            
                            	Network type
                            	**type**\:   :py:class:`Ospfv3InterfaceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3InterfaceEnum>`
                            
                            .. attribute:: next_hello_time
                            
                            	Time until next Hello (s) 
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ospf_interface_state
                            
                            	Interface state
                            	**type**\:   :py:class:`Ospfv3InterfaceStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3InterfaceStateEnum>`
                            
                            .. attribute:: transmission_delay
                            
                            	Interface transmission delay (sec)
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: wait_interval
                            
                            	Configured wait interval (s) 
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.interface_name = None
                                self.active_interface = Ospfv3.Processes.Process.Vrfs.Vrf.InterfaceProcessTable.Interface.ActiveInterface()
                                self.active_interface.parent = self
                                self.adjacent_neighbor = None
                                self.backup_designated_router_address = None
                                self.backup_designated_router_id = None
                                self.configured_ldp_sync = None
                                self.dead_interval = None
                                self.designated_router_address = None
                                self.designated_router_id = None
                                self.hello_interval = None
                                self.interface_address = None
                                self.interface_authentication_spi = None
                                self.interface_authentication_transmit = None
                                self.interface_bfd = Ospfv3.Processes.Process.Vrfs.Vrf.InterfaceProcessTable.Interface.InterfaceBfd()
                                self.interface_bfd.parent = self
                                self.interface_dc_bitless_ls_as = None
                                self.interface_encrypted_authentication_transmitted = None
                                self.interface_encryption_spi = None
                                self.interface_encryption_transmitted = None
                                self.interface_ldp_sync = None
                                self.interface_link_cost = None
                                self.interface_neighbor = YList()
                                self.interface_neighbor.parent = self
                                self.interface_neighbor.name = 'interface_neighbor'
                                self.interface_number = None
                                self.interface_priority = None
                                self.interface_references = None
                                self.interface_retransmission_interval = None
                                self.interface_router_id = None
                                self.interface_state = None
                                self.is_demand_circuit_configured = None
                                self.is_designated_router = None
                                self.is_interface_demand_circuit = None
                                self.is_interface_encryption_enabled = None
                                self.is_interface_flood_reduction = None
                                self.is_interface_ip_security_active = None
                                self.is_interface_ip_security_required = None
                                self.is_interface_line_up = None
                                self.is_interface_lsa_filtered = None
                                self.is_prefix_suppress = None
                                self.network_lsa_flush_timer = None
                                self.network_type = None
                                self.next_hello_time = None
                                self.ospf_interface_state = None
                                self.transmission_delay = None
                                self.wait_interval = None


                            class ActiveInterface(object):
                                """
                                Active interface details 
                                
                                .. attribute:: flood_queue_length
                                
                                	Flood queue length
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: flood_scan_length
                                
                                	Last flood scan length 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interface_area_flood_index
                                
                                	Area scope LSAs flood index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interface_area_next_flood
                                
                                	Next LSA to flood (Area scope)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interface_area_next_flood_index
                                
                                	Index of next LSA to flood (Area scope) 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interface_as_flood_index
                                
                                	AS scope LSAs flood index 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interface_as_next_flood
                                
                                	Next LSA to flood (AS scope)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interface_as_next_flood_index
                                
                                	Index of next LSA to flood (AS scope)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interface_flood_pacing_timer
                                
                                	Time until next flood pacing timer (ms) 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interface_link_flood_index
                                
                                	Interface flood link index 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interface_link_next_flood
                                
                                	Interface link next flood information 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interface_link_next_index
                                
                                	Interface link next information index 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interface_neighbors
                                
                                	Total number of neighbors 
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: last_flood_time
                                
                                	Last flood scan time (ms)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: maximum_flood_length
                                
                                	Maximum flood length 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: maximum_flood_time
                                
                                	Maximum flood time (ms) 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: suppressed_hellos
                                
                                	Number of neighbors for which hellos are suppressed 
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: wait_time
                                
                                	Wait time for DR/BDR selection (s)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.flood_queue_length = None
                                    self.flood_scan_length = None
                                    self.interface_area_flood_index = None
                                    self.interface_area_next_flood = None
                                    self.interface_area_next_flood_index = None
                                    self.interface_as_flood_index = None
                                    self.interface_as_next_flood = None
                                    self.interface_as_next_flood_index = None
                                    self.interface_flood_pacing_timer = None
                                    self.interface_link_flood_index = None
                                    self.interface_link_next_flood = None
                                    self.interface_link_next_index = None
                                    self.interface_neighbors = None
                                    self.last_flood_time = None
                                    self.maximum_flood_length = None
                                    self.maximum_flood_time = None
                                    self.suppressed_hellos = None
                                    self.wait_time = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:active-interface'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.flood_queue_length is not None:
                                        return True

                                    if self.flood_scan_length is not None:
                                        return True

                                    if self.interface_area_flood_index is not None:
                                        return True

                                    if self.interface_area_next_flood is not None:
                                        return True

                                    if self.interface_area_next_flood_index is not None:
                                        return True

                                    if self.interface_as_flood_index is not None:
                                        return True

                                    if self.interface_as_next_flood is not None:
                                        return True

                                    if self.interface_as_next_flood_index is not None:
                                        return True

                                    if self.interface_flood_pacing_timer is not None:
                                        return True

                                    if self.interface_link_flood_index is not None:
                                        return True

                                    if self.interface_link_next_flood is not None:
                                        return True

                                    if self.interface_link_next_index is not None:
                                        return True

                                    if self.interface_neighbors is not None:
                                        return True

                                    if self.last_flood_time is not None:
                                        return True

                                    if self.maximum_flood_length is not None:
                                        return True

                                    if self.maximum_flood_time is not None:
                                        return True

                                    if self.suppressed_hellos is not None:
                                        return True

                                    if self.wait_time is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                    return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.InterfaceProcessTable.Interface.ActiveInterface']['meta_info']


                            class InterfaceBfd(object):
                                """
                                BFD information 
                                
                                .. attribute:: bfd_detection_multiplier
                                
                                	BFD detection multiplier 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bfd_interval
                                
                                	BFD interval (ms) 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bfd_intf_enable_mode
                                
                                	BFD Enable Mode on the interface \- Default/Strict
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.bfd_detection_multiplier = None
                                    self.bfd_interval = None
                                    self.bfd_intf_enable_mode = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:interface-bfd'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.bfd_detection_multiplier is not None:
                                        return True

                                    if self.bfd_interval is not None:
                                        return True

                                    if self.bfd_intf_enable_mode is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                    return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.InterfaceProcessTable.Interface.InterfaceBfd']['meta_info']


                            class InterfaceNeighbor(object):
                                """
                                Information for neighbors on the interface
                                
                                .. attribute:: interface_neighbor_cost
                                
                                	Cost of link to neighbor
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interface_neighbor_id
                                
                                	Neighbor router ID 
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: is_hello_suppressed
                                
                                	If true, hello is suppressed 
                                	**type**\:  bool
                                
                                .. attribute:: is_neighbor_bdr
                                
                                	If true, backup designated router is found 
                                	**type**\:  bool
                                
                                .. attribute:: is_neighbor_dr
                                
                                	If true, designated router is found 
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.interface_neighbor_cost = None
                                    self.interface_neighbor_id = None
                                    self.is_hello_suppressed = None
                                    self.is_neighbor_bdr = None
                                    self.is_neighbor_dr = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:interface-neighbor'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.interface_neighbor_cost is not None:
                                        return True

                                    if self.interface_neighbor_id is not None:
                                        return True

                                    if self.is_hello_suppressed is not None:
                                        return True

                                    if self.is_neighbor_bdr is not None:
                                        return True

                                    if self.is_neighbor_dr is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                    return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.InterfaceProcessTable.Interface.InterfaceNeighbor']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')
                                if self.interface_name is None:
                                    raise YPYModelError('Key property interface_name is None')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:interface[Cisco-IOS-XR-ipv6-ospfv3-oper:interface-name = ' + str(self.interface_name) + ']'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.interface_name is not None:
                                    return True

                                if self.active_interface is not None and self.active_interface._has_data():
                                    return True

                                if self.adjacent_neighbor is not None:
                                    return True

                                if self.backup_designated_router_address is not None:
                                    return True

                                if self.backup_designated_router_id is not None:
                                    return True

                                if self.configured_ldp_sync is not None:
                                    return True

                                if self.dead_interval is not None:
                                    return True

                                if self.designated_router_address is not None:
                                    return True

                                if self.designated_router_id is not None:
                                    return True

                                if self.hello_interval is not None:
                                    return True

                                if self.interface_address is not None:
                                    return True

                                if self.interface_authentication_spi is not None:
                                    return True

                                if self.interface_authentication_transmit is not None:
                                    return True

                                if self.interface_bfd is not None and self.interface_bfd._has_data():
                                    return True

                                if self.interface_dc_bitless_ls_as is not None:
                                    return True

                                if self.interface_encrypted_authentication_transmitted is not None:
                                    return True

                                if self.interface_encryption_spi is not None:
                                    return True

                                if self.interface_encryption_transmitted is not None:
                                    return True

                                if self.interface_ldp_sync is not None:
                                    return True

                                if self.interface_link_cost is not None:
                                    return True

                                if self.interface_neighbor is not None:
                                    for child_ref in self.interface_neighbor:
                                        if child_ref._has_data():
                                            return True

                                if self.interface_number is not None:
                                    return True

                                if self.interface_priority is not None:
                                    return True

                                if self.interface_references is not None:
                                    return True

                                if self.interface_retransmission_interval is not None:
                                    return True

                                if self.interface_router_id is not None:
                                    return True

                                if self.interface_state is not None:
                                    return True

                                if self.is_demand_circuit_configured is not None:
                                    return True

                                if self.is_designated_router is not None:
                                    return True

                                if self.is_interface_demand_circuit is not None:
                                    return True

                                if self.is_interface_encryption_enabled is not None:
                                    return True

                                if self.is_interface_flood_reduction is not None:
                                    return True

                                if self.is_interface_ip_security_active is not None:
                                    return True

                                if self.is_interface_ip_security_required is not None:
                                    return True

                                if self.is_interface_line_up is not None:
                                    return True

                                if self.is_interface_lsa_filtered is not None:
                                    return True

                                if self.is_prefix_suppress is not None:
                                    return True

                                if self.network_lsa_flush_timer is not None:
                                    return True

                                if self.network_type is not None:
                                    return True

                                if self.next_hello_time is not None:
                                    return True

                                if self.ospf_interface_state is not None:
                                    return True

                                if self.transmission_delay is not None:
                                    return True

                                if self.wait_interval is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.InterfaceProcessTable.Interface']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:interface-process-table'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.interface is not None:
                                for child_ref in self.interface:
                                    if child_ref._has_data():
                                        return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                            return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.InterfaceProcessTable']['meta_info']


                    class Redistributions(object):
                        """
                        Redistribution information table
                        
                        .. attribute:: redistribution
                        
                        	Redistribution information
                        	**type**\: list of    :py:class:`Redistribution <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Redistributions.Redistribution>`
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.redistribution = YList()
                            self.redistribution.parent = self
                            self.redistribution.name = 'redistribution'


                        class Redistribution(object):
                            """
                            Redistribution information
                            
                            .. attribute:: policy_name
                            
                            	Route policy name 
                            	**type**\:  str
                            
                            .. attribute:: process_id
                            
                            	Process ID 
                            	**type**\:  str
                            
                            	**length:** 0..40
                            
                            .. attribute:: process_name
                            
                            	Process name of a protocolbeing redistributed 
                            	**type**\:  str
                            
                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                            
                            .. attribute:: protocol_name
                            
                            	Protocol name that is redistributed
                            	**type**\:  str
                            
                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                            
                            .. attribute:: protocol_name_xr
                            
                            	Protocol name 
                            	**type**\:  str
                            
                            	**length:** 0..40
                            
                            .. attribute:: red_metric
                            
                            	red metric
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: red_metric_flag
                            
                            	red metric flag
                            	**type**\:  bool
                            
                            .. attribute:: red_metric_type
                            
                            	red metric type
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: red_mtype_flag
                            
                            	red mtype flag
                            	**type**\:  bool
                            
                            .. attribute:: red_tag
                            
                            	red tag
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.policy_name = None
                                self.process_id = None
                                self.process_name = None
                                self.protocol_name = None
                                self.protocol_name_xr = None
                                self.red_metric = None
                                self.red_metric_flag = None
                                self.red_metric_type = None
                                self.red_mtype_flag = None
                                self.red_tag = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:redistribution'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.policy_name is not None:
                                    return True

                                if self.process_id is not None:
                                    return True

                                if self.process_name is not None:
                                    return True

                                if self.protocol_name is not None:
                                    return True

                                if self.protocol_name_xr is not None:
                                    return True

                                if self.red_metric is not None:
                                    return True

                                if self.red_metric_flag is not None:
                                    return True

                                if self.red_metric_type is not None:
                                    return True

                                if self.red_mtype_flag is not None:
                                    return True

                                if self.red_tag is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Redistributions.Redistribution']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:redistributions'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.redistribution is not None:
                                for child_ref in self.redistribution:
                                    if child_ref._has_data():
                                        return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                            return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Redistributions']['meta_info']


                    class ExternalRoutes(object):
                        """
                        OSPFv3 external route information table
                        
                        .. attribute:: external_route
                        
                        	OSPFv3 external route information
                        	**type**\: list of    :py:class:`ExternalRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.ExternalRoutes.ExternalRoute>`
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.external_route = YList()
                            self.external_route.parent = self
                            self.external_route.name = 'external_route'


                        class ExternalRoute(object):
                            """
                            OSPFv3 external route information
                            
                            .. attribute:: prefix
                            
                            	Route prefix
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: prefix_length
                            
                            	Prefix length
                            	**type**\:  int
                            
                            	**range:** 0..128
                            
                            .. attribute:: route_extended_community
                            
                            	Extended communities in the route
                            	**type**\:   :py:class:`RouteExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.ExternalRoutes.ExternalRoute.RouteExtendedCommunity>`
                            
                            .. attribute:: route_path
                            
                            	List of paths to this route
                            	**type**\: list of    :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.ExternalRoutes.ExternalRoute.RoutePath>`
                            
                            .. attribute:: route_topology
                            
                            	Common Route topology information
                            	**type**\:   :py:class:`RouteTopology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.ExternalRoutes.ExternalRoute.RouteTopology>`
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.prefix = None
                                self.prefix_length = None
                                self.route_extended_community = Ospfv3.Processes.Process.Vrfs.Vrf.ExternalRoutes.ExternalRoute.RouteExtendedCommunity()
                                self.route_extended_community.parent = self
                                self.route_path = YList()
                                self.route_path.parent = self
                                self.route_path.name = 'route_path'
                                self.route_topology = Ospfv3.Processes.Process.Vrfs.Vrf.ExternalRoutes.ExternalRoute.RouteTopology()
                                self.route_topology.parent = self


                            class RouteTopology(object):
                                """
                                Common Route topology information
                                
                                .. attribute:: route_cost
                                
                                	Route cost 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: route_distance
                                
                                	Route distance 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: route_id
                                
                                	Route ID 
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: route_type
                                
                                	Route type
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.route_cost = None
                                    self.route_distance = None
                                    self.route_id = None
                                    self.route_type = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:route-topology'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.route_cost is not None:
                                        return True

                                    if self.route_distance is not None:
                                        return True

                                    if self.route_id is not None:
                                        return True

                                    if self.route_type is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                    return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.ExternalRoutes.ExternalRoute.RouteTopology']['meta_info']


                            class RouteExtendedCommunity(object):
                                """
                                Extended communities in the route
                                
                                .. attribute:: extended_community_area_id
                                
                                	Area id
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: extended_community_domain_id_value
                                
                                	Domain ID value
                                	**type**\:  str
                                
                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                
                                .. attribute:: extended_community_options
                                
                                	Route Options
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: extended_community_route_type
                                
                                	Route type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: extended_community_router_id
                                
                                	Router id
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: extended_communityl_domain_id_type
                                
                                	Domain ID type
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.extended_community_area_id = None
                                    self.extended_community_domain_id_value = None
                                    self.extended_community_options = None
                                    self.extended_community_route_type = None
                                    self.extended_community_router_id = None
                                    self.extended_communityl_domain_id_type = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:route-extended-community'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.extended_community_area_id is not None:
                                        return True

                                    if self.extended_community_domain_id_value is not None:
                                        return True

                                    if self.extended_community_options is not None:
                                        return True

                                    if self.extended_community_route_type is not None:
                                        return True

                                    if self.extended_community_router_id is not None:
                                        return True

                                    if self.extended_communityl_domain_id_type is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                    return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.ExternalRoutes.ExternalRoute.RouteExtendedCommunity']['meta_info']


                            class RoutePath(object):
                                """
                                List of paths to this route
                                
                                .. attribute:: interface_name
                                
                                	Route path interface name 
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: route_backup_path
                                
                                	Backup Path Info
                                	**type**\:   :py:class:`RouteBackupPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.ExternalRoutes.ExternalRoute.RoutePath.RouteBackupPath>`
                                
                                .. attribute:: route_path_id
                                
                                	Path ID of path
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: route_path_next_hop
                                
                                	Route path next hop 
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.interface_name = None
                                    self.route_backup_path = Ospfv3.Processes.Process.Vrfs.Vrf.ExternalRoutes.ExternalRoute.RoutePath.RouteBackupPath()
                                    self.route_backup_path.parent = self
                                    self.route_path_id = None
                                    self.route_path_next_hop = None


                                class RouteBackupPath(object):
                                    """
                                    Backup Path Info
                                    
                                    .. attribute:: backup_metric
                                    
                                    	Metric
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: backup_route_interface_name
                                    
                                    	Next hop Interface
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                    
                                    .. attribute:: backup_route_next_hop_address
                                    
                                    	Nexthop IP address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: backup_route_source
                                    
                                    	IP address of source of route
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: downstream
                                    
                                    	Downstream
                                    	**type**\:  bool
                                    
                                    .. attribute:: line_card_disjoint
                                    
                                    	Line Card Disjoint
                                    	**type**\:  bool
                                    
                                    .. attribute:: node_protect
                                    
                                    	Node Protect
                                    	**type**\:  bool
                                    
                                    .. attribute:: primary_path
                                    
                                    	Primary Path
                                    	**type**\:  bool
                                    
                                    .. attribute:: srlg_disjoint
                                    
                                    	SRLG Disjoint
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.backup_metric = None
                                        self.backup_route_interface_name = None
                                        self.backup_route_next_hop_address = None
                                        self.backup_route_source = None
                                        self.downstream = None
                                        self.line_card_disjoint = None
                                        self.node_protect = None
                                        self.primary_path = None
                                        self.srlg_disjoint = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:route-backup-path'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.backup_metric is not None:
                                            return True

                                        if self.backup_route_interface_name is not None:
                                            return True

                                        if self.backup_route_next_hop_address is not None:
                                            return True

                                        if self.backup_route_source is not None:
                                            return True

                                        if self.downstream is not None:
                                            return True

                                        if self.line_card_disjoint is not None:
                                            return True

                                        if self.node_protect is not None:
                                            return True

                                        if self.primary_path is not None:
                                            return True

                                        if self.srlg_disjoint is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                        return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.ExternalRoutes.ExternalRoute.RoutePath.RouteBackupPath']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:route-path'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.interface_name is not None:
                                        return True

                                    if self.route_backup_path is not None and self.route_backup_path._has_data():
                                        return True

                                    if self.route_path_id is not None:
                                        return True

                                    if self.route_path_next_hop is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                    return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.ExternalRoutes.ExternalRoute.RoutePath']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:external-route'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.prefix is not None:
                                    return True

                                if self.prefix_length is not None:
                                    return True

                                if self.route_extended_community is not None and self.route_extended_community._has_data():
                                    return True

                                if self.route_path is not None:
                                    for child_ref in self.route_path:
                                        if child_ref._has_data():
                                            return True

                                if self.route_topology is not None and self.route_topology._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.ExternalRoutes.ExternalRoute']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:external-routes'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.external_route is not None:
                                for child_ref in self.external_route:
                                    if child_ref._has_data():
                                        return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                            return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.ExternalRoutes']['meta_info']


                    class RequestListProcessTable(object):
                        """
                        OSPFv3 request list information for all areas
                        
                        .. attribute:: request
                        
                        	OSPFv3 request list information
                        	**type**\: list of    :py:class:`Request <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.RequestListProcessTable.Request>`
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.request = YList()
                            self.request.parent = self
                            self.request.name = 'request'


                        class Request(object):
                            """
                            OSPFv3 request list information
                            
                            .. attribute:: interface_name
                            
                            	Interface name
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: is_request_sham_link
                            
                            	If true, sham link is requested 
                            	**type**\:  bool
                            
                            .. attribute:: is_request_virtual_link
                            
                            	If true, virtual link is requested 
                            	**type**\:  bool
                            
                            .. attribute:: neighbor_address
                            
                            	Neighbor address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: request
                            
                            	List of request list entries
                            	**type**\: list of    :py:class:`Request_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.RequestListProcessTable.Request.Request_>`
                            
                            .. attribute:: request_neighbor_address
                            
                            	Neighbor IP address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: request_sham_link_id
                            
                            	Request sham link ID 
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: request_virtual_link_id
                            
                            	Request virtual link ID 
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.interface_name = None
                                self.is_request_sham_link = None
                                self.is_request_virtual_link = None
                                self.neighbor_address = None
                                self.request = YList()
                                self.request.parent = self
                                self.request.name = 'request'
                                self.request_neighbor_address = None
                                self.request_sham_link_id = None
                                self.request_virtual_link_id = None


                            class Request_(object):
                                """
                                List of request list entries
                                
                                .. attribute:: header_advertising_router
                                
                                	Router ID of the advertising router
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: header_lsa_age
                                
                                	Age of the LSA (seconds)
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                	**units**\: second
                                
                                .. attribute:: header_lsa_id
                                
                                	LSA ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: header_lsa_type
                                
                                	LSA type
                                	**type**\:   :py:class:`Ospfv3Lsa1Enum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Lsa1Enum>`
                                
                                .. attribute:: header_sequence_number
                                
                                	Current LSA sequence number
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.header_advertising_router = None
                                    self.header_lsa_age = None
                                    self.header_lsa_id = None
                                    self.header_lsa_type = None
                                    self.header_sequence_number = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:request'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.header_advertising_router is not None:
                                        return True

                                    if self.header_lsa_age is not None:
                                        return True

                                    if self.header_lsa_id is not None:
                                        return True

                                    if self.header_lsa_type is not None:
                                        return True

                                    if self.header_sequence_number is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                    return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.RequestListProcessTable.Request.Request_']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:request'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.interface_name is not None:
                                    return True

                                if self.is_request_sham_link is not None:
                                    return True

                                if self.is_request_virtual_link is not None:
                                    return True

                                if self.neighbor_address is not None:
                                    return True

                                if self.request is not None:
                                    for child_ref in self.request:
                                        if child_ref._has_data():
                                            return True

                                if self.request_neighbor_address is not None:
                                    return True

                                if self.request_sham_link_id is not None:
                                    return True

                                if self.request_virtual_link_id is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.RequestListProcessTable.Request']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:request-list-process-table'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.request is not None:
                                for child_ref in self.request:
                                    if child_ref._has_data():
                                        return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                            return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.RequestListProcessTable']['meta_info']


                    class VirtualLink(object):
                        """
                        Virtual link information
                        
                        .. attribute:: interface_name
                        
                        	Interface on which this virtual link is formed
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: is_virtual_link_authentication_enabled
                        
                        	If true, virtual link authentication is enabled 
                        	**type**\:  bool
                        
                        .. attribute:: is_virtual_link_demand_circuit
                        
                        	If true, the link runs as demand circuit
                        	**type**\:  bool
                        
                        .. attribute:: is_virtual_link_encryption_enabled
                        
                        	If true, virtual link encryption is enabled 
                        	**type**\:  bool
                        
                        .. attribute:: is_virtual_link_ip_security_active
                        
                        	If true, Virtual link IP security is active 
                        	**type**\:  bool
                        
                        .. attribute:: is_virtual_link_ip_security_required
                        
                        	If true, virtual link IP security is required 
                        	**type**\:  bool
                        
                        .. attribute:: is_virtual_link_passive
                        
                        	If true, interface is passive
                        	**type**\:  bool
                        
                        .. attribute:: transit_area_id
                        
                        	Transit area id 
                        	**type**\:  str
                        
                        .. attribute:: virtual_link_authentication_spi
                        
                        	Virtual link authentication spi 
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: virtual_link_authentication_transmit
                        
                        	Virtual link authentication transmit 
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: virtual_link_cost
                        
                        	Cost of the virtual link
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: virtual_link_dc_bitless_lsa
                        
                        	Number of LSA's with demand circuit bit not set 
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: virtual_link_dead_interval
                        
                        	Dead interval (s)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: virtual_link_encrypted_authentication_transmitted
                        
                        	Virtual link encrypted authentication transmitted 
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: virtual_link_encryption_spi
                        
                        	Virtual link encryption spi
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: virtual_link_encryption_transmitted
                        
                        	Virtual link encryption transmitted 
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: virtual_link_hello_interval
                        
                        	Hello interval (s)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: virtual_link_interface_number
                        
                        	Virtual link interface number 
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: virtual_link_neighbor
                        
                        	Neighbor information 
                        	**type**\:   :py:class:`VirtualLinkNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.VirtualLink.VirtualLinkNeighbor>`
                        
                        .. attribute:: virtual_link_neighbor_address
                        
                        	Virtual link neighbor addresss 
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: virtual_link_neighbor_id
                        
                        	Neighbor on other end of this virtual link
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: virtual_link_next_hello
                        
                        	Time until next hello (s)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: virtual_link_retransmission_interval
                        
                        	Retransmission interval (s)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: virtual_link_state
                        
                        	OSPF interface state for the virtual link
                        	**type**\:   :py:class:`Ospfv3InterfaceStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3InterfaceStateEnum>`
                        
                        .. attribute:: virtual_link_wait_interval
                        
                        	Wait interval (s)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: virual_link_transmission_delay
                        
                        	Transmission delay in seconds
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.interface_name = None
                            self.is_virtual_link_authentication_enabled = None
                            self.is_virtual_link_demand_circuit = None
                            self.is_virtual_link_encryption_enabled = None
                            self.is_virtual_link_ip_security_active = None
                            self.is_virtual_link_ip_security_required = None
                            self.is_virtual_link_passive = None
                            self.transit_area_id = None
                            self.virtual_link_authentication_spi = None
                            self.virtual_link_authentication_transmit = None
                            self.virtual_link_cost = None
                            self.virtual_link_dc_bitless_lsa = None
                            self.virtual_link_dead_interval = None
                            self.virtual_link_encrypted_authentication_transmitted = None
                            self.virtual_link_encryption_spi = None
                            self.virtual_link_encryption_transmitted = None
                            self.virtual_link_hello_interval = None
                            self.virtual_link_interface_number = None
                            self.virtual_link_neighbor = Ospfv3.Processes.Process.Vrfs.Vrf.VirtualLink.VirtualLinkNeighbor()
                            self.virtual_link_neighbor.parent = self
                            self.virtual_link_neighbor_address = None
                            self.virtual_link_neighbor_id = None
                            self.virtual_link_next_hello = None
                            self.virtual_link_retransmission_interval = None
                            self.virtual_link_state = None
                            self.virtual_link_wait_interval = None
                            self.virual_link_transmission_delay = None


                        class VirtualLinkNeighbor(object):
                            """
                            Neighbor information 
                            
                            .. attribute:: is_virtual_link_hello_suppressed
                            
                            	If true, hello suppressed 
                            	**type**\:  bool
                            
                            .. attribute:: virtual_link_retransmission
                            
                            	Virtual link retransmission information 
                            	**type**\:   :py:class:`VirtualLinkRetransmission <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.VirtualLink.VirtualLinkNeighbor.VirtualLinkRetransmission>`
                            
                            .. attribute:: virtual_link_state
                            
                            	OSPF interface state for the virtual link
                            	**type**\:   :py:class:`Ospfv3InterfaceStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3InterfaceStateEnum>`
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.is_virtual_link_hello_suppressed = None
                                self.virtual_link_retransmission = Ospfv3.Processes.Process.Vrfs.Vrf.VirtualLink.VirtualLinkNeighbor.VirtualLinkRetransmission()
                                self.virtual_link_retransmission.parent = self
                                self.virtual_link_state = None


                            class VirtualLinkRetransmission(object):
                                """
                                Virtual link retransmission information 
                                
                                .. attribute:: area_first_flood
                                
                                	First flood item for area scope LSAs
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: area_first_flood_index
                                
                                	Index of the first flood item for area scope LSAs
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: area_flood_index
                                
                                	Area scope LSA's flood index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: area_next_flood
                                
                                	Next flood item for area scope LSAs
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: area_next_flood_index
                                
                                	Index of next flood item for Area scope LSAs
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: as_first_flood
                                
                                	First flood item for AS scope LSAs
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: as_first_flood_index
                                
                                	Index for first flood item for AS scope LSAs
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: as_flood_index
                                
                                	AS scope LSA's flood index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: as_next_flood
                                
                                	Next flood item for AS scope LSAs
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: as_next_flood_index
                                
                                	Index of next flood item for AS scope LSAs
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: database_descriptor_retransmissions
                                
                                	Number of database descriptor retransmissions during last exchange
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: last_retransmission_length
                                
                                	Number of LSAs sent in last retransmission
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: last_retransmission_time
                                
                                	Last retransmission scan time (ms)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: link_first_flood
                                
                                	Link first flood information 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: link_first_flood_index
                                
                                	Link first flood information index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: link_flood_index
                                
                                	Link flood index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: link_next_flood
                                
                                	Link next flood information 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: link_next_flood_index
                                
                                	Link next flood information index 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: lsa_retransmission_timer
                                
                                	Time until next LSA retransmission (ms)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: maximum_retransmission_length
                                
                                	Maximum number of LSAs sent in a retransmission
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: maximum_retransmission_time
                                
                                	Maximum retransmission scan time (ms)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: neighbor_retransmissions
                                
                                	Number of neighbor retransmissions 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: retransmissions
                                
                                	Number of retransmissions for this neighbor
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.area_first_flood = None
                                    self.area_first_flood_index = None
                                    self.area_flood_index = None
                                    self.area_next_flood = None
                                    self.area_next_flood_index = None
                                    self.as_first_flood = None
                                    self.as_first_flood_index = None
                                    self.as_flood_index = None
                                    self.as_next_flood = None
                                    self.as_next_flood_index = None
                                    self.database_descriptor_retransmissions = None
                                    self.last_retransmission_length = None
                                    self.last_retransmission_time = None
                                    self.link_first_flood = None
                                    self.link_first_flood_index = None
                                    self.link_flood_index = None
                                    self.link_next_flood = None
                                    self.link_next_flood_index = None
                                    self.lsa_retransmission_timer = None
                                    self.maximum_retransmission_length = None
                                    self.maximum_retransmission_time = None
                                    self.neighbor_retransmissions = None
                                    self.retransmissions = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:virtual-link-retransmission'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.area_first_flood is not None:
                                        return True

                                    if self.area_first_flood_index is not None:
                                        return True

                                    if self.area_flood_index is not None:
                                        return True

                                    if self.area_next_flood is not None:
                                        return True

                                    if self.area_next_flood_index is not None:
                                        return True

                                    if self.as_first_flood is not None:
                                        return True

                                    if self.as_first_flood_index is not None:
                                        return True

                                    if self.as_flood_index is not None:
                                        return True

                                    if self.as_next_flood is not None:
                                        return True

                                    if self.as_next_flood_index is not None:
                                        return True

                                    if self.database_descriptor_retransmissions is not None:
                                        return True

                                    if self.last_retransmission_length is not None:
                                        return True

                                    if self.last_retransmission_time is not None:
                                        return True

                                    if self.link_first_flood is not None:
                                        return True

                                    if self.link_first_flood_index is not None:
                                        return True

                                    if self.link_flood_index is not None:
                                        return True

                                    if self.link_next_flood is not None:
                                        return True

                                    if self.link_next_flood_index is not None:
                                        return True

                                    if self.lsa_retransmission_timer is not None:
                                        return True

                                    if self.maximum_retransmission_length is not None:
                                        return True

                                    if self.maximum_retransmission_time is not None:
                                        return True

                                    if self.neighbor_retransmissions is not None:
                                        return True

                                    if self.retransmissions is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                    return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.VirtualLink.VirtualLinkNeighbor.VirtualLinkRetransmission']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:virtual-link-neighbor'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.is_virtual_link_hello_suppressed is not None:
                                    return True

                                if self.virtual_link_retransmission is not None and self.virtual_link_retransmission._has_data():
                                    return True

                                if self.virtual_link_state is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.VirtualLink.VirtualLinkNeighbor']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:virtual-link'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.interface_name is not None:
                                return True

                            if self.is_virtual_link_authentication_enabled is not None:
                                return True

                            if self.is_virtual_link_demand_circuit is not None:
                                return True

                            if self.is_virtual_link_encryption_enabled is not None:
                                return True

                            if self.is_virtual_link_ip_security_active is not None:
                                return True

                            if self.is_virtual_link_ip_security_required is not None:
                                return True

                            if self.is_virtual_link_passive is not None:
                                return True

                            if self.transit_area_id is not None:
                                return True

                            if self.virtual_link_authentication_spi is not None:
                                return True

                            if self.virtual_link_authentication_transmit is not None:
                                return True

                            if self.virtual_link_cost is not None:
                                return True

                            if self.virtual_link_dc_bitless_lsa is not None:
                                return True

                            if self.virtual_link_dead_interval is not None:
                                return True

                            if self.virtual_link_encrypted_authentication_transmitted is not None:
                                return True

                            if self.virtual_link_encryption_spi is not None:
                                return True

                            if self.virtual_link_encryption_transmitted is not None:
                                return True

                            if self.virtual_link_hello_interval is not None:
                                return True

                            if self.virtual_link_interface_number is not None:
                                return True

                            if self.virtual_link_neighbor is not None and self.virtual_link_neighbor._has_data():
                                return True

                            if self.virtual_link_neighbor_address is not None:
                                return True

                            if self.virtual_link_neighbor_id is not None:
                                return True

                            if self.virtual_link_next_hello is not None:
                                return True

                            if self.virtual_link_retransmission_interval is not None:
                                return True

                            if self.virtual_link_state is not None:
                                return True

                            if self.virtual_link_wait_interval is not None:
                                return True

                            if self.virual_link_transmission_delay is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                            return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.VirtualLink']['meta_info']


                    class FloodListProcessTable(object):
                        """
                        OSPFv3 flood list information table for all
                        areas
                        
                        .. attribute:: flood
                        
                        	OSPFv3 flood list information
                        	**type**\: list of    :py:class:`Flood <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.FloodListProcessTable.Flood>`
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.flood = YList()
                            self.flood.parent = self
                            self.flood.name = 'flood'


                        class Flood(object):
                            """
                            OSPFv3 flood list information
                            
                            .. attribute:: interface_name  <key>
                            
                            	Interface name
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: area_flood
                            
                            	Area scope floodlist
                            	**type**\: list of    :py:class:`AreaFlood <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.FloodListProcessTable.Flood.AreaFlood>`
                            
                            .. attribute:: as_flood
                            
                            	AS scope floodlist
                            	**type**\: list of    :py:class:`AsFlood <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.FloodListProcessTable.Flood.AsFlood>`
                            
                            .. attribute:: link_flood
                            
                            	Link floodlist
                            	**type**\: list of    :py:class:`LinkFlood <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.FloodListProcessTable.Flood.LinkFlood>`
                            
                            .. attribute:: ls_transmission_timer
                            
                            	Time until next LS transmission (ms) 
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: queue_length
                            
                            	Number of LSAs currently being flooded 
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.interface_name = None
                                self.area_flood = YList()
                                self.area_flood.parent = self
                                self.area_flood.name = 'area_flood'
                                self.as_flood = YList()
                                self.as_flood.parent = self
                                self.as_flood.name = 'as_flood'
                                self.link_flood = YList()
                                self.link_flood.parent = self
                                self.link_flood.name = 'link_flood'
                                self.ls_transmission_timer = None
                                self.queue_length = None


                            class LinkFlood(object):
                                """
                                Link floodlist
                                
                                .. attribute:: header_advertising_router
                                
                                	Router ID of the advertising router
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: header_lsa_age
                                
                                	Age of the LSA (seconds)
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                	**units**\: second
                                
                                .. attribute:: header_lsa_id
                                
                                	LSA ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: header_lsa_type
                                
                                	LSA type
                                	**type**\:   :py:class:`Ospfv3Lsa1Enum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Lsa1Enum>`
                                
                                .. attribute:: header_sequence_number
                                
                                	Current LSA sequence number
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.header_advertising_router = None
                                    self.header_lsa_age = None
                                    self.header_lsa_id = None
                                    self.header_lsa_type = None
                                    self.header_sequence_number = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:link-flood'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.header_advertising_router is not None:
                                        return True

                                    if self.header_lsa_age is not None:
                                        return True

                                    if self.header_lsa_id is not None:
                                        return True

                                    if self.header_lsa_type is not None:
                                        return True

                                    if self.header_sequence_number is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                    return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.FloodListProcessTable.Flood.LinkFlood']['meta_info']


                            class AreaFlood(object):
                                """
                                Area scope floodlist
                                
                                .. attribute:: header_advertising_router
                                
                                	Router ID of the advertising router
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: header_lsa_age
                                
                                	Age of the LSA (seconds)
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                	**units**\: second
                                
                                .. attribute:: header_lsa_id
                                
                                	LSA ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: header_lsa_type
                                
                                	LSA type
                                	**type**\:   :py:class:`Ospfv3Lsa1Enum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Lsa1Enum>`
                                
                                .. attribute:: header_sequence_number
                                
                                	Current LSA sequence number
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.header_advertising_router = None
                                    self.header_lsa_age = None
                                    self.header_lsa_id = None
                                    self.header_lsa_type = None
                                    self.header_sequence_number = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:area-flood'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.header_advertising_router is not None:
                                        return True

                                    if self.header_lsa_age is not None:
                                        return True

                                    if self.header_lsa_id is not None:
                                        return True

                                    if self.header_lsa_type is not None:
                                        return True

                                    if self.header_sequence_number is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                    return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.FloodListProcessTable.Flood.AreaFlood']['meta_info']


                            class AsFlood(object):
                                """
                                AS scope floodlist
                                
                                .. attribute:: header_advertising_router
                                
                                	Router ID of the advertising router
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: header_lsa_age
                                
                                	Age of the LSA (seconds)
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                	**units**\: second
                                
                                .. attribute:: header_lsa_id
                                
                                	LSA ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: header_lsa_type
                                
                                	LSA type
                                	**type**\:   :py:class:`Ospfv3Lsa1Enum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Lsa1Enum>`
                                
                                .. attribute:: header_sequence_number
                                
                                	Current LSA sequence number
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.header_advertising_router = None
                                    self.header_lsa_age = None
                                    self.header_lsa_id = None
                                    self.header_lsa_type = None
                                    self.header_sequence_number = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:as-flood'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.header_advertising_router is not None:
                                        return True

                                    if self.header_lsa_age is not None:
                                        return True

                                    if self.header_lsa_id is not None:
                                        return True

                                    if self.header_lsa_type is not None:
                                        return True

                                    if self.header_sequence_number is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                    return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.FloodListProcessTable.Flood.AsFlood']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')
                                if self.interface_name is None:
                                    raise YPYModelError('Key property interface_name is None')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:flood[Cisco-IOS-XR-ipv6-ospfv3-oper:interface-name = ' + str(self.interface_name) + ']'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.interface_name is not None:
                                    return True

                                if self.area_flood is not None:
                                    for child_ref in self.area_flood:
                                        if child_ref._has_data():
                                            return True

                                if self.as_flood is not None:
                                    for child_ref in self.as_flood:
                                        if child_ref._has_data():
                                            return True

                                if self.link_flood is not None:
                                    for child_ref in self.link_flood:
                                        if child_ref._has_data():
                                            return True

                                if self.ls_transmission_timer is not None:
                                    return True

                                if self.queue_length is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.FloodListProcessTable.Flood']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:flood-list-process-table'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.flood is not None:
                                for child_ref in self.flood:
                                    if child_ref._has_data():
                                        return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                            return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.FloodListProcessTable']['meta_info']


                    class RouteSummary(object):
                        """
                        Summarize OSPFv3 local RIB tables
                        
                        .. attribute:: extern_one_route
                        
                        	Extern 1 route summary 
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: extern_two_route
                        
                        	Extern 2 route summary 
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: inter_area_route
                        
                        	Inter route summary 
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: intra_area_route
                        
                        	Intra route summary 
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: nssa_one_route
                        
                        	NSSA 1 route summary 
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: nssa_two_route
                        
                        	NSSA 2 route summary 
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: redistribution_route
                        
                        	Redistribution route summary 
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: route_connected
                        
                        	Route connected 
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: route_id
                        
                        	Route summary of a route ID 
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: total_received_route
                        
                        	Total route received summary
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: total_sent_route
                        
                        	Total route summary 
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.extern_one_route = None
                            self.extern_two_route = None
                            self.inter_area_route = None
                            self.intra_area_route = None
                            self.nssa_one_route = None
                            self.nssa_two_route = None
                            self.redistribution_route = None
                            self.route_connected = None
                            self.route_id = None
                            self.total_received_route = None
                            self.total_sent_route = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:route-summary'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.extern_one_route is not None:
                                return True

                            if self.extern_two_route is not None:
                                return True

                            if self.inter_area_route is not None:
                                return True

                            if self.intra_area_route is not None:
                                return True

                            if self.nssa_one_route is not None:
                                return True

                            if self.nssa_two_route is not None:
                                return True

                            if self.redistribution_route is not None:
                                return True

                            if self.route_connected is not None:
                                return True

                            if self.route_id is not None:
                                return True

                            if self.total_received_route is not None:
                                return True

                            if self.total_sent_route is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                            return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.RouteSummary']['meta_info']


                    class Areas(object):
                        """
                        OSPFv3 area table
                        
                        .. attribute:: area
                        
                        	Per\-area information
                        	**type**\: list of    :py:class:`Area <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area>`
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.area = YList()
                            self.area.parent = self
                            self.area.name = 'area'


                        class Area(object):
                            """
                            Per\-area information
                            
                            .. attribute:: area_id  <key>
                            
                            	Area ID
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: database_summary_table
                            
                            	Database summary table
                            	**type**\:   :py:class:`DatabaseSummaryTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseSummaryTable>`
                            
                            .. attribute:: database_table
                            
                            	OSPF Link State Database
                            	**type**\:   :py:class:`DatabaseTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable>`
                            
                            .. attribute:: flood_list_table
                            
                            	OSPFv3 flood list information table for an area
                            	**type**\:   :py:class:`FloodListTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.FloodListTable>`
                            
                            .. attribute:: interface_brief_table
                            
                            	OSPFv3 interface brief information table for an area
                            	**type**\:   :py:class:`InterfaceBriefTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.InterfaceBriefTable>`
                            
                            .. attribute:: interface_table
                            
                            	OSPFv3 interface information table for an area
                            	**type**\:   :py:class:`InterfaceTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.InterfaceTable>`
                            
                            .. attribute:: neighbor_detail_table
                            
                            	OSPFv3 area neighbor information table
                            	**type**\:   :py:class:`NeighborDetailTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborDetailTable>`
                            
                            .. attribute:: neighbor_table
                            
                            	OSPFv3 neighbor information table
                            	**type**\:   :py:class:`NeighborTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborTable>`
                            
                            .. attribute:: request_list_table
                            
                            	OSPFv3 request list information in an area
                            	**type**\:   :py:class:`RequestListTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.RequestListTable>`
                            
                            .. attribute:: retransmission_list_table
                            
                            	OSPFv3 retransmission list information table in an area
                            	**type**\:   :py:class:`RetransmissionListTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.RetransmissionListTable>`
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.area_id = None
                                self.database_summary_table = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseSummaryTable()
                                self.database_summary_table.parent = self
                                self.database_table = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable()
                                self.database_table.parent = self
                                self.flood_list_table = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.FloodListTable()
                                self.flood_list_table.parent = self
                                self.interface_brief_table = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.InterfaceBriefTable()
                                self.interface_brief_table.parent = self
                                self.interface_table = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.InterfaceTable()
                                self.interface_table.parent = self
                                self.neighbor_detail_table = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborDetailTable()
                                self.neighbor_detail_table.parent = self
                                self.neighbor_table = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborTable()
                                self.neighbor_table.parent = self
                                self.request_list_table = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.RequestListTable()
                                self.request_list_table.parent = self
                                self.retransmission_list_table = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.RetransmissionListTable()
                                self.retransmission_list_table.parent = self


                            class NeighborDetailTable(object):
                                """
                                OSPFv3 area neighbor information table
                                
                                .. attribute:: neighbor_detail
                                
                                	OSPFv3 neighbor detail information
                                	**type**\: list of    :py:class:`NeighborDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborDetailTable.NeighborDetail>`
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.neighbor_detail = YList()
                                    self.neighbor_detail.parent = self
                                    self.neighbor_detail.name = 'neighbor_detail'


                                class NeighborDetail(object):
                                    """
                                    OSPFv3 neighbor detail information
                                    
                                    .. attribute:: interface_name
                                    
                                    	Interface name
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                    
                                    .. attribute:: is_neighbor_sham_link
                                    
                                    	If true, neighbor is on a sham link 
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_neighbor_virtual_link
                                    
                                    	If true, neighbor is on a virtual link 
                                    	**type**\:  bool
                                    
                                    .. attribute:: neighbor_address
                                    
                                    	Neighbor ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: neighbor_address_xr
                                    
                                    	Neighbor IP Address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: neighbor_bfd_info
                                    
                                    	Neighbor BFD information
                                    	**type**\:   :py:class:`NeighborBfdInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborDetailTable.NeighborDetail.NeighborBfdInfo>`
                                    
                                    .. attribute:: neighbor_dead_timer
                                    
                                    	Time until neighbor's dead timer expires (seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: neighbor_designated_router
                                    
                                    	Designated router 
                                    	**type**\:  str
                                    
                                    	**length:** 0..9
                                    
                                    .. attribute:: neighbor_detail
                                    
                                    	Detailed OSPFv3 neighbor information 
                                    	**type**\:   :py:class:`NeighborDetail_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborDetailTable.NeighborDetail.NeighborDetail_>`
                                    
                                    .. attribute:: neighbor_dr_priority
                                    
                                    	Neighbor's DR priority
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: neighbor_interface_id
                                    
                                    	Neighbor interface ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: neighbor_sham_link_id
                                    
                                    	Neighbor sham link id 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: neighbor_state
                                    
                                    	Neighbor's state
                                    	**type**\:   :py:class:`Ospfv3NeighborStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3NeighborStateEnum>`
                                    
                                    .. attribute:: neighbor_up_time
                                    
                                    	Amount of time since the adjacency is up (seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: neighbor_virtual_link_id
                                    
                                    	Neighbor virtual link id 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.interface_name = None
                                        self.is_neighbor_sham_link = None
                                        self.is_neighbor_virtual_link = None
                                        self.neighbor_address = None
                                        self.neighbor_address_xr = None
                                        self.neighbor_bfd_info = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborDetailTable.NeighborDetail.NeighborBfdInfo()
                                        self.neighbor_bfd_info.parent = self
                                        self.neighbor_dead_timer = None
                                        self.neighbor_designated_router = None
                                        self.neighbor_detail = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborDetailTable.NeighborDetail.NeighborDetail_()
                                        self.neighbor_detail.parent = self
                                        self.neighbor_dr_priority = None
                                        self.neighbor_interface_id = None
                                        self.neighbor_sham_link_id = None
                                        self.neighbor_state = None
                                        self.neighbor_up_time = None
                                        self.neighbor_virtual_link_id = None


                                    class NeighborDetail_(object):
                                        """
                                        Detailed OSPFv3 neighbor information 
                                        
                                        .. attribute:: interface_type
                                        
                                        	Interface type
                                        	**type**\:   :py:class:`Ospfv3InterfaceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3InterfaceEnum>`
                                        
                                        .. attribute:: is_neighbor_filtered
                                        
                                        	If true, filter outgoing LSAs 
                                        	**type**\:  bool
                                        
                                        .. attribute:: neighbor_backup_designated_router_address
                                        
                                        	Address of backup designated router
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: neighbor_cost
                                        
                                        	Cost of path to this neighbor 
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: neighbor_designated_router_address
                                        
                                        	Address of designated router
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: neighbor_ignore_timer
                                        
                                        	Remaining time when ignore timer is running 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: neighbor_option
                                        
                                        	 This is bitmask of neighbor's option field received 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: neighbor_retransmission
                                        
                                        	Retransmission information with this neighbor
                                        	**type**\:   :py:class:`NeighborRetransmission <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborDetailTable.NeighborDetail.NeighborDetail_.NeighborRetransmission>`
                                        
                                        .. attribute:: next_poll_interval
                                        
                                        	For NBMA networks, amount of time remaining in seconds before the next poll interval expires and Hello is sent (s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: pending_events
                                        
                                        	Number of pending events 
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: poll_interval
                                        
                                        	Poll interval (s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: state_changes
                                        
                                        	Number of state changes 
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface_type = None
                                            self.is_neighbor_filtered = None
                                            self.neighbor_backup_designated_router_address = None
                                            self.neighbor_cost = None
                                            self.neighbor_designated_router_address = None
                                            self.neighbor_ignore_timer = None
                                            self.neighbor_option = None
                                            self.neighbor_retransmission = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborDetailTable.NeighborDetail.NeighborDetail_.NeighborRetransmission()
                                            self.neighbor_retransmission.parent = self
                                            self.next_poll_interval = None
                                            self.pending_events = None
                                            self.poll_interval = None
                                            self.state_changes = None


                                        class NeighborRetransmission(object):
                                            """
                                            Retransmission information with this neighbor
                                            
                                            .. attribute:: area_first_flood
                                            
                                            	First flood item for area scope LSAs
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: area_first_flood_index
                                            
                                            	Index of the first flood item for area scope LSAs
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: area_flood_index
                                            
                                            	Area scope LSA's flood index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: area_next_flood
                                            
                                            	Next flood item for area scope LSAs
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: area_next_flood_index
                                            
                                            	Index of next flood item for Area scope LSAs
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: as_first_flood
                                            
                                            	First flood item for AS scope LSAs
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: as_first_flood_index
                                            
                                            	Index for first flood item for AS scope LSAs
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: as_flood_index
                                            
                                            	AS scope LSA's flood index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: as_next_flood
                                            
                                            	Next flood item for AS scope LSAs
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: as_next_flood_index
                                            
                                            	Index of next flood item for AS scope LSAs
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: database_descriptor_retransmissions
                                            
                                            	Number of database descriptor retransmissions during last exchange
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_retransmission_length
                                            
                                            	Number of LSAs sent in last retransmission
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_retransmission_time
                                            
                                            	Last retransmission scan time (ms)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: link_first_flood
                                            
                                            	Link first flood information 
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: link_first_flood_index
                                            
                                            	Link first flood information index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: link_flood_index
                                            
                                            	Link flood index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: link_next_flood
                                            
                                            	Link next flood information 
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: link_next_flood_index
                                            
                                            	Link next flood information index 
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: lsa_retransmission_timer
                                            
                                            	Time until next LSA retransmission (ms)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: maximum_retransmission_length
                                            
                                            	Maximum number of LSAs sent in a retransmission
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: maximum_retransmission_time
                                            
                                            	Maximum retransmission scan time (ms)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: neighbor_retransmissions
                                            
                                            	Number of neighbor retransmissions 
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: retransmissions
                                            
                                            	Number of retransmissions for this neighbor
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.area_first_flood = None
                                                self.area_first_flood_index = None
                                                self.area_flood_index = None
                                                self.area_next_flood = None
                                                self.area_next_flood_index = None
                                                self.as_first_flood = None
                                                self.as_first_flood_index = None
                                                self.as_flood_index = None
                                                self.as_next_flood = None
                                                self.as_next_flood_index = None
                                                self.database_descriptor_retransmissions = None
                                                self.last_retransmission_length = None
                                                self.last_retransmission_time = None
                                                self.link_first_flood = None
                                                self.link_first_flood_index = None
                                                self.link_flood_index = None
                                                self.link_next_flood = None
                                                self.link_next_flood_index = None
                                                self.lsa_retransmission_timer = None
                                                self.maximum_retransmission_length = None
                                                self.maximum_retransmission_time = None
                                                self.neighbor_retransmissions = None
                                                self.retransmissions = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:neighbor-retransmission'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.area_first_flood is not None:
                                                    return True

                                                if self.area_first_flood_index is not None:
                                                    return True

                                                if self.area_flood_index is not None:
                                                    return True

                                                if self.area_next_flood is not None:
                                                    return True

                                                if self.area_next_flood_index is not None:
                                                    return True

                                                if self.as_first_flood is not None:
                                                    return True

                                                if self.as_first_flood_index is not None:
                                                    return True

                                                if self.as_flood_index is not None:
                                                    return True

                                                if self.as_next_flood is not None:
                                                    return True

                                                if self.as_next_flood_index is not None:
                                                    return True

                                                if self.database_descriptor_retransmissions is not None:
                                                    return True

                                                if self.last_retransmission_length is not None:
                                                    return True

                                                if self.last_retransmission_time is not None:
                                                    return True

                                                if self.link_first_flood is not None:
                                                    return True

                                                if self.link_first_flood_index is not None:
                                                    return True

                                                if self.link_flood_index is not None:
                                                    return True

                                                if self.link_next_flood is not None:
                                                    return True

                                                if self.link_next_flood_index is not None:
                                                    return True

                                                if self.lsa_retransmission_timer is not None:
                                                    return True

                                                if self.maximum_retransmission_length is not None:
                                                    return True

                                                if self.maximum_retransmission_time is not None:
                                                    return True

                                                if self.neighbor_retransmissions is not None:
                                                    return True

                                                if self.retransmissions is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborDetailTable.NeighborDetail.NeighborDetail_.NeighborRetransmission']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:neighbor-detail'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface_type is not None:
                                                return True

                                            if self.is_neighbor_filtered is not None:
                                                return True

                                            if self.neighbor_backup_designated_router_address is not None:
                                                return True

                                            if self.neighbor_cost is not None:
                                                return True

                                            if self.neighbor_designated_router_address is not None:
                                                return True

                                            if self.neighbor_ignore_timer is not None:
                                                return True

                                            if self.neighbor_option is not None:
                                                return True

                                            if self.neighbor_retransmission is not None and self.neighbor_retransmission._has_data():
                                                return True

                                            if self.next_poll_interval is not None:
                                                return True

                                            if self.pending_events is not None:
                                                return True

                                            if self.poll_interval is not None:
                                                return True

                                            if self.state_changes is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborDetailTable.NeighborDetail.NeighborDetail_']['meta_info']


                                    class NeighborBfdInfo(object):
                                        """
                                        Neighbor BFD information
                                        
                                        .. attribute:: bfd_intf_enable_mode
                                        
                                        	BFD enable mode \- Default/Strict
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bfd_status_flag
                                        
                                        	Status of the BFD Session
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.bfd_intf_enable_mode = None
                                            self.bfd_status_flag = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:neighbor-bfd-info'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bfd_intf_enable_mode is not None:
                                                return True

                                            if self.bfd_status_flag is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborDetailTable.NeighborDetail.NeighborBfdInfo']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:neighbor-detail'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.interface_name is not None:
                                            return True

                                        if self.is_neighbor_sham_link is not None:
                                            return True

                                        if self.is_neighbor_virtual_link is not None:
                                            return True

                                        if self.neighbor_address is not None:
                                            return True

                                        if self.neighbor_address_xr is not None:
                                            return True

                                        if self.neighbor_bfd_info is not None and self.neighbor_bfd_info._has_data():
                                            return True

                                        if self.neighbor_dead_timer is not None:
                                            return True

                                        if self.neighbor_designated_router is not None:
                                            return True

                                        if self.neighbor_detail is not None and self.neighbor_detail._has_data():
                                            return True

                                        if self.neighbor_dr_priority is not None:
                                            return True

                                        if self.neighbor_interface_id is not None:
                                            return True

                                        if self.neighbor_sham_link_id is not None:
                                            return True

                                        if self.neighbor_state is not None:
                                            return True

                                        if self.neighbor_up_time is not None:
                                            return True

                                        if self.neighbor_virtual_link_id is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                        return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborDetailTable.NeighborDetail']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:neighbor-detail-table'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.neighbor_detail is not None:
                                        for child_ref in self.neighbor_detail:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                    return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborDetailTable']['meta_info']


                            class InterfaceBriefTable(object):
                                """
                                OSPFv3 interface brief information table for
                                an area
                                
                                .. attribute:: interface_brief
                                
                                	Interface brief information
                                	**type**\: list of    :py:class:`InterfaceBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.InterfaceBriefTable.InterfaceBrief>`
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.interface_brief = YList()
                                    self.interface_brief.parent = self
                                    self.interface_brief.name = 'interface_brief'


                                class InterfaceBrief(object):
                                    """
                                    Interface brief information
                                    
                                    .. attribute:: interface_name  <key>
                                    
                                    	Interface name
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                    
                                    .. attribute:: interface_address
                                    
                                    	Interface IP address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: interface_adjacent_neighbors
                                    
                                    	Total number of adjacent neighbors
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: interface_link_cost
                                    
                                    	Interface link cost
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: interface_neighbors
                                    
                                    	Total number of neighbors 
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: network_type
                                    
                                    	Network type
                                    	**type**\:   :py:class:`Ospfv3InterfaceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3InterfaceEnum>`
                                    
                                    .. attribute:: ospf_interface_state
                                    
                                    	Interface OSPF state
                                    	**type**\:   :py:class:`Ospfv3InterfaceStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3InterfaceStateEnum>`
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.interface_name = None
                                        self.interface_address = None
                                        self.interface_adjacent_neighbors = None
                                        self.interface_link_cost = None
                                        self.interface_neighbors = None
                                        self.network_type = None
                                        self.ospf_interface_state = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')
                                        if self.interface_name is None:
                                            raise YPYModelError('Key property interface_name is None')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:interface-brief[Cisco-IOS-XR-ipv6-ospfv3-oper:interface-name = ' + str(self.interface_name) + ']'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.interface_name is not None:
                                            return True

                                        if self.interface_address is not None:
                                            return True

                                        if self.interface_adjacent_neighbors is not None:
                                            return True

                                        if self.interface_link_cost is not None:
                                            return True

                                        if self.interface_neighbors is not None:
                                            return True

                                        if self.network_type is not None:
                                            return True

                                        if self.ospf_interface_state is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                        return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.InterfaceBriefTable.InterfaceBrief']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:interface-brief-table'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.interface_brief is not None:
                                        for child_ref in self.interface_brief:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                    return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.InterfaceBriefTable']['meta_info']


                            class RequestListTable(object):
                                """
                                OSPFv3 request list information in an area
                                
                                .. attribute:: request
                                
                                	OSPFv3 request list information
                                	**type**\: list of    :py:class:`Request <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.RequestListTable.Request>`
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.request = YList()
                                    self.request.parent = self
                                    self.request.name = 'request'


                                class Request(object):
                                    """
                                    OSPFv3 request list information
                                    
                                    .. attribute:: interface_name
                                    
                                    	Interface name
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                    
                                    .. attribute:: is_request_sham_link
                                    
                                    	If true, sham link is requested 
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_request_virtual_link
                                    
                                    	If true, virtual link is requested 
                                    	**type**\:  bool
                                    
                                    .. attribute:: neighbor_address
                                    
                                    	Neighbor address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: request
                                    
                                    	List of request list entries
                                    	**type**\: list of    :py:class:`Request_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.RequestListTable.Request.Request_>`
                                    
                                    .. attribute:: request_neighbor_address
                                    
                                    	Neighbor IP address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: request_sham_link_id
                                    
                                    	Request sham link ID 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: request_virtual_link_id
                                    
                                    	Request virtual link ID 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.interface_name = None
                                        self.is_request_sham_link = None
                                        self.is_request_virtual_link = None
                                        self.neighbor_address = None
                                        self.request = YList()
                                        self.request.parent = self
                                        self.request.name = 'request'
                                        self.request_neighbor_address = None
                                        self.request_sham_link_id = None
                                        self.request_virtual_link_id = None


                                    class Request_(object):
                                        """
                                        List of request list entries
                                        
                                        .. attribute:: header_advertising_router
                                        
                                        	Router ID of the advertising router
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: header_lsa_age
                                        
                                        	Age of the LSA (seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: header_lsa_id
                                        
                                        	LSA ID
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: header_lsa_type
                                        
                                        	LSA type
                                        	**type**\:   :py:class:`Ospfv3Lsa1Enum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Lsa1Enum>`
                                        
                                        .. attribute:: header_sequence_number
                                        
                                        	Current LSA sequence number
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.header_advertising_router = None
                                            self.header_lsa_age = None
                                            self.header_lsa_id = None
                                            self.header_lsa_type = None
                                            self.header_sequence_number = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:request'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.header_advertising_router is not None:
                                                return True

                                            if self.header_lsa_age is not None:
                                                return True

                                            if self.header_lsa_id is not None:
                                                return True

                                            if self.header_lsa_type is not None:
                                                return True

                                            if self.header_sequence_number is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.RequestListTable.Request.Request_']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:request'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.interface_name is not None:
                                            return True

                                        if self.is_request_sham_link is not None:
                                            return True

                                        if self.is_request_virtual_link is not None:
                                            return True

                                        if self.neighbor_address is not None:
                                            return True

                                        if self.request is not None:
                                            for child_ref in self.request:
                                                if child_ref._has_data():
                                                    return True

                                        if self.request_neighbor_address is not None:
                                            return True

                                        if self.request_sham_link_id is not None:
                                            return True

                                        if self.request_virtual_link_id is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                        return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.RequestListTable.Request']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:request-list-table'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.request is not None:
                                        for child_ref in self.request:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                    return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.RequestListTable']['meta_info']


                            class NeighborTable(object):
                                """
                                OSPFv3 neighbor information table
                                
                                .. attribute:: neighbor
                                
                                	OSPFv3 neighbor detail information
                                	**type**\: list of    :py:class:`Neighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborTable.Neighbor>`
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.neighbor = YList()
                                    self.neighbor.parent = self
                                    self.neighbor.name = 'neighbor'


                                class Neighbor(object):
                                    """
                                    OSPFv3 neighbor detail information
                                    
                                    .. attribute:: interface_name
                                    
                                    	Interface name
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                    
                                    .. attribute:: is_neighbor_sham_link
                                    
                                    	If true, neighbor is on a sham link 
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_neighbor_virtual_link
                                    
                                    	If true, neighbor is on a virtual link 
                                    	**type**\:  bool
                                    
                                    .. attribute:: neighbor_address
                                    
                                    	Neighbor ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: neighbor_address_xr
                                    
                                    	Neighbor IP Address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: neighbor_bfd_info
                                    
                                    	Neighbor BFD information
                                    	**type**\:   :py:class:`NeighborBfdInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborTable.Neighbor.NeighborBfdInfo>`
                                    
                                    .. attribute:: neighbor_dead_timer
                                    
                                    	Time until neighbor's dead timer expires (seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: neighbor_designated_router
                                    
                                    	Designated router 
                                    	**type**\:  str
                                    
                                    	**length:** 0..9
                                    
                                    .. attribute:: neighbor_detail
                                    
                                    	Detailed OSPFv3 neighbor information 
                                    	**type**\:   :py:class:`NeighborDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborTable.Neighbor.NeighborDetail>`
                                    
                                    .. attribute:: neighbor_dr_priority
                                    
                                    	Neighbor's DR priority
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: neighbor_interface_id
                                    
                                    	Neighbor interface ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: neighbor_sham_link_id
                                    
                                    	Neighbor sham link id 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: neighbor_state
                                    
                                    	Neighbor's state
                                    	**type**\:   :py:class:`Ospfv3NeighborStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3NeighborStateEnum>`
                                    
                                    .. attribute:: neighbor_up_time
                                    
                                    	Amount of time since the adjacency is up (seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: neighbor_virtual_link_id
                                    
                                    	Neighbor virtual link id 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.interface_name = None
                                        self.is_neighbor_sham_link = None
                                        self.is_neighbor_virtual_link = None
                                        self.neighbor_address = None
                                        self.neighbor_address_xr = None
                                        self.neighbor_bfd_info = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborTable.Neighbor.NeighborBfdInfo()
                                        self.neighbor_bfd_info.parent = self
                                        self.neighbor_dead_timer = None
                                        self.neighbor_designated_router = None
                                        self.neighbor_detail = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborTable.Neighbor.NeighborDetail()
                                        self.neighbor_detail.parent = self
                                        self.neighbor_dr_priority = None
                                        self.neighbor_interface_id = None
                                        self.neighbor_sham_link_id = None
                                        self.neighbor_state = None
                                        self.neighbor_up_time = None
                                        self.neighbor_virtual_link_id = None


                                    class NeighborDetail(object):
                                        """
                                        Detailed OSPFv3 neighbor information 
                                        
                                        .. attribute:: interface_type
                                        
                                        	Interface type
                                        	**type**\:   :py:class:`Ospfv3InterfaceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3InterfaceEnum>`
                                        
                                        .. attribute:: is_neighbor_filtered
                                        
                                        	If true, filter outgoing LSAs 
                                        	**type**\:  bool
                                        
                                        .. attribute:: neighbor_backup_designated_router_address
                                        
                                        	Address of backup designated router
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: neighbor_cost
                                        
                                        	Cost of path to this neighbor 
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: neighbor_designated_router_address
                                        
                                        	Address of designated router
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: neighbor_ignore_timer
                                        
                                        	Remaining time when ignore timer is running 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: neighbor_option
                                        
                                        	 This is bitmask of neighbor's option field received 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: neighbor_retransmission
                                        
                                        	Retransmission information with this neighbor
                                        	**type**\:   :py:class:`NeighborRetransmission <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborTable.Neighbor.NeighborDetail.NeighborRetransmission>`
                                        
                                        .. attribute:: next_poll_interval
                                        
                                        	For NBMA networks, amount of time remaining in seconds before the next poll interval expires and Hello is sent (s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: pending_events
                                        
                                        	Number of pending events 
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: poll_interval
                                        
                                        	Poll interval (s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: state_changes
                                        
                                        	Number of state changes 
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface_type = None
                                            self.is_neighbor_filtered = None
                                            self.neighbor_backup_designated_router_address = None
                                            self.neighbor_cost = None
                                            self.neighbor_designated_router_address = None
                                            self.neighbor_ignore_timer = None
                                            self.neighbor_option = None
                                            self.neighbor_retransmission = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborTable.Neighbor.NeighborDetail.NeighborRetransmission()
                                            self.neighbor_retransmission.parent = self
                                            self.next_poll_interval = None
                                            self.pending_events = None
                                            self.poll_interval = None
                                            self.state_changes = None


                                        class NeighborRetransmission(object):
                                            """
                                            Retransmission information with this neighbor
                                            
                                            .. attribute:: area_first_flood
                                            
                                            	First flood item for area scope LSAs
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: area_first_flood_index
                                            
                                            	Index of the first flood item for area scope LSAs
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: area_flood_index
                                            
                                            	Area scope LSA's flood index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: area_next_flood
                                            
                                            	Next flood item for area scope LSAs
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: area_next_flood_index
                                            
                                            	Index of next flood item for Area scope LSAs
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: as_first_flood
                                            
                                            	First flood item for AS scope LSAs
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: as_first_flood_index
                                            
                                            	Index for first flood item for AS scope LSAs
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: as_flood_index
                                            
                                            	AS scope LSA's flood index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: as_next_flood
                                            
                                            	Next flood item for AS scope LSAs
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: as_next_flood_index
                                            
                                            	Index of next flood item for AS scope LSAs
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: database_descriptor_retransmissions
                                            
                                            	Number of database descriptor retransmissions during last exchange
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_retransmission_length
                                            
                                            	Number of LSAs sent in last retransmission
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_retransmission_time
                                            
                                            	Last retransmission scan time (ms)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: link_first_flood
                                            
                                            	Link first flood information 
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: link_first_flood_index
                                            
                                            	Link first flood information index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: link_flood_index
                                            
                                            	Link flood index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: link_next_flood
                                            
                                            	Link next flood information 
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: link_next_flood_index
                                            
                                            	Link next flood information index 
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: lsa_retransmission_timer
                                            
                                            	Time until next LSA retransmission (ms)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: maximum_retransmission_length
                                            
                                            	Maximum number of LSAs sent in a retransmission
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: maximum_retransmission_time
                                            
                                            	Maximum retransmission scan time (ms)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: neighbor_retransmissions
                                            
                                            	Number of neighbor retransmissions 
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: retransmissions
                                            
                                            	Number of retransmissions for this neighbor
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.area_first_flood = None
                                                self.area_first_flood_index = None
                                                self.area_flood_index = None
                                                self.area_next_flood = None
                                                self.area_next_flood_index = None
                                                self.as_first_flood = None
                                                self.as_first_flood_index = None
                                                self.as_flood_index = None
                                                self.as_next_flood = None
                                                self.as_next_flood_index = None
                                                self.database_descriptor_retransmissions = None
                                                self.last_retransmission_length = None
                                                self.last_retransmission_time = None
                                                self.link_first_flood = None
                                                self.link_first_flood_index = None
                                                self.link_flood_index = None
                                                self.link_next_flood = None
                                                self.link_next_flood_index = None
                                                self.lsa_retransmission_timer = None
                                                self.maximum_retransmission_length = None
                                                self.maximum_retransmission_time = None
                                                self.neighbor_retransmissions = None
                                                self.retransmissions = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:neighbor-retransmission'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.area_first_flood is not None:
                                                    return True

                                                if self.area_first_flood_index is not None:
                                                    return True

                                                if self.area_flood_index is not None:
                                                    return True

                                                if self.area_next_flood is not None:
                                                    return True

                                                if self.area_next_flood_index is not None:
                                                    return True

                                                if self.as_first_flood is not None:
                                                    return True

                                                if self.as_first_flood_index is not None:
                                                    return True

                                                if self.as_flood_index is not None:
                                                    return True

                                                if self.as_next_flood is not None:
                                                    return True

                                                if self.as_next_flood_index is not None:
                                                    return True

                                                if self.database_descriptor_retransmissions is not None:
                                                    return True

                                                if self.last_retransmission_length is not None:
                                                    return True

                                                if self.last_retransmission_time is not None:
                                                    return True

                                                if self.link_first_flood is not None:
                                                    return True

                                                if self.link_first_flood_index is not None:
                                                    return True

                                                if self.link_flood_index is not None:
                                                    return True

                                                if self.link_next_flood is not None:
                                                    return True

                                                if self.link_next_flood_index is not None:
                                                    return True

                                                if self.lsa_retransmission_timer is not None:
                                                    return True

                                                if self.maximum_retransmission_length is not None:
                                                    return True

                                                if self.maximum_retransmission_time is not None:
                                                    return True

                                                if self.neighbor_retransmissions is not None:
                                                    return True

                                                if self.retransmissions is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborTable.Neighbor.NeighborDetail.NeighborRetransmission']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:neighbor-detail'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface_type is not None:
                                                return True

                                            if self.is_neighbor_filtered is not None:
                                                return True

                                            if self.neighbor_backup_designated_router_address is not None:
                                                return True

                                            if self.neighbor_cost is not None:
                                                return True

                                            if self.neighbor_designated_router_address is not None:
                                                return True

                                            if self.neighbor_ignore_timer is not None:
                                                return True

                                            if self.neighbor_option is not None:
                                                return True

                                            if self.neighbor_retransmission is not None and self.neighbor_retransmission._has_data():
                                                return True

                                            if self.next_poll_interval is not None:
                                                return True

                                            if self.pending_events is not None:
                                                return True

                                            if self.poll_interval is not None:
                                                return True

                                            if self.state_changes is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborTable.Neighbor.NeighborDetail']['meta_info']


                                    class NeighborBfdInfo(object):
                                        """
                                        Neighbor BFD information
                                        
                                        .. attribute:: bfd_intf_enable_mode
                                        
                                        	BFD enable mode \- Default/Strict
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bfd_status_flag
                                        
                                        	Status of the BFD Session
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.bfd_intf_enable_mode = None
                                            self.bfd_status_flag = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:neighbor-bfd-info'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bfd_intf_enable_mode is not None:
                                                return True

                                            if self.bfd_status_flag is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborTable.Neighbor.NeighborBfdInfo']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:neighbor'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.interface_name is not None:
                                            return True

                                        if self.is_neighbor_sham_link is not None:
                                            return True

                                        if self.is_neighbor_virtual_link is not None:
                                            return True

                                        if self.neighbor_address is not None:
                                            return True

                                        if self.neighbor_address_xr is not None:
                                            return True

                                        if self.neighbor_bfd_info is not None and self.neighbor_bfd_info._has_data():
                                            return True

                                        if self.neighbor_dead_timer is not None:
                                            return True

                                        if self.neighbor_designated_router is not None:
                                            return True

                                        if self.neighbor_detail is not None and self.neighbor_detail._has_data():
                                            return True

                                        if self.neighbor_dr_priority is not None:
                                            return True

                                        if self.neighbor_interface_id is not None:
                                            return True

                                        if self.neighbor_sham_link_id is not None:
                                            return True

                                        if self.neighbor_state is not None:
                                            return True

                                        if self.neighbor_up_time is not None:
                                            return True

                                        if self.neighbor_virtual_link_id is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                        return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborTable.Neighbor']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:neighbor-table'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.neighbor is not None:
                                        for child_ref in self.neighbor:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                    return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborTable']['meta_info']


                            class InterfaceTable(object):
                                """
                                OSPFv3 interface information table for an area
                                
                                .. attribute:: interface
                                
                                	OSPFv3 interface information
                                	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.InterfaceTable.Interface>`
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.interface = YList()
                                    self.interface.parent = self
                                    self.interface.name = 'interface'


                                class Interface(object):
                                    """
                                    OSPFv3 interface information
                                    
                                    .. attribute:: interface_name  <key>
                                    
                                    	Interface name
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                    
                                    .. attribute:: active_interface
                                    
                                    	Active interface details 
                                    	**type**\:   :py:class:`ActiveInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.InterfaceTable.Interface.ActiveInterface>`
                                    
                                    .. attribute:: adjacent_neighbor
                                    
                                    	Number of adjacent neighbors
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: backup_designated_router_address
                                    
                                    	Backup designated router interface address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: backup_designated_router_id
                                    
                                    	Backup designated router ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: configured_ldp_sync
                                    
                                    	If true, configured as LDP sync
                                    	**type**\:  bool
                                    
                                    .. attribute:: dead_interval
                                    
                                    	Configured dead interval (s) 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: designated_router_address
                                    
                                    	Designated router interface address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: designated_router_id
                                    
                                    	Designated router ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: hello_interval
                                    
                                    	Configured hello interval (s)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_address
                                    
                                    	Interface IPv6 address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: interface_authentication_spi
                                    
                                    	Interface authentication spi 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_authentication_transmit
                                    
                                    	Interface authentication transmit 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_bfd
                                    
                                    	BFD information 
                                    	**type**\:   :py:class:`InterfaceBfd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.InterfaceTable.Interface.InterfaceBfd>`
                                    
                                    .. attribute:: interface_dc_bitless_ls_as
                                    
                                    	Number of LSAs with demand circuit bit not set for the area in which the interface is running
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_encrypted_authentication_transmitted
                                    
                                    	Interface encrypted authentication transmitted 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_encryption_spi
                                    
                                    	Interface encryption spi
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_encryption_transmitted
                                    
                                    	Interface encryption transmitted 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_ldp_sync
                                    
                                    	If true, interface LDP sync is achieved
                                    	**type**\:  bool
                                    
                                    .. attribute:: interface_link_cost
                                    
                                    	Interface link cost
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: interface_neighbor
                                    
                                    	Information for neighbors on the interface
                                    	**type**\: list of    :py:class:`InterfaceNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.InterfaceTable.Interface.InterfaceNeighbor>`
                                    
                                    .. attribute:: interface_number
                                    
                                    	Interface number 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_priority
                                    
                                    	Interface priority
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: interface_references
                                    
                                    	Interface reference count 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_retransmission_interval
                                    
                                    	Configured retransmit interval (s) 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_router_id
                                    
                                    	Interface router ID 
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: interface_state
                                    
                                    	Interface state
                                    	**type**\:   :py:class:`ImStateEnumEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.ImStateEnumEnum>`
                                    
                                    .. attribute:: is_demand_circuit_configured
                                    
                                    	If true, configured as demand circuit 
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_designated_router
                                    
                                    	If true, designated router
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_interface_demand_circuit
                                    
                                    	If true, interface running as demand circuit
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_interface_encryption_enabled
                                    
                                    	If true, interface encryption is enabled 
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_interface_flood_reduction
                                    
                                    	If true, interface flood reduction is active 
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_interface_ip_security_active
                                    
                                    	If true, interface IP security is active 
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_interface_ip_security_required
                                    
                                    	If true, interface IP security is required 
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_interface_line_up
                                    
                                    	If true, line protocol is up 
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_interface_lsa_filtered
                                    
                                    	Filter is configured for out going LSAs 
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_prefix_suppress
                                    
                                    	If true prefix suppression is enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: network_lsa_flush_timer
                                    
                                    	The amount of time in seconds before flush timer for old network LSA expires 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: network_type
                                    
                                    	Network type
                                    	**type**\:   :py:class:`Ospfv3InterfaceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3InterfaceEnum>`
                                    
                                    .. attribute:: next_hello_time
                                    
                                    	Time until next Hello (s) 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: ospf_interface_state
                                    
                                    	Interface state
                                    	**type**\:   :py:class:`Ospfv3InterfaceStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3InterfaceStateEnum>`
                                    
                                    .. attribute:: transmission_delay
                                    
                                    	Interface transmission delay (sec)
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: wait_interval
                                    
                                    	Configured wait interval (s) 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.interface_name = None
                                        self.active_interface = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.InterfaceTable.Interface.ActiveInterface()
                                        self.active_interface.parent = self
                                        self.adjacent_neighbor = None
                                        self.backup_designated_router_address = None
                                        self.backup_designated_router_id = None
                                        self.configured_ldp_sync = None
                                        self.dead_interval = None
                                        self.designated_router_address = None
                                        self.designated_router_id = None
                                        self.hello_interval = None
                                        self.interface_address = None
                                        self.interface_authentication_spi = None
                                        self.interface_authentication_transmit = None
                                        self.interface_bfd = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.InterfaceTable.Interface.InterfaceBfd()
                                        self.interface_bfd.parent = self
                                        self.interface_dc_bitless_ls_as = None
                                        self.interface_encrypted_authentication_transmitted = None
                                        self.interface_encryption_spi = None
                                        self.interface_encryption_transmitted = None
                                        self.interface_ldp_sync = None
                                        self.interface_link_cost = None
                                        self.interface_neighbor = YList()
                                        self.interface_neighbor.parent = self
                                        self.interface_neighbor.name = 'interface_neighbor'
                                        self.interface_number = None
                                        self.interface_priority = None
                                        self.interface_references = None
                                        self.interface_retransmission_interval = None
                                        self.interface_router_id = None
                                        self.interface_state = None
                                        self.is_demand_circuit_configured = None
                                        self.is_designated_router = None
                                        self.is_interface_demand_circuit = None
                                        self.is_interface_encryption_enabled = None
                                        self.is_interface_flood_reduction = None
                                        self.is_interface_ip_security_active = None
                                        self.is_interface_ip_security_required = None
                                        self.is_interface_line_up = None
                                        self.is_interface_lsa_filtered = None
                                        self.is_prefix_suppress = None
                                        self.network_lsa_flush_timer = None
                                        self.network_type = None
                                        self.next_hello_time = None
                                        self.ospf_interface_state = None
                                        self.transmission_delay = None
                                        self.wait_interval = None


                                    class ActiveInterface(object):
                                        """
                                        Active interface details 
                                        
                                        .. attribute:: flood_queue_length
                                        
                                        	Flood queue length
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: flood_scan_length
                                        
                                        	Last flood scan length 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_area_flood_index
                                        
                                        	Area scope LSAs flood index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_area_next_flood
                                        
                                        	Next LSA to flood (Area scope)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_area_next_flood_index
                                        
                                        	Index of next LSA to flood (Area scope) 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_as_flood_index
                                        
                                        	AS scope LSAs flood index 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_as_next_flood
                                        
                                        	Next LSA to flood (AS scope)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_as_next_flood_index
                                        
                                        	Index of next LSA to flood (AS scope)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_flood_pacing_timer
                                        
                                        	Time until next flood pacing timer (ms) 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_link_flood_index
                                        
                                        	Interface flood link index 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_link_next_flood
                                        
                                        	Interface link next flood information 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_link_next_index
                                        
                                        	Interface link next information index 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_neighbors
                                        
                                        	Total number of neighbors 
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: last_flood_time
                                        
                                        	Last flood scan time (ms)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: maximum_flood_length
                                        
                                        	Maximum flood length 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: maximum_flood_time
                                        
                                        	Maximum flood time (ms) 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: suppressed_hellos
                                        
                                        	Number of neighbors for which hellos are suppressed 
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: wait_time
                                        
                                        	Wait time for DR/BDR selection (s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.flood_queue_length = None
                                            self.flood_scan_length = None
                                            self.interface_area_flood_index = None
                                            self.interface_area_next_flood = None
                                            self.interface_area_next_flood_index = None
                                            self.interface_as_flood_index = None
                                            self.interface_as_next_flood = None
                                            self.interface_as_next_flood_index = None
                                            self.interface_flood_pacing_timer = None
                                            self.interface_link_flood_index = None
                                            self.interface_link_next_flood = None
                                            self.interface_link_next_index = None
                                            self.interface_neighbors = None
                                            self.last_flood_time = None
                                            self.maximum_flood_length = None
                                            self.maximum_flood_time = None
                                            self.suppressed_hellos = None
                                            self.wait_time = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:active-interface'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.flood_queue_length is not None:
                                                return True

                                            if self.flood_scan_length is not None:
                                                return True

                                            if self.interface_area_flood_index is not None:
                                                return True

                                            if self.interface_area_next_flood is not None:
                                                return True

                                            if self.interface_area_next_flood_index is not None:
                                                return True

                                            if self.interface_as_flood_index is not None:
                                                return True

                                            if self.interface_as_next_flood is not None:
                                                return True

                                            if self.interface_as_next_flood_index is not None:
                                                return True

                                            if self.interface_flood_pacing_timer is not None:
                                                return True

                                            if self.interface_link_flood_index is not None:
                                                return True

                                            if self.interface_link_next_flood is not None:
                                                return True

                                            if self.interface_link_next_index is not None:
                                                return True

                                            if self.interface_neighbors is not None:
                                                return True

                                            if self.last_flood_time is not None:
                                                return True

                                            if self.maximum_flood_length is not None:
                                                return True

                                            if self.maximum_flood_time is not None:
                                                return True

                                            if self.suppressed_hellos is not None:
                                                return True

                                            if self.wait_time is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.InterfaceTable.Interface.ActiveInterface']['meta_info']


                                    class InterfaceBfd(object):
                                        """
                                        BFD information 
                                        
                                        .. attribute:: bfd_detection_multiplier
                                        
                                        	BFD detection multiplier 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bfd_interval
                                        
                                        	BFD interval (ms) 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bfd_intf_enable_mode
                                        
                                        	BFD Enable Mode on the interface \- Default/Strict
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.bfd_detection_multiplier = None
                                            self.bfd_interval = None
                                            self.bfd_intf_enable_mode = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:interface-bfd'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bfd_detection_multiplier is not None:
                                                return True

                                            if self.bfd_interval is not None:
                                                return True

                                            if self.bfd_intf_enable_mode is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.InterfaceTable.Interface.InterfaceBfd']['meta_info']


                                    class InterfaceNeighbor(object):
                                        """
                                        Information for neighbors on the interface
                                        
                                        .. attribute:: interface_neighbor_cost
                                        
                                        	Cost of link to neighbor
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_neighbor_id
                                        
                                        	Neighbor router ID 
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: is_hello_suppressed
                                        
                                        	If true, hello is suppressed 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_neighbor_bdr
                                        
                                        	If true, backup designated router is found 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_neighbor_dr
                                        
                                        	If true, designated router is found 
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface_neighbor_cost = None
                                            self.interface_neighbor_id = None
                                            self.is_hello_suppressed = None
                                            self.is_neighbor_bdr = None
                                            self.is_neighbor_dr = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:interface-neighbor'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface_neighbor_cost is not None:
                                                return True

                                            if self.interface_neighbor_id is not None:
                                                return True

                                            if self.is_hello_suppressed is not None:
                                                return True

                                            if self.is_neighbor_bdr is not None:
                                                return True

                                            if self.is_neighbor_dr is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.InterfaceTable.Interface.InterfaceNeighbor']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')
                                        if self.interface_name is None:
                                            raise YPYModelError('Key property interface_name is None')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:interface[Cisco-IOS-XR-ipv6-ospfv3-oper:interface-name = ' + str(self.interface_name) + ']'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.interface_name is not None:
                                            return True

                                        if self.active_interface is not None and self.active_interface._has_data():
                                            return True

                                        if self.adjacent_neighbor is not None:
                                            return True

                                        if self.backup_designated_router_address is not None:
                                            return True

                                        if self.backup_designated_router_id is not None:
                                            return True

                                        if self.configured_ldp_sync is not None:
                                            return True

                                        if self.dead_interval is not None:
                                            return True

                                        if self.designated_router_address is not None:
                                            return True

                                        if self.designated_router_id is not None:
                                            return True

                                        if self.hello_interval is not None:
                                            return True

                                        if self.interface_address is not None:
                                            return True

                                        if self.interface_authentication_spi is not None:
                                            return True

                                        if self.interface_authentication_transmit is not None:
                                            return True

                                        if self.interface_bfd is not None and self.interface_bfd._has_data():
                                            return True

                                        if self.interface_dc_bitless_ls_as is not None:
                                            return True

                                        if self.interface_encrypted_authentication_transmitted is not None:
                                            return True

                                        if self.interface_encryption_spi is not None:
                                            return True

                                        if self.interface_encryption_transmitted is not None:
                                            return True

                                        if self.interface_ldp_sync is not None:
                                            return True

                                        if self.interface_link_cost is not None:
                                            return True

                                        if self.interface_neighbor is not None:
                                            for child_ref in self.interface_neighbor:
                                                if child_ref._has_data():
                                                    return True

                                        if self.interface_number is not None:
                                            return True

                                        if self.interface_priority is not None:
                                            return True

                                        if self.interface_references is not None:
                                            return True

                                        if self.interface_retransmission_interval is not None:
                                            return True

                                        if self.interface_router_id is not None:
                                            return True

                                        if self.interface_state is not None:
                                            return True

                                        if self.is_demand_circuit_configured is not None:
                                            return True

                                        if self.is_designated_router is not None:
                                            return True

                                        if self.is_interface_demand_circuit is not None:
                                            return True

                                        if self.is_interface_encryption_enabled is not None:
                                            return True

                                        if self.is_interface_flood_reduction is not None:
                                            return True

                                        if self.is_interface_ip_security_active is not None:
                                            return True

                                        if self.is_interface_ip_security_required is not None:
                                            return True

                                        if self.is_interface_line_up is not None:
                                            return True

                                        if self.is_interface_lsa_filtered is not None:
                                            return True

                                        if self.is_prefix_suppress is not None:
                                            return True

                                        if self.network_lsa_flush_timer is not None:
                                            return True

                                        if self.network_type is not None:
                                            return True

                                        if self.next_hello_time is not None:
                                            return True

                                        if self.ospf_interface_state is not None:
                                            return True

                                        if self.transmission_delay is not None:
                                            return True

                                        if self.wait_interval is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                        return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.InterfaceTable.Interface']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:interface-table'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.interface is not None:
                                        for child_ref in self.interface:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                    return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.InterfaceTable']['meta_info']


                            class FloodListTable(object):
                                """
                                OSPFv3 flood list information table for an
                                area
                                
                                .. attribute:: flood
                                
                                	OSPFv3 flood list information
                                	**type**\: list of    :py:class:`Flood <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.FloodListTable.Flood>`
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.flood = YList()
                                    self.flood.parent = self
                                    self.flood.name = 'flood'


                                class Flood(object):
                                    """
                                    OSPFv3 flood list information
                                    
                                    .. attribute:: interface_name  <key>
                                    
                                    	Interface name
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                    
                                    .. attribute:: area_flood
                                    
                                    	Area scope floodlist
                                    	**type**\: list of    :py:class:`AreaFlood <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.FloodListTable.Flood.AreaFlood>`
                                    
                                    .. attribute:: as_flood
                                    
                                    	AS scope floodlist
                                    	**type**\: list of    :py:class:`AsFlood <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.FloodListTable.Flood.AsFlood>`
                                    
                                    .. attribute:: link_flood
                                    
                                    	Link floodlist
                                    	**type**\: list of    :py:class:`LinkFlood <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.FloodListTable.Flood.LinkFlood>`
                                    
                                    .. attribute:: ls_transmission_timer
                                    
                                    	Time until next LS transmission (ms) 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: queue_length
                                    
                                    	Number of LSAs currently being flooded 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.interface_name = None
                                        self.area_flood = YList()
                                        self.area_flood.parent = self
                                        self.area_flood.name = 'area_flood'
                                        self.as_flood = YList()
                                        self.as_flood.parent = self
                                        self.as_flood.name = 'as_flood'
                                        self.link_flood = YList()
                                        self.link_flood.parent = self
                                        self.link_flood.name = 'link_flood'
                                        self.ls_transmission_timer = None
                                        self.queue_length = None


                                    class LinkFlood(object):
                                        """
                                        Link floodlist
                                        
                                        .. attribute:: header_advertising_router
                                        
                                        	Router ID of the advertising router
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: header_lsa_age
                                        
                                        	Age of the LSA (seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: header_lsa_id
                                        
                                        	LSA ID
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: header_lsa_type
                                        
                                        	LSA type
                                        	**type**\:   :py:class:`Ospfv3Lsa1Enum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Lsa1Enum>`
                                        
                                        .. attribute:: header_sequence_number
                                        
                                        	Current LSA sequence number
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.header_advertising_router = None
                                            self.header_lsa_age = None
                                            self.header_lsa_id = None
                                            self.header_lsa_type = None
                                            self.header_sequence_number = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:link-flood'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.header_advertising_router is not None:
                                                return True

                                            if self.header_lsa_age is not None:
                                                return True

                                            if self.header_lsa_id is not None:
                                                return True

                                            if self.header_lsa_type is not None:
                                                return True

                                            if self.header_sequence_number is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.FloodListTable.Flood.LinkFlood']['meta_info']


                                    class AreaFlood(object):
                                        """
                                        Area scope floodlist
                                        
                                        .. attribute:: header_advertising_router
                                        
                                        	Router ID of the advertising router
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: header_lsa_age
                                        
                                        	Age of the LSA (seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: header_lsa_id
                                        
                                        	LSA ID
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: header_lsa_type
                                        
                                        	LSA type
                                        	**type**\:   :py:class:`Ospfv3Lsa1Enum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Lsa1Enum>`
                                        
                                        .. attribute:: header_sequence_number
                                        
                                        	Current LSA sequence number
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.header_advertising_router = None
                                            self.header_lsa_age = None
                                            self.header_lsa_id = None
                                            self.header_lsa_type = None
                                            self.header_sequence_number = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:area-flood'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.header_advertising_router is not None:
                                                return True

                                            if self.header_lsa_age is not None:
                                                return True

                                            if self.header_lsa_id is not None:
                                                return True

                                            if self.header_lsa_type is not None:
                                                return True

                                            if self.header_sequence_number is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.FloodListTable.Flood.AreaFlood']['meta_info']


                                    class AsFlood(object):
                                        """
                                        AS scope floodlist
                                        
                                        .. attribute:: header_advertising_router
                                        
                                        	Router ID of the advertising router
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: header_lsa_age
                                        
                                        	Age of the LSA (seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: header_lsa_id
                                        
                                        	LSA ID
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: header_lsa_type
                                        
                                        	LSA type
                                        	**type**\:   :py:class:`Ospfv3Lsa1Enum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Lsa1Enum>`
                                        
                                        .. attribute:: header_sequence_number
                                        
                                        	Current LSA sequence number
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.header_advertising_router = None
                                            self.header_lsa_age = None
                                            self.header_lsa_id = None
                                            self.header_lsa_type = None
                                            self.header_sequence_number = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:as-flood'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.header_advertising_router is not None:
                                                return True

                                            if self.header_lsa_age is not None:
                                                return True

                                            if self.header_lsa_id is not None:
                                                return True

                                            if self.header_lsa_type is not None:
                                                return True

                                            if self.header_sequence_number is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.FloodListTable.Flood.AsFlood']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')
                                        if self.interface_name is None:
                                            raise YPYModelError('Key property interface_name is None')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:flood[Cisco-IOS-XR-ipv6-ospfv3-oper:interface-name = ' + str(self.interface_name) + ']'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.interface_name is not None:
                                            return True

                                        if self.area_flood is not None:
                                            for child_ref in self.area_flood:
                                                if child_ref._has_data():
                                                    return True

                                        if self.as_flood is not None:
                                            for child_ref in self.as_flood:
                                                if child_ref._has_data():
                                                    return True

                                        if self.link_flood is not None:
                                            for child_ref in self.link_flood:
                                                if child_ref._has_data():
                                                    return True

                                        if self.ls_transmission_timer is not None:
                                            return True

                                        if self.queue_length is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                        return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.FloodListTable.Flood']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:flood-list-table'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.flood is not None:
                                        for child_ref in self.flood:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                    return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.FloodListTable']['meta_info']


                            class RetransmissionListTable(object):
                                """
                                OSPFv3 retransmission list information table
                                in an area
                                
                                .. attribute:: retransmission
                                
                                	OSPFv3 retransmission list information
                                	**type**\: list of    :py:class:`Retransmission <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.RetransmissionListTable.Retransmission>`
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.retransmission = YList()
                                    self.retransmission.parent = self
                                    self.retransmission.name = 'retransmission'


                                class Retransmission(object):
                                    """
                                    OSPFv3 retransmission list information
                                    
                                    .. attribute:: interface_name
                                    
                                    	Interface name
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                    
                                    .. attribute:: is_retransmission_sham_link
                                    
                                    	If true, sham link is retransmitted 
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_retransmissionvirtual_link
                                    
                                    	If true, virtual link is retransmitted 
                                    	**type**\:  bool
                                    
                                    .. attribute:: neighbor_address
                                    
                                    	Neighbor address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: retransmission_area_db
                                    
                                    	List of area scope entries
                                    	**type**\: list of    :py:class:`RetransmissionAreaDb <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.RetransmissionListTable.Retransmission.RetransmissionAreaDb>`
                                    
                                    .. attribute:: retransmission_asdb
                                    
                                    	List of AS scope entries
                                    	**type**\: list of    :py:class:`RetransmissionAsdb <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.RetransmissionListTable.Retransmission.RetransmissionAsdb>`
                                    
                                    .. attribute:: retransmission_length
                                    
                                    	Retransmission queue length
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: retransmission_neighbor_address
                                    
                                    	Neighbor IP address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: retransmission_sham_link_id
                                    
                                    	Retransmission sham link ID 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: retransmission_timer
                                    
                                    	Amount of time remaining on retransmission timer (ms)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: retransmissionvirtual_link_db
                                    
                                    	List of virtual link scope entries 
                                    	**type**\: list of    :py:class:`RetransmissionvirtualLinkDb <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.RetransmissionListTable.Retransmission.RetransmissionvirtualLinkDb>`
                                    
                                    .. attribute:: retransmissionvirtual_link_id
                                    
                                    	Retransmission virtual link ID 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.interface_name = None
                                        self.is_retransmission_sham_link = None
                                        self.is_retransmissionvirtual_link = None
                                        self.neighbor_address = None
                                        self.retransmission_area_db = YList()
                                        self.retransmission_area_db.parent = self
                                        self.retransmission_area_db.name = 'retransmission_area_db'
                                        self.retransmission_asdb = YList()
                                        self.retransmission_asdb.parent = self
                                        self.retransmission_asdb.name = 'retransmission_asdb'
                                        self.retransmission_length = None
                                        self.retransmission_neighbor_address = None
                                        self.retransmission_sham_link_id = None
                                        self.retransmission_timer = None
                                        self.retransmissionvirtual_link_db = YList()
                                        self.retransmissionvirtual_link_db.parent = self
                                        self.retransmissionvirtual_link_db.name = 'retransmissionvirtual_link_db'
                                        self.retransmissionvirtual_link_id = None


                                    class RetransmissionvirtualLinkDb(object):
                                        """
                                        List of virtual link scope entries 
                                        
                                        .. attribute:: header_advertising_router
                                        
                                        	Router ID of the advertising router
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: header_lsa_age
                                        
                                        	Age of the LSA (seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: header_lsa_id
                                        
                                        	LSA ID
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: header_lsa_type
                                        
                                        	LSA type
                                        	**type**\:   :py:class:`Ospfv3Lsa1Enum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Lsa1Enum>`
                                        
                                        .. attribute:: header_sequence_number
                                        
                                        	Current LSA sequence number
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.header_advertising_router = None
                                            self.header_lsa_age = None
                                            self.header_lsa_id = None
                                            self.header_lsa_type = None
                                            self.header_sequence_number = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:retransmissionvirtual-link-db'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.header_advertising_router is not None:
                                                return True

                                            if self.header_lsa_age is not None:
                                                return True

                                            if self.header_lsa_id is not None:
                                                return True

                                            if self.header_lsa_type is not None:
                                                return True

                                            if self.header_sequence_number is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.RetransmissionListTable.Retransmission.RetransmissionvirtualLinkDb']['meta_info']


                                    class RetransmissionAreaDb(object):
                                        """
                                        List of area scope entries
                                        
                                        .. attribute:: header_advertising_router
                                        
                                        	Router ID of the advertising router
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: header_lsa_age
                                        
                                        	Age of the LSA (seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: header_lsa_id
                                        
                                        	LSA ID
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: header_lsa_type
                                        
                                        	LSA type
                                        	**type**\:   :py:class:`Ospfv3Lsa1Enum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Lsa1Enum>`
                                        
                                        .. attribute:: header_sequence_number
                                        
                                        	Current LSA sequence number
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.header_advertising_router = None
                                            self.header_lsa_age = None
                                            self.header_lsa_id = None
                                            self.header_lsa_type = None
                                            self.header_sequence_number = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:retransmission-area-db'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.header_advertising_router is not None:
                                                return True

                                            if self.header_lsa_age is not None:
                                                return True

                                            if self.header_lsa_id is not None:
                                                return True

                                            if self.header_lsa_type is not None:
                                                return True

                                            if self.header_sequence_number is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.RetransmissionListTable.Retransmission.RetransmissionAreaDb']['meta_info']


                                    class RetransmissionAsdb(object):
                                        """
                                        List of AS scope entries
                                        
                                        .. attribute:: header_advertising_router
                                        
                                        	Router ID of the advertising router
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: header_lsa_age
                                        
                                        	Age of the LSA (seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: header_lsa_id
                                        
                                        	LSA ID
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: header_lsa_type
                                        
                                        	LSA type
                                        	**type**\:   :py:class:`Ospfv3Lsa1Enum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Lsa1Enum>`
                                        
                                        .. attribute:: header_sequence_number
                                        
                                        	Current LSA sequence number
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.header_advertising_router = None
                                            self.header_lsa_age = None
                                            self.header_lsa_id = None
                                            self.header_lsa_type = None
                                            self.header_sequence_number = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:retransmission-asdb'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.header_advertising_router is not None:
                                                return True

                                            if self.header_lsa_age is not None:
                                                return True

                                            if self.header_lsa_id is not None:
                                                return True

                                            if self.header_lsa_type is not None:
                                                return True

                                            if self.header_sequence_number is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.RetransmissionListTable.Retransmission.RetransmissionAsdb']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:retransmission'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.interface_name is not None:
                                            return True

                                        if self.is_retransmission_sham_link is not None:
                                            return True

                                        if self.is_retransmissionvirtual_link is not None:
                                            return True

                                        if self.neighbor_address is not None:
                                            return True

                                        if self.retransmission_area_db is not None:
                                            for child_ref in self.retransmission_area_db:
                                                if child_ref._has_data():
                                                    return True

                                        if self.retransmission_asdb is not None:
                                            for child_ref in self.retransmission_asdb:
                                                if child_ref._has_data():
                                                    return True

                                        if self.retransmission_length is not None:
                                            return True

                                        if self.retransmission_neighbor_address is not None:
                                            return True

                                        if self.retransmission_sham_link_id is not None:
                                            return True

                                        if self.retransmission_timer is not None:
                                            return True

                                        if self.retransmissionvirtual_link_db is not None:
                                            for child_ref in self.retransmissionvirtual_link_db:
                                                if child_ref._has_data():
                                                    return True

                                        if self.retransmissionvirtual_link_id is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                        return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.RetransmissionListTable.Retransmission']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:retransmission-list-table'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.retransmission is not None:
                                        for child_ref in self.retransmission:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                    return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.RetransmissionListTable']['meta_info']


                            class DatabaseTable(object):
                                """
                                OSPF Link State Database
                                
                                .. attribute:: lsa_internal_table
                                
                                	Database LSA information
                                	**type**\:   :py:class:`LsaInternalTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable>`
                                
                                .. attribute:: lsa_table
                                
                                	Database LSA information
                                	**type**\:   :py:class:`LsaTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable>`
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.lsa_internal_table = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable()
                                    self.lsa_internal_table.parent = self
                                    self.lsa_table = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable()
                                    self.lsa_table.parent = self


                                class LsaTable(object):
                                    """
                                    Database LSA information
                                    
                                    .. attribute:: lsa
                                    
                                    	Database LSA information
                                    	**type**\: list of    :py:class:`Lsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa>`
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.lsa = YList()
                                        self.lsa.parent = self
                                        self.lsa.name = 'lsa'


                                    class Lsa(object):
                                        """
                                        Database LSA information
                                        
                                        .. attribute:: advertising_router
                                        
                                        	Advertising Router ID
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: area_id
                                        
                                        	Area ID
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: interface_name
                                        
                                        	InterfaceName
                                        	**type**\:  str
                                        
                                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                        
                                        .. attribute:: ls_id
                                        
                                        	Link state ID
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: ls_type
                                        
                                        	LSA type
                                        	**type**\:   :py:class:`Ospfv3LsaEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3LsaEnum>`
                                        
                                        .. attribute:: lsa_info
                                        
                                        	Summary of all LSAs or LSA specific information 
                                        	**type**\:   :py:class:`LsaInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo>`
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.advertising_router = None
                                            self.area_id = None
                                            self.interface_name = None
                                            self.ls_id = None
                                            self.ls_type = None
                                            self.lsa_info = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo()
                                            self.lsa_info.parent = self


                                        class LsaInfo(object):
                                            """
                                            Summary of all LSAs or LSA specific information 
                                            
                                            .. attribute:: external_lsa_type
                                            
                                            	External LSA
                                            	**type**\:   :py:class:`ExternalLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType>`
                                            
                                            .. attribute:: grace_lsa
                                            
                                            	Grace LSA
                                            	**type**\:   :py:class:`GraceLsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa>`
                                            
                                            .. attribute:: inter_area_prefix_lsa_type
                                            
                                            	Inter Area Prefix LSA
                                            	**type**\:   :py:class:`InterAreaPrefixLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType>`
                                            
                                            .. attribute:: inter_area_router_lsa_type
                                            
                                            	Inter Area Router LSA
                                            	**type**\:   :py:class:`InterAreaRouterLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType>`
                                            
                                            .. attribute:: intra_area_prefix_lsa_type
                                            
                                            	Intra Area Prefix LSA
                                            	**type**\:   :py:class:`IntraAreaPrefixLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType>`
                                            
                                            .. attribute:: link_lsa_type
                                            
                                            	Link LSA
                                            	**type**\:   :py:class:`LinkLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType>`
                                            
                                            .. attribute:: lsa_info_type
                                            
                                            	LSAInfoType
                                            	**type**\:   :py:class:`Ospfv3LsaInfoTypesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3LsaInfoTypesEnum>`
                                            
                                            .. attribute:: lsa_summary_info
                                            
                                            	Summary information of LSAs
                                            	**type**\:   :py:class:`LsaSummaryInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo>`
                                            
                                            .. attribute:: network_lsa_type
                                            
                                            	Network LSA
                                            	**type**\:   :py:class:`NetworkLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType>`
                                            
                                            .. attribute:: nssalsa_type
                                            
                                            	NSSA External LSA
                                            	**type**\:   :py:class:`NssalsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType>`
                                            
                                            .. attribute:: router_lsa_type
                                            
                                            	Router LSA
                                            	**type**\:   :py:class:`RouterLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType>`
                                            
                                            .. attribute:: unknown_area_lsa_type
                                            
                                            	Unknown\-Area scope LSA
                                            	**type**\:   :py:class:`UnknownAreaLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType>`
                                            
                                            .. attribute:: unknown_aslsa_type
                                            
                                            	Unknown\-AS scope LSA
                                            	**type**\:   :py:class:`UnknownAslsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType>`
                                            
                                            .. attribute:: unknown_link_lsa_type
                                            
                                            	Unknown Link Scope LSA
                                            	**type**\:   :py:class:`UnknownLinkLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType>`
                                            
                                            .. attribute:: unknown_lsa_type
                                            
                                            	Unknown LSA
                                            	**type**\:   :py:class:`UnknownLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType>`
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.external_lsa_type = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType()
                                                self.external_lsa_type.parent = self
                                                self.grace_lsa = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa()
                                                self.grace_lsa.parent = self
                                                self.inter_area_prefix_lsa_type = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType()
                                                self.inter_area_prefix_lsa_type.parent = self
                                                self.inter_area_router_lsa_type = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType()
                                                self.inter_area_router_lsa_type.parent = self
                                                self.intra_area_prefix_lsa_type = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType()
                                                self.intra_area_prefix_lsa_type.parent = self
                                                self.link_lsa_type = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType()
                                                self.link_lsa_type.parent = self
                                                self.lsa_info_type = None
                                                self.lsa_summary_info = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo()
                                                self.lsa_summary_info.parent = self
                                                self.network_lsa_type = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType()
                                                self.network_lsa_type.parent = self
                                                self.nssalsa_type = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType()
                                                self.nssalsa_type.parent = self
                                                self.router_lsa_type = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType()
                                                self.router_lsa_type.parent = self
                                                self.unknown_area_lsa_type = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType()
                                                self.unknown_area_lsa_type.parent = self
                                                self.unknown_aslsa_type = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType()
                                                self.unknown_aslsa_type.parent = self
                                                self.unknown_link_lsa_type = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType()
                                                self.unknown_link_lsa_type.parent = self
                                                self.unknown_lsa_type = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType()
                                                self.unknown_lsa_type.parent = self


                                            class LsaSummaryInfo(object):
                                                """
                                                Summary information of LSAs
                                                
                                                .. attribute:: interface_name
                                                
                                                	LSA interface name 
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                
                                                .. attribute:: is_sham_link
                                                
                                                	If true, it is a sham link 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_virtual_link
                                                
                                                	If true, it is a virtual link 
                                                	**type**\:  bool
                                                
                                                .. attribute:: links
                                                
                                                	Number of links
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_detail
                                                
                                                	Detailed LSA information
                                                	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo.LsaDetail>`
                                                
                                                .. attribute:: lsa_header
                                                
                                                	Header information 
                                                	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo.LsaHeader>`
                                                
                                                .. attribute:: lsa_router_id
                                                
                                                	LSA router ID 
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: prefix
                                                
                                                	OSPFv3 address Prefix 
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: prefix_length
                                                
                                                	Prefix length 
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: reference_lsa_id
                                                
                                                	Reference LSA ID 
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: reference_type
                                                
                                                	Reference type 
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: router_la_bits
                                                
                                                	Router LA bits 
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: sham_link_id
                                                
                                                	Sham link ID 
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: virtual_link_id
                                                
                                                	Virtual link ID 
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.interface_name = None
                                                    self.is_sham_link = None
                                                    self.is_virtual_link = None
                                                    self.links = None
                                                    self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo.LsaDetail()
                                                    self.lsa_detail.parent = self
                                                    self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo.LsaHeader()
                                                    self.lsa_header.parent = self
                                                    self.lsa_router_id = None
                                                    self.prefix = None
                                                    self.prefix_length = None
                                                    self.reference_lsa_id = None
                                                    self.reference_type = None
                                                    self.router_la_bits = None
                                                    self.sham_link_id = None
                                                    self.virtual_link_id = None


                                                class LsaHeader(object):
                                                    """
                                                    Header information 
                                                    
                                                    .. attribute:: advertising_router
                                                    
                                                    	Router ID of Advertising Router
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: checksum
                                                    
                                                    	Checksum value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: is_do_not_age_lsa
                                                    
                                                    	If true, Do Not Age this LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_graceful_restart_active
                                                    
                                                    	If true, if grace restart is active 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: ls_id
                                                    
                                                    	LS ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: lsa_age
                                                    
                                                    	LSA's Age (s)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_area_id
                                                    
                                                    	Area ID in decimal or dotted\-decimal format
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..16
                                                    
                                                    .. attribute:: lsa_type
                                                    
                                                    	LSA type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: sequence_number
                                                    
                                                    	Current Sequence number
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.advertising_router = None
                                                        self.checksum = None
                                                        self.is_do_not_age_lsa = None
                                                        self.is_graceful_restart_active = None
                                                        self.ls_id = None
                                                        self.lsa_age = None
                                                        self.lsa_area_id = None
                                                        self.lsa_type = None
                                                        self.sequence_number = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-header'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.advertising_router is not None:
                                                            return True

                                                        if self.checksum is not None:
                                                            return True

                                                        if self.is_do_not_age_lsa is not None:
                                                            return True

                                                        if self.is_graceful_restart_active is not None:
                                                            return True

                                                        if self.ls_id is not None:
                                                            return True

                                                        if self.lsa_age is not None:
                                                            return True

                                                        if self.lsa_area_id is not None:
                                                            return True

                                                        if self.lsa_type is not None:
                                                            return True

                                                        if self.sequence_number is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                        return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo.LsaHeader']['meta_info']


                                                class LsaDetail(object):
                                                    """
                                                    Detailed LSA information
                                                    
                                                    .. attribute:: free_time
                                                    
                                                    	The amount of time since the last check was made to free this LSA (s)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_acknowledged
                                                    
                                                    	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_advertising_router_reachable
                                                    
                                                    	If true, Advertising Router is reachable
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_deleted
                                                    
                                                    	If true, flag is set to delete this LSA 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_flood_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_maximum_aged
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_neighbor_exchange
                                                    
                                                    	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_no_delete
                                                    
                                                    	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_nsr_ack_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_partial_spf
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_routing_bit
                                                    
                                                    	If true, Routing Bit set on the LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_routing_table
                                                    
                                                    	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: lsa_flood_required_post_fail_over
                                                    
                                                    	LSA flood required after FO
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: lsa_length
                                                    
                                                    	Length of the LSA
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_sync_state
                                                    
                                                    	State of LSA sync with active
                                                    	**type**\:   :py:class:`OspfLsaSyncStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncStateEnum>`
                                                    
                                                    .. attribute:: minute_table_index
                                                    
                                                    	Minute table index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: nsr_flood_required
                                                    
                                                    	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: rate_limit
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: second_table_index
                                                    
                                                    	Second table index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.free_time = None
                                                        self.is_acknowledged = None
                                                        self.is_advertising_router_reachable = None
                                                        self.is_deleted = None
                                                        self.is_flood_pending = None
                                                        self.is_maximum_aged = None
                                                        self.is_neighbor_exchange = None
                                                        self.is_no_delete = None
                                                        self.is_nsr_ack_pending = None
                                                        self.is_partial_spf = None
                                                        self.is_routing_bit = None
                                                        self.is_routing_table = None
                                                        self.lsa_flood_required_post_fail_over = None
                                                        self.lsa_length = None
                                                        self.lsa_sync_state = None
                                                        self.minute_table_index = None
                                                        self.nsr_flood_required = None
                                                        self.rate_limit = None
                                                        self.second_table_index = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-detail'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.free_time is not None:
                                                            return True

                                                        if self.is_acknowledged is not None:
                                                            return True

                                                        if self.is_advertising_router_reachable is not None:
                                                            return True

                                                        if self.is_deleted is not None:
                                                            return True

                                                        if self.is_flood_pending is not None:
                                                            return True

                                                        if self.is_maximum_aged is not None:
                                                            return True

                                                        if self.is_neighbor_exchange is not None:
                                                            return True

                                                        if self.is_no_delete is not None:
                                                            return True

                                                        if self.is_nsr_ack_pending is not None:
                                                            return True

                                                        if self.is_partial_spf is not None:
                                                            return True

                                                        if self.is_routing_bit is not None:
                                                            return True

                                                        if self.is_routing_table is not None:
                                                            return True

                                                        if self.lsa_flood_required_post_fail_over is not None:
                                                            return True

                                                        if self.lsa_length is not None:
                                                            return True

                                                        if self.lsa_sync_state is not None:
                                                            return True

                                                        if self.minute_table_index is not None:
                                                            return True

                                                        if self.nsr_flood_required is not None:
                                                            return True

                                                        if self.rate_limit is not None:
                                                            return True

                                                        if self.second_table_index is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                        return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo.LsaDetail']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-summary-info'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.interface_name is not None:
                                                        return True

                                                    if self.is_sham_link is not None:
                                                        return True

                                                    if self.is_virtual_link is not None:
                                                        return True

                                                    if self.links is not None:
                                                        return True

                                                    if self.lsa_detail is not None and self.lsa_detail._has_data():
                                                        return True

                                                    if self.lsa_header is not None and self.lsa_header._has_data():
                                                        return True

                                                    if self.lsa_router_id is not None:
                                                        return True

                                                    if self.prefix is not None:
                                                        return True

                                                    if self.prefix_length is not None:
                                                        return True

                                                    if self.reference_lsa_id is not None:
                                                        return True

                                                    if self.reference_type is not None:
                                                        return True

                                                    if self.router_la_bits is not None:
                                                        return True

                                                    if self.sham_link_id is not None:
                                                        return True

                                                    if self.virtual_link_id is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                    return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo']['meta_info']


                                            class RouterLsaType(object):
                                                """
                                                Router LSA
                                                
                                                .. attribute:: link
                                                
                                                	List of links in this LSA
                                                	**type**\: list of    :py:class:`Link <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.Link>`
                                                
                                                .. attribute:: lsa_detail
                                                
                                                	Detailed LSA information
                                                	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.LsaDetail>`
                                                
                                                .. attribute:: lsa_header
                                                
                                                	Header information 
                                                	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.LsaHeader>`
                                                
                                                .. attribute:: router_la_bits
                                                
                                                	Router LA bits 
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: rpf_path
                                                
                                                	Router LSA Reverse\-Path Forwarding information 
                                                	**type**\:   :py:class:`RpfPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.RpfPath>`
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.link = YList()
                                                    self.link.parent = self
                                                    self.link.name = 'link'
                                                    self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.LsaDetail()
                                                    self.lsa_detail.parent = self
                                                    self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.LsaHeader()
                                                    self.lsa_header.parent = self
                                                    self.router_la_bits = None
                                                    self.rpf_path = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.RpfPath()
                                                    self.rpf_path.parent = self


                                                class LsaHeader(object):
                                                    """
                                                    Header information 
                                                    
                                                    .. attribute:: advertising_router
                                                    
                                                    	Router ID of Advertising Router
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: checksum
                                                    
                                                    	Checksum value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: is_do_not_age_lsa
                                                    
                                                    	If true, Do Not Age this LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_graceful_restart_active
                                                    
                                                    	If true, if grace restart is active 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: ls_id
                                                    
                                                    	LS ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: lsa_age
                                                    
                                                    	LSA's Age (s)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_area_id
                                                    
                                                    	Area ID in decimal or dotted\-decimal format
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..16
                                                    
                                                    .. attribute:: lsa_type
                                                    
                                                    	LSA type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: sequence_number
                                                    
                                                    	Current Sequence number
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.advertising_router = None
                                                        self.checksum = None
                                                        self.is_do_not_age_lsa = None
                                                        self.is_graceful_restart_active = None
                                                        self.ls_id = None
                                                        self.lsa_age = None
                                                        self.lsa_area_id = None
                                                        self.lsa_type = None
                                                        self.sequence_number = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-header'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.advertising_router is not None:
                                                            return True

                                                        if self.checksum is not None:
                                                            return True

                                                        if self.is_do_not_age_lsa is not None:
                                                            return True

                                                        if self.is_graceful_restart_active is not None:
                                                            return True

                                                        if self.ls_id is not None:
                                                            return True

                                                        if self.lsa_age is not None:
                                                            return True

                                                        if self.lsa_area_id is not None:
                                                            return True

                                                        if self.lsa_type is not None:
                                                            return True

                                                        if self.sequence_number is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                        return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.LsaHeader']['meta_info']


                                                class LsaDetail(object):
                                                    """
                                                    Detailed LSA information
                                                    
                                                    .. attribute:: free_time
                                                    
                                                    	The amount of time since the last check was made to free this LSA (s)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_acknowledged
                                                    
                                                    	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_advertising_router_reachable
                                                    
                                                    	If true, Advertising Router is reachable
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_deleted
                                                    
                                                    	If true, flag is set to delete this LSA 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_flood_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_maximum_aged
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_neighbor_exchange
                                                    
                                                    	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_no_delete
                                                    
                                                    	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_nsr_ack_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_partial_spf
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_routing_bit
                                                    
                                                    	If true, Routing Bit set on the LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_routing_table
                                                    
                                                    	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: lsa_flood_required_post_fail_over
                                                    
                                                    	LSA flood required after FO
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: lsa_length
                                                    
                                                    	Length of the LSA
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_sync_state
                                                    
                                                    	State of LSA sync with active
                                                    	**type**\:   :py:class:`OspfLsaSyncStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncStateEnum>`
                                                    
                                                    .. attribute:: minute_table_index
                                                    
                                                    	Minute table index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: nsr_flood_required
                                                    
                                                    	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: rate_limit
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: second_table_index
                                                    
                                                    	Second table index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.free_time = None
                                                        self.is_acknowledged = None
                                                        self.is_advertising_router_reachable = None
                                                        self.is_deleted = None
                                                        self.is_flood_pending = None
                                                        self.is_maximum_aged = None
                                                        self.is_neighbor_exchange = None
                                                        self.is_no_delete = None
                                                        self.is_nsr_ack_pending = None
                                                        self.is_partial_spf = None
                                                        self.is_routing_bit = None
                                                        self.is_routing_table = None
                                                        self.lsa_flood_required_post_fail_over = None
                                                        self.lsa_length = None
                                                        self.lsa_sync_state = None
                                                        self.minute_table_index = None
                                                        self.nsr_flood_required = None
                                                        self.rate_limit = None
                                                        self.second_table_index = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-detail'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.free_time is not None:
                                                            return True

                                                        if self.is_acknowledged is not None:
                                                            return True

                                                        if self.is_advertising_router_reachable is not None:
                                                            return True

                                                        if self.is_deleted is not None:
                                                            return True

                                                        if self.is_flood_pending is not None:
                                                            return True

                                                        if self.is_maximum_aged is not None:
                                                            return True

                                                        if self.is_neighbor_exchange is not None:
                                                            return True

                                                        if self.is_no_delete is not None:
                                                            return True

                                                        if self.is_nsr_ack_pending is not None:
                                                            return True

                                                        if self.is_partial_spf is not None:
                                                            return True

                                                        if self.is_routing_bit is not None:
                                                            return True

                                                        if self.is_routing_table is not None:
                                                            return True

                                                        if self.lsa_flood_required_post_fail_over is not None:
                                                            return True

                                                        if self.lsa_length is not None:
                                                            return True

                                                        if self.lsa_sync_state is not None:
                                                            return True

                                                        if self.minute_table_index is not None:
                                                            return True

                                                        if self.nsr_flood_required is not None:
                                                            return True

                                                        if self.rate_limit is not None:
                                                            return True

                                                        if self.second_table_index is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                        return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.LsaDetail']['meta_info']


                                                class RpfPath(object):
                                                    """
                                                    Router LSA Reverse\-Path Forwarding information 
                                                    
                                                    .. attribute:: interface_name
                                                    
                                                    	RPF multicast IDB 
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                    
                                                    .. attribute:: rpf_multicast_next_hop
                                                    
                                                    	RPF multicast next hop 
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.interface_name = None
                                                        self.rpf_multicast_next_hop = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:rpf-path'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.interface_name is not None:
                                                            return True

                                                        if self.rpf_multicast_next_hop is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                        return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.RpfPath']['meta_info']


                                                class Link(object):
                                                    """
                                                    List of links in this LSA
                                                    
                                                    .. attribute:: link_interface_id
                                                    
                                                    	LSA link interface ID 
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: link_metric
                                                    
                                                    	LSA link metric 
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: link_neighbor_interface_id
                                                    
                                                    	LSA link neighbor interface ID 
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: link_neighbor_router_id
                                                    
                                                    	LSA link neigbhor router id 
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: link_type
                                                    
                                                    	Type of link
                                                    	**type**\:   :py:class:`Ospfv3LinkEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3LinkEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.link_interface_id = None
                                                        self.link_metric = None
                                                        self.link_neighbor_interface_id = None
                                                        self.link_neighbor_router_id = None
                                                        self.link_type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:link'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.link_interface_id is not None:
                                                            return True

                                                        if self.link_metric is not None:
                                                            return True

                                                        if self.link_neighbor_interface_id is not None:
                                                            return True

                                                        if self.link_neighbor_router_id is not None:
                                                            return True

                                                        if self.link_type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                        return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.Link']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:router-lsa-type'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.link is not None:
                                                        for child_ref in self.link:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.lsa_detail is not None and self.lsa_detail._has_data():
                                                        return True

                                                    if self.lsa_header is not None and self.lsa_header._has_data():
                                                        return True

                                                    if self.router_la_bits is not None:
                                                        return True

                                                    if self.rpf_path is not None and self.rpf_path._has_data():
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                    return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType']['meta_info']


                                            class NetworkLsaType(object):
                                                """
                                                Network LSA
                                                
                                                .. attribute:: lsa_detail
                                                
                                                	Detailed LSA information
                                                	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType.LsaDetail>`
                                                
                                                .. attribute:: lsa_header
                                                
                                                	Header information 
                                                	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType.LsaHeader>`
                                                
                                                .. attribute:: neighbor_router
                                                
                                                	Neighbor router list
                                                	**type**\:  list of str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType.LsaDetail()
                                                    self.lsa_detail.parent = self
                                                    self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType.LsaHeader()
                                                    self.lsa_header.parent = self
                                                    self.neighbor_router = YLeafList()
                                                    self.neighbor_router.parent = self
                                                    self.neighbor_router.name = 'neighbor_router'


                                                class LsaHeader(object):
                                                    """
                                                    Header information 
                                                    
                                                    .. attribute:: advertising_router
                                                    
                                                    	Router ID of Advertising Router
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: checksum
                                                    
                                                    	Checksum value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: is_do_not_age_lsa
                                                    
                                                    	If true, Do Not Age this LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_graceful_restart_active
                                                    
                                                    	If true, if grace restart is active 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: ls_id
                                                    
                                                    	LS ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: lsa_age
                                                    
                                                    	LSA's Age (s)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_area_id
                                                    
                                                    	Area ID in decimal or dotted\-decimal format
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..16
                                                    
                                                    .. attribute:: lsa_type
                                                    
                                                    	LSA type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: sequence_number
                                                    
                                                    	Current Sequence number
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.advertising_router = None
                                                        self.checksum = None
                                                        self.is_do_not_age_lsa = None
                                                        self.is_graceful_restart_active = None
                                                        self.ls_id = None
                                                        self.lsa_age = None
                                                        self.lsa_area_id = None
                                                        self.lsa_type = None
                                                        self.sequence_number = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-header'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.advertising_router is not None:
                                                            return True

                                                        if self.checksum is not None:
                                                            return True

                                                        if self.is_do_not_age_lsa is not None:
                                                            return True

                                                        if self.is_graceful_restart_active is not None:
                                                            return True

                                                        if self.ls_id is not None:
                                                            return True

                                                        if self.lsa_age is not None:
                                                            return True

                                                        if self.lsa_area_id is not None:
                                                            return True

                                                        if self.lsa_type is not None:
                                                            return True

                                                        if self.sequence_number is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                        return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType.LsaHeader']['meta_info']


                                                class LsaDetail(object):
                                                    """
                                                    Detailed LSA information
                                                    
                                                    .. attribute:: free_time
                                                    
                                                    	The amount of time since the last check was made to free this LSA (s)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_acknowledged
                                                    
                                                    	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_advertising_router_reachable
                                                    
                                                    	If true, Advertising Router is reachable
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_deleted
                                                    
                                                    	If true, flag is set to delete this LSA 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_flood_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_maximum_aged
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_neighbor_exchange
                                                    
                                                    	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_no_delete
                                                    
                                                    	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_nsr_ack_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_partial_spf
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_routing_bit
                                                    
                                                    	If true, Routing Bit set on the LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_routing_table
                                                    
                                                    	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: lsa_flood_required_post_fail_over
                                                    
                                                    	LSA flood required after FO
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: lsa_length
                                                    
                                                    	Length of the LSA
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_sync_state
                                                    
                                                    	State of LSA sync with active
                                                    	**type**\:   :py:class:`OspfLsaSyncStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncStateEnum>`
                                                    
                                                    .. attribute:: minute_table_index
                                                    
                                                    	Minute table index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: nsr_flood_required
                                                    
                                                    	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: rate_limit
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: second_table_index
                                                    
                                                    	Second table index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.free_time = None
                                                        self.is_acknowledged = None
                                                        self.is_advertising_router_reachable = None
                                                        self.is_deleted = None
                                                        self.is_flood_pending = None
                                                        self.is_maximum_aged = None
                                                        self.is_neighbor_exchange = None
                                                        self.is_no_delete = None
                                                        self.is_nsr_ack_pending = None
                                                        self.is_partial_spf = None
                                                        self.is_routing_bit = None
                                                        self.is_routing_table = None
                                                        self.lsa_flood_required_post_fail_over = None
                                                        self.lsa_length = None
                                                        self.lsa_sync_state = None
                                                        self.minute_table_index = None
                                                        self.nsr_flood_required = None
                                                        self.rate_limit = None
                                                        self.second_table_index = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-detail'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.free_time is not None:
                                                            return True

                                                        if self.is_acknowledged is not None:
                                                            return True

                                                        if self.is_advertising_router_reachable is not None:
                                                            return True

                                                        if self.is_deleted is not None:
                                                            return True

                                                        if self.is_flood_pending is not None:
                                                            return True

                                                        if self.is_maximum_aged is not None:
                                                            return True

                                                        if self.is_neighbor_exchange is not None:
                                                            return True

                                                        if self.is_no_delete is not None:
                                                            return True

                                                        if self.is_nsr_ack_pending is not None:
                                                            return True

                                                        if self.is_partial_spf is not None:
                                                            return True

                                                        if self.is_routing_bit is not None:
                                                            return True

                                                        if self.is_routing_table is not None:
                                                            return True

                                                        if self.lsa_flood_required_post_fail_over is not None:
                                                            return True

                                                        if self.lsa_length is not None:
                                                            return True

                                                        if self.lsa_sync_state is not None:
                                                            return True

                                                        if self.minute_table_index is not None:
                                                            return True

                                                        if self.nsr_flood_required is not None:
                                                            return True

                                                        if self.rate_limit is not None:
                                                            return True

                                                        if self.second_table_index is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                        return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType.LsaDetail']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:network-lsa-type'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.lsa_detail is not None and self.lsa_detail._has_data():
                                                        return True

                                                    if self.lsa_header is not None and self.lsa_header._has_data():
                                                        return True

                                                    if self.neighbor_router is not None:
                                                        for child in self.neighbor_router:
                                                            if child is not None:
                                                                return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                    return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType']['meta_info']


                                            class InterAreaPrefixLsaType(object):
                                                """
                                                Inter Area Prefix LSA
                                                
                                                .. attribute:: lsa_detail
                                                
                                                	Detailed LSA Information
                                                	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaDetail>`
                                                
                                                .. attribute:: lsa_header
                                                
                                                	Header information 
                                                	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaHeader>`
                                                
                                                .. attribute:: prefix
                                                
                                                	LSA address prefix 
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: prefix_length
                                                
                                                	Prefix length 
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: priority
                                                
                                                	Prefix priority
                                                	**type**\:   :py:class:`PrefixPriorityEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.PrefixPriorityEnum>`
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaDetail()
                                                    self.lsa_detail.parent = self
                                                    self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaHeader()
                                                    self.lsa_header.parent = self
                                                    self.prefix = None
                                                    self.prefix_length = None
                                                    self.priority = None


                                                class LsaHeader(object):
                                                    """
                                                    Header information 
                                                    
                                                    .. attribute:: advertising_router
                                                    
                                                    	Router ID of Advertising Router
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: checksum
                                                    
                                                    	Checksum value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: is_do_not_age_lsa
                                                    
                                                    	If true, Do Not Age this LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_graceful_restart_active
                                                    
                                                    	If true, if grace restart is active 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: ls_id
                                                    
                                                    	LS ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: lsa_age
                                                    
                                                    	LSA's Age (s)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_area_id
                                                    
                                                    	Area ID in decimal or dotted\-decimal format
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..16
                                                    
                                                    .. attribute:: lsa_type
                                                    
                                                    	LSA type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: sequence_number
                                                    
                                                    	Current Sequence number
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.advertising_router = None
                                                        self.checksum = None
                                                        self.is_do_not_age_lsa = None
                                                        self.is_graceful_restart_active = None
                                                        self.ls_id = None
                                                        self.lsa_age = None
                                                        self.lsa_area_id = None
                                                        self.lsa_type = None
                                                        self.sequence_number = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-header'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.advertising_router is not None:
                                                            return True

                                                        if self.checksum is not None:
                                                            return True

                                                        if self.is_do_not_age_lsa is not None:
                                                            return True

                                                        if self.is_graceful_restart_active is not None:
                                                            return True

                                                        if self.ls_id is not None:
                                                            return True

                                                        if self.lsa_age is not None:
                                                            return True

                                                        if self.lsa_area_id is not None:
                                                            return True

                                                        if self.lsa_type is not None:
                                                            return True

                                                        if self.sequence_number is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                        return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaHeader']['meta_info']


                                                class LsaDetail(object):
                                                    """
                                                    Detailed LSA Information
                                                    
                                                    .. attribute:: free_time
                                                    
                                                    	The amount of time since the last check was made to free this LSA (s)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_acknowledged
                                                    
                                                    	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_advertising_router_reachable
                                                    
                                                    	If true, Advertising Router is reachable
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_deleted
                                                    
                                                    	If true, flag is set to delete this LSA 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_flood_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_maximum_aged
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_neighbor_exchange
                                                    
                                                    	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_no_delete
                                                    
                                                    	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_nsr_ack_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_partial_spf
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_routing_bit
                                                    
                                                    	If true, Routing Bit set on the LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_routing_table
                                                    
                                                    	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: lsa_flood_required_post_fail_over
                                                    
                                                    	LSA flood required after FO
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: lsa_length
                                                    
                                                    	Length of the LSA
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_sync_state
                                                    
                                                    	State of LSA sync with active
                                                    	**type**\:   :py:class:`OspfLsaSyncStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncStateEnum>`
                                                    
                                                    .. attribute:: minute_table_index
                                                    
                                                    	Minute table index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: nsr_flood_required
                                                    
                                                    	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: rate_limit
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: second_table_index
                                                    
                                                    	Second table index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.free_time = None
                                                        self.is_acknowledged = None
                                                        self.is_advertising_router_reachable = None
                                                        self.is_deleted = None
                                                        self.is_flood_pending = None
                                                        self.is_maximum_aged = None
                                                        self.is_neighbor_exchange = None
                                                        self.is_no_delete = None
                                                        self.is_nsr_ack_pending = None
                                                        self.is_partial_spf = None
                                                        self.is_routing_bit = None
                                                        self.is_routing_table = None
                                                        self.lsa_flood_required_post_fail_over = None
                                                        self.lsa_length = None
                                                        self.lsa_sync_state = None
                                                        self.minute_table_index = None
                                                        self.nsr_flood_required = None
                                                        self.rate_limit = None
                                                        self.second_table_index = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-detail'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.free_time is not None:
                                                            return True

                                                        if self.is_acknowledged is not None:
                                                            return True

                                                        if self.is_advertising_router_reachable is not None:
                                                            return True

                                                        if self.is_deleted is not None:
                                                            return True

                                                        if self.is_flood_pending is not None:
                                                            return True

                                                        if self.is_maximum_aged is not None:
                                                            return True

                                                        if self.is_neighbor_exchange is not None:
                                                            return True

                                                        if self.is_no_delete is not None:
                                                            return True

                                                        if self.is_nsr_ack_pending is not None:
                                                            return True

                                                        if self.is_partial_spf is not None:
                                                            return True

                                                        if self.is_routing_bit is not None:
                                                            return True

                                                        if self.is_routing_table is not None:
                                                            return True

                                                        if self.lsa_flood_required_post_fail_over is not None:
                                                            return True

                                                        if self.lsa_length is not None:
                                                            return True

                                                        if self.lsa_sync_state is not None:
                                                            return True

                                                        if self.minute_table_index is not None:
                                                            return True

                                                        if self.nsr_flood_required is not None:
                                                            return True

                                                        if self.rate_limit is not None:
                                                            return True

                                                        if self.second_table_index is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                        return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaDetail']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:inter-area-prefix-lsa-type'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.lsa_detail is not None and self.lsa_detail._has_data():
                                                        return True

                                                    if self.lsa_header is not None and self.lsa_header._has_data():
                                                        return True

                                                    if self.prefix is not None:
                                                        return True

                                                    if self.prefix_length is not None:
                                                        return True

                                                    if self.priority is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                    return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType']['meta_info']


                                            class InterAreaRouterLsaType(object):
                                                """
                                                Inter Area Router LSA
                                                
                                                .. attribute:: lsa_detail
                                                
                                                	Detailed LSA information
                                                	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaDetail>`
                                                
                                                .. attribute:: lsa_header
                                                
                                                	Header information 
                                                	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaHeader>`
                                                
                                                .. attribute:: lsa_router_id
                                                
                                                	LSA router ID 
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaDetail()
                                                    self.lsa_detail.parent = self
                                                    self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaHeader()
                                                    self.lsa_header.parent = self
                                                    self.lsa_router_id = None


                                                class LsaHeader(object):
                                                    """
                                                    Header information 
                                                    
                                                    .. attribute:: advertising_router
                                                    
                                                    	Router ID of Advertising Router
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: checksum
                                                    
                                                    	Checksum value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: is_do_not_age_lsa
                                                    
                                                    	If true, Do Not Age this LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_graceful_restart_active
                                                    
                                                    	If true, if grace restart is active 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: ls_id
                                                    
                                                    	LS ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: lsa_age
                                                    
                                                    	LSA's Age (s)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_area_id
                                                    
                                                    	Area ID in decimal or dotted\-decimal format
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..16
                                                    
                                                    .. attribute:: lsa_type
                                                    
                                                    	LSA type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: sequence_number
                                                    
                                                    	Current Sequence number
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.advertising_router = None
                                                        self.checksum = None
                                                        self.is_do_not_age_lsa = None
                                                        self.is_graceful_restart_active = None
                                                        self.ls_id = None
                                                        self.lsa_age = None
                                                        self.lsa_area_id = None
                                                        self.lsa_type = None
                                                        self.sequence_number = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-header'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.advertising_router is not None:
                                                            return True

                                                        if self.checksum is not None:
                                                            return True

                                                        if self.is_do_not_age_lsa is not None:
                                                            return True

                                                        if self.is_graceful_restart_active is not None:
                                                            return True

                                                        if self.ls_id is not None:
                                                            return True

                                                        if self.lsa_age is not None:
                                                            return True

                                                        if self.lsa_area_id is not None:
                                                            return True

                                                        if self.lsa_type is not None:
                                                            return True

                                                        if self.sequence_number is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                        return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaHeader']['meta_info']


                                                class LsaDetail(object):
                                                    """
                                                    Detailed LSA information
                                                    
                                                    .. attribute:: free_time
                                                    
                                                    	The amount of time since the last check was made to free this LSA (s)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_acknowledged
                                                    
                                                    	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_advertising_router_reachable
                                                    
                                                    	If true, Advertising Router is reachable
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_deleted
                                                    
                                                    	If true, flag is set to delete this LSA 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_flood_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_maximum_aged
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_neighbor_exchange
                                                    
                                                    	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_no_delete
                                                    
                                                    	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_nsr_ack_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_partial_spf
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_routing_bit
                                                    
                                                    	If true, Routing Bit set on the LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_routing_table
                                                    
                                                    	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: lsa_flood_required_post_fail_over
                                                    
                                                    	LSA flood required after FO
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: lsa_length
                                                    
                                                    	Length of the LSA
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_sync_state
                                                    
                                                    	State of LSA sync with active
                                                    	**type**\:   :py:class:`OspfLsaSyncStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncStateEnum>`
                                                    
                                                    .. attribute:: minute_table_index
                                                    
                                                    	Minute table index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: nsr_flood_required
                                                    
                                                    	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: rate_limit
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: second_table_index
                                                    
                                                    	Second table index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.free_time = None
                                                        self.is_acknowledged = None
                                                        self.is_advertising_router_reachable = None
                                                        self.is_deleted = None
                                                        self.is_flood_pending = None
                                                        self.is_maximum_aged = None
                                                        self.is_neighbor_exchange = None
                                                        self.is_no_delete = None
                                                        self.is_nsr_ack_pending = None
                                                        self.is_partial_spf = None
                                                        self.is_routing_bit = None
                                                        self.is_routing_table = None
                                                        self.lsa_flood_required_post_fail_over = None
                                                        self.lsa_length = None
                                                        self.lsa_sync_state = None
                                                        self.minute_table_index = None
                                                        self.nsr_flood_required = None
                                                        self.rate_limit = None
                                                        self.second_table_index = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-detail'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.free_time is not None:
                                                            return True

                                                        if self.is_acknowledged is not None:
                                                            return True

                                                        if self.is_advertising_router_reachable is not None:
                                                            return True

                                                        if self.is_deleted is not None:
                                                            return True

                                                        if self.is_flood_pending is not None:
                                                            return True

                                                        if self.is_maximum_aged is not None:
                                                            return True

                                                        if self.is_neighbor_exchange is not None:
                                                            return True

                                                        if self.is_no_delete is not None:
                                                            return True

                                                        if self.is_nsr_ack_pending is not None:
                                                            return True

                                                        if self.is_partial_spf is not None:
                                                            return True

                                                        if self.is_routing_bit is not None:
                                                            return True

                                                        if self.is_routing_table is not None:
                                                            return True

                                                        if self.lsa_flood_required_post_fail_over is not None:
                                                            return True

                                                        if self.lsa_length is not None:
                                                            return True

                                                        if self.lsa_sync_state is not None:
                                                            return True

                                                        if self.minute_table_index is not None:
                                                            return True

                                                        if self.nsr_flood_required is not None:
                                                            return True

                                                        if self.rate_limit is not None:
                                                            return True

                                                        if self.second_table_index is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                        return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaDetail']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:inter-area-router-lsa-type'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.lsa_detail is not None and self.lsa_detail._has_data():
                                                        return True

                                                    if self.lsa_header is not None and self.lsa_header._has_data():
                                                        return True

                                                    if self.lsa_router_id is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                    return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType']['meta_info']


                                            class ExternalLsaType(object):
                                                """
                                                External LSA
                                                
                                                .. attribute:: external_tag
                                                
                                                	Route Tag
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: forwarding_address
                                                
                                                	Forwarding Address
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: is_forwarding_address_set
                                                
                                                	If true, forwarding address is set 
                                                	**type**\:  bool
                                                
                                                .. attribute:: lsa_detail
                                                
                                                	Detailed LSA Information
                                                	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType.LsaDetail>`
                                                
                                                .. attribute:: lsa_header
                                                
                                                	Header information 
                                                	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType.LsaHeader>`
                                                
                                                .. attribute:: metric_type
                                                
                                                	Metric type 
                                                	**type**\:   :py:class:`Ospfv3DefaultMetricEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3DefaultMetricEnum>`
                                                
                                                .. attribute:: prefix
                                                
                                                	IPV6 address prefix 
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: prefix_length
                                                
                                                	Prefix length 
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: priority
                                                
                                                	Prefix priority
                                                	**type**\:   :py:class:`PrefixPriorityEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.PrefixPriorityEnum>`
                                                
                                                .. attribute:: tos_cost
                                                
                                                	Type of service cost metric 
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.external_tag = None
                                                    self.forwarding_address = None
                                                    self.is_forwarding_address_set = None
                                                    self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType.LsaDetail()
                                                    self.lsa_detail.parent = self
                                                    self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType.LsaHeader()
                                                    self.lsa_header.parent = self
                                                    self.metric_type = None
                                                    self.prefix = None
                                                    self.prefix_length = None
                                                    self.priority = None
                                                    self.tos_cost = None


                                                class LsaHeader(object):
                                                    """
                                                    Header information 
                                                    
                                                    .. attribute:: advertising_router
                                                    
                                                    	Router ID of Advertising Router
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: checksum
                                                    
                                                    	Checksum value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: is_do_not_age_lsa
                                                    
                                                    	If true, Do Not Age this LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_graceful_restart_active
                                                    
                                                    	If true, if grace restart is active 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: ls_id
                                                    
                                                    	LS ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: lsa_age
                                                    
                                                    	LSA's Age (s)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_area_id
                                                    
                                                    	Area ID in decimal or dotted\-decimal format
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..16
                                                    
                                                    .. attribute:: lsa_type
                                                    
                                                    	LSA type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: sequence_number
                                                    
                                                    	Current Sequence number
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.advertising_router = None
                                                        self.checksum = None
                                                        self.is_do_not_age_lsa = None
                                                        self.is_graceful_restart_active = None
                                                        self.ls_id = None
                                                        self.lsa_age = None
                                                        self.lsa_area_id = None
                                                        self.lsa_type = None
                                                        self.sequence_number = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-header'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.advertising_router is not None:
                                                            return True

                                                        if self.checksum is not None:
                                                            return True

                                                        if self.is_do_not_age_lsa is not None:
                                                            return True

                                                        if self.is_graceful_restart_active is not None:
                                                            return True

                                                        if self.ls_id is not None:
                                                            return True

                                                        if self.lsa_age is not None:
                                                            return True

                                                        if self.lsa_area_id is not None:
                                                            return True

                                                        if self.lsa_type is not None:
                                                            return True

                                                        if self.sequence_number is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                        return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType.LsaHeader']['meta_info']


                                                class LsaDetail(object):
                                                    """
                                                    Detailed LSA Information
                                                    
                                                    .. attribute:: free_time
                                                    
                                                    	The amount of time since the last check was made to free this LSA (s)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_acknowledged
                                                    
                                                    	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_advertising_router_reachable
                                                    
                                                    	If true, Advertising Router is reachable
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_deleted
                                                    
                                                    	If true, flag is set to delete this LSA 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_flood_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_maximum_aged
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_neighbor_exchange
                                                    
                                                    	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_no_delete
                                                    
                                                    	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_nsr_ack_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_partial_spf
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_routing_bit
                                                    
                                                    	If true, Routing Bit set on the LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_routing_table
                                                    
                                                    	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: lsa_flood_required_post_fail_over
                                                    
                                                    	LSA flood required after FO
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: lsa_length
                                                    
                                                    	Length of the LSA
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_sync_state
                                                    
                                                    	State of LSA sync with active
                                                    	**type**\:   :py:class:`OspfLsaSyncStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncStateEnum>`
                                                    
                                                    .. attribute:: minute_table_index
                                                    
                                                    	Minute table index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: nsr_flood_required
                                                    
                                                    	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: rate_limit
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: second_table_index
                                                    
                                                    	Second table index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.free_time = None
                                                        self.is_acknowledged = None
                                                        self.is_advertising_router_reachable = None
                                                        self.is_deleted = None
                                                        self.is_flood_pending = None
                                                        self.is_maximum_aged = None
                                                        self.is_neighbor_exchange = None
                                                        self.is_no_delete = None
                                                        self.is_nsr_ack_pending = None
                                                        self.is_partial_spf = None
                                                        self.is_routing_bit = None
                                                        self.is_routing_table = None
                                                        self.lsa_flood_required_post_fail_over = None
                                                        self.lsa_length = None
                                                        self.lsa_sync_state = None
                                                        self.minute_table_index = None
                                                        self.nsr_flood_required = None
                                                        self.rate_limit = None
                                                        self.second_table_index = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-detail'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.free_time is not None:
                                                            return True

                                                        if self.is_acknowledged is not None:
                                                            return True

                                                        if self.is_advertising_router_reachable is not None:
                                                            return True

                                                        if self.is_deleted is not None:
                                                            return True

                                                        if self.is_flood_pending is not None:
                                                            return True

                                                        if self.is_maximum_aged is not None:
                                                            return True

                                                        if self.is_neighbor_exchange is not None:
                                                            return True

                                                        if self.is_no_delete is not None:
                                                            return True

                                                        if self.is_nsr_ack_pending is not None:
                                                            return True

                                                        if self.is_partial_spf is not None:
                                                            return True

                                                        if self.is_routing_bit is not None:
                                                            return True

                                                        if self.is_routing_table is not None:
                                                            return True

                                                        if self.lsa_flood_required_post_fail_over is not None:
                                                            return True

                                                        if self.lsa_length is not None:
                                                            return True

                                                        if self.lsa_sync_state is not None:
                                                            return True

                                                        if self.minute_table_index is not None:
                                                            return True

                                                        if self.nsr_flood_required is not None:
                                                            return True

                                                        if self.rate_limit is not None:
                                                            return True

                                                        if self.second_table_index is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                        return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType.LsaDetail']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:external-lsa-type'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.external_tag is not None:
                                                        return True

                                                    if self.forwarding_address is not None:
                                                        return True

                                                    if self.is_forwarding_address_set is not None:
                                                        return True

                                                    if self.lsa_detail is not None and self.lsa_detail._has_data():
                                                        return True

                                                    if self.lsa_header is not None and self.lsa_header._has_data():
                                                        return True

                                                    if self.metric_type is not None:
                                                        return True

                                                    if self.prefix is not None:
                                                        return True

                                                    if self.prefix_length is not None:
                                                        return True

                                                    if self.priority is not None:
                                                        return True

                                                    if self.tos_cost is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                    return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType']['meta_info']


                                            class NssalsaType(object):
                                                """
                                                NSSA External LSA
                                                
                                                .. attribute:: external_tag
                                                
                                                	Route Tag
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: forwarding_address
                                                
                                                	Forwarding Address
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: is_forwarding_address_set
                                                
                                                	If true, forwarding address is set 
                                                	**type**\:  bool
                                                
                                                .. attribute:: lsa_detail
                                                
                                                	Detailed LSA Information
                                                	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType.LsaDetail>`
                                                
                                                .. attribute:: lsa_header
                                                
                                                	Header information 
                                                	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType.LsaHeader>`
                                                
                                                .. attribute:: metric_type
                                                
                                                	Metric type 
                                                	**type**\:   :py:class:`Ospfv3DefaultMetricEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3DefaultMetricEnum>`
                                                
                                                .. attribute:: prefix
                                                
                                                	IPV6 address prefix 
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: prefix_length
                                                
                                                	Prefix length 
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: priority
                                                
                                                	Prefix priority
                                                	**type**\:   :py:class:`PrefixPriorityEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.PrefixPriorityEnum>`
                                                
                                                .. attribute:: tos_cost
                                                
                                                	Type of service cost metric 
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.external_tag = None
                                                    self.forwarding_address = None
                                                    self.is_forwarding_address_set = None
                                                    self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType.LsaDetail()
                                                    self.lsa_detail.parent = self
                                                    self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType.LsaHeader()
                                                    self.lsa_header.parent = self
                                                    self.metric_type = None
                                                    self.prefix = None
                                                    self.prefix_length = None
                                                    self.priority = None
                                                    self.tos_cost = None


                                                class LsaHeader(object):
                                                    """
                                                    Header information 
                                                    
                                                    .. attribute:: advertising_router
                                                    
                                                    	Router ID of Advertising Router
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: checksum
                                                    
                                                    	Checksum value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: is_do_not_age_lsa
                                                    
                                                    	If true, Do Not Age this LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_graceful_restart_active
                                                    
                                                    	If true, if grace restart is active 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: ls_id
                                                    
                                                    	LS ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: lsa_age
                                                    
                                                    	LSA's Age (s)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_area_id
                                                    
                                                    	Area ID in decimal or dotted\-decimal format
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..16
                                                    
                                                    .. attribute:: lsa_type
                                                    
                                                    	LSA type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: sequence_number
                                                    
                                                    	Current Sequence number
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.advertising_router = None
                                                        self.checksum = None
                                                        self.is_do_not_age_lsa = None
                                                        self.is_graceful_restart_active = None
                                                        self.ls_id = None
                                                        self.lsa_age = None
                                                        self.lsa_area_id = None
                                                        self.lsa_type = None
                                                        self.sequence_number = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-header'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.advertising_router is not None:
                                                            return True

                                                        if self.checksum is not None:
                                                            return True

                                                        if self.is_do_not_age_lsa is not None:
                                                            return True

                                                        if self.is_graceful_restart_active is not None:
                                                            return True

                                                        if self.ls_id is not None:
                                                            return True

                                                        if self.lsa_age is not None:
                                                            return True

                                                        if self.lsa_area_id is not None:
                                                            return True

                                                        if self.lsa_type is not None:
                                                            return True

                                                        if self.sequence_number is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                        return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType.LsaHeader']['meta_info']


                                                class LsaDetail(object):
                                                    """
                                                    Detailed LSA Information
                                                    
                                                    .. attribute:: free_time
                                                    
                                                    	The amount of time since the last check was made to free this LSA (s)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_acknowledged
                                                    
                                                    	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_advertising_router_reachable
                                                    
                                                    	If true, Advertising Router is reachable
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_deleted
                                                    
                                                    	If true, flag is set to delete this LSA 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_flood_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_maximum_aged
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_neighbor_exchange
                                                    
                                                    	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_no_delete
                                                    
                                                    	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_nsr_ack_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_partial_spf
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_routing_bit
                                                    
                                                    	If true, Routing Bit set on the LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_routing_table
                                                    
                                                    	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: lsa_flood_required_post_fail_over
                                                    
                                                    	LSA flood required after FO
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: lsa_length
                                                    
                                                    	Length of the LSA
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_sync_state
                                                    
                                                    	State of LSA sync with active
                                                    	**type**\:   :py:class:`OspfLsaSyncStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncStateEnum>`
                                                    
                                                    .. attribute:: minute_table_index
                                                    
                                                    	Minute table index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: nsr_flood_required
                                                    
                                                    	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: rate_limit
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: second_table_index
                                                    
                                                    	Second table index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.free_time = None
                                                        self.is_acknowledged = None
                                                        self.is_advertising_router_reachable = None
                                                        self.is_deleted = None
                                                        self.is_flood_pending = None
                                                        self.is_maximum_aged = None
                                                        self.is_neighbor_exchange = None
                                                        self.is_no_delete = None
                                                        self.is_nsr_ack_pending = None
                                                        self.is_partial_spf = None
                                                        self.is_routing_bit = None
                                                        self.is_routing_table = None
                                                        self.lsa_flood_required_post_fail_over = None
                                                        self.lsa_length = None
                                                        self.lsa_sync_state = None
                                                        self.minute_table_index = None
                                                        self.nsr_flood_required = None
                                                        self.rate_limit = None
                                                        self.second_table_index = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-detail'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.free_time is not None:
                                                            return True

                                                        if self.is_acknowledged is not None:
                                                            return True

                                                        if self.is_advertising_router_reachable is not None:
                                                            return True

                                                        if self.is_deleted is not None:
                                                            return True

                                                        if self.is_flood_pending is not None:
                                                            return True

                                                        if self.is_maximum_aged is not None:
                                                            return True

                                                        if self.is_neighbor_exchange is not None:
                                                            return True

                                                        if self.is_no_delete is not None:
                                                            return True

                                                        if self.is_nsr_ack_pending is not None:
                                                            return True

                                                        if self.is_partial_spf is not None:
                                                            return True

                                                        if self.is_routing_bit is not None:
                                                            return True

                                                        if self.is_routing_table is not None:
                                                            return True

                                                        if self.lsa_flood_required_post_fail_over is not None:
                                                            return True

                                                        if self.lsa_length is not None:
                                                            return True

                                                        if self.lsa_sync_state is not None:
                                                            return True

                                                        if self.minute_table_index is not None:
                                                            return True

                                                        if self.nsr_flood_required is not None:
                                                            return True

                                                        if self.rate_limit is not None:
                                                            return True

                                                        if self.second_table_index is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                        return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType.LsaDetail']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:nssalsa-type'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.external_tag is not None:
                                                        return True

                                                    if self.forwarding_address is not None:
                                                        return True

                                                    if self.is_forwarding_address_set is not None:
                                                        return True

                                                    if self.lsa_detail is not None and self.lsa_detail._has_data():
                                                        return True

                                                    if self.lsa_header is not None and self.lsa_header._has_data():
                                                        return True

                                                    if self.metric_type is not None:
                                                        return True

                                                    if self.prefix is not None:
                                                        return True

                                                    if self.prefix_length is not None:
                                                        return True

                                                    if self.priority is not None:
                                                        return True

                                                    if self.tos_cost is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                    return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType']['meta_info']


                                            class LinkLsaType(object):
                                                """
                                                Link LSA
                                                
                                                .. attribute:: interface_name
                                                
                                                	LSA interface handle
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                
                                                .. attribute:: is_sham_link
                                                
                                                	If true, it is a sham link
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_virtual_link
                                                
                                                	If true, it is a virtual link
                                                	**type**\:  bool
                                                
                                                .. attribute:: lsa_detail
                                                
                                                	Detailed LSA information
                                                	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType.LsaDetail>`
                                                
                                                .. attribute:: lsa_header
                                                
                                                	Header information 
                                                	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType.LsaHeader>`
                                                
                                                .. attribute:: lsa_link_local
                                                
                                                	LSA link local 
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: prefix
                                                
                                                	OSPFv3 prefix 
                                                	**type**\: list of    :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType.Prefix>`
                                                
                                                .. attribute:: router_priority
                                                
                                                	Router priority 
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: sham_link_id
                                                
                                                	Sham link ID 
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: virtual_link_id
                                                
                                                	Virtual link ID 
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.interface_name = None
                                                    self.is_sham_link = None
                                                    self.is_virtual_link = None
                                                    self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType.LsaDetail()
                                                    self.lsa_detail.parent = self
                                                    self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType.LsaHeader()
                                                    self.lsa_header.parent = self
                                                    self.lsa_link_local = None
                                                    self.prefix = YList()
                                                    self.prefix.parent = self
                                                    self.prefix.name = 'prefix'
                                                    self.router_priority = None
                                                    self.sham_link_id = None
                                                    self.virtual_link_id = None


                                                class LsaHeader(object):
                                                    """
                                                    Header information 
                                                    
                                                    .. attribute:: advertising_router
                                                    
                                                    	Router ID of Advertising Router
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: checksum
                                                    
                                                    	Checksum value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: is_do_not_age_lsa
                                                    
                                                    	If true, Do Not Age this LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_graceful_restart_active
                                                    
                                                    	If true, if grace restart is active 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: ls_id
                                                    
                                                    	LS ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: lsa_age
                                                    
                                                    	LSA's Age (s)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_area_id
                                                    
                                                    	Area ID in decimal or dotted\-decimal format
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..16
                                                    
                                                    .. attribute:: lsa_type
                                                    
                                                    	LSA type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: sequence_number
                                                    
                                                    	Current Sequence number
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.advertising_router = None
                                                        self.checksum = None
                                                        self.is_do_not_age_lsa = None
                                                        self.is_graceful_restart_active = None
                                                        self.ls_id = None
                                                        self.lsa_age = None
                                                        self.lsa_area_id = None
                                                        self.lsa_type = None
                                                        self.sequence_number = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-header'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.advertising_router is not None:
                                                            return True

                                                        if self.checksum is not None:
                                                            return True

                                                        if self.is_do_not_age_lsa is not None:
                                                            return True

                                                        if self.is_graceful_restart_active is not None:
                                                            return True

                                                        if self.ls_id is not None:
                                                            return True

                                                        if self.lsa_age is not None:
                                                            return True

                                                        if self.lsa_area_id is not None:
                                                            return True

                                                        if self.lsa_type is not None:
                                                            return True

                                                        if self.sequence_number is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                        return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType.LsaHeader']['meta_info']


                                                class LsaDetail(object):
                                                    """
                                                    Detailed LSA information
                                                    
                                                    .. attribute:: free_time
                                                    
                                                    	The amount of time since the last check was made to free this LSA (s)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_acknowledged
                                                    
                                                    	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_advertising_router_reachable
                                                    
                                                    	If true, Advertising Router is reachable
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_deleted
                                                    
                                                    	If true, flag is set to delete this LSA 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_flood_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_maximum_aged
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_neighbor_exchange
                                                    
                                                    	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_no_delete
                                                    
                                                    	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_nsr_ack_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_partial_spf
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_routing_bit
                                                    
                                                    	If true, Routing Bit set on the LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_routing_table
                                                    
                                                    	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: lsa_flood_required_post_fail_over
                                                    
                                                    	LSA flood required after FO
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: lsa_length
                                                    
                                                    	Length of the LSA
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_sync_state
                                                    
                                                    	State of LSA sync with active
                                                    	**type**\:   :py:class:`OspfLsaSyncStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncStateEnum>`
                                                    
                                                    .. attribute:: minute_table_index
                                                    
                                                    	Minute table index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: nsr_flood_required
                                                    
                                                    	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: rate_limit
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: second_table_index
                                                    
                                                    	Second table index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.free_time = None
                                                        self.is_acknowledged = None
                                                        self.is_advertising_router_reachable = None
                                                        self.is_deleted = None
                                                        self.is_flood_pending = None
                                                        self.is_maximum_aged = None
                                                        self.is_neighbor_exchange = None
                                                        self.is_no_delete = None
                                                        self.is_nsr_ack_pending = None
                                                        self.is_partial_spf = None
                                                        self.is_routing_bit = None
                                                        self.is_routing_table = None
                                                        self.lsa_flood_required_post_fail_over = None
                                                        self.lsa_length = None
                                                        self.lsa_sync_state = None
                                                        self.minute_table_index = None
                                                        self.nsr_flood_required = None
                                                        self.rate_limit = None
                                                        self.second_table_index = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-detail'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.free_time is not None:
                                                            return True

                                                        if self.is_acknowledged is not None:
                                                            return True

                                                        if self.is_advertising_router_reachable is not None:
                                                            return True

                                                        if self.is_deleted is not None:
                                                            return True

                                                        if self.is_flood_pending is not None:
                                                            return True

                                                        if self.is_maximum_aged is not None:
                                                            return True

                                                        if self.is_neighbor_exchange is not None:
                                                            return True

                                                        if self.is_no_delete is not None:
                                                            return True

                                                        if self.is_nsr_ack_pending is not None:
                                                            return True

                                                        if self.is_partial_spf is not None:
                                                            return True

                                                        if self.is_routing_bit is not None:
                                                            return True

                                                        if self.is_routing_table is not None:
                                                            return True

                                                        if self.lsa_flood_required_post_fail_over is not None:
                                                            return True

                                                        if self.lsa_length is not None:
                                                            return True

                                                        if self.lsa_sync_state is not None:
                                                            return True

                                                        if self.minute_table_index is not None:
                                                            return True

                                                        if self.nsr_flood_required is not None:
                                                            return True

                                                        if self.rate_limit is not None:
                                                            return True

                                                        if self.second_table_index is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                        return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType.LsaDetail']['meta_info']


                                                class Prefix(object):
                                                    """
                                                    OSPFv3 prefix 
                                                    
                                                    .. attribute:: ospfv3_prefix_length
                                                    
                                                    	OSPFv3 prefix length 
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: ospfv3_prefix_metric
                                                    
                                                    	OSPFv3 prefix metric 
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: ospfv3_prefix_options
                                                    
                                                    	OSPFv3 prefix options 
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: prefix
                                                    
                                                    	OSPFv3 prefix 
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: priority
                                                    
                                                    	Prefix priority
                                                    	**type**\:   :py:class:`PrefixPriorityEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.PrefixPriorityEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ospfv3_prefix_length = None
                                                        self.ospfv3_prefix_metric = None
                                                        self.ospfv3_prefix_options = None
                                                        self.prefix = None
                                                        self.priority = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:prefix'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ospfv3_prefix_length is not None:
                                                            return True

                                                        if self.ospfv3_prefix_metric is not None:
                                                            return True

                                                        if self.ospfv3_prefix_options is not None:
                                                            return True

                                                        if self.prefix is not None:
                                                            return True

                                                        if self.priority is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                        return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType.Prefix']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:link-lsa-type'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.interface_name is not None:
                                                        return True

                                                    if self.is_sham_link is not None:
                                                        return True

                                                    if self.is_virtual_link is not None:
                                                        return True

                                                    if self.lsa_detail is not None and self.lsa_detail._has_data():
                                                        return True

                                                    if self.lsa_header is not None and self.lsa_header._has_data():
                                                        return True

                                                    if self.lsa_link_local is not None:
                                                        return True

                                                    if self.prefix is not None:
                                                        for child_ref in self.prefix:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.router_priority is not None:
                                                        return True

                                                    if self.sham_link_id is not None:
                                                        return True

                                                    if self.virtual_link_id is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                    return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType']['meta_info']


                                            class IntraAreaPrefixLsaType(object):
                                                """
                                                Intra Area Prefix LSA
                                                
                                                .. attribute:: lsa_detail
                                                
                                                	Detailed LSA information
                                                	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaDetail>`
                                                
                                                .. attribute:: lsa_header
                                                
                                                	Header information 
                                                	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaHeader>`
                                                
                                                .. attribute:: prefix
                                                
                                                	OSPFv3 prefix 
                                                	**type**\: list of    :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.Prefix>`
                                                
                                                .. attribute:: reference_advertised_router
                                                
                                                	Reference advertised router 
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: reference_lsa_id
                                                
                                                	Reference LSA ID 
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: reference_type
                                                
                                                	Reference type 
                                                	**type**\:   :py:class:`Ospfv3Lsa1Enum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Lsa1Enum>`
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaDetail()
                                                    self.lsa_detail.parent = self
                                                    self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaHeader()
                                                    self.lsa_header.parent = self
                                                    self.prefix = YList()
                                                    self.prefix.parent = self
                                                    self.prefix.name = 'prefix'
                                                    self.reference_advertised_router = None
                                                    self.reference_lsa_id = None
                                                    self.reference_type = None


                                                class LsaHeader(object):
                                                    """
                                                    Header information 
                                                    
                                                    .. attribute:: advertising_router
                                                    
                                                    	Router ID of Advertising Router
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: checksum
                                                    
                                                    	Checksum value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: is_do_not_age_lsa
                                                    
                                                    	If true, Do Not Age this LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_graceful_restart_active
                                                    
                                                    	If true, if grace restart is active 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: ls_id
                                                    
                                                    	LS ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: lsa_age
                                                    
                                                    	LSA's Age (s)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_area_id
                                                    
                                                    	Area ID in decimal or dotted\-decimal format
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..16
                                                    
                                                    .. attribute:: lsa_type
                                                    
                                                    	LSA type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: sequence_number
                                                    
                                                    	Current Sequence number
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.advertising_router = None
                                                        self.checksum = None
                                                        self.is_do_not_age_lsa = None
                                                        self.is_graceful_restart_active = None
                                                        self.ls_id = None
                                                        self.lsa_age = None
                                                        self.lsa_area_id = None
                                                        self.lsa_type = None
                                                        self.sequence_number = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-header'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.advertising_router is not None:
                                                            return True

                                                        if self.checksum is not None:
                                                            return True

                                                        if self.is_do_not_age_lsa is not None:
                                                            return True

                                                        if self.is_graceful_restart_active is not None:
                                                            return True

                                                        if self.ls_id is not None:
                                                            return True

                                                        if self.lsa_age is not None:
                                                            return True

                                                        if self.lsa_area_id is not None:
                                                            return True

                                                        if self.lsa_type is not None:
                                                            return True

                                                        if self.sequence_number is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                        return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaHeader']['meta_info']


                                                class LsaDetail(object):
                                                    """
                                                    Detailed LSA information
                                                    
                                                    .. attribute:: free_time
                                                    
                                                    	The amount of time since the last check was made to free this LSA (s)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_acknowledged
                                                    
                                                    	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_advertising_router_reachable
                                                    
                                                    	If true, Advertising Router is reachable
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_deleted
                                                    
                                                    	If true, flag is set to delete this LSA 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_flood_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_maximum_aged
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_neighbor_exchange
                                                    
                                                    	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_no_delete
                                                    
                                                    	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_nsr_ack_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_partial_spf
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_routing_bit
                                                    
                                                    	If true, Routing Bit set on the LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_routing_table
                                                    
                                                    	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: lsa_flood_required_post_fail_over
                                                    
                                                    	LSA flood required after FO
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: lsa_length
                                                    
                                                    	Length of the LSA
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_sync_state
                                                    
                                                    	State of LSA sync with active
                                                    	**type**\:   :py:class:`OspfLsaSyncStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncStateEnum>`
                                                    
                                                    .. attribute:: minute_table_index
                                                    
                                                    	Minute table index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: nsr_flood_required
                                                    
                                                    	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: rate_limit
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: second_table_index
                                                    
                                                    	Second table index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.free_time = None
                                                        self.is_acknowledged = None
                                                        self.is_advertising_router_reachable = None
                                                        self.is_deleted = None
                                                        self.is_flood_pending = None
                                                        self.is_maximum_aged = None
                                                        self.is_neighbor_exchange = None
                                                        self.is_no_delete = None
                                                        self.is_nsr_ack_pending = None
                                                        self.is_partial_spf = None
                                                        self.is_routing_bit = None
                                                        self.is_routing_table = None
                                                        self.lsa_flood_required_post_fail_over = None
                                                        self.lsa_length = None
                                                        self.lsa_sync_state = None
                                                        self.minute_table_index = None
                                                        self.nsr_flood_required = None
                                                        self.rate_limit = None
                                                        self.second_table_index = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-detail'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.free_time is not None:
                                                            return True

                                                        if self.is_acknowledged is not None:
                                                            return True

                                                        if self.is_advertising_router_reachable is not None:
                                                            return True

                                                        if self.is_deleted is not None:
                                                            return True

                                                        if self.is_flood_pending is not None:
                                                            return True

                                                        if self.is_maximum_aged is not None:
                                                            return True

                                                        if self.is_neighbor_exchange is not None:
                                                            return True

                                                        if self.is_no_delete is not None:
                                                            return True

                                                        if self.is_nsr_ack_pending is not None:
                                                            return True

                                                        if self.is_partial_spf is not None:
                                                            return True

                                                        if self.is_routing_bit is not None:
                                                            return True

                                                        if self.is_routing_table is not None:
                                                            return True

                                                        if self.lsa_flood_required_post_fail_over is not None:
                                                            return True

                                                        if self.lsa_length is not None:
                                                            return True

                                                        if self.lsa_sync_state is not None:
                                                            return True

                                                        if self.minute_table_index is not None:
                                                            return True

                                                        if self.nsr_flood_required is not None:
                                                            return True

                                                        if self.rate_limit is not None:
                                                            return True

                                                        if self.second_table_index is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                        return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaDetail']['meta_info']


                                                class Prefix(object):
                                                    """
                                                    OSPFv3 prefix 
                                                    
                                                    .. attribute:: ospfv3_prefix_length
                                                    
                                                    	OSPFv3 prefix length 
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: ospfv3_prefix_metric
                                                    
                                                    	OSPFv3 prefix metric 
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: ospfv3_prefix_options
                                                    
                                                    	OSPFv3 prefix options 
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: prefix
                                                    
                                                    	OSPFv3 prefix 
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: priority
                                                    
                                                    	Prefix priority
                                                    	**type**\:   :py:class:`PrefixPriorityEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.PrefixPriorityEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ospfv3_prefix_length = None
                                                        self.ospfv3_prefix_metric = None
                                                        self.ospfv3_prefix_options = None
                                                        self.prefix = None
                                                        self.priority = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:prefix'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ospfv3_prefix_length is not None:
                                                            return True

                                                        if self.ospfv3_prefix_metric is not None:
                                                            return True

                                                        if self.ospfv3_prefix_options is not None:
                                                            return True

                                                        if self.prefix is not None:
                                                            return True

                                                        if self.priority is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                        return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.Prefix']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:intra-area-prefix-lsa-type'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.lsa_detail is not None and self.lsa_detail._has_data():
                                                        return True

                                                    if self.lsa_header is not None and self.lsa_header._has_data():
                                                        return True

                                                    if self.prefix is not None:
                                                        for child_ref in self.prefix:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.reference_advertised_router is not None:
                                                        return True

                                                    if self.reference_lsa_id is not None:
                                                        return True

                                                    if self.reference_type is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                    return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType']['meta_info']


                                            class GraceLsa(object):
                                                """
                                                Grace LSA
                                                
                                                .. attribute:: grace_period
                                                
                                                	The grace periord where helper routers should wait before advertising it fully adjacent(s) 
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: grace_reason
                                                
                                                	Reason for router restart
                                                	**type**\:   :py:class:`Ospfv3GracefulRestartReasonEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3GracefulRestartReasonEnum>`
                                                
                                                .. attribute:: lsa_detail
                                                
                                                	Detailed LSA information
                                                	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa.LsaDetail>`
                                                
                                                .. attribute:: lsa_header
                                                
                                                	Header information 
                                                	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa.LsaHeader>`
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.grace_period = None
                                                    self.grace_reason = None
                                                    self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa.LsaDetail()
                                                    self.lsa_detail.parent = self
                                                    self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa.LsaHeader()
                                                    self.lsa_header.parent = self


                                                class LsaHeader(object):
                                                    """
                                                    Header information 
                                                    
                                                    .. attribute:: advertising_router
                                                    
                                                    	Router ID of Advertising Router
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: checksum
                                                    
                                                    	Checksum value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: is_do_not_age_lsa
                                                    
                                                    	If true, Do Not Age this LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_graceful_restart_active
                                                    
                                                    	If true, if grace restart is active 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: ls_id
                                                    
                                                    	LS ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: lsa_age
                                                    
                                                    	LSA's Age (s)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_area_id
                                                    
                                                    	Area ID in decimal or dotted\-decimal format
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..16
                                                    
                                                    .. attribute:: lsa_type
                                                    
                                                    	LSA type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: sequence_number
                                                    
                                                    	Current Sequence number
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.advertising_router = None
                                                        self.checksum = None
                                                        self.is_do_not_age_lsa = None
                                                        self.is_graceful_restart_active = None
                                                        self.ls_id = None
                                                        self.lsa_age = None
                                                        self.lsa_area_id = None
                                                        self.lsa_type = None
                                                        self.sequence_number = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-header'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.advertising_router is not None:
                                                            return True

                                                        if self.checksum is not None:
                                                            return True

                                                        if self.is_do_not_age_lsa is not None:
                                                            return True

                                                        if self.is_graceful_restart_active is not None:
                                                            return True

                                                        if self.ls_id is not None:
                                                            return True

                                                        if self.lsa_age is not None:
                                                            return True

                                                        if self.lsa_area_id is not None:
                                                            return True

                                                        if self.lsa_type is not None:
                                                            return True

                                                        if self.sequence_number is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                        return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa.LsaHeader']['meta_info']


                                                class LsaDetail(object):
                                                    """
                                                    Detailed LSA information
                                                    
                                                    .. attribute:: free_time
                                                    
                                                    	The amount of time since the last check was made to free this LSA (s)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_acknowledged
                                                    
                                                    	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_advertising_router_reachable
                                                    
                                                    	If true, Advertising Router is reachable
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_deleted
                                                    
                                                    	If true, flag is set to delete this LSA 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_flood_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_maximum_aged
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_neighbor_exchange
                                                    
                                                    	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_no_delete
                                                    
                                                    	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_nsr_ack_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_partial_spf
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_routing_bit
                                                    
                                                    	If true, Routing Bit set on the LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_routing_table
                                                    
                                                    	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: lsa_flood_required_post_fail_over
                                                    
                                                    	LSA flood required after FO
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: lsa_length
                                                    
                                                    	Length of the LSA
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_sync_state
                                                    
                                                    	State of LSA sync with active
                                                    	**type**\:   :py:class:`OspfLsaSyncStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncStateEnum>`
                                                    
                                                    .. attribute:: minute_table_index
                                                    
                                                    	Minute table index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: nsr_flood_required
                                                    
                                                    	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: rate_limit
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: second_table_index
                                                    
                                                    	Second table index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.free_time = None
                                                        self.is_acknowledged = None
                                                        self.is_advertising_router_reachable = None
                                                        self.is_deleted = None
                                                        self.is_flood_pending = None
                                                        self.is_maximum_aged = None
                                                        self.is_neighbor_exchange = None
                                                        self.is_no_delete = None
                                                        self.is_nsr_ack_pending = None
                                                        self.is_partial_spf = None
                                                        self.is_routing_bit = None
                                                        self.is_routing_table = None
                                                        self.lsa_flood_required_post_fail_over = None
                                                        self.lsa_length = None
                                                        self.lsa_sync_state = None
                                                        self.minute_table_index = None
                                                        self.nsr_flood_required = None
                                                        self.rate_limit = None
                                                        self.second_table_index = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-detail'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.free_time is not None:
                                                            return True

                                                        if self.is_acknowledged is not None:
                                                            return True

                                                        if self.is_advertising_router_reachable is not None:
                                                            return True

                                                        if self.is_deleted is not None:
                                                            return True

                                                        if self.is_flood_pending is not None:
                                                            return True

                                                        if self.is_maximum_aged is not None:
                                                            return True

                                                        if self.is_neighbor_exchange is not None:
                                                            return True

                                                        if self.is_no_delete is not None:
                                                            return True

                                                        if self.is_nsr_ack_pending is not None:
                                                            return True

                                                        if self.is_partial_spf is not None:
                                                            return True

                                                        if self.is_routing_bit is not None:
                                                            return True

                                                        if self.is_routing_table is not None:
                                                            return True

                                                        if self.lsa_flood_required_post_fail_over is not None:
                                                            return True

                                                        if self.lsa_length is not None:
                                                            return True

                                                        if self.lsa_sync_state is not None:
                                                            return True

                                                        if self.minute_table_index is not None:
                                                            return True

                                                        if self.nsr_flood_required is not None:
                                                            return True

                                                        if self.rate_limit is not None:
                                                            return True

                                                        if self.second_table_index is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                        return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa.LsaDetail']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:grace-lsa'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.grace_period is not None:
                                                        return True

                                                    if self.grace_reason is not None:
                                                        return True

                                                    if self.lsa_detail is not None and self.lsa_detail._has_data():
                                                        return True

                                                    if self.lsa_header is not None and self.lsa_header._has_data():
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                    return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa']['meta_info']


                                            class UnknownLinkLsaType(object):
                                                """
                                                Unknown Link Scope LSA
                                                
                                                .. attribute:: interface_name
                                                
                                                	LSA interface name 
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                
                                                .. attribute:: is_sham_link
                                                
                                                	If true, it is a sham link 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_virtual_link
                                                
                                                	If true, it is a virtual link 
                                                	**type**\:  bool
                                                
                                                .. attribute:: lsa_detail
                                                
                                                	Detailed LSA information
                                                	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaDetail>`
                                                
                                                .. attribute:: lsa_header
                                                
                                                	Header information 
                                                	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaHeader>`
                                                
                                                .. attribute:: sham_link_id
                                                
                                                	Shamlink ID 
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: virtual_link_id
                                                
                                                	Virtual link ID 
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.interface_name = None
                                                    self.is_sham_link = None
                                                    self.is_virtual_link = None
                                                    self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaDetail()
                                                    self.lsa_detail.parent = self
                                                    self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaHeader()
                                                    self.lsa_header.parent = self
                                                    self.sham_link_id = None
                                                    self.virtual_link_id = None


                                                class LsaHeader(object):
                                                    """
                                                    Header information 
                                                    
                                                    .. attribute:: advertising_router
                                                    
                                                    	Router ID of Advertising Router
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: checksum
                                                    
                                                    	Checksum value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: is_do_not_age_lsa
                                                    
                                                    	If true, Do Not Age this LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_graceful_restart_active
                                                    
                                                    	If true, if grace restart is active 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: ls_id
                                                    
                                                    	LS ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: lsa_age
                                                    
                                                    	LSA's Age (s)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_area_id
                                                    
                                                    	Area ID in decimal or dotted\-decimal format
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..16
                                                    
                                                    .. attribute:: lsa_type
                                                    
                                                    	LSA type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: sequence_number
                                                    
                                                    	Current Sequence number
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.advertising_router = None
                                                        self.checksum = None
                                                        self.is_do_not_age_lsa = None
                                                        self.is_graceful_restart_active = None
                                                        self.ls_id = None
                                                        self.lsa_age = None
                                                        self.lsa_area_id = None
                                                        self.lsa_type = None
                                                        self.sequence_number = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-header'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.advertising_router is not None:
                                                            return True

                                                        if self.checksum is not None:
                                                            return True

                                                        if self.is_do_not_age_lsa is not None:
                                                            return True

                                                        if self.is_graceful_restart_active is not None:
                                                            return True

                                                        if self.ls_id is not None:
                                                            return True

                                                        if self.lsa_age is not None:
                                                            return True

                                                        if self.lsa_area_id is not None:
                                                            return True

                                                        if self.lsa_type is not None:
                                                            return True

                                                        if self.sequence_number is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                        return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaHeader']['meta_info']


                                                class LsaDetail(object):
                                                    """
                                                    Detailed LSA information
                                                    
                                                    .. attribute:: free_time
                                                    
                                                    	The amount of time since the last check was made to free this LSA (s)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_acknowledged
                                                    
                                                    	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_advertising_router_reachable
                                                    
                                                    	If true, Advertising Router is reachable
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_deleted
                                                    
                                                    	If true, flag is set to delete this LSA 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_flood_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_maximum_aged
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_neighbor_exchange
                                                    
                                                    	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_no_delete
                                                    
                                                    	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_nsr_ack_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_partial_spf
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_routing_bit
                                                    
                                                    	If true, Routing Bit set on the LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_routing_table
                                                    
                                                    	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: lsa_flood_required_post_fail_over
                                                    
                                                    	LSA flood required after FO
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: lsa_length
                                                    
                                                    	Length of the LSA
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_sync_state
                                                    
                                                    	State of LSA sync with active
                                                    	**type**\:   :py:class:`OspfLsaSyncStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncStateEnum>`
                                                    
                                                    .. attribute:: minute_table_index
                                                    
                                                    	Minute table index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: nsr_flood_required
                                                    
                                                    	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: rate_limit
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: second_table_index
                                                    
                                                    	Second table index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.free_time = None
                                                        self.is_acknowledged = None
                                                        self.is_advertising_router_reachable = None
                                                        self.is_deleted = None
                                                        self.is_flood_pending = None
                                                        self.is_maximum_aged = None
                                                        self.is_neighbor_exchange = None
                                                        self.is_no_delete = None
                                                        self.is_nsr_ack_pending = None
                                                        self.is_partial_spf = None
                                                        self.is_routing_bit = None
                                                        self.is_routing_table = None
                                                        self.lsa_flood_required_post_fail_over = None
                                                        self.lsa_length = None
                                                        self.lsa_sync_state = None
                                                        self.minute_table_index = None
                                                        self.nsr_flood_required = None
                                                        self.rate_limit = None
                                                        self.second_table_index = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-detail'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.free_time is not None:
                                                            return True

                                                        if self.is_acknowledged is not None:
                                                            return True

                                                        if self.is_advertising_router_reachable is not None:
                                                            return True

                                                        if self.is_deleted is not None:
                                                            return True

                                                        if self.is_flood_pending is not None:
                                                            return True

                                                        if self.is_maximum_aged is not None:
                                                            return True

                                                        if self.is_neighbor_exchange is not None:
                                                            return True

                                                        if self.is_no_delete is not None:
                                                            return True

                                                        if self.is_nsr_ack_pending is not None:
                                                            return True

                                                        if self.is_partial_spf is not None:
                                                            return True

                                                        if self.is_routing_bit is not None:
                                                            return True

                                                        if self.is_routing_table is not None:
                                                            return True

                                                        if self.lsa_flood_required_post_fail_over is not None:
                                                            return True

                                                        if self.lsa_length is not None:
                                                            return True

                                                        if self.lsa_sync_state is not None:
                                                            return True

                                                        if self.minute_table_index is not None:
                                                            return True

                                                        if self.nsr_flood_required is not None:
                                                            return True

                                                        if self.rate_limit is not None:
                                                            return True

                                                        if self.second_table_index is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                        return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaDetail']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:unknown-link-lsa-type'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.interface_name is not None:
                                                        return True

                                                    if self.is_sham_link is not None:
                                                        return True

                                                    if self.is_virtual_link is not None:
                                                        return True

                                                    if self.lsa_detail is not None and self.lsa_detail._has_data():
                                                        return True

                                                    if self.lsa_header is not None and self.lsa_header._has_data():
                                                        return True

                                                    if self.sham_link_id is not None:
                                                        return True

                                                    if self.virtual_link_id is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                    return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType']['meta_info']


                                            class UnknownAreaLsaType(object):
                                                """
                                                Unknown\-Area scope LSA
                                                
                                                .. attribute:: interface_name
                                                
                                                	LSA interface name 
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                
                                                .. attribute:: is_sham_link
                                                
                                                	If true, it is a sham link 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_virtual_link
                                                
                                                	If true, it is a virtual link 
                                                	**type**\:  bool
                                                
                                                .. attribute:: lsa_detail
                                                
                                                	Detailed LSA information
                                                	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaDetail>`
                                                
                                                .. attribute:: lsa_header
                                                
                                                	Header information 
                                                	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaHeader>`
                                                
                                                .. attribute:: sham_link_id
                                                
                                                	Shamlink ID 
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: virtual_link_id
                                                
                                                	Virtual link ID 
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.interface_name = None
                                                    self.is_sham_link = None
                                                    self.is_virtual_link = None
                                                    self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaDetail()
                                                    self.lsa_detail.parent = self
                                                    self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaHeader()
                                                    self.lsa_header.parent = self
                                                    self.sham_link_id = None
                                                    self.virtual_link_id = None


                                                class LsaHeader(object):
                                                    """
                                                    Header information 
                                                    
                                                    .. attribute:: advertising_router
                                                    
                                                    	Router ID of Advertising Router
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: checksum
                                                    
                                                    	Checksum value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: is_do_not_age_lsa
                                                    
                                                    	If true, Do Not Age this LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_graceful_restart_active
                                                    
                                                    	If true, if grace restart is active 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: ls_id
                                                    
                                                    	LS ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: lsa_age
                                                    
                                                    	LSA's Age (s)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_area_id
                                                    
                                                    	Area ID in decimal or dotted\-decimal format
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..16
                                                    
                                                    .. attribute:: lsa_type
                                                    
                                                    	LSA type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: sequence_number
                                                    
                                                    	Current Sequence number
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.advertising_router = None
                                                        self.checksum = None
                                                        self.is_do_not_age_lsa = None
                                                        self.is_graceful_restart_active = None
                                                        self.ls_id = None
                                                        self.lsa_age = None
                                                        self.lsa_area_id = None
                                                        self.lsa_type = None
                                                        self.sequence_number = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-header'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.advertising_router is not None:
                                                            return True

                                                        if self.checksum is not None:
                                                            return True

                                                        if self.is_do_not_age_lsa is not None:
                                                            return True

                                                        if self.is_graceful_restart_active is not None:
                                                            return True

                                                        if self.ls_id is not None:
                                                            return True

                                                        if self.lsa_age is not None:
                                                            return True

                                                        if self.lsa_area_id is not None:
                                                            return True

                                                        if self.lsa_type is not None:
                                                            return True

                                                        if self.sequence_number is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                        return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaHeader']['meta_info']


                                                class LsaDetail(object):
                                                    """
                                                    Detailed LSA information
                                                    
                                                    .. attribute:: free_time
                                                    
                                                    	The amount of time since the last check was made to free this LSA (s)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_acknowledged
                                                    
                                                    	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_advertising_router_reachable
                                                    
                                                    	If true, Advertising Router is reachable
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_deleted
                                                    
                                                    	If true, flag is set to delete this LSA 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_flood_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_maximum_aged
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_neighbor_exchange
                                                    
                                                    	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_no_delete
                                                    
                                                    	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_nsr_ack_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_partial_spf
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_routing_bit
                                                    
                                                    	If true, Routing Bit set on the LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_routing_table
                                                    
                                                    	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: lsa_flood_required_post_fail_over
                                                    
                                                    	LSA flood required after FO
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: lsa_length
                                                    
                                                    	Length of the LSA
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_sync_state
                                                    
                                                    	State of LSA sync with active
                                                    	**type**\:   :py:class:`OspfLsaSyncStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncStateEnum>`
                                                    
                                                    .. attribute:: minute_table_index
                                                    
                                                    	Minute table index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: nsr_flood_required
                                                    
                                                    	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: rate_limit
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: second_table_index
                                                    
                                                    	Second table index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.free_time = None
                                                        self.is_acknowledged = None
                                                        self.is_advertising_router_reachable = None
                                                        self.is_deleted = None
                                                        self.is_flood_pending = None
                                                        self.is_maximum_aged = None
                                                        self.is_neighbor_exchange = None
                                                        self.is_no_delete = None
                                                        self.is_nsr_ack_pending = None
                                                        self.is_partial_spf = None
                                                        self.is_routing_bit = None
                                                        self.is_routing_table = None
                                                        self.lsa_flood_required_post_fail_over = None
                                                        self.lsa_length = None
                                                        self.lsa_sync_state = None
                                                        self.minute_table_index = None
                                                        self.nsr_flood_required = None
                                                        self.rate_limit = None
                                                        self.second_table_index = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-detail'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.free_time is not None:
                                                            return True

                                                        if self.is_acknowledged is not None:
                                                            return True

                                                        if self.is_advertising_router_reachable is not None:
                                                            return True

                                                        if self.is_deleted is not None:
                                                            return True

                                                        if self.is_flood_pending is not None:
                                                            return True

                                                        if self.is_maximum_aged is not None:
                                                            return True

                                                        if self.is_neighbor_exchange is not None:
                                                            return True

                                                        if self.is_no_delete is not None:
                                                            return True

                                                        if self.is_nsr_ack_pending is not None:
                                                            return True

                                                        if self.is_partial_spf is not None:
                                                            return True

                                                        if self.is_routing_bit is not None:
                                                            return True

                                                        if self.is_routing_table is not None:
                                                            return True

                                                        if self.lsa_flood_required_post_fail_over is not None:
                                                            return True

                                                        if self.lsa_length is not None:
                                                            return True

                                                        if self.lsa_sync_state is not None:
                                                            return True

                                                        if self.minute_table_index is not None:
                                                            return True

                                                        if self.nsr_flood_required is not None:
                                                            return True

                                                        if self.rate_limit is not None:
                                                            return True

                                                        if self.second_table_index is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                        return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaDetail']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:unknown-area-lsa-type'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.interface_name is not None:
                                                        return True

                                                    if self.is_sham_link is not None:
                                                        return True

                                                    if self.is_virtual_link is not None:
                                                        return True

                                                    if self.lsa_detail is not None and self.lsa_detail._has_data():
                                                        return True

                                                    if self.lsa_header is not None and self.lsa_header._has_data():
                                                        return True

                                                    if self.sham_link_id is not None:
                                                        return True

                                                    if self.virtual_link_id is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                    return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType']['meta_info']


                                            class UnknownAslsaType(object):
                                                """
                                                Unknown\-AS scope LSA
                                                
                                                .. attribute:: interface_name
                                                
                                                	LSA interface name 
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                
                                                .. attribute:: is_sham_link
                                                
                                                	If true, it is a sham link 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_virtual_link
                                                
                                                	If true, it is a virtual link 
                                                	**type**\:  bool
                                                
                                                .. attribute:: lsa_detail
                                                
                                                	Detailed LSA information
                                                	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType.LsaDetail>`
                                                
                                                .. attribute:: lsa_header
                                                
                                                	Header information 
                                                	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType.LsaHeader>`
                                                
                                                .. attribute:: sham_link_id
                                                
                                                	Shamlink ID 
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: virtual_link_id
                                                
                                                	Virtual link ID 
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.interface_name = None
                                                    self.is_sham_link = None
                                                    self.is_virtual_link = None
                                                    self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType.LsaDetail()
                                                    self.lsa_detail.parent = self
                                                    self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType.LsaHeader()
                                                    self.lsa_header.parent = self
                                                    self.sham_link_id = None
                                                    self.virtual_link_id = None


                                                class LsaHeader(object):
                                                    """
                                                    Header information 
                                                    
                                                    .. attribute:: advertising_router
                                                    
                                                    	Router ID of Advertising Router
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: checksum
                                                    
                                                    	Checksum value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: is_do_not_age_lsa
                                                    
                                                    	If true, Do Not Age this LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_graceful_restart_active
                                                    
                                                    	If true, if grace restart is active 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: ls_id
                                                    
                                                    	LS ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: lsa_age
                                                    
                                                    	LSA's Age (s)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_area_id
                                                    
                                                    	Area ID in decimal or dotted\-decimal format
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..16
                                                    
                                                    .. attribute:: lsa_type
                                                    
                                                    	LSA type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: sequence_number
                                                    
                                                    	Current Sequence number
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.advertising_router = None
                                                        self.checksum = None
                                                        self.is_do_not_age_lsa = None
                                                        self.is_graceful_restart_active = None
                                                        self.ls_id = None
                                                        self.lsa_age = None
                                                        self.lsa_area_id = None
                                                        self.lsa_type = None
                                                        self.sequence_number = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-header'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.advertising_router is not None:
                                                            return True

                                                        if self.checksum is not None:
                                                            return True

                                                        if self.is_do_not_age_lsa is not None:
                                                            return True

                                                        if self.is_graceful_restart_active is not None:
                                                            return True

                                                        if self.ls_id is not None:
                                                            return True

                                                        if self.lsa_age is not None:
                                                            return True

                                                        if self.lsa_area_id is not None:
                                                            return True

                                                        if self.lsa_type is not None:
                                                            return True

                                                        if self.sequence_number is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                        return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType.LsaHeader']['meta_info']


                                                class LsaDetail(object):
                                                    """
                                                    Detailed LSA information
                                                    
                                                    .. attribute:: free_time
                                                    
                                                    	The amount of time since the last check was made to free this LSA (s)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_acknowledged
                                                    
                                                    	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_advertising_router_reachable
                                                    
                                                    	If true, Advertising Router is reachable
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_deleted
                                                    
                                                    	If true, flag is set to delete this LSA 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_flood_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_maximum_aged
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_neighbor_exchange
                                                    
                                                    	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_no_delete
                                                    
                                                    	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_nsr_ack_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_partial_spf
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_routing_bit
                                                    
                                                    	If true, Routing Bit set on the LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_routing_table
                                                    
                                                    	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: lsa_flood_required_post_fail_over
                                                    
                                                    	LSA flood required after FO
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: lsa_length
                                                    
                                                    	Length of the LSA
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_sync_state
                                                    
                                                    	State of LSA sync with active
                                                    	**type**\:   :py:class:`OspfLsaSyncStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncStateEnum>`
                                                    
                                                    .. attribute:: minute_table_index
                                                    
                                                    	Minute table index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: nsr_flood_required
                                                    
                                                    	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: rate_limit
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: second_table_index
                                                    
                                                    	Second table index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.free_time = None
                                                        self.is_acknowledged = None
                                                        self.is_advertising_router_reachable = None
                                                        self.is_deleted = None
                                                        self.is_flood_pending = None
                                                        self.is_maximum_aged = None
                                                        self.is_neighbor_exchange = None
                                                        self.is_no_delete = None
                                                        self.is_nsr_ack_pending = None
                                                        self.is_partial_spf = None
                                                        self.is_routing_bit = None
                                                        self.is_routing_table = None
                                                        self.lsa_flood_required_post_fail_over = None
                                                        self.lsa_length = None
                                                        self.lsa_sync_state = None
                                                        self.minute_table_index = None
                                                        self.nsr_flood_required = None
                                                        self.rate_limit = None
                                                        self.second_table_index = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-detail'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.free_time is not None:
                                                            return True

                                                        if self.is_acknowledged is not None:
                                                            return True

                                                        if self.is_advertising_router_reachable is not None:
                                                            return True

                                                        if self.is_deleted is not None:
                                                            return True

                                                        if self.is_flood_pending is not None:
                                                            return True

                                                        if self.is_maximum_aged is not None:
                                                            return True

                                                        if self.is_neighbor_exchange is not None:
                                                            return True

                                                        if self.is_no_delete is not None:
                                                            return True

                                                        if self.is_nsr_ack_pending is not None:
                                                            return True

                                                        if self.is_partial_spf is not None:
                                                            return True

                                                        if self.is_routing_bit is not None:
                                                            return True

                                                        if self.is_routing_table is not None:
                                                            return True

                                                        if self.lsa_flood_required_post_fail_over is not None:
                                                            return True

                                                        if self.lsa_length is not None:
                                                            return True

                                                        if self.lsa_sync_state is not None:
                                                            return True

                                                        if self.minute_table_index is not None:
                                                            return True

                                                        if self.nsr_flood_required is not None:
                                                            return True

                                                        if self.rate_limit is not None:
                                                            return True

                                                        if self.second_table_index is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                        return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType.LsaDetail']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:unknown-aslsa-type'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.interface_name is not None:
                                                        return True

                                                    if self.is_sham_link is not None:
                                                        return True

                                                    if self.is_virtual_link is not None:
                                                        return True

                                                    if self.lsa_detail is not None and self.lsa_detail._has_data():
                                                        return True

                                                    if self.lsa_header is not None and self.lsa_header._has_data():
                                                        return True

                                                    if self.sham_link_id is not None:
                                                        return True

                                                    if self.virtual_link_id is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                    return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType']['meta_info']


                                            class UnknownLsaType(object):
                                                """
                                                Unknown LSA
                                                
                                                .. attribute:: interface_name
                                                
                                                	LSA interface name 
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                
                                                .. attribute:: is_sham_link
                                                
                                                	If true, it is a sham link 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_virtual_link
                                                
                                                	If true, it is a virtual link 
                                                	**type**\:  bool
                                                
                                                .. attribute:: lsa_detail
                                                
                                                	Detailed LSA information
                                                	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType.LsaDetail>`
                                                
                                                .. attribute:: lsa_header
                                                
                                                	Header information 
                                                	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType.LsaHeader>`
                                                
                                                .. attribute:: sham_link_id
                                                
                                                	Shamlink ID 
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: virtual_link_id
                                                
                                                	Virtual link ID 
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.interface_name = None
                                                    self.is_sham_link = None
                                                    self.is_virtual_link = None
                                                    self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType.LsaDetail()
                                                    self.lsa_detail.parent = self
                                                    self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType.LsaHeader()
                                                    self.lsa_header.parent = self
                                                    self.sham_link_id = None
                                                    self.virtual_link_id = None


                                                class LsaHeader(object):
                                                    """
                                                    Header information 
                                                    
                                                    .. attribute:: advertising_router
                                                    
                                                    	Router ID of Advertising Router
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: checksum
                                                    
                                                    	Checksum value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: is_do_not_age_lsa
                                                    
                                                    	If true, Do Not Age this LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_graceful_restart_active
                                                    
                                                    	If true, if grace restart is active 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: ls_id
                                                    
                                                    	LS ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: lsa_age
                                                    
                                                    	LSA's Age (s)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_area_id
                                                    
                                                    	Area ID in decimal or dotted\-decimal format
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..16
                                                    
                                                    .. attribute:: lsa_type
                                                    
                                                    	LSA type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: sequence_number
                                                    
                                                    	Current Sequence number
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.advertising_router = None
                                                        self.checksum = None
                                                        self.is_do_not_age_lsa = None
                                                        self.is_graceful_restart_active = None
                                                        self.ls_id = None
                                                        self.lsa_age = None
                                                        self.lsa_area_id = None
                                                        self.lsa_type = None
                                                        self.sequence_number = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-header'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.advertising_router is not None:
                                                            return True

                                                        if self.checksum is not None:
                                                            return True

                                                        if self.is_do_not_age_lsa is not None:
                                                            return True

                                                        if self.is_graceful_restart_active is not None:
                                                            return True

                                                        if self.ls_id is not None:
                                                            return True

                                                        if self.lsa_age is not None:
                                                            return True

                                                        if self.lsa_area_id is not None:
                                                            return True

                                                        if self.lsa_type is not None:
                                                            return True

                                                        if self.sequence_number is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                        return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType.LsaHeader']['meta_info']


                                                class LsaDetail(object):
                                                    """
                                                    Detailed LSA information
                                                    
                                                    .. attribute:: free_time
                                                    
                                                    	The amount of time since the last check was made to free this LSA (s)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_acknowledged
                                                    
                                                    	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_advertising_router_reachable
                                                    
                                                    	If true, Advertising Router is reachable
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_deleted
                                                    
                                                    	If true, flag is set to delete this LSA 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_flood_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_maximum_aged
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_neighbor_exchange
                                                    
                                                    	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_no_delete
                                                    
                                                    	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_nsr_ack_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_partial_spf
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_routing_bit
                                                    
                                                    	If true, Routing Bit set on the LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_routing_table
                                                    
                                                    	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: lsa_flood_required_post_fail_over
                                                    
                                                    	LSA flood required after FO
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: lsa_length
                                                    
                                                    	Length of the LSA
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_sync_state
                                                    
                                                    	State of LSA sync with active
                                                    	**type**\:   :py:class:`OspfLsaSyncStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncStateEnum>`
                                                    
                                                    .. attribute:: minute_table_index
                                                    
                                                    	Minute table index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: nsr_flood_required
                                                    
                                                    	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: rate_limit
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: second_table_index
                                                    
                                                    	Second table index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.free_time = None
                                                        self.is_acknowledged = None
                                                        self.is_advertising_router_reachable = None
                                                        self.is_deleted = None
                                                        self.is_flood_pending = None
                                                        self.is_maximum_aged = None
                                                        self.is_neighbor_exchange = None
                                                        self.is_no_delete = None
                                                        self.is_nsr_ack_pending = None
                                                        self.is_partial_spf = None
                                                        self.is_routing_bit = None
                                                        self.is_routing_table = None
                                                        self.lsa_flood_required_post_fail_over = None
                                                        self.lsa_length = None
                                                        self.lsa_sync_state = None
                                                        self.minute_table_index = None
                                                        self.nsr_flood_required = None
                                                        self.rate_limit = None
                                                        self.second_table_index = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-detail'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.free_time is not None:
                                                            return True

                                                        if self.is_acknowledged is not None:
                                                            return True

                                                        if self.is_advertising_router_reachable is not None:
                                                            return True

                                                        if self.is_deleted is not None:
                                                            return True

                                                        if self.is_flood_pending is not None:
                                                            return True

                                                        if self.is_maximum_aged is not None:
                                                            return True

                                                        if self.is_neighbor_exchange is not None:
                                                            return True

                                                        if self.is_no_delete is not None:
                                                            return True

                                                        if self.is_nsr_ack_pending is not None:
                                                            return True

                                                        if self.is_partial_spf is not None:
                                                            return True

                                                        if self.is_routing_bit is not None:
                                                            return True

                                                        if self.is_routing_table is not None:
                                                            return True

                                                        if self.lsa_flood_required_post_fail_over is not None:
                                                            return True

                                                        if self.lsa_length is not None:
                                                            return True

                                                        if self.lsa_sync_state is not None:
                                                            return True

                                                        if self.minute_table_index is not None:
                                                            return True

                                                        if self.nsr_flood_required is not None:
                                                            return True

                                                        if self.rate_limit is not None:
                                                            return True

                                                        if self.second_table_index is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                        return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType.LsaDetail']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:unknown-lsa-type'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.interface_name is not None:
                                                        return True

                                                    if self.is_sham_link is not None:
                                                        return True

                                                    if self.is_virtual_link is not None:
                                                        return True

                                                    if self.lsa_detail is not None and self.lsa_detail._has_data():
                                                        return True

                                                    if self.lsa_header is not None and self.lsa_header._has_data():
                                                        return True

                                                    if self.sham_link_id is not None:
                                                        return True

                                                    if self.virtual_link_id is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                    return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-info'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.external_lsa_type is not None and self.external_lsa_type._has_data():
                                                    return True

                                                if self.grace_lsa is not None and self.grace_lsa._has_data():
                                                    return True

                                                if self.inter_area_prefix_lsa_type is not None and self.inter_area_prefix_lsa_type._has_data():
                                                    return True

                                                if self.inter_area_router_lsa_type is not None and self.inter_area_router_lsa_type._has_data():
                                                    return True

                                                if self.intra_area_prefix_lsa_type is not None and self.intra_area_prefix_lsa_type._has_data():
                                                    return True

                                                if self.link_lsa_type is not None and self.link_lsa_type._has_data():
                                                    return True

                                                if self.lsa_info_type is not None:
                                                    return True

                                                if self.lsa_summary_info is not None and self.lsa_summary_info._has_data():
                                                    return True

                                                if self.network_lsa_type is not None and self.network_lsa_type._has_data():
                                                    return True

                                                if self.nssalsa_type is not None and self.nssalsa_type._has_data():
                                                    return True

                                                if self.router_lsa_type is not None and self.router_lsa_type._has_data():
                                                    return True

                                                if self.unknown_area_lsa_type is not None and self.unknown_area_lsa_type._has_data():
                                                    return True

                                                if self.unknown_aslsa_type is not None and self.unknown_aslsa_type._has_data():
                                                    return True

                                                if self.unknown_link_lsa_type is not None and self.unknown_link_lsa_type._has_data():
                                                    return True

                                                if self.unknown_lsa_type is not None and self.unknown_lsa_type._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.advertising_router is not None:
                                                return True

                                            if self.area_id is not None:
                                                return True

                                            if self.interface_name is not None:
                                                return True

                                            if self.ls_id is not None:
                                                return True

                                            if self.ls_type is not None:
                                                return True

                                            if self.lsa_info is not None and self.lsa_info._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-table'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.lsa is not None:
                                            for child_ref in self.lsa:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                        return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable']['meta_info']


                                class LsaInternalTable(object):
                                    """
                                    Database LSA information
                                    
                                    .. attribute:: lsa
                                    
                                    	Database LSA information
                                    	**type**\: list of    :py:class:`Lsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa>`
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.lsa = YList()
                                        self.lsa.parent = self
                                        self.lsa.name = 'lsa'


                                    class Lsa(object):
                                        """
                                        Database LSA information
                                        
                                        .. attribute:: advertising_router
                                        
                                        	Advertising Router ID
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: area_id
                                        
                                        	Area ID
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: interface_name
                                        
                                        	InterfaceName
                                        	**type**\:  str
                                        
                                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                        
                                        .. attribute:: ls_id
                                        
                                        	Link state ID
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: ls_type
                                        
                                        	LSA type
                                        	**type**\:   :py:class:`Ospfv3LsaEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3LsaEnum>`
                                        
                                        .. attribute:: lsa_info
                                        
                                        	Summary of all LSAs or LSA specific information 
                                        	**type**\:   :py:class:`LsaInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo>`
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.advertising_router = None
                                            self.area_id = None
                                            self.interface_name = None
                                            self.ls_id = None
                                            self.ls_type = None
                                            self.lsa_info = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo()
                                            self.lsa_info.parent = self


                                        class LsaInfo(object):
                                            """
                                            Summary of all LSAs or LSA specific information 
                                            
                                            .. attribute:: external_lsa_type
                                            
                                            	External LSA
                                            	**type**\:   :py:class:`ExternalLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType>`
                                            
                                            .. attribute:: grace_lsa
                                            
                                            	Grace LSA
                                            	**type**\:   :py:class:`GraceLsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa>`
                                            
                                            .. attribute:: inter_area_prefix_lsa_type
                                            
                                            	Inter Area Prefix LSA
                                            	**type**\:   :py:class:`InterAreaPrefixLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType>`
                                            
                                            .. attribute:: inter_area_router_lsa_type
                                            
                                            	Inter Area Router LSA
                                            	**type**\:   :py:class:`InterAreaRouterLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType>`
                                            
                                            .. attribute:: intra_area_prefix_lsa_type
                                            
                                            	Intra Area Prefix LSA
                                            	**type**\:   :py:class:`IntraAreaPrefixLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType>`
                                            
                                            .. attribute:: link_lsa_type
                                            
                                            	Link LSA
                                            	**type**\:   :py:class:`LinkLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType>`
                                            
                                            .. attribute:: lsa_info_type
                                            
                                            	LSAInfoType
                                            	**type**\:   :py:class:`Ospfv3LsaInfoTypesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3LsaInfoTypesEnum>`
                                            
                                            .. attribute:: lsa_summary_info
                                            
                                            	Summary information of LSAs
                                            	**type**\:   :py:class:`LsaSummaryInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo>`
                                            
                                            .. attribute:: network_lsa_type
                                            
                                            	Network LSA
                                            	**type**\:   :py:class:`NetworkLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType>`
                                            
                                            .. attribute:: nssalsa_type
                                            
                                            	NSSA External LSA
                                            	**type**\:   :py:class:`NssalsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType>`
                                            
                                            .. attribute:: router_lsa_type
                                            
                                            	Router LSA
                                            	**type**\:   :py:class:`RouterLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType>`
                                            
                                            .. attribute:: unknown_area_lsa_type
                                            
                                            	Unknown\-Area scope LSA
                                            	**type**\:   :py:class:`UnknownAreaLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType>`
                                            
                                            .. attribute:: unknown_aslsa_type
                                            
                                            	Unknown\-AS scope LSA
                                            	**type**\:   :py:class:`UnknownAslsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType>`
                                            
                                            .. attribute:: unknown_link_lsa_type
                                            
                                            	Unknown Link Scope LSA
                                            	**type**\:   :py:class:`UnknownLinkLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType>`
                                            
                                            .. attribute:: unknown_lsa_type
                                            
                                            	Unknown LSA
                                            	**type**\:   :py:class:`UnknownLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType>`
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.external_lsa_type = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType()
                                                self.external_lsa_type.parent = self
                                                self.grace_lsa = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa()
                                                self.grace_lsa.parent = self
                                                self.inter_area_prefix_lsa_type = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType()
                                                self.inter_area_prefix_lsa_type.parent = self
                                                self.inter_area_router_lsa_type = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType()
                                                self.inter_area_router_lsa_type.parent = self
                                                self.intra_area_prefix_lsa_type = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType()
                                                self.intra_area_prefix_lsa_type.parent = self
                                                self.link_lsa_type = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType()
                                                self.link_lsa_type.parent = self
                                                self.lsa_info_type = None
                                                self.lsa_summary_info = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo()
                                                self.lsa_summary_info.parent = self
                                                self.network_lsa_type = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType()
                                                self.network_lsa_type.parent = self
                                                self.nssalsa_type = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType()
                                                self.nssalsa_type.parent = self
                                                self.router_lsa_type = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType()
                                                self.router_lsa_type.parent = self
                                                self.unknown_area_lsa_type = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType()
                                                self.unknown_area_lsa_type.parent = self
                                                self.unknown_aslsa_type = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType()
                                                self.unknown_aslsa_type.parent = self
                                                self.unknown_link_lsa_type = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType()
                                                self.unknown_link_lsa_type.parent = self
                                                self.unknown_lsa_type = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType()
                                                self.unknown_lsa_type.parent = self


                                            class LsaSummaryInfo(object):
                                                """
                                                Summary information of LSAs
                                                
                                                .. attribute:: interface_name
                                                
                                                	LSA interface name 
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                
                                                .. attribute:: is_sham_link
                                                
                                                	If true, it is a sham link 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_virtual_link
                                                
                                                	If true, it is a virtual link 
                                                	**type**\:  bool
                                                
                                                .. attribute:: links
                                                
                                                	Number of links
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_detail
                                                
                                                	Detailed LSA information
                                                	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo.LsaDetail>`
                                                
                                                .. attribute:: lsa_header
                                                
                                                	Header information 
                                                	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo.LsaHeader>`
                                                
                                                .. attribute:: lsa_router_id
                                                
                                                	LSA router ID 
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: prefix
                                                
                                                	OSPFv3 address Prefix 
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: prefix_length
                                                
                                                	Prefix length 
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: reference_lsa_id
                                                
                                                	Reference LSA ID 
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: reference_type
                                                
                                                	Reference type 
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: router_la_bits
                                                
                                                	Router LA bits 
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: sham_link_id
                                                
                                                	Sham link ID 
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: virtual_link_id
                                                
                                                	Virtual link ID 
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.interface_name = None
                                                    self.is_sham_link = None
                                                    self.is_virtual_link = None
                                                    self.links = None
                                                    self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo.LsaDetail()
                                                    self.lsa_detail.parent = self
                                                    self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo.LsaHeader()
                                                    self.lsa_header.parent = self
                                                    self.lsa_router_id = None
                                                    self.prefix = None
                                                    self.prefix_length = None
                                                    self.reference_lsa_id = None
                                                    self.reference_type = None
                                                    self.router_la_bits = None
                                                    self.sham_link_id = None
                                                    self.virtual_link_id = None


                                                class LsaHeader(object):
                                                    """
                                                    Header information 
                                                    
                                                    .. attribute:: advertising_router
                                                    
                                                    	Router ID of Advertising Router
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: checksum
                                                    
                                                    	Checksum value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: is_do_not_age_lsa
                                                    
                                                    	If true, Do Not Age this LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_graceful_restart_active
                                                    
                                                    	If true, if grace restart is active 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: ls_id
                                                    
                                                    	LS ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: lsa_age
                                                    
                                                    	LSA's Age (s)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_area_id
                                                    
                                                    	Area ID in decimal or dotted\-decimal format
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..16
                                                    
                                                    .. attribute:: lsa_type
                                                    
                                                    	LSA type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: sequence_number
                                                    
                                                    	Current Sequence number
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.advertising_router = None
                                                        self.checksum = None
                                                        self.is_do_not_age_lsa = None
                                                        self.is_graceful_restart_active = None
                                                        self.ls_id = None
                                                        self.lsa_age = None
                                                        self.lsa_area_id = None
                                                        self.lsa_type = None
                                                        self.sequence_number = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-header'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.advertising_router is not None:
                                                            return True

                                                        if self.checksum is not None:
                                                            return True

                                                        if self.is_do_not_age_lsa is not None:
                                                            return True

                                                        if self.is_graceful_restart_active is not None:
                                                            return True

                                                        if self.ls_id is not None:
                                                            return True

                                                        if self.lsa_age is not None:
                                                            return True

                                                        if self.lsa_area_id is not None:
                                                            return True

                                                        if self.lsa_type is not None:
                                                            return True

                                                        if self.sequence_number is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                        return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo.LsaHeader']['meta_info']


                                                class LsaDetail(object):
                                                    """
                                                    Detailed LSA information
                                                    
                                                    .. attribute:: free_time
                                                    
                                                    	The amount of time since the last check was made to free this LSA (s)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_acknowledged
                                                    
                                                    	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_advertising_router_reachable
                                                    
                                                    	If true, Advertising Router is reachable
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_deleted
                                                    
                                                    	If true, flag is set to delete this LSA 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_flood_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_maximum_aged
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_neighbor_exchange
                                                    
                                                    	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_no_delete
                                                    
                                                    	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_nsr_ack_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_partial_spf
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_routing_bit
                                                    
                                                    	If true, Routing Bit set on the LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_routing_table
                                                    
                                                    	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: lsa_flood_required_post_fail_over
                                                    
                                                    	LSA flood required after FO
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: lsa_length
                                                    
                                                    	Length of the LSA
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_sync_state
                                                    
                                                    	State of LSA sync with active
                                                    	**type**\:   :py:class:`OspfLsaSyncStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncStateEnum>`
                                                    
                                                    .. attribute:: minute_table_index
                                                    
                                                    	Minute table index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: nsr_flood_required
                                                    
                                                    	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: rate_limit
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: second_table_index
                                                    
                                                    	Second table index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.free_time = None
                                                        self.is_acknowledged = None
                                                        self.is_advertising_router_reachable = None
                                                        self.is_deleted = None
                                                        self.is_flood_pending = None
                                                        self.is_maximum_aged = None
                                                        self.is_neighbor_exchange = None
                                                        self.is_no_delete = None
                                                        self.is_nsr_ack_pending = None
                                                        self.is_partial_spf = None
                                                        self.is_routing_bit = None
                                                        self.is_routing_table = None
                                                        self.lsa_flood_required_post_fail_over = None
                                                        self.lsa_length = None
                                                        self.lsa_sync_state = None
                                                        self.minute_table_index = None
                                                        self.nsr_flood_required = None
                                                        self.rate_limit = None
                                                        self.second_table_index = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-detail'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.free_time is not None:
                                                            return True

                                                        if self.is_acknowledged is not None:
                                                            return True

                                                        if self.is_advertising_router_reachable is not None:
                                                            return True

                                                        if self.is_deleted is not None:
                                                            return True

                                                        if self.is_flood_pending is not None:
                                                            return True

                                                        if self.is_maximum_aged is not None:
                                                            return True

                                                        if self.is_neighbor_exchange is not None:
                                                            return True

                                                        if self.is_no_delete is not None:
                                                            return True

                                                        if self.is_nsr_ack_pending is not None:
                                                            return True

                                                        if self.is_partial_spf is not None:
                                                            return True

                                                        if self.is_routing_bit is not None:
                                                            return True

                                                        if self.is_routing_table is not None:
                                                            return True

                                                        if self.lsa_flood_required_post_fail_over is not None:
                                                            return True

                                                        if self.lsa_length is not None:
                                                            return True

                                                        if self.lsa_sync_state is not None:
                                                            return True

                                                        if self.minute_table_index is not None:
                                                            return True

                                                        if self.nsr_flood_required is not None:
                                                            return True

                                                        if self.rate_limit is not None:
                                                            return True

                                                        if self.second_table_index is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                        return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo.LsaDetail']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-summary-info'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.interface_name is not None:
                                                        return True

                                                    if self.is_sham_link is not None:
                                                        return True

                                                    if self.is_virtual_link is not None:
                                                        return True

                                                    if self.links is not None:
                                                        return True

                                                    if self.lsa_detail is not None and self.lsa_detail._has_data():
                                                        return True

                                                    if self.lsa_header is not None and self.lsa_header._has_data():
                                                        return True

                                                    if self.lsa_router_id is not None:
                                                        return True

                                                    if self.prefix is not None:
                                                        return True

                                                    if self.prefix_length is not None:
                                                        return True

                                                    if self.reference_lsa_id is not None:
                                                        return True

                                                    if self.reference_type is not None:
                                                        return True

                                                    if self.router_la_bits is not None:
                                                        return True

                                                    if self.sham_link_id is not None:
                                                        return True

                                                    if self.virtual_link_id is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                    return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo']['meta_info']


                                            class RouterLsaType(object):
                                                """
                                                Router LSA
                                                
                                                .. attribute:: link
                                                
                                                	List of links in this LSA
                                                	**type**\: list of    :py:class:`Link <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.Link>`
                                                
                                                .. attribute:: lsa_detail
                                                
                                                	Detailed LSA information
                                                	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.LsaDetail>`
                                                
                                                .. attribute:: lsa_header
                                                
                                                	Header information 
                                                	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.LsaHeader>`
                                                
                                                .. attribute:: router_la_bits
                                                
                                                	Router LA bits 
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: rpf_path
                                                
                                                	Router LSA Reverse\-Path Forwarding information 
                                                	**type**\:   :py:class:`RpfPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.RpfPath>`
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.link = YList()
                                                    self.link.parent = self
                                                    self.link.name = 'link'
                                                    self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.LsaDetail()
                                                    self.lsa_detail.parent = self
                                                    self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.LsaHeader()
                                                    self.lsa_header.parent = self
                                                    self.router_la_bits = None
                                                    self.rpf_path = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.RpfPath()
                                                    self.rpf_path.parent = self


                                                class LsaHeader(object):
                                                    """
                                                    Header information 
                                                    
                                                    .. attribute:: advertising_router
                                                    
                                                    	Router ID of Advertising Router
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: checksum
                                                    
                                                    	Checksum value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: is_do_not_age_lsa
                                                    
                                                    	If true, Do Not Age this LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_graceful_restart_active
                                                    
                                                    	If true, if grace restart is active 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: ls_id
                                                    
                                                    	LS ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: lsa_age
                                                    
                                                    	LSA's Age (s)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_area_id
                                                    
                                                    	Area ID in decimal or dotted\-decimal format
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..16
                                                    
                                                    .. attribute:: lsa_type
                                                    
                                                    	LSA type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: sequence_number
                                                    
                                                    	Current Sequence number
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.advertising_router = None
                                                        self.checksum = None
                                                        self.is_do_not_age_lsa = None
                                                        self.is_graceful_restart_active = None
                                                        self.ls_id = None
                                                        self.lsa_age = None
                                                        self.lsa_area_id = None
                                                        self.lsa_type = None
                                                        self.sequence_number = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-header'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.advertising_router is not None:
                                                            return True

                                                        if self.checksum is not None:
                                                            return True

                                                        if self.is_do_not_age_lsa is not None:
                                                            return True

                                                        if self.is_graceful_restart_active is not None:
                                                            return True

                                                        if self.ls_id is not None:
                                                            return True

                                                        if self.lsa_age is not None:
                                                            return True

                                                        if self.lsa_area_id is not None:
                                                            return True

                                                        if self.lsa_type is not None:
                                                            return True

                                                        if self.sequence_number is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                        return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.LsaHeader']['meta_info']


                                                class LsaDetail(object):
                                                    """
                                                    Detailed LSA information
                                                    
                                                    .. attribute:: free_time
                                                    
                                                    	The amount of time since the last check was made to free this LSA (s)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_acknowledged
                                                    
                                                    	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_advertising_router_reachable
                                                    
                                                    	If true, Advertising Router is reachable
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_deleted
                                                    
                                                    	If true, flag is set to delete this LSA 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_flood_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_maximum_aged
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_neighbor_exchange
                                                    
                                                    	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_no_delete
                                                    
                                                    	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_nsr_ack_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_partial_spf
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_routing_bit
                                                    
                                                    	If true, Routing Bit set on the LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_routing_table
                                                    
                                                    	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: lsa_flood_required_post_fail_over
                                                    
                                                    	LSA flood required after FO
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: lsa_length
                                                    
                                                    	Length of the LSA
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_sync_state
                                                    
                                                    	State of LSA sync with active
                                                    	**type**\:   :py:class:`OspfLsaSyncStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncStateEnum>`
                                                    
                                                    .. attribute:: minute_table_index
                                                    
                                                    	Minute table index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: nsr_flood_required
                                                    
                                                    	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: rate_limit
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: second_table_index
                                                    
                                                    	Second table index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.free_time = None
                                                        self.is_acknowledged = None
                                                        self.is_advertising_router_reachable = None
                                                        self.is_deleted = None
                                                        self.is_flood_pending = None
                                                        self.is_maximum_aged = None
                                                        self.is_neighbor_exchange = None
                                                        self.is_no_delete = None
                                                        self.is_nsr_ack_pending = None
                                                        self.is_partial_spf = None
                                                        self.is_routing_bit = None
                                                        self.is_routing_table = None
                                                        self.lsa_flood_required_post_fail_over = None
                                                        self.lsa_length = None
                                                        self.lsa_sync_state = None
                                                        self.minute_table_index = None
                                                        self.nsr_flood_required = None
                                                        self.rate_limit = None
                                                        self.second_table_index = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-detail'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.free_time is not None:
                                                            return True

                                                        if self.is_acknowledged is not None:
                                                            return True

                                                        if self.is_advertising_router_reachable is not None:
                                                            return True

                                                        if self.is_deleted is not None:
                                                            return True

                                                        if self.is_flood_pending is not None:
                                                            return True

                                                        if self.is_maximum_aged is not None:
                                                            return True

                                                        if self.is_neighbor_exchange is not None:
                                                            return True

                                                        if self.is_no_delete is not None:
                                                            return True

                                                        if self.is_nsr_ack_pending is not None:
                                                            return True

                                                        if self.is_partial_spf is not None:
                                                            return True

                                                        if self.is_routing_bit is not None:
                                                            return True

                                                        if self.is_routing_table is not None:
                                                            return True

                                                        if self.lsa_flood_required_post_fail_over is not None:
                                                            return True

                                                        if self.lsa_length is not None:
                                                            return True

                                                        if self.lsa_sync_state is not None:
                                                            return True

                                                        if self.minute_table_index is not None:
                                                            return True

                                                        if self.nsr_flood_required is not None:
                                                            return True

                                                        if self.rate_limit is not None:
                                                            return True

                                                        if self.second_table_index is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                        return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.LsaDetail']['meta_info']


                                                class RpfPath(object):
                                                    """
                                                    Router LSA Reverse\-Path Forwarding information 
                                                    
                                                    .. attribute:: interface_name
                                                    
                                                    	RPF multicast IDB 
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                    
                                                    .. attribute:: rpf_multicast_next_hop
                                                    
                                                    	RPF multicast next hop 
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.interface_name = None
                                                        self.rpf_multicast_next_hop = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:rpf-path'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.interface_name is not None:
                                                            return True

                                                        if self.rpf_multicast_next_hop is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                        return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.RpfPath']['meta_info']


                                                class Link(object):
                                                    """
                                                    List of links in this LSA
                                                    
                                                    .. attribute:: link_interface_id
                                                    
                                                    	LSA link interface ID 
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: link_metric
                                                    
                                                    	LSA link metric 
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: link_neighbor_interface_id
                                                    
                                                    	LSA link neighbor interface ID 
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: link_neighbor_router_id
                                                    
                                                    	LSA link neigbhor router id 
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: link_type
                                                    
                                                    	Type of link
                                                    	**type**\:   :py:class:`Ospfv3LinkEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3LinkEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.link_interface_id = None
                                                        self.link_metric = None
                                                        self.link_neighbor_interface_id = None
                                                        self.link_neighbor_router_id = None
                                                        self.link_type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:link'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.link_interface_id is not None:
                                                            return True

                                                        if self.link_metric is not None:
                                                            return True

                                                        if self.link_neighbor_interface_id is not None:
                                                            return True

                                                        if self.link_neighbor_router_id is not None:
                                                            return True

                                                        if self.link_type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                        return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.Link']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:router-lsa-type'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.link is not None:
                                                        for child_ref in self.link:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.lsa_detail is not None and self.lsa_detail._has_data():
                                                        return True

                                                    if self.lsa_header is not None and self.lsa_header._has_data():
                                                        return True

                                                    if self.router_la_bits is not None:
                                                        return True

                                                    if self.rpf_path is not None and self.rpf_path._has_data():
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                    return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType']['meta_info']


                                            class NetworkLsaType(object):
                                                """
                                                Network LSA
                                                
                                                .. attribute:: lsa_detail
                                                
                                                	Detailed LSA information
                                                	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType.LsaDetail>`
                                                
                                                .. attribute:: lsa_header
                                                
                                                	Header information 
                                                	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType.LsaHeader>`
                                                
                                                .. attribute:: neighbor_router
                                                
                                                	Neighbor router list
                                                	**type**\:  list of str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType.LsaDetail()
                                                    self.lsa_detail.parent = self
                                                    self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType.LsaHeader()
                                                    self.lsa_header.parent = self
                                                    self.neighbor_router = YLeafList()
                                                    self.neighbor_router.parent = self
                                                    self.neighbor_router.name = 'neighbor_router'


                                                class LsaHeader(object):
                                                    """
                                                    Header information 
                                                    
                                                    .. attribute:: advertising_router
                                                    
                                                    	Router ID of Advertising Router
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: checksum
                                                    
                                                    	Checksum value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: is_do_not_age_lsa
                                                    
                                                    	If true, Do Not Age this LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_graceful_restart_active
                                                    
                                                    	If true, if grace restart is active 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: ls_id
                                                    
                                                    	LS ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: lsa_age
                                                    
                                                    	LSA's Age (s)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_area_id
                                                    
                                                    	Area ID in decimal or dotted\-decimal format
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..16
                                                    
                                                    .. attribute:: lsa_type
                                                    
                                                    	LSA type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: sequence_number
                                                    
                                                    	Current Sequence number
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.advertising_router = None
                                                        self.checksum = None
                                                        self.is_do_not_age_lsa = None
                                                        self.is_graceful_restart_active = None
                                                        self.ls_id = None
                                                        self.lsa_age = None
                                                        self.lsa_area_id = None
                                                        self.lsa_type = None
                                                        self.sequence_number = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-header'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.advertising_router is not None:
                                                            return True

                                                        if self.checksum is not None:
                                                            return True

                                                        if self.is_do_not_age_lsa is not None:
                                                            return True

                                                        if self.is_graceful_restart_active is not None:
                                                            return True

                                                        if self.ls_id is not None:
                                                            return True

                                                        if self.lsa_age is not None:
                                                            return True

                                                        if self.lsa_area_id is not None:
                                                            return True

                                                        if self.lsa_type is not None:
                                                            return True

                                                        if self.sequence_number is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                        return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType.LsaHeader']['meta_info']


                                                class LsaDetail(object):
                                                    """
                                                    Detailed LSA information
                                                    
                                                    .. attribute:: free_time
                                                    
                                                    	The amount of time since the last check was made to free this LSA (s)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_acknowledged
                                                    
                                                    	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_advertising_router_reachable
                                                    
                                                    	If true, Advertising Router is reachable
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_deleted
                                                    
                                                    	If true, flag is set to delete this LSA 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_flood_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_maximum_aged
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_neighbor_exchange
                                                    
                                                    	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_no_delete
                                                    
                                                    	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_nsr_ack_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_partial_spf
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_routing_bit
                                                    
                                                    	If true, Routing Bit set on the LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_routing_table
                                                    
                                                    	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: lsa_flood_required_post_fail_over
                                                    
                                                    	LSA flood required after FO
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: lsa_length
                                                    
                                                    	Length of the LSA
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_sync_state
                                                    
                                                    	State of LSA sync with active
                                                    	**type**\:   :py:class:`OspfLsaSyncStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncStateEnum>`
                                                    
                                                    .. attribute:: minute_table_index
                                                    
                                                    	Minute table index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: nsr_flood_required
                                                    
                                                    	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: rate_limit
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: second_table_index
                                                    
                                                    	Second table index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.free_time = None
                                                        self.is_acknowledged = None
                                                        self.is_advertising_router_reachable = None
                                                        self.is_deleted = None
                                                        self.is_flood_pending = None
                                                        self.is_maximum_aged = None
                                                        self.is_neighbor_exchange = None
                                                        self.is_no_delete = None
                                                        self.is_nsr_ack_pending = None
                                                        self.is_partial_spf = None
                                                        self.is_routing_bit = None
                                                        self.is_routing_table = None
                                                        self.lsa_flood_required_post_fail_over = None
                                                        self.lsa_length = None
                                                        self.lsa_sync_state = None
                                                        self.minute_table_index = None
                                                        self.nsr_flood_required = None
                                                        self.rate_limit = None
                                                        self.second_table_index = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-detail'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.free_time is not None:
                                                            return True

                                                        if self.is_acknowledged is not None:
                                                            return True

                                                        if self.is_advertising_router_reachable is not None:
                                                            return True

                                                        if self.is_deleted is not None:
                                                            return True

                                                        if self.is_flood_pending is not None:
                                                            return True

                                                        if self.is_maximum_aged is not None:
                                                            return True

                                                        if self.is_neighbor_exchange is not None:
                                                            return True

                                                        if self.is_no_delete is not None:
                                                            return True

                                                        if self.is_nsr_ack_pending is not None:
                                                            return True

                                                        if self.is_partial_spf is not None:
                                                            return True

                                                        if self.is_routing_bit is not None:
                                                            return True

                                                        if self.is_routing_table is not None:
                                                            return True

                                                        if self.lsa_flood_required_post_fail_over is not None:
                                                            return True

                                                        if self.lsa_length is not None:
                                                            return True

                                                        if self.lsa_sync_state is not None:
                                                            return True

                                                        if self.minute_table_index is not None:
                                                            return True

                                                        if self.nsr_flood_required is not None:
                                                            return True

                                                        if self.rate_limit is not None:
                                                            return True

                                                        if self.second_table_index is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                        return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType.LsaDetail']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:network-lsa-type'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.lsa_detail is not None and self.lsa_detail._has_data():
                                                        return True

                                                    if self.lsa_header is not None and self.lsa_header._has_data():
                                                        return True

                                                    if self.neighbor_router is not None:
                                                        for child in self.neighbor_router:
                                                            if child is not None:
                                                                return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                    return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType']['meta_info']


                                            class InterAreaPrefixLsaType(object):
                                                """
                                                Inter Area Prefix LSA
                                                
                                                .. attribute:: lsa_detail
                                                
                                                	Detailed LSA Information
                                                	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaDetail>`
                                                
                                                .. attribute:: lsa_header
                                                
                                                	Header information 
                                                	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaHeader>`
                                                
                                                .. attribute:: prefix
                                                
                                                	LSA address prefix 
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: prefix_length
                                                
                                                	Prefix length 
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: priority
                                                
                                                	Prefix priority
                                                	**type**\:   :py:class:`PrefixPriorityEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.PrefixPriorityEnum>`
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaDetail()
                                                    self.lsa_detail.parent = self
                                                    self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaHeader()
                                                    self.lsa_header.parent = self
                                                    self.prefix = None
                                                    self.prefix_length = None
                                                    self.priority = None


                                                class LsaHeader(object):
                                                    """
                                                    Header information 
                                                    
                                                    .. attribute:: advertising_router
                                                    
                                                    	Router ID of Advertising Router
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: checksum
                                                    
                                                    	Checksum value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: is_do_not_age_lsa
                                                    
                                                    	If true, Do Not Age this LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_graceful_restart_active
                                                    
                                                    	If true, if grace restart is active 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: ls_id
                                                    
                                                    	LS ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: lsa_age
                                                    
                                                    	LSA's Age (s)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_area_id
                                                    
                                                    	Area ID in decimal or dotted\-decimal format
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..16
                                                    
                                                    .. attribute:: lsa_type
                                                    
                                                    	LSA type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: sequence_number
                                                    
                                                    	Current Sequence number
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.advertising_router = None
                                                        self.checksum = None
                                                        self.is_do_not_age_lsa = None
                                                        self.is_graceful_restart_active = None
                                                        self.ls_id = None
                                                        self.lsa_age = None
                                                        self.lsa_area_id = None
                                                        self.lsa_type = None
                                                        self.sequence_number = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-header'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.advertising_router is not None:
                                                            return True

                                                        if self.checksum is not None:
                                                            return True

                                                        if self.is_do_not_age_lsa is not None:
                                                            return True

                                                        if self.is_graceful_restart_active is not None:
                                                            return True

                                                        if self.ls_id is not None:
                                                            return True

                                                        if self.lsa_age is not None:
                                                            return True

                                                        if self.lsa_area_id is not None:
                                                            return True

                                                        if self.lsa_type is not None:
                                                            return True

                                                        if self.sequence_number is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                        return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaHeader']['meta_info']


                                                class LsaDetail(object):
                                                    """
                                                    Detailed LSA Information
                                                    
                                                    .. attribute:: free_time
                                                    
                                                    	The amount of time since the last check was made to free this LSA (s)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_acknowledged
                                                    
                                                    	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_advertising_router_reachable
                                                    
                                                    	If true, Advertising Router is reachable
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_deleted
                                                    
                                                    	If true, flag is set to delete this LSA 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_flood_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_maximum_aged
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_neighbor_exchange
                                                    
                                                    	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_no_delete
                                                    
                                                    	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_nsr_ack_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_partial_spf
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_routing_bit
                                                    
                                                    	If true, Routing Bit set on the LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_routing_table
                                                    
                                                    	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: lsa_flood_required_post_fail_over
                                                    
                                                    	LSA flood required after FO
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: lsa_length
                                                    
                                                    	Length of the LSA
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_sync_state
                                                    
                                                    	State of LSA sync with active
                                                    	**type**\:   :py:class:`OspfLsaSyncStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncStateEnum>`
                                                    
                                                    .. attribute:: minute_table_index
                                                    
                                                    	Minute table index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: nsr_flood_required
                                                    
                                                    	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: rate_limit
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: second_table_index
                                                    
                                                    	Second table index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.free_time = None
                                                        self.is_acknowledged = None
                                                        self.is_advertising_router_reachable = None
                                                        self.is_deleted = None
                                                        self.is_flood_pending = None
                                                        self.is_maximum_aged = None
                                                        self.is_neighbor_exchange = None
                                                        self.is_no_delete = None
                                                        self.is_nsr_ack_pending = None
                                                        self.is_partial_spf = None
                                                        self.is_routing_bit = None
                                                        self.is_routing_table = None
                                                        self.lsa_flood_required_post_fail_over = None
                                                        self.lsa_length = None
                                                        self.lsa_sync_state = None
                                                        self.minute_table_index = None
                                                        self.nsr_flood_required = None
                                                        self.rate_limit = None
                                                        self.second_table_index = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-detail'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.free_time is not None:
                                                            return True

                                                        if self.is_acknowledged is not None:
                                                            return True

                                                        if self.is_advertising_router_reachable is not None:
                                                            return True

                                                        if self.is_deleted is not None:
                                                            return True

                                                        if self.is_flood_pending is not None:
                                                            return True

                                                        if self.is_maximum_aged is not None:
                                                            return True

                                                        if self.is_neighbor_exchange is not None:
                                                            return True

                                                        if self.is_no_delete is not None:
                                                            return True

                                                        if self.is_nsr_ack_pending is not None:
                                                            return True

                                                        if self.is_partial_spf is not None:
                                                            return True

                                                        if self.is_routing_bit is not None:
                                                            return True

                                                        if self.is_routing_table is not None:
                                                            return True

                                                        if self.lsa_flood_required_post_fail_over is not None:
                                                            return True

                                                        if self.lsa_length is not None:
                                                            return True

                                                        if self.lsa_sync_state is not None:
                                                            return True

                                                        if self.minute_table_index is not None:
                                                            return True

                                                        if self.nsr_flood_required is not None:
                                                            return True

                                                        if self.rate_limit is not None:
                                                            return True

                                                        if self.second_table_index is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                        return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaDetail']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:inter-area-prefix-lsa-type'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.lsa_detail is not None and self.lsa_detail._has_data():
                                                        return True

                                                    if self.lsa_header is not None and self.lsa_header._has_data():
                                                        return True

                                                    if self.prefix is not None:
                                                        return True

                                                    if self.prefix_length is not None:
                                                        return True

                                                    if self.priority is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                    return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType']['meta_info']


                                            class InterAreaRouterLsaType(object):
                                                """
                                                Inter Area Router LSA
                                                
                                                .. attribute:: lsa_detail
                                                
                                                	Detailed LSA information
                                                	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaDetail>`
                                                
                                                .. attribute:: lsa_header
                                                
                                                	Header information 
                                                	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaHeader>`
                                                
                                                .. attribute:: lsa_router_id
                                                
                                                	LSA router ID 
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaDetail()
                                                    self.lsa_detail.parent = self
                                                    self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaHeader()
                                                    self.lsa_header.parent = self
                                                    self.lsa_router_id = None


                                                class LsaHeader(object):
                                                    """
                                                    Header information 
                                                    
                                                    .. attribute:: advertising_router
                                                    
                                                    	Router ID of Advertising Router
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: checksum
                                                    
                                                    	Checksum value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: is_do_not_age_lsa
                                                    
                                                    	If true, Do Not Age this LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_graceful_restart_active
                                                    
                                                    	If true, if grace restart is active 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: ls_id
                                                    
                                                    	LS ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: lsa_age
                                                    
                                                    	LSA's Age (s)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_area_id
                                                    
                                                    	Area ID in decimal or dotted\-decimal format
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..16
                                                    
                                                    .. attribute:: lsa_type
                                                    
                                                    	LSA type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: sequence_number
                                                    
                                                    	Current Sequence number
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.advertising_router = None
                                                        self.checksum = None
                                                        self.is_do_not_age_lsa = None
                                                        self.is_graceful_restart_active = None
                                                        self.ls_id = None
                                                        self.lsa_age = None
                                                        self.lsa_area_id = None
                                                        self.lsa_type = None
                                                        self.sequence_number = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-header'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.advertising_router is not None:
                                                            return True

                                                        if self.checksum is not None:
                                                            return True

                                                        if self.is_do_not_age_lsa is not None:
                                                            return True

                                                        if self.is_graceful_restart_active is not None:
                                                            return True

                                                        if self.ls_id is not None:
                                                            return True

                                                        if self.lsa_age is not None:
                                                            return True

                                                        if self.lsa_area_id is not None:
                                                            return True

                                                        if self.lsa_type is not None:
                                                            return True

                                                        if self.sequence_number is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                        return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaHeader']['meta_info']


                                                class LsaDetail(object):
                                                    """
                                                    Detailed LSA information
                                                    
                                                    .. attribute:: free_time
                                                    
                                                    	The amount of time since the last check was made to free this LSA (s)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_acknowledged
                                                    
                                                    	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_advertising_router_reachable
                                                    
                                                    	If true, Advertising Router is reachable
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_deleted
                                                    
                                                    	If true, flag is set to delete this LSA 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_flood_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_maximum_aged
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_neighbor_exchange
                                                    
                                                    	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_no_delete
                                                    
                                                    	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_nsr_ack_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_partial_spf
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_routing_bit
                                                    
                                                    	If true, Routing Bit set on the LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_routing_table
                                                    
                                                    	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: lsa_flood_required_post_fail_over
                                                    
                                                    	LSA flood required after FO
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: lsa_length
                                                    
                                                    	Length of the LSA
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_sync_state
                                                    
                                                    	State of LSA sync with active
                                                    	**type**\:   :py:class:`OspfLsaSyncStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncStateEnum>`
                                                    
                                                    .. attribute:: minute_table_index
                                                    
                                                    	Minute table index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: nsr_flood_required
                                                    
                                                    	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: rate_limit
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: second_table_index
                                                    
                                                    	Second table index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.free_time = None
                                                        self.is_acknowledged = None
                                                        self.is_advertising_router_reachable = None
                                                        self.is_deleted = None
                                                        self.is_flood_pending = None
                                                        self.is_maximum_aged = None
                                                        self.is_neighbor_exchange = None
                                                        self.is_no_delete = None
                                                        self.is_nsr_ack_pending = None
                                                        self.is_partial_spf = None
                                                        self.is_routing_bit = None
                                                        self.is_routing_table = None
                                                        self.lsa_flood_required_post_fail_over = None
                                                        self.lsa_length = None
                                                        self.lsa_sync_state = None
                                                        self.minute_table_index = None
                                                        self.nsr_flood_required = None
                                                        self.rate_limit = None
                                                        self.second_table_index = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-detail'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.free_time is not None:
                                                            return True

                                                        if self.is_acknowledged is not None:
                                                            return True

                                                        if self.is_advertising_router_reachable is not None:
                                                            return True

                                                        if self.is_deleted is not None:
                                                            return True

                                                        if self.is_flood_pending is not None:
                                                            return True

                                                        if self.is_maximum_aged is not None:
                                                            return True

                                                        if self.is_neighbor_exchange is not None:
                                                            return True

                                                        if self.is_no_delete is not None:
                                                            return True

                                                        if self.is_nsr_ack_pending is not None:
                                                            return True

                                                        if self.is_partial_spf is not None:
                                                            return True

                                                        if self.is_routing_bit is not None:
                                                            return True

                                                        if self.is_routing_table is not None:
                                                            return True

                                                        if self.lsa_flood_required_post_fail_over is not None:
                                                            return True

                                                        if self.lsa_length is not None:
                                                            return True

                                                        if self.lsa_sync_state is not None:
                                                            return True

                                                        if self.minute_table_index is not None:
                                                            return True

                                                        if self.nsr_flood_required is not None:
                                                            return True

                                                        if self.rate_limit is not None:
                                                            return True

                                                        if self.second_table_index is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                        return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaDetail']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:inter-area-router-lsa-type'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.lsa_detail is not None and self.lsa_detail._has_data():
                                                        return True

                                                    if self.lsa_header is not None and self.lsa_header._has_data():
                                                        return True

                                                    if self.lsa_router_id is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                    return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType']['meta_info']


                                            class ExternalLsaType(object):
                                                """
                                                External LSA
                                                
                                                .. attribute:: external_tag
                                                
                                                	Route Tag
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: forwarding_address
                                                
                                                	Forwarding Address
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: is_forwarding_address_set
                                                
                                                	If true, forwarding address is set 
                                                	**type**\:  bool
                                                
                                                .. attribute:: lsa_detail
                                                
                                                	Detailed LSA Information
                                                	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType.LsaDetail>`
                                                
                                                .. attribute:: lsa_header
                                                
                                                	Header information 
                                                	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType.LsaHeader>`
                                                
                                                .. attribute:: metric_type
                                                
                                                	Metric type 
                                                	**type**\:   :py:class:`Ospfv3DefaultMetricEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3DefaultMetricEnum>`
                                                
                                                .. attribute:: prefix
                                                
                                                	IPV6 address prefix 
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: prefix_length
                                                
                                                	Prefix length 
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: priority
                                                
                                                	Prefix priority
                                                	**type**\:   :py:class:`PrefixPriorityEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.PrefixPriorityEnum>`
                                                
                                                .. attribute:: tos_cost
                                                
                                                	Type of service cost metric 
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.external_tag = None
                                                    self.forwarding_address = None
                                                    self.is_forwarding_address_set = None
                                                    self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType.LsaDetail()
                                                    self.lsa_detail.parent = self
                                                    self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType.LsaHeader()
                                                    self.lsa_header.parent = self
                                                    self.metric_type = None
                                                    self.prefix = None
                                                    self.prefix_length = None
                                                    self.priority = None
                                                    self.tos_cost = None


                                                class LsaHeader(object):
                                                    """
                                                    Header information 
                                                    
                                                    .. attribute:: advertising_router
                                                    
                                                    	Router ID of Advertising Router
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: checksum
                                                    
                                                    	Checksum value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: is_do_not_age_lsa
                                                    
                                                    	If true, Do Not Age this LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_graceful_restart_active
                                                    
                                                    	If true, if grace restart is active 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: ls_id
                                                    
                                                    	LS ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: lsa_age
                                                    
                                                    	LSA's Age (s)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_area_id
                                                    
                                                    	Area ID in decimal or dotted\-decimal format
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..16
                                                    
                                                    .. attribute:: lsa_type
                                                    
                                                    	LSA type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: sequence_number
                                                    
                                                    	Current Sequence number
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.advertising_router = None
                                                        self.checksum = None
                                                        self.is_do_not_age_lsa = None
                                                        self.is_graceful_restart_active = None
                                                        self.ls_id = None
                                                        self.lsa_age = None
                                                        self.lsa_area_id = None
                                                        self.lsa_type = None
                                                        self.sequence_number = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-header'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.advertising_router is not None:
                                                            return True

                                                        if self.checksum is not None:
                                                            return True

                                                        if self.is_do_not_age_lsa is not None:
                                                            return True

                                                        if self.is_graceful_restart_active is not None:
                                                            return True

                                                        if self.ls_id is not None:
                                                            return True

                                                        if self.lsa_age is not None:
                                                            return True

                                                        if self.lsa_area_id is not None:
                                                            return True

                                                        if self.lsa_type is not None:
                                                            return True

                                                        if self.sequence_number is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                        return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType.LsaHeader']['meta_info']


                                                class LsaDetail(object):
                                                    """
                                                    Detailed LSA Information
                                                    
                                                    .. attribute:: free_time
                                                    
                                                    	The amount of time since the last check was made to free this LSA (s)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_acknowledged
                                                    
                                                    	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_advertising_router_reachable
                                                    
                                                    	If true, Advertising Router is reachable
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_deleted
                                                    
                                                    	If true, flag is set to delete this LSA 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_flood_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_maximum_aged
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_neighbor_exchange
                                                    
                                                    	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_no_delete
                                                    
                                                    	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_nsr_ack_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_partial_spf
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_routing_bit
                                                    
                                                    	If true, Routing Bit set on the LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_routing_table
                                                    
                                                    	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: lsa_flood_required_post_fail_over
                                                    
                                                    	LSA flood required after FO
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: lsa_length
                                                    
                                                    	Length of the LSA
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_sync_state
                                                    
                                                    	State of LSA sync with active
                                                    	**type**\:   :py:class:`OspfLsaSyncStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncStateEnum>`
                                                    
                                                    .. attribute:: minute_table_index
                                                    
                                                    	Minute table index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: nsr_flood_required
                                                    
                                                    	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: rate_limit
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: second_table_index
                                                    
                                                    	Second table index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.free_time = None
                                                        self.is_acknowledged = None
                                                        self.is_advertising_router_reachable = None
                                                        self.is_deleted = None
                                                        self.is_flood_pending = None
                                                        self.is_maximum_aged = None
                                                        self.is_neighbor_exchange = None
                                                        self.is_no_delete = None
                                                        self.is_nsr_ack_pending = None
                                                        self.is_partial_spf = None
                                                        self.is_routing_bit = None
                                                        self.is_routing_table = None
                                                        self.lsa_flood_required_post_fail_over = None
                                                        self.lsa_length = None
                                                        self.lsa_sync_state = None
                                                        self.minute_table_index = None
                                                        self.nsr_flood_required = None
                                                        self.rate_limit = None
                                                        self.second_table_index = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-detail'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.free_time is not None:
                                                            return True

                                                        if self.is_acknowledged is not None:
                                                            return True

                                                        if self.is_advertising_router_reachable is not None:
                                                            return True

                                                        if self.is_deleted is not None:
                                                            return True

                                                        if self.is_flood_pending is not None:
                                                            return True

                                                        if self.is_maximum_aged is not None:
                                                            return True

                                                        if self.is_neighbor_exchange is not None:
                                                            return True

                                                        if self.is_no_delete is not None:
                                                            return True

                                                        if self.is_nsr_ack_pending is not None:
                                                            return True

                                                        if self.is_partial_spf is not None:
                                                            return True

                                                        if self.is_routing_bit is not None:
                                                            return True

                                                        if self.is_routing_table is not None:
                                                            return True

                                                        if self.lsa_flood_required_post_fail_over is not None:
                                                            return True

                                                        if self.lsa_length is not None:
                                                            return True

                                                        if self.lsa_sync_state is not None:
                                                            return True

                                                        if self.minute_table_index is not None:
                                                            return True

                                                        if self.nsr_flood_required is not None:
                                                            return True

                                                        if self.rate_limit is not None:
                                                            return True

                                                        if self.second_table_index is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                        return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType.LsaDetail']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:external-lsa-type'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.external_tag is not None:
                                                        return True

                                                    if self.forwarding_address is not None:
                                                        return True

                                                    if self.is_forwarding_address_set is not None:
                                                        return True

                                                    if self.lsa_detail is not None and self.lsa_detail._has_data():
                                                        return True

                                                    if self.lsa_header is not None and self.lsa_header._has_data():
                                                        return True

                                                    if self.metric_type is not None:
                                                        return True

                                                    if self.prefix is not None:
                                                        return True

                                                    if self.prefix_length is not None:
                                                        return True

                                                    if self.priority is not None:
                                                        return True

                                                    if self.tos_cost is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                    return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType']['meta_info']


                                            class NssalsaType(object):
                                                """
                                                NSSA External LSA
                                                
                                                .. attribute:: external_tag
                                                
                                                	Route Tag
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: forwarding_address
                                                
                                                	Forwarding Address
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: is_forwarding_address_set
                                                
                                                	If true, forwarding address is set 
                                                	**type**\:  bool
                                                
                                                .. attribute:: lsa_detail
                                                
                                                	Detailed LSA Information
                                                	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType.LsaDetail>`
                                                
                                                .. attribute:: lsa_header
                                                
                                                	Header information 
                                                	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType.LsaHeader>`
                                                
                                                .. attribute:: metric_type
                                                
                                                	Metric type 
                                                	**type**\:   :py:class:`Ospfv3DefaultMetricEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3DefaultMetricEnum>`
                                                
                                                .. attribute:: prefix
                                                
                                                	IPV6 address prefix 
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: prefix_length
                                                
                                                	Prefix length 
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: priority
                                                
                                                	Prefix priority
                                                	**type**\:   :py:class:`PrefixPriorityEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.PrefixPriorityEnum>`
                                                
                                                .. attribute:: tos_cost
                                                
                                                	Type of service cost metric 
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.external_tag = None
                                                    self.forwarding_address = None
                                                    self.is_forwarding_address_set = None
                                                    self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType.LsaDetail()
                                                    self.lsa_detail.parent = self
                                                    self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType.LsaHeader()
                                                    self.lsa_header.parent = self
                                                    self.metric_type = None
                                                    self.prefix = None
                                                    self.prefix_length = None
                                                    self.priority = None
                                                    self.tos_cost = None


                                                class LsaHeader(object):
                                                    """
                                                    Header information 
                                                    
                                                    .. attribute:: advertising_router
                                                    
                                                    	Router ID of Advertising Router
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: checksum
                                                    
                                                    	Checksum value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: is_do_not_age_lsa
                                                    
                                                    	If true, Do Not Age this LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_graceful_restart_active
                                                    
                                                    	If true, if grace restart is active 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: ls_id
                                                    
                                                    	LS ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: lsa_age
                                                    
                                                    	LSA's Age (s)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_area_id
                                                    
                                                    	Area ID in decimal or dotted\-decimal format
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..16
                                                    
                                                    .. attribute:: lsa_type
                                                    
                                                    	LSA type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: sequence_number
                                                    
                                                    	Current Sequence number
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.advertising_router = None
                                                        self.checksum = None
                                                        self.is_do_not_age_lsa = None
                                                        self.is_graceful_restart_active = None
                                                        self.ls_id = None
                                                        self.lsa_age = None
                                                        self.lsa_area_id = None
                                                        self.lsa_type = None
                                                        self.sequence_number = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-header'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.advertising_router is not None:
                                                            return True

                                                        if self.checksum is not None:
                                                            return True

                                                        if self.is_do_not_age_lsa is not None:
                                                            return True

                                                        if self.is_graceful_restart_active is not None:
                                                            return True

                                                        if self.ls_id is not None:
                                                            return True

                                                        if self.lsa_age is not None:
                                                            return True

                                                        if self.lsa_area_id is not None:
                                                            return True

                                                        if self.lsa_type is not None:
                                                            return True

                                                        if self.sequence_number is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                        return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType.LsaHeader']['meta_info']


                                                class LsaDetail(object):
                                                    """
                                                    Detailed LSA Information
                                                    
                                                    .. attribute:: free_time
                                                    
                                                    	The amount of time since the last check was made to free this LSA (s)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_acknowledged
                                                    
                                                    	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_advertising_router_reachable
                                                    
                                                    	If true, Advertising Router is reachable
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_deleted
                                                    
                                                    	If true, flag is set to delete this LSA 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_flood_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_maximum_aged
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_neighbor_exchange
                                                    
                                                    	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_no_delete
                                                    
                                                    	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_nsr_ack_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_partial_spf
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_routing_bit
                                                    
                                                    	If true, Routing Bit set on the LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_routing_table
                                                    
                                                    	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: lsa_flood_required_post_fail_over
                                                    
                                                    	LSA flood required after FO
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: lsa_length
                                                    
                                                    	Length of the LSA
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_sync_state
                                                    
                                                    	State of LSA sync with active
                                                    	**type**\:   :py:class:`OspfLsaSyncStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncStateEnum>`
                                                    
                                                    .. attribute:: minute_table_index
                                                    
                                                    	Minute table index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: nsr_flood_required
                                                    
                                                    	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: rate_limit
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: second_table_index
                                                    
                                                    	Second table index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.free_time = None
                                                        self.is_acknowledged = None
                                                        self.is_advertising_router_reachable = None
                                                        self.is_deleted = None
                                                        self.is_flood_pending = None
                                                        self.is_maximum_aged = None
                                                        self.is_neighbor_exchange = None
                                                        self.is_no_delete = None
                                                        self.is_nsr_ack_pending = None
                                                        self.is_partial_spf = None
                                                        self.is_routing_bit = None
                                                        self.is_routing_table = None
                                                        self.lsa_flood_required_post_fail_over = None
                                                        self.lsa_length = None
                                                        self.lsa_sync_state = None
                                                        self.minute_table_index = None
                                                        self.nsr_flood_required = None
                                                        self.rate_limit = None
                                                        self.second_table_index = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-detail'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.free_time is not None:
                                                            return True

                                                        if self.is_acknowledged is not None:
                                                            return True

                                                        if self.is_advertising_router_reachable is not None:
                                                            return True

                                                        if self.is_deleted is not None:
                                                            return True

                                                        if self.is_flood_pending is not None:
                                                            return True

                                                        if self.is_maximum_aged is not None:
                                                            return True

                                                        if self.is_neighbor_exchange is not None:
                                                            return True

                                                        if self.is_no_delete is not None:
                                                            return True

                                                        if self.is_nsr_ack_pending is not None:
                                                            return True

                                                        if self.is_partial_spf is not None:
                                                            return True

                                                        if self.is_routing_bit is not None:
                                                            return True

                                                        if self.is_routing_table is not None:
                                                            return True

                                                        if self.lsa_flood_required_post_fail_over is not None:
                                                            return True

                                                        if self.lsa_length is not None:
                                                            return True

                                                        if self.lsa_sync_state is not None:
                                                            return True

                                                        if self.minute_table_index is not None:
                                                            return True

                                                        if self.nsr_flood_required is not None:
                                                            return True

                                                        if self.rate_limit is not None:
                                                            return True

                                                        if self.second_table_index is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                        return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType.LsaDetail']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:nssalsa-type'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.external_tag is not None:
                                                        return True

                                                    if self.forwarding_address is not None:
                                                        return True

                                                    if self.is_forwarding_address_set is not None:
                                                        return True

                                                    if self.lsa_detail is not None and self.lsa_detail._has_data():
                                                        return True

                                                    if self.lsa_header is not None and self.lsa_header._has_data():
                                                        return True

                                                    if self.metric_type is not None:
                                                        return True

                                                    if self.prefix is not None:
                                                        return True

                                                    if self.prefix_length is not None:
                                                        return True

                                                    if self.priority is not None:
                                                        return True

                                                    if self.tos_cost is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                    return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType']['meta_info']


                                            class LinkLsaType(object):
                                                """
                                                Link LSA
                                                
                                                .. attribute:: interface_name
                                                
                                                	LSA interface handle
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                
                                                .. attribute:: is_sham_link
                                                
                                                	If true, it is a sham link
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_virtual_link
                                                
                                                	If true, it is a virtual link
                                                	**type**\:  bool
                                                
                                                .. attribute:: lsa_detail
                                                
                                                	Detailed LSA information
                                                	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType.LsaDetail>`
                                                
                                                .. attribute:: lsa_header
                                                
                                                	Header information 
                                                	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType.LsaHeader>`
                                                
                                                .. attribute:: lsa_link_local
                                                
                                                	LSA link local 
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: prefix
                                                
                                                	OSPFv3 prefix 
                                                	**type**\: list of    :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType.Prefix>`
                                                
                                                .. attribute:: router_priority
                                                
                                                	Router priority 
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: sham_link_id
                                                
                                                	Sham link ID 
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: virtual_link_id
                                                
                                                	Virtual link ID 
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.interface_name = None
                                                    self.is_sham_link = None
                                                    self.is_virtual_link = None
                                                    self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType.LsaDetail()
                                                    self.lsa_detail.parent = self
                                                    self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType.LsaHeader()
                                                    self.lsa_header.parent = self
                                                    self.lsa_link_local = None
                                                    self.prefix = YList()
                                                    self.prefix.parent = self
                                                    self.prefix.name = 'prefix'
                                                    self.router_priority = None
                                                    self.sham_link_id = None
                                                    self.virtual_link_id = None


                                                class LsaHeader(object):
                                                    """
                                                    Header information 
                                                    
                                                    .. attribute:: advertising_router
                                                    
                                                    	Router ID of Advertising Router
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: checksum
                                                    
                                                    	Checksum value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: is_do_not_age_lsa
                                                    
                                                    	If true, Do Not Age this LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_graceful_restart_active
                                                    
                                                    	If true, if grace restart is active 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: ls_id
                                                    
                                                    	LS ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: lsa_age
                                                    
                                                    	LSA's Age (s)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_area_id
                                                    
                                                    	Area ID in decimal or dotted\-decimal format
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..16
                                                    
                                                    .. attribute:: lsa_type
                                                    
                                                    	LSA type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: sequence_number
                                                    
                                                    	Current Sequence number
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.advertising_router = None
                                                        self.checksum = None
                                                        self.is_do_not_age_lsa = None
                                                        self.is_graceful_restart_active = None
                                                        self.ls_id = None
                                                        self.lsa_age = None
                                                        self.lsa_area_id = None
                                                        self.lsa_type = None
                                                        self.sequence_number = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-header'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.advertising_router is not None:
                                                            return True

                                                        if self.checksum is not None:
                                                            return True

                                                        if self.is_do_not_age_lsa is not None:
                                                            return True

                                                        if self.is_graceful_restart_active is not None:
                                                            return True

                                                        if self.ls_id is not None:
                                                            return True

                                                        if self.lsa_age is not None:
                                                            return True

                                                        if self.lsa_area_id is not None:
                                                            return True

                                                        if self.lsa_type is not None:
                                                            return True

                                                        if self.sequence_number is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                        return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType.LsaHeader']['meta_info']


                                                class LsaDetail(object):
                                                    """
                                                    Detailed LSA information
                                                    
                                                    .. attribute:: free_time
                                                    
                                                    	The amount of time since the last check was made to free this LSA (s)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_acknowledged
                                                    
                                                    	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_advertising_router_reachable
                                                    
                                                    	If true, Advertising Router is reachable
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_deleted
                                                    
                                                    	If true, flag is set to delete this LSA 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_flood_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_maximum_aged
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_neighbor_exchange
                                                    
                                                    	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_no_delete
                                                    
                                                    	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_nsr_ack_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_partial_spf
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_routing_bit
                                                    
                                                    	If true, Routing Bit set on the LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_routing_table
                                                    
                                                    	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: lsa_flood_required_post_fail_over
                                                    
                                                    	LSA flood required after FO
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: lsa_length
                                                    
                                                    	Length of the LSA
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_sync_state
                                                    
                                                    	State of LSA sync with active
                                                    	**type**\:   :py:class:`OspfLsaSyncStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncStateEnum>`
                                                    
                                                    .. attribute:: minute_table_index
                                                    
                                                    	Minute table index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: nsr_flood_required
                                                    
                                                    	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: rate_limit
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: second_table_index
                                                    
                                                    	Second table index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.free_time = None
                                                        self.is_acknowledged = None
                                                        self.is_advertising_router_reachable = None
                                                        self.is_deleted = None
                                                        self.is_flood_pending = None
                                                        self.is_maximum_aged = None
                                                        self.is_neighbor_exchange = None
                                                        self.is_no_delete = None
                                                        self.is_nsr_ack_pending = None
                                                        self.is_partial_spf = None
                                                        self.is_routing_bit = None
                                                        self.is_routing_table = None
                                                        self.lsa_flood_required_post_fail_over = None
                                                        self.lsa_length = None
                                                        self.lsa_sync_state = None
                                                        self.minute_table_index = None
                                                        self.nsr_flood_required = None
                                                        self.rate_limit = None
                                                        self.second_table_index = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-detail'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.free_time is not None:
                                                            return True

                                                        if self.is_acknowledged is not None:
                                                            return True

                                                        if self.is_advertising_router_reachable is not None:
                                                            return True

                                                        if self.is_deleted is not None:
                                                            return True

                                                        if self.is_flood_pending is not None:
                                                            return True

                                                        if self.is_maximum_aged is not None:
                                                            return True

                                                        if self.is_neighbor_exchange is not None:
                                                            return True

                                                        if self.is_no_delete is not None:
                                                            return True

                                                        if self.is_nsr_ack_pending is not None:
                                                            return True

                                                        if self.is_partial_spf is not None:
                                                            return True

                                                        if self.is_routing_bit is not None:
                                                            return True

                                                        if self.is_routing_table is not None:
                                                            return True

                                                        if self.lsa_flood_required_post_fail_over is not None:
                                                            return True

                                                        if self.lsa_length is not None:
                                                            return True

                                                        if self.lsa_sync_state is not None:
                                                            return True

                                                        if self.minute_table_index is not None:
                                                            return True

                                                        if self.nsr_flood_required is not None:
                                                            return True

                                                        if self.rate_limit is not None:
                                                            return True

                                                        if self.second_table_index is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                        return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType.LsaDetail']['meta_info']


                                                class Prefix(object):
                                                    """
                                                    OSPFv3 prefix 
                                                    
                                                    .. attribute:: ospfv3_prefix_length
                                                    
                                                    	OSPFv3 prefix length 
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: ospfv3_prefix_metric
                                                    
                                                    	OSPFv3 prefix metric 
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: ospfv3_prefix_options
                                                    
                                                    	OSPFv3 prefix options 
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: prefix
                                                    
                                                    	OSPFv3 prefix 
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: priority
                                                    
                                                    	Prefix priority
                                                    	**type**\:   :py:class:`PrefixPriorityEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.PrefixPriorityEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ospfv3_prefix_length = None
                                                        self.ospfv3_prefix_metric = None
                                                        self.ospfv3_prefix_options = None
                                                        self.prefix = None
                                                        self.priority = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:prefix'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ospfv3_prefix_length is not None:
                                                            return True

                                                        if self.ospfv3_prefix_metric is not None:
                                                            return True

                                                        if self.ospfv3_prefix_options is not None:
                                                            return True

                                                        if self.prefix is not None:
                                                            return True

                                                        if self.priority is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                        return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType.Prefix']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:link-lsa-type'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.interface_name is not None:
                                                        return True

                                                    if self.is_sham_link is not None:
                                                        return True

                                                    if self.is_virtual_link is not None:
                                                        return True

                                                    if self.lsa_detail is not None and self.lsa_detail._has_data():
                                                        return True

                                                    if self.lsa_header is not None and self.lsa_header._has_data():
                                                        return True

                                                    if self.lsa_link_local is not None:
                                                        return True

                                                    if self.prefix is not None:
                                                        for child_ref in self.prefix:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.router_priority is not None:
                                                        return True

                                                    if self.sham_link_id is not None:
                                                        return True

                                                    if self.virtual_link_id is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                    return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType']['meta_info']


                                            class IntraAreaPrefixLsaType(object):
                                                """
                                                Intra Area Prefix LSA
                                                
                                                .. attribute:: lsa_detail
                                                
                                                	Detailed LSA information
                                                	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaDetail>`
                                                
                                                .. attribute:: lsa_header
                                                
                                                	Header information 
                                                	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaHeader>`
                                                
                                                .. attribute:: prefix
                                                
                                                	OSPFv3 prefix 
                                                	**type**\: list of    :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.Prefix>`
                                                
                                                .. attribute:: reference_advertised_router
                                                
                                                	Reference advertised router 
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: reference_lsa_id
                                                
                                                	Reference LSA ID 
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: reference_type
                                                
                                                	Reference type 
                                                	**type**\:   :py:class:`Ospfv3Lsa1Enum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Lsa1Enum>`
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaDetail()
                                                    self.lsa_detail.parent = self
                                                    self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaHeader()
                                                    self.lsa_header.parent = self
                                                    self.prefix = YList()
                                                    self.prefix.parent = self
                                                    self.prefix.name = 'prefix'
                                                    self.reference_advertised_router = None
                                                    self.reference_lsa_id = None
                                                    self.reference_type = None


                                                class LsaHeader(object):
                                                    """
                                                    Header information 
                                                    
                                                    .. attribute:: advertising_router
                                                    
                                                    	Router ID of Advertising Router
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: checksum
                                                    
                                                    	Checksum value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: is_do_not_age_lsa
                                                    
                                                    	If true, Do Not Age this LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_graceful_restart_active
                                                    
                                                    	If true, if grace restart is active 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: ls_id
                                                    
                                                    	LS ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: lsa_age
                                                    
                                                    	LSA's Age (s)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_area_id
                                                    
                                                    	Area ID in decimal or dotted\-decimal format
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..16
                                                    
                                                    .. attribute:: lsa_type
                                                    
                                                    	LSA type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: sequence_number
                                                    
                                                    	Current Sequence number
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.advertising_router = None
                                                        self.checksum = None
                                                        self.is_do_not_age_lsa = None
                                                        self.is_graceful_restart_active = None
                                                        self.ls_id = None
                                                        self.lsa_age = None
                                                        self.lsa_area_id = None
                                                        self.lsa_type = None
                                                        self.sequence_number = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-header'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.advertising_router is not None:
                                                            return True

                                                        if self.checksum is not None:
                                                            return True

                                                        if self.is_do_not_age_lsa is not None:
                                                            return True

                                                        if self.is_graceful_restart_active is not None:
                                                            return True

                                                        if self.ls_id is not None:
                                                            return True

                                                        if self.lsa_age is not None:
                                                            return True

                                                        if self.lsa_area_id is not None:
                                                            return True

                                                        if self.lsa_type is not None:
                                                            return True

                                                        if self.sequence_number is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                        return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaHeader']['meta_info']


                                                class LsaDetail(object):
                                                    """
                                                    Detailed LSA information
                                                    
                                                    .. attribute:: free_time
                                                    
                                                    	The amount of time since the last check was made to free this LSA (s)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_acknowledged
                                                    
                                                    	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_advertising_router_reachable
                                                    
                                                    	If true, Advertising Router is reachable
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_deleted
                                                    
                                                    	If true, flag is set to delete this LSA 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_flood_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_maximum_aged
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_neighbor_exchange
                                                    
                                                    	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_no_delete
                                                    
                                                    	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_nsr_ack_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_partial_spf
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_routing_bit
                                                    
                                                    	If true, Routing Bit set on the LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_routing_table
                                                    
                                                    	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: lsa_flood_required_post_fail_over
                                                    
                                                    	LSA flood required after FO
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: lsa_length
                                                    
                                                    	Length of the LSA
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_sync_state
                                                    
                                                    	State of LSA sync with active
                                                    	**type**\:   :py:class:`OspfLsaSyncStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncStateEnum>`
                                                    
                                                    .. attribute:: minute_table_index
                                                    
                                                    	Minute table index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: nsr_flood_required
                                                    
                                                    	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: rate_limit
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: second_table_index
                                                    
                                                    	Second table index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.free_time = None
                                                        self.is_acknowledged = None
                                                        self.is_advertising_router_reachable = None
                                                        self.is_deleted = None
                                                        self.is_flood_pending = None
                                                        self.is_maximum_aged = None
                                                        self.is_neighbor_exchange = None
                                                        self.is_no_delete = None
                                                        self.is_nsr_ack_pending = None
                                                        self.is_partial_spf = None
                                                        self.is_routing_bit = None
                                                        self.is_routing_table = None
                                                        self.lsa_flood_required_post_fail_over = None
                                                        self.lsa_length = None
                                                        self.lsa_sync_state = None
                                                        self.minute_table_index = None
                                                        self.nsr_flood_required = None
                                                        self.rate_limit = None
                                                        self.second_table_index = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-detail'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.free_time is not None:
                                                            return True

                                                        if self.is_acknowledged is not None:
                                                            return True

                                                        if self.is_advertising_router_reachable is not None:
                                                            return True

                                                        if self.is_deleted is not None:
                                                            return True

                                                        if self.is_flood_pending is not None:
                                                            return True

                                                        if self.is_maximum_aged is not None:
                                                            return True

                                                        if self.is_neighbor_exchange is not None:
                                                            return True

                                                        if self.is_no_delete is not None:
                                                            return True

                                                        if self.is_nsr_ack_pending is not None:
                                                            return True

                                                        if self.is_partial_spf is not None:
                                                            return True

                                                        if self.is_routing_bit is not None:
                                                            return True

                                                        if self.is_routing_table is not None:
                                                            return True

                                                        if self.lsa_flood_required_post_fail_over is not None:
                                                            return True

                                                        if self.lsa_length is not None:
                                                            return True

                                                        if self.lsa_sync_state is not None:
                                                            return True

                                                        if self.minute_table_index is not None:
                                                            return True

                                                        if self.nsr_flood_required is not None:
                                                            return True

                                                        if self.rate_limit is not None:
                                                            return True

                                                        if self.second_table_index is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                        return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaDetail']['meta_info']


                                                class Prefix(object):
                                                    """
                                                    OSPFv3 prefix 
                                                    
                                                    .. attribute:: ospfv3_prefix_length
                                                    
                                                    	OSPFv3 prefix length 
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: ospfv3_prefix_metric
                                                    
                                                    	OSPFv3 prefix metric 
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: ospfv3_prefix_options
                                                    
                                                    	OSPFv3 prefix options 
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: prefix
                                                    
                                                    	OSPFv3 prefix 
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: priority
                                                    
                                                    	Prefix priority
                                                    	**type**\:   :py:class:`PrefixPriorityEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.PrefixPriorityEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ospfv3_prefix_length = None
                                                        self.ospfv3_prefix_metric = None
                                                        self.ospfv3_prefix_options = None
                                                        self.prefix = None
                                                        self.priority = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:prefix'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ospfv3_prefix_length is not None:
                                                            return True

                                                        if self.ospfv3_prefix_metric is not None:
                                                            return True

                                                        if self.ospfv3_prefix_options is not None:
                                                            return True

                                                        if self.prefix is not None:
                                                            return True

                                                        if self.priority is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                        return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.Prefix']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:intra-area-prefix-lsa-type'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.lsa_detail is not None and self.lsa_detail._has_data():
                                                        return True

                                                    if self.lsa_header is not None and self.lsa_header._has_data():
                                                        return True

                                                    if self.prefix is not None:
                                                        for child_ref in self.prefix:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.reference_advertised_router is not None:
                                                        return True

                                                    if self.reference_lsa_id is not None:
                                                        return True

                                                    if self.reference_type is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                    return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType']['meta_info']


                                            class GraceLsa(object):
                                                """
                                                Grace LSA
                                                
                                                .. attribute:: grace_period
                                                
                                                	The grace periord where helper routers should wait before advertising it fully adjacent(s) 
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: grace_reason
                                                
                                                	Reason for router restart
                                                	**type**\:   :py:class:`Ospfv3GracefulRestartReasonEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3GracefulRestartReasonEnum>`
                                                
                                                .. attribute:: lsa_detail
                                                
                                                	Detailed LSA information
                                                	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa.LsaDetail>`
                                                
                                                .. attribute:: lsa_header
                                                
                                                	Header information 
                                                	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa.LsaHeader>`
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.grace_period = None
                                                    self.grace_reason = None
                                                    self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa.LsaDetail()
                                                    self.lsa_detail.parent = self
                                                    self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa.LsaHeader()
                                                    self.lsa_header.parent = self


                                                class LsaHeader(object):
                                                    """
                                                    Header information 
                                                    
                                                    .. attribute:: advertising_router
                                                    
                                                    	Router ID of Advertising Router
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: checksum
                                                    
                                                    	Checksum value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: is_do_not_age_lsa
                                                    
                                                    	If true, Do Not Age this LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_graceful_restart_active
                                                    
                                                    	If true, if grace restart is active 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: ls_id
                                                    
                                                    	LS ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: lsa_age
                                                    
                                                    	LSA's Age (s)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_area_id
                                                    
                                                    	Area ID in decimal or dotted\-decimal format
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..16
                                                    
                                                    .. attribute:: lsa_type
                                                    
                                                    	LSA type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: sequence_number
                                                    
                                                    	Current Sequence number
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.advertising_router = None
                                                        self.checksum = None
                                                        self.is_do_not_age_lsa = None
                                                        self.is_graceful_restart_active = None
                                                        self.ls_id = None
                                                        self.lsa_age = None
                                                        self.lsa_area_id = None
                                                        self.lsa_type = None
                                                        self.sequence_number = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-header'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.advertising_router is not None:
                                                            return True

                                                        if self.checksum is not None:
                                                            return True

                                                        if self.is_do_not_age_lsa is not None:
                                                            return True

                                                        if self.is_graceful_restart_active is not None:
                                                            return True

                                                        if self.ls_id is not None:
                                                            return True

                                                        if self.lsa_age is not None:
                                                            return True

                                                        if self.lsa_area_id is not None:
                                                            return True

                                                        if self.lsa_type is not None:
                                                            return True

                                                        if self.sequence_number is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                        return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa.LsaHeader']['meta_info']


                                                class LsaDetail(object):
                                                    """
                                                    Detailed LSA information
                                                    
                                                    .. attribute:: free_time
                                                    
                                                    	The amount of time since the last check was made to free this LSA (s)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_acknowledged
                                                    
                                                    	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_advertising_router_reachable
                                                    
                                                    	If true, Advertising Router is reachable
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_deleted
                                                    
                                                    	If true, flag is set to delete this LSA 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_flood_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_maximum_aged
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_neighbor_exchange
                                                    
                                                    	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_no_delete
                                                    
                                                    	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_nsr_ack_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_partial_spf
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_routing_bit
                                                    
                                                    	If true, Routing Bit set on the LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_routing_table
                                                    
                                                    	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: lsa_flood_required_post_fail_over
                                                    
                                                    	LSA flood required after FO
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: lsa_length
                                                    
                                                    	Length of the LSA
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_sync_state
                                                    
                                                    	State of LSA sync with active
                                                    	**type**\:   :py:class:`OspfLsaSyncStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncStateEnum>`
                                                    
                                                    .. attribute:: minute_table_index
                                                    
                                                    	Minute table index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: nsr_flood_required
                                                    
                                                    	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: rate_limit
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: second_table_index
                                                    
                                                    	Second table index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.free_time = None
                                                        self.is_acknowledged = None
                                                        self.is_advertising_router_reachable = None
                                                        self.is_deleted = None
                                                        self.is_flood_pending = None
                                                        self.is_maximum_aged = None
                                                        self.is_neighbor_exchange = None
                                                        self.is_no_delete = None
                                                        self.is_nsr_ack_pending = None
                                                        self.is_partial_spf = None
                                                        self.is_routing_bit = None
                                                        self.is_routing_table = None
                                                        self.lsa_flood_required_post_fail_over = None
                                                        self.lsa_length = None
                                                        self.lsa_sync_state = None
                                                        self.minute_table_index = None
                                                        self.nsr_flood_required = None
                                                        self.rate_limit = None
                                                        self.second_table_index = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-detail'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.free_time is not None:
                                                            return True

                                                        if self.is_acknowledged is not None:
                                                            return True

                                                        if self.is_advertising_router_reachable is not None:
                                                            return True

                                                        if self.is_deleted is not None:
                                                            return True

                                                        if self.is_flood_pending is not None:
                                                            return True

                                                        if self.is_maximum_aged is not None:
                                                            return True

                                                        if self.is_neighbor_exchange is not None:
                                                            return True

                                                        if self.is_no_delete is not None:
                                                            return True

                                                        if self.is_nsr_ack_pending is not None:
                                                            return True

                                                        if self.is_partial_spf is not None:
                                                            return True

                                                        if self.is_routing_bit is not None:
                                                            return True

                                                        if self.is_routing_table is not None:
                                                            return True

                                                        if self.lsa_flood_required_post_fail_over is not None:
                                                            return True

                                                        if self.lsa_length is not None:
                                                            return True

                                                        if self.lsa_sync_state is not None:
                                                            return True

                                                        if self.minute_table_index is not None:
                                                            return True

                                                        if self.nsr_flood_required is not None:
                                                            return True

                                                        if self.rate_limit is not None:
                                                            return True

                                                        if self.second_table_index is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                        return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa.LsaDetail']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:grace-lsa'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.grace_period is not None:
                                                        return True

                                                    if self.grace_reason is not None:
                                                        return True

                                                    if self.lsa_detail is not None and self.lsa_detail._has_data():
                                                        return True

                                                    if self.lsa_header is not None and self.lsa_header._has_data():
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                    return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa']['meta_info']


                                            class UnknownLinkLsaType(object):
                                                """
                                                Unknown Link Scope LSA
                                                
                                                .. attribute:: interface_name
                                                
                                                	LSA interface name 
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                
                                                .. attribute:: is_sham_link
                                                
                                                	If true, it is a sham link 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_virtual_link
                                                
                                                	If true, it is a virtual link 
                                                	**type**\:  bool
                                                
                                                .. attribute:: lsa_detail
                                                
                                                	Detailed LSA information
                                                	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaDetail>`
                                                
                                                .. attribute:: lsa_header
                                                
                                                	Header information 
                                                	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaHeader>`
                                                
                                                .. attribute:: sham_link_id
                                                
                                                	Shamlink ID 
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: virtual_link_id
                                                
                                                	Virtual link ID 
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.interface_name = None
                                                    self.is_sham_link = None
                                                    self.is_virtual_link = None
                                                    self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaDetail()
                                                    self.lsa_detail.parent = self
                                                    self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaHeader()
                                                    self.lsa_header.parent = self
                                                    self.sham_link_id = None
                                                    self.virtual_link_id = None


                                                class LsaHeader(object):
                                                    """
                                                    Header information 
                                                    
                                                    .. attribute:: advertising_router
                                                    
                                                    	Router ID of Advertising Router
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: checksum
                                                    
                                                    	Checksum value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: is_do_not_age_lsa
                                                    
                                                    	If true, Do Not Age this LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_graceful_restart_active
                                                    
                                                    	If true, if grace restart is active 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: ls_id
                                                    
                                                    	LS ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: lsa_age
                                                    
                                                    	LSA's Age (s)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_area_id
                                                    
                                                    	Area ID in decimal or dotted\-decimal format
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..16
                                                    
                                                    .. attribute:: lsa_type
                                                    
                                                    	LSA type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: sequence_number
                                                    
                                                    	Current Sequence number
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.advertising_router = None
                                                        self.checksum = None
                                                        self.is_do_not_age_lsa = None
                                                        self.is_graceful_restart_active = None
                                                        self.ls_id = None
                                                        self.lsa_age = None
                                                        self.lsa_area_id = None
                                                        self.lsa_type = None
                                                        self.sequence_number = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-header'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.advertising_router is not None:
                                                            return True

                                                        if self.checksum is not None:
                                                            return True

                                                        if self.is_do_not_age_lsa is not None:
                                                            return True

                                                        if self.is_graceful_restart_active is not None:
                                                            return True

                                                        if self.ls_id is not None:
                                                            return True

                                                        if self.lsa_age is not None:
                                                            return True

                                                        if self.lsa_area_id is not None:
                                                            return True

                                                        if self.lsa_type is not None:
                                                            return True

                                                        if self.sequence_number is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                        return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaHeader']['meta_info']


                                                class LsaDetail(object):
                                                    """
                                                    Detailed LSA information
                                                    
                                                    .. attribute:: free_time
                                                    
                                                    	The amount of time since the last check was made to free this LSA (s)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_acknowledged
                                                    
                                                    	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_advertising_router_reachable
                                                    
                                                    	If true, Advertising Router is reachable
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_deleted
                                                    
                                                    	If true, flag is set to delete this LSA 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_flood_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_maximum_aged
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_neighbor_exchange
                                                    
                                                    	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_no_delete
                                                    
                                                    	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_nsr_ack_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_partial_spf
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_routing_bit
                                                    
                                                    	If true, Routing Bit set on the LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_routing_table
                                                    
                                                    	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: lsa_flood_required_post_fail_over
                                                    
                                                    	LSA flood required after FO
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: lsa_length
                                                    
                                                    	Length of the LSA
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_sync_state
                                                    
                                                    	State of LSA sync with active
                                                    	**type**\:   :py:class:`OspfLsaSyncStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncStateEnum>`
                                                    
                                                    .. attribute:: minute_table_index
                                                    
                                                    	Minute table index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: nsr_flood_required
                                                    
                                                    	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: rate_limit
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: second_table_index
                                                    
                                                    	Second table index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.free_time = None
                                                        self.is_acknowledged = None
                                                        self.is_advertising_router_reachable = None
                                                        self.is_deleted = None
                                                        self.is_flood_pending = None
                                                        self.is_maximum_aged = None
                                                        self.is_neighbor_exchange = None
                                                        self.is_no_delete = None
                                                        self.is_nsr_ack_pending = None
                                                        self.is_partial_spf = None
                                                        self.is_routing_bit = None
                                                        self.is_routing_table = None
                                                        self.lsa_flood_required_post_fail_over = None
                                                        self.lsa_length = None
                                                        self.lsa_sync_state = None
                                                        self.minute_table_index = None
                                                        self.nsr_flood_required = None
                                                        self.rate_limit = None
                                                        self.second_table_index = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-detail'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.free_time is not None:
                                                            return True

                                                        if self.is_acknowledged is not None:
                                                            return True

                                                        if self.is_advertising_router_reachable is not None:
                                                            return True

                                                        if self.is_deleted is not None:
                                                            return True

                                                        if self.is_flood_pending is not None:
                                                            return True

                                                        if self.is_maximum_aged is not None:
                                                            return True

                                                        if self.is_neighbor_exchange is not None:
                                                            return True

                                                        if self.is_no_delete is not None:
                                                            return True

                                                        if self.is_nsr_ack_pending is not None:
                                                            return True

                                                        if self.is_partial_spf is not None:
                                                            return True

                                                        if self.is_routing_bit is not None:
                                                            return True

                                                        if self.is_routing_table is not None:
                                                            return True

                                                        if self.lsa_flood_required_post_fail_over is not None:
                                                            return True

                                                        if self.lsa_length is not None:
                                                            return True

                                                        if self.lsa_sync_state is not None:
                                                            return True

                                                        if self.minute_table_index is not None:
                                                            return True

                                                        if self.nsr_flood_required is not None:
                                                            return True

                                                        if self.rate_limit is not None:
                                                            return True

                                                        if self.second_table_index is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                        return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaDetail']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:unknown-link-lsa-type'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.interface_name is not None:
                                                        return True

                                                    if self.is_sham_link is not None:
                                                        return True

                                                    if self.is_virtual_link is not None:
                                                        return True

                                                    if self.lsa_detail is not None and self.lsa_detail._has_data():
                                                        return True

                                                    if self.lsa_header is not None and self.lsa_header._has_data():
                                                        return True

                                                    if self.sham_link_id is not None:
                                                        return True

                                                    if self.virtual_link_id is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                    return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType']['meta_info']


                                            class UnknownAreaLsaType(object):
                                                """
                                                Unknown\-Area scope LSA
                                                
                                                .. attribute:: interface_name
                                                
                                                	LSA interface name 
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                
                                                .. attribute:: is_sham_link
                                                
                                                	If true, it is a sham link 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_virtual_link
                                                
                                                	If true, it is a virtual link 
                                                	**type**\:  bool
                                                
                                                .. attribute:: lsa_detail
                                                
                                                	Detailed LSA information
                                                	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaDetail>`
                                                
                                                .. attribute:: lsa_header
                                                
                                                	Header information 
                                                	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaHeader>`
                                                
                                                .. attribute:: sham_link_id
                                                
                                                	Shamlink ID 
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: virtual_link_id
                                                
                                                	Virtual link ID 
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.interface_name = None
                                                    self.is_sham_link = None
                                                    self.is_virtual_link = None
                                                    self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaDetail()
                                                    self.lsa_detail.parent = self
                                                    self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaHeader()
                                                    self.lsa_header.parent = self
                                                    self.sham_link_id = None
                                                    self.virtual_link_id = None


                                                class LsaHeader(object):
                                                    """
                                                    Header information 
                                                    
                                                    .. attribute:: advertising_router
                                                    
                                                    	Router ID of Advertising Router
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: checksum
                                                    
                                                    	Checksum value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: is_do_not_age_lsa
                                                    
                                                    	If true, Do Not Age this LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_graceful_restart_active
                                                    
                                                    	If true, if grace restart is active 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: ls_id
                                                    
                                                    	LS ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: lsa_age
                                                    
                                                    	LSA's Age (s)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_area_id
                                                    
                                                    	Area ID in decimal or dotted\-decimal format
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..16
                                                    
                                                    .. attribute:: lsa_type
                                                    
                                                    	LSA type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: sequence_number
                                                    
                                                    	Current Sequence number
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.advertising_router = None
                                                        self.checksum = None
                                                        self.is_do_not_age_lsa = None
                                                        self.is_graceful_restart_active = None
                                                        self.ls_id = None
                                                        self.lsa_age = None
                                                        self.lsa_area_id = None
                                                        self.lsa_type = None
                                                        self.sequence_number = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-header'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.advertising_router is not None:
                                                            return True

                                                        if self.checksum is not None:
                                                            return True

                                                        if self.is_do_not_age_lsa is not None:
                                                            return True

                                                        if self.is_graceful_restart_active is not None:
                                                            return True

                                                        if self.ls_id is not None:
                                                            return True

                                                        if self.lsa_age is not None:
                                                            return True

                                                        if self.lsa_area_id is not None:
                                                            return True

                                                        if self.lsa_type is not None:
                                                            return True

                                                        if self.sequence_number is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                        return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaHeader']['meta_info']


                                                class LsaDetail(object):
                                                    """
                                                    Detailed LSA information
                                                    
                                                    .. attribute:: free_time
                                                    
                                                    	The amount of time since the last check was made to free this LSA (s)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_acknowledged
                                                    
                                                    	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_advertising_router_reachable
                                                    
                                                    	If true, Advertising Router is reachable
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_deleted
                                                    
                                                    	If true, flag is set to delete this LSA 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_flood_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_maximum_aged
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_neighbor_exchange
                                                    
                                                    	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_no_delete
                                                    
                                                    	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_nsr_ack_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_partial_spf
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_routing_bit
                                                    
                                                    	If true, Routing Bit set on the LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_routing_table
                                                    
                                                    	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: lsa_flood_required_post_fail_over
                                                    
                                                    	LSA flood required after FO
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: lsa_length
                                                    
                                                    	Length of the LSA
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_sync_state
                                                    
                                                    	State of LSA sync with active
                                                    	**type**\:   :py:class:`OspfLsaSyncStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncStateEnum>`
                                                    
                                                    .. attribute:: minute_table_index
                                                    
                                                    	Minute table index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: nsr_flood_required
                                                    
                                                    	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: rate_limit
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: second_table_index
                                                    
                                                    	Second table index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.free_time = None
                                                        self.is_acknowledged = None
                                                        self.is_advertising_router_reachable = None
                                                        self.is_deleted = None
                                                        self.is_flood_pending = None
                                                        self.is_maximum_aged = None
                                                        self.is_neighbor_exchange = None
                                                        self.is_no_delete = None
                                                        self.is_nsr_ack_pending = None
                                                        self.is_partial_spf = None
                                                        self.is_routing_bit = None
                                                        self.is_routing_table = None
                                                        self.lsa_flood_required_post_fail_over = None
                                                        self.lsa_length = None
                                                        self.lsa_sync_state = None
                                                        self.minute_table_index = None
                                                        self.nsr_flood_required = None
                                                        self.rate_limit = None
                                                        self.second_table_index = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-detail'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.free_time is not None:
                                                            return True

                                                        if self.is_acknowledged is not None:
                                                            return True

                                                        if self.is_advertising_router_reachable is not None:
                                                            return True

                                                        if self.is_deleted is not None:
                                                            return True

                                                        if self.is_flood_pending is not None:
                                                            return True

                                                        if self.is_maximum_aged is not None:
                                                            return True

                                                        if self.is_neighbor_exchange is not None:
                                                            return True

                                                        if self.is_no_delete is not None:
                                                            return True

                                                        if self.is_nsr_ack_pending is not None:
                                                            return True

                                                        if self.is_partial_spf is not None:
                                                            return True

                                                        if self.is_routing_bit is not None:
                                                            return True

                                                        if self.is_routing_table is not None:
                                                            return True

                                                        if self.lsa_flood_required_post_fail_over is not None:
                                                            return True

                                                        if self.lsa_length is not None:
                                                            return True

                                                        if self.lsa_sync_state is not None:
                                                            return True

                                                        if self.minute_table_index is not None:
                                                            return True

                                                        if self.nsr_flood_required is not None:
                                                            return True

                                                        if self.rate_limit is not None:
                                                            return True

                                                        if self.second_table_index is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                        return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaDetail']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:unknown-area-lsa-type'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.interface_name is not None:
                                                        return True

                                                    if self.is_sham_link is not None:
                                                        return True

                                                    if self.is_virtual_link is not None:
                                                        return True

                                                    if self.lsa_detail is not None and self.lsa_detail._has_data():
                                                        return True

                                                    if self.lsa_header is not None and self.lsa_header._has_data():
                                                        return True

                                                    if self.sham_link_id is not None:
                                                        return True

                                                    if self.virtual_link_id is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                    return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType']['meta_info']


                                            class UnknownAslsaType(object):
                                                """
                                                Unknown\-AS scope LSA
                                                
                                                .. attribute:: interface_name
                                                
                                                	LSA interface name 
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                
                                                .. attribute:: is_sham_link
                                                
                                                	If true, it is a sham link 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_virtual_link
                                                
                                                	If true, it is a virtual link 
                                                	**type**\:  bool
                                                
                                                .. attribute:: lsa_detail
                                                
                                                	Detailed LSA information
                                                	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType.LsaDetail>`
                                                
                                                .. attribute:: lsa_header
                                                
                                                	Header information 
                                                	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType.LsaHeader>`
                                                
                                                .. attribute:: sham_link_id
                                                
                                                	Shamlink ID 
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: virtual_link_id
                                                
                                                	Virtual link ID 
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.interface_name = None
                                                    self.is_sham_link = None
                                                    self.is_virtual_link = None
                                                    self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType.LsaDetail()
                                                    self.lsa_detail.parent = self
                                                    self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType.LsaHeader()
                                                    self.lsa_header.parent = self
                                                    self.sham_link_id = None
                                                    self.virtual_link_id = None


                                                class LsaHeader(object):
                                                    """
                                                    Header information 
                                                    
                                                    .. attribute:: advertising_router
                                                    
                                                    	Router ID of Advertising Router
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: checksum
                                                    
                                                    	Checksum value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: is_do_not_age_lsa
                                                    
                                                    	If true, Do Not Age this LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_graceful_restart_active
                                                    
                                                    	If true, if grace restart is active 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: ls_id
                                                    
                                                    	LS ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: lsa_age
                                                    
                                                    	LSA's Age (s)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_area_id
                                                    
                                                    	Area ID in decimal or dotted\-decimal format
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..16
                                                    
                                                    .. attribute:: lsa_type
                                                    
                                                    	LSA type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: sequence_number
                                                    
                                                    	Current Sequence number
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.advertising_router = None
                                                        self.checksum = None
                                                        self.is_do_not_age_lsa = None
                                                        self.is_graceful_restart_active = None
                                                        self.ls_id = None
                                                        self.lsa_age = None
                                                        self.lsa_area_id = None
                                                        self.lsa_type = None
                                                        self.sequence_number = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-header'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.advertising_router is not None:
                                                            return True

                                                        if self.checksum is not None:
                                                            return True

                                                        if self.is_do_not_age_lsa is not None:
                                                            return True

                                                        if self.is_graceful_restart_active is not None:
                                                            return True

                                                        if self.ls_id is not None:
                                                            return True

                                                        if self.lsa_age is not None:
                                                            return True

                                                        if self.lsa_area_id is not None:
                                                            return True

                                                        if self.lsa_type is not None:
                                                            return True

                                                        if self.sequence_number is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                        return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType.LsaHeader']['meta_info']


                                                class LsaDetail(object):
                                                    """
                                                    Detailed LSA information
                                                    
                                                    .. attribute:: free_time
                                                    
                                                    	The amount of time since the last check was made to free this LSA (s)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_acknowledged
                                                    
                                                    	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_advertising_router_reachable
                                                    
                                                    	If true, Advertising Router is reachable
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_deleted
                                                    
                                                    	If true, flag is set to delete this LSA 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_flood_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_maximum_aged
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_neighbor_exchange
                                                    
                                                    	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_no_delete
                                                    
                                                    	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_nsr_ack_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_partial_spf
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_routing_bit
                                                    
                                                    	If true, Routing Bit set on the LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_routing_table
                                                    
                                                    	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: lsa_flood_required_post_fail_over
                                                    
                                                    	LSA flood required after FO
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: lsa_length
                                                    
                                                    	Length of the LSA
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_sync_state
                                                    
                                                    	State of LSA sync with active
                                                    	**type**\:   :py:class:`OspfLsaSyncStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncStateEnum>`
                                                    
                                                    .. attribute:: minute_table_index
                                                    
                                                    	Minute table index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: nsr_flood_required
                                                    
                                                    	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: rate_limit
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: second_table_index
                                                    
                                                    	Second table index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.free_time = None
                                                        self.is_acknowledged = None
                                                        self.is_advertising_router_reachable = None
                                                        self.is_deleted = None
                                                        self.is_flood_pending = None
                                                        self.is_maximum_aged = None
                                                        self.is_neighbor_exchange = None
                                                        self.is_no_delete = None
                                                        self.is_nsr_ack_pending = None
                                                        self.is_partial_spf = None
                                                        self.is_routing_bit = None
                                                        self.is_routing_table = None
                                                        self.lsa_flood_required_post_fail_over = None
                                                        self.lsa_length = None
                                                        self.lsa_sync_state = None
                                                        self.minute_table_index = None
                                                        self.nsr_flood_required = None
                                                        self.rate_limit = None
                                                        self.second_table_index = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-detail'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.free_time is not None:
                                                            return True

                                                        if self.is_acknowledged is not None:
                                                            return True

                                                        if self.is_advertising_router_reachable is not None:
                                                            return True

                                                        if self.is_deleted is not None:
                                                            return True

                                                        if self.is_flood_pending is not None:
                                                            return True

                                                        if self.is_maximum_aged is not None:
                                                            return True

                                                        if self.is_neighbor_exchange is not None:
                                                            return True

                                                        if self.is_no_delete is not None:
                                                            return True

                                                        if self.is_nsr_ack_pending is not None:
                                                            return True

                                                        if self.is_partial_spf is not None:
                                                            return True

                                                        if self.is_routing_bit is not None:
                                                            return True

                                                        if self.is_routing_table is not None:
                                                            return True

                                                        if self.lsa_flood_required_post_fail_over is not None:
                                                            return True

                                                        if self.lsa_length is not None:
                                                            return True

                                                        if self.lsa_sync_state is not None:
                                                            return True

                                                        if self.minute_table_index is not None:
                                                            return True

                                                        if self.nsr_flood_required is not None:
                                                            return True

                                                        if self.rate_limit is not None:
                                                            return True

                                                        if self.second_table_index is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                        return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType.LsaDetail']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:unknown-aslsa-type'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.interface_name is not None:
                                                        return True

                                                    if self.is_sham_link is not None:
                                                        return True

                                                    if self.is_virtual_link is not None:
                                                        return True

                                                    if self.lsa_detail is not None and self.lsa_detail._has_data():
                                                        return True

                                                    if self.lsa_header is not None and self.lsa_header._has_data():
                                                        return True

                                                    if self.sham_link_id is not None:
                                                        return True

                                                    if self.virtual_link_id is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                    return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType']['meta_info']


                                            class UnknownLsaType(object):
                                                """
                                                Unknown LSA
                                                
                                                .. attribute:: interface_name
                                                
                                                	LSA interface name 
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                
                                                .. attribute:: is_sham_link
                                                
                                                	If true, it is a sham link 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_virtual_link
                                                
                                                	If true, it is a virtual link 
                                                	**type**\:  bool
                                                
                                                .. attribute:: lsa_detail
                                                
                                                	Detailed LSA information
                                                	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType.LsaDetail>`
                                                
                                                .. attribute:: lsa_header
                                                
                                                	Header information 
                                                	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType.LsaHeader>`
                                                
                                                .. attribute:: sham_link_id
                                                
                                                	Shamlink ID 
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: virtual_link_id
                                                
                                                	Virtual link ID 
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.interface_name = None
                                                    self.is_sham_link = None
                                                    self.is_virtual_link = None
                                                    self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType.LsaDetail()
                                                    self.lsa_detail.parent = self
                                                    self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType.LsaHeader()
                                                    self.lsa_header.parent = self
                                                    self.sham_link_id = None
                                                    self.virtual_link_id = None


                                                class LsaHeader(object):
                                                    """
                                                    Header information 
                                                    
                                                    .. attribute:: advertising_router
                                                    
                                                    	Router ID of Advertising Router
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: checksum
                                                    
                                                    	Checksum value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: is_do_not_age_lsa
                                                    
                                                    	If true, Do Not Age this LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_graceful_restart_active
                                                    
                                                    	If true, if grace restart is active 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: ls_id
                                                    
                                                    	LS ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: lsa_age
                                                    
                                                    	LSA's Age (s)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_area_id
                                                    
                                                    	Area ID in decimal or dotted\-decimal format
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..16
                                                    
                                                    .. attribute:: lsa_type
                                                    
                                                    	LSA type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: sequence_number
                                                    
                                                    	Current Sequence number
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.advertising_router = None
                                                        self.checksum = None
                                                        self.is_do_not_age_lsa = None
                                                        self.is_graceful_restart_active = None
                                                        self.ls_id = None
                                                        self.lsa_age = None
                                                        self.lsa_area_id = None
                                                        self.lsa_type = None
                                                        self.sequence_number = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-header'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.advertising_router is not None:
                                                            return True

                                                        if self.checksum is not None:
                                                            return True

                                                        if self.is_do_not_age_lsa is not None:
                                                            return True

                                                        if self.is_graceful_restart_active is not None:
                                                            return True

                                                        if self.ls_id is not None:
                                                            return True

                                                        if self.lsa_age is not None:
                                                            return True

                                                        if self.lsa_area_id is not None:
                                                            return True

                                                        if self.lsa_type is not None:
                                                            return True

                                                        if self.sequence_number is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                        return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType.LsaHeader']['meta_info']


                                                class LsaDetail(object):
                                                    """
                                                    Detailed LSA information
                                                    
                                                    .. attribute:: free_time
                                                    
                                                    	The amount of time since the last check was made to free this LSA (s)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_acknowledged
                                                    
                                                    	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_advertising_router_reachable
                                                    
                                                    	If true, Advertising Router is reachable
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_deleted
                                                    
                                                    	If true, flag is set to delete this LSA 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_flood_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_maximum_aged
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_neighbor_exchange
                                                    
                                                    	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_no_delete
                                                    
                                                    	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_nsr_ack_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_partial_spf
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_routing_bit
                                                    
                                                    	If true, Routing Bit set on the LSA
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_routing_table
                                                    
                                                    	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: lsa_flood_required_post_fail_over
                                                    
                                                    	LSA flood required after FO
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: lsa_length
                                                    
                                                    	Length of the LSA
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_sync_state
                                                    
                                                    	State of LSA sync with active
                                                    	**type**\:   :py:class:`OspfLsaSyncStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncStateEnum>`
                                                    
                                                    .. attribute:: minute_table_index
                                                    
                                                    	Minute table index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: nsr_flood_required
                                                    
                                                    	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: rate_limit
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: second_table_index
                                                    
                                                    	Second table index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.free_time = None
                                                        self.is_acknowledged = None
                                                        self.is_advertising_router_reachable = None
                                                        self.is_deleted = None
                                                        self.is_flood_pending = None
                                                        self.is_maximum_aged = None
                                                        self.is_neighbor_exchange = None
                                                        self.is_no_delete = None
                                                        self.is_nsr_ack_pending = None
                                                        self.is_partial_spf = None
                                                        self.is_routing_bit = None
                                                        self.is_routing_table = None
                                                        self.lsa_flood_required_post_fail_over = None
                                                        self.lsa_length = None
                                                        self.lsa_sync_state = None
                                                        self.minute_table_index = None
                                                        self.nsr_flood_required = None
                                                        self.rate_limit = None
                                                        self.second_table_index = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-detail'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.free_time is not None:
                                                            return True

                                                        if self.is_acknowledged is not None:
                                                            return True

                                                        if self.is_advertising_router_reachable is not None:
                                                            return True

                                                        if self.is_deleted is not None:
                                                            return True

                                                        if self.is_flood_pending is not None:
                                                            return True

                                                        if self.is_maximum_aged is not None:
                                                            return True

                                                        if self.is_neighbor_exchange is not None:
                                                            return True

                                                        if self.is_no_delete is not None:
                                                            return True

                                                        if self.is_nsr_ack_pending is not None:
                                                            return True

                                                        if self.is_partial_spf is not None:
                                                            return True

                                                        if self.is_routing_bit is not None:
                                                            return True

                                                        if self.is_routing_table is not None:
                                                            return True

                                                        if self.lsa_flood_required_post_fail_over is not None:
                                                            return True

                                                        if self.lsa_length is not None:
                                                            return True

                                                        if self.lsa_sync_state is not None:
                                                            return True

                                                        if self.minute_table_index is not None:
                                                            return True

                                                        if self.nsr_flood_required is not None:
                                                            return True

                                                        if self.rate_limit is not None:
                                                            return True

                                                        if self.second_table_index is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                        return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType.LsaDetail']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:unknown-lsa-type'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.interface_name is not None:
                                                        return True

                                                    if self.is_sham_link is not None:
                                                        return True

                                                    if self.is_virtual_link is not None:
                                                        return True

                                                    if self.lsa_detail is not None and self.lsa_detail._has_data():
                                                        return True

                                                    if self.lsa_header is not None and self.lsa_header._has_data():
                                                        return True

                                                    if self.sham_link_id is not None:
                                                        return True

                                                    if self.virtual_link_id is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                    return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-info'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.external_lsa_type is not None and self.external_lsa_type._has_data():
                                                    return True

                                                if self.grace_lsa is not None and self.grace_lsa._has_data():
                                                    return True

                                                if self.inter_area_prefix_lsa_type is not None and self.inter_area_prefix_lsa_type._has_data():
                                                    return True

                                                if self.inter_area_router_lsa_type is not None and self.inter_area_router_lsa_type._has_data():
                                                    return True

                                                if self.intra_area_prefix_lsa_type is not None and self.intra_area_prefix_lsa_type._has_data():
                                                    return True

                                                if self.link_lsa_type is not None and self.link_lsa_type._has_data():
                                                    return True

                                                if self.lsa_info_type is not None:
                                                    return True

                                                if self.lsa_summary_info is not None and self.lsa_summary_info._has_data():
                                                    return True

                                                if self.network_lsa_type is not None and self.network_lsa_type._has_data():
                                                    return True

                                                if self.nssalsa_type is not None and self.nssalsa_type._has_data():
                                                    return True

                                                if self.router_lsa_type is not None and self.router_lsa_type._has_data():
                                                    return True

                                                if self.unknown_area_lsa_type is not None and self.unknown_area_lsa_type._has_data():
                                                    return True

                                                if self.unknown_aslsa_type is not None and self.unknown_aslsa_type._has_data():
                                                    return True

                                                if self.unknown_link_lsa_type is not None and self.unknown_link_lsa_type._has_data():
                                                    return True

                                                if self.unknown_lsa_type is not None and self.unknown_lsa_type._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.advertising_router is not None:
                                                return True

                                            if self.area_id is not None:
                                                return True

                                            if self.interface_name is not None:
                                                return True

                                            if self.ls_id is not None:
                                                return True

                                            if self.ls_type is not None:
                                                return True

                                            if self.lsa_info is not None and self.lsa_info._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-internal-table'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.lsa is not None:
                                            for child_ref in self.lsa:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                        return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:database-table'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.lsa_internal_table is not None and self.lsa_internal_table._has_data():
                                        return True

                                    if self.lsa_table is not None and self.lsa_table._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                    return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable']['meta_info']


                            class DatabaseSummaryTable(object):
                                """
                                Database summary table
                                
                                .. attribute:: database_summary
                                
                                	Database Summary information
                                	**type**\:   :py:class:`DatabaseSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseSummaryTable.DatabaseSummary>`
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.database_summary = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseSummaryTable.DatabaseSummary()
                                    self.database_summary.parent = self


                                class DatabaseSummary(object):
                                    """
                                    Database Summary information
                                    
                                    .. attribute:: area_database
                                    
                                    	OSPFv3 Area Database list 
                                    	**type**\: list of    :py:class:`AreaDatabase <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseSummaryTable.DatabaseSummary.AreaDatabase>`
                                    
                                    .. attribute:: database_counters
                                    
                                    	OSPFv3 database counters 
                                    	**type**\:   :py:class:`DatabaseCounters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseSummaryTable.DatabaseSummary.DatabaseCounters>`
                                    
                                    .. attribute:: database_router_id
                                    
                                    	Database router ID 
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: is_opaque_database_capable
                                    
                                    	If true, opaque database is capable 
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.area_database = YList()
                                        self.area_database.parent = self
                                        self.area_database.name = 'area_database'
                                        self.database_counters = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseSummaryTable.DatabaseSummary.DatabaseCounters()
                                        self.database_counters.parent = self
                                        self.database_router_id = None
                                        self.is_opaque_database_capable = None


                                    class DatabaseCounters(object):
                                        """
                                        OSPFv3 database counters 
                                        
                                        .. attribute:: deleted_lsa
                                        
                                        	deleted lsa
                                        	**type**\:  list of int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: lsa
                                        
                                        	lsa
                                        	**type**\:  list of int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: lsa_checksum
                                        
                                        	lsa checksum
                                        	**type**\:  list of int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: max_age_lsa
                                        
                                        	max age lsa
                                        	**type**\:  list of int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.deleted_lsa = YLeafList()
                                            self.deleted_lsa.parent = self
                                            self.deleted_lsa.name = 'deleted_lsa'
                                            self.lsa = YLeafList()
                                            self.lsa.parent = self
                                            self.lsa.name = 'lsa'
                                            self.lsa_checksum = YLeafList()
                                            self.lsa_checksum.parent = self
                                            self.lsa_checksum.name = 'lsa_checksum'
                                            self.max_age_lsa = YLeafList()
                                            self.max_age_lsa.parent = self
                                            self.max_age_lsa.name = 'max_age_lsa'

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:database-counters'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.deleted_lsa is not None:
                                                for child in self.deleted_lsa:
                                                    if child is not None:
                                                        return True

                                            if self.lsa is not None:
                                                for child in self.lsa:
                                                    if child is not None:
                                                        return True

                                            if self.lsa_checksum is not None:
                                                for child in self.lsa_checksum:
                                                    if child is not None:
                                                        return True

                                            if self.max_age_lsa is not None:
                                                for child in self.max_age_lsa:
                                                    if child is not None:
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseSummaryTable.DatabaseSummary.DatabaseCounters']['meta_info']


                                    class AreaDatabase(object):
                                        """
                                        OSPFv3 Area Database list 
                                        
                                        .. attribute:: area_database_summary
                                        
                                        	Area database summary 
                                        	**type**\:   :py:class:`AreaDatabaseSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseSummaryTable.DatabaseSummary.AreaDatabase.AreaDatabaseSummary>`
                                        
                                        .. attribute:: lsa_area_id
                                        
                                        	Area ID in decimal or dotted\-decimal format
                                        	**type**\:  str
                                        
                                        	**length:** 0..16
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.area_database_summary = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseSummaryTable.DatabaseSummary.AreaDatabase.AreaDatabaseSummary()
                                            self.area_database_summary.parent = self
                                            self.lsa_area_id = None


                                        class AreaDatabaseSummary(object):
                                            """
                                            Area database summary 
                                            
                                            .. attribute:: deleted_lsa
                                            
                                            	deleted lsa
                                            	**type**\:  list of int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: lsa
                                            
                                            	lsa
                                            	**type**\:  list of int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: lsa_checksum
                                            
                                            	lsa checksum
                                            	**type**\:  list of int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: max_age_lsa
                                            
                                            	max age lsa
                                            	**type**\:  list of int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.deleted_lsa = YLeafList()
                                                self.deleted_lsa.parent = self
                                                self.deleted_lsa.name = 'deleted_lsa'
                                                self.lsa = YLeafList()
                                                self.lsa.parent = self
                                                self.lsa.name = 'lsa'
                                                self.lsa_checksum = YLeafList()
                                                self.lsa_checksum.parent = self
                                                self.lsa_checksum.name = 'lsa_checksum'
                                                self.max_age_lsa = YLeafList()
                                                self.max_age_lsa.parent = self
                                                self.max_age_lsa.name = 'max_age_lsa'

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:area-database-summary'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.deleted_lsa is not None:
                                                    for child in self.deleted_lsa:
                                                        if child is not None:
                                                            return True

                                                if self.lsa is not None:
                                                    for child in self.lsa:
                                                        if child is not None:
                                                            return True

                                                if self.lsa_checksum is not None:
                                                    for child in self.lsa_checksum:
                                                        if child is not None:
                                                            return True

                                                if self.max_age_lsa is not None:
                                                    for child in self.max_age_lsa:
                                                        if child is not None:
                                                            return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseSummaryTable.DatabaseSummary.AreaDatabase.AreaDatabaseSummary']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:area-database'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.area_database_summary is not None and self.area_database_summary._has_data():
                                                return True

                                            if self.lsa_area_id is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseSummaryTable.DatabaseSummary.AreaDatabase']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:database-summary'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.area_database is not None:
                                            for child_ref in self.area_database:
                                                if child_ref._has_data():
                                                    return True

                                        if self.database_counters is not None and self.database_counters._has_data():
                                            return True

                                        if self.database_router_id is not None:
                                            return True

                                        if self.is_opaque_database_capable is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                        return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseSummaryTable.DatabaseSummary']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:database-summary-table'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.database_summary is not None and self.database_summary._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                    return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseSummaryTable']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')
                                if self.area_id is None:
                                    raise YPYModelError('Key property area_id is None')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:area[Cisco-IOS-XR-ipv6-ospfv3-oper:area-id = ' + str(self.area_id) + ']'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.area_id is not None:
                                    return True

                                if self.database_summary_table is not None and self.database_summary_table._has_data():
                                    return True

                                if self.database_table is not None and self.database_table._has_data():
                                    return True

                                if self.flood_list_table is not None and self.flood_list_table._has_data():
                                    return True

                                if self.interface_brief_table is not None and self.interface_brief_table._has_data():
                                    return True

                                if self.interface_table is not None and self.interface_table._has_data():
                                    return True

                                if self.neighbor_detail_table is not None and self.neighbor_detail_table._has_data():
                                    return True

                                if self.neighbor_table is not None and self.neighbor_table._has_data():
                                    return True

                                if self.request_list_table is not None and self.request_list_table._has_data():
                                    return True

                                if self.retransmission_list_table is not None and self.retransmission_list_table._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:areas'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.area is not None:
                                for child_ref in self.area:
                                    if child_ref._has_data():
                                        return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                            return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Areas']['meta_info']


                    class InternalRoutes(object):
                        """
                        OSPFv3 internal route information table
                        
                        .. attribute:: internal_route
                        
                        	OSPFv3 internal route information
                        	**type**\: list of    :py:class:`InternalRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.InternalRoutes.InternalRoute>`
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.internal_route = YList()
                            self.internal_route.parent = self
                            self.internal_route.name = 'internal_route'


                        class InternalRoute(object):
                            """
                            OSPFv3 internal route information
                            
                            .. attribute:: prefix
                            
                            	Route prefix
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: prefix_length
                            
                            	Prefix length
                            	**type**\:  int
                            
                            	**range:** 0..128
                            
                            .. attribute:: route_area_id
                            
                            	Route area ID 
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: route_path
                            
                            	List of paths to this route
                            	**type**\: list of    :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.InternalRoutes.InternalRoute.RoutePath>`
                            
                            .. attribute:: route_source
                            
                            	List of topology source information
                            	**type**\: list of    :py:class:`RouteSource <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.InternalRoutes.InternalRoute.RouteSource>`
                            
                            .. attribute:: route_topology
                            
                            	Common Route topology information
                            	**type**\:   :py:class:`RouteTopology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.InternalRoutes.InternalRoute.RouteTopology>`
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.prefix = None
                                self.prefix_length = None
                                self.route_area_id = None
                                self.route_path = YList()
                                self.route_path.parent = self
                                self.route_path.name = 'route_path'
                                self.route_source = YList()
                                self.route_source.parent = self
                                self.route_source.name = 'route_source'
                                self.route_topology = Ospfv3.Processes.Process.Vrfs.Vrf.InternalRoutes.InternalRoute.RouteTopology()
                                self.route_topology.parent = self


                            class RouteTopology(object):
                                """
                                Common Route topology information
                                
                                .. attribute:: route_cost
                                
                                	Route cost 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: route_distance
                                
                                	Route distance 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: route_id
                                
                                	Route ID 
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: route_type
                                
                                	Route type
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.route_cost = None
                                    self.route_distance = None
                                    self.route_id = None
                                    self.route_type = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:route-topology'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.route_cost is not None:
                                        return True

                                    if self.route_distance is not None:
                                        return True

                                    if self.route_id is not None:
                                        return True

                                    if self.route_type is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                    return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.InternalRoutes.InternalRoute.RouteTopology']['meta_info']


                            class RouteSource(object):
                                """
                                List of topology source information
                                
                                .. attribute:: route_source_adversting_router
                                
                                	Route source of the advertising router 
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: route_source_id
                                
                                	Route source ID 
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: route_source_lsa_type
                                
                                	Type of LSA advertising the prefix, see RFC5340
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.route_source_adversting_router = None
                                    self.route_source_id = None
                                    self.route_source_lsa_type = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:route-source'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.route_source_adversting_router is not None:
                                        return True

                                    if self.route_source_id is not None:
                                        return True

                                    if self.route_source_lsa_type is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                    return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.InternalRoutes.InternalRoute.RouteSource']['meta_info']


                            class RoutePath(object):
                                """
                                List of paths to this route
                                
                                .. attribute:: interface_name
                                
                                	Route path interface name 
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: route_backup_path
                                
                                	Backup Path Info
                                	**type**\:   :py:class:`RouteBackupPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.InternalRoutes.InternalRoute.RoutePath.RouteBackupPath>`
                                
                                .. attribute:: route_path_id
                                
                                	Path ID of path
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: route_path_next_hop
                                
                                	Route path next hop 
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.interface_name = None
                                    self.route_backup_path = Ospfv3.Processes.Process.Vrfs.Vrf.InternalRoutes.InternalRoute.RoutePath.RouteBackupPath()
                                    self.route_backup_path.parent = self
                                    self.route_path_id = None
                                    self.route_path_next_hop = None


                                class RouteBackupPath(object):
                                    """
                                    Backup Path Info
                                    
                                    .. attribute:: backup_metric
                                    
                                    	Metric
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: backup_route_interface_name
                                    
                                    	Next hop Interface
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                    
                                    .. attribute:: backup_route_next_hop_address
                                    
                                    	Nexthop IP address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: backup_route_source
                                    
                                    	IP address of source of route
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: downstream
                                    
                                    	Downstream
                                    	**type**\:  bool
                                    
                                    .. attribute:: line_card_disjoint
                                    
                                    	Line Card Disjoint
                                    	**type**\:  bool
                                    
                                    .. attribute:: node_protect
                                    
                                    	Node Protect
                                    	**type**\:  bool
                                    
                                    .. attribute:: primary_path
                                    
                                    	Primary Path
                                    	**type**\:  bool
                                    
                                    .. attribute:: srlg_disjoint
                                    
                                    	SRLG Disjoint
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.backup_metric = None
                                        self.backup_route_interface_name = None
                                        self.backup_route_next_hop_address = None
                                        self.backup_route_source = None
                                        self.downstream = None
                                        self.line_card_disjoint = None
                                        self.node_protect = None
                                        self.primary_path = None
                                        self.srlg_disjoint = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:route-backup-path'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.backup_metric is not None:
                                            return True

                                        if self.backup_route_interface_name is not None:
                                            return True

                                        if self.backup_route_next_hop_address is not None:
                                            return True

                                        if self.backup_route_source is not None:
                                            return True

                                        if self.downstream is not None:
                                            return True

                                        if self.line_card_disjoint is not None:
                                            return True

                                        if self.node_protect is not None:
                                            return True

                                        if self.primary_path is not None:
                                            return True

                                        if self.srlg_disjoint is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                        return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.InternalRoutes.InternalRoute.RoutePath.RouteBackupPath']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:route-path'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.interface_name is not None:
                                        return True

                                    if self.route_backup_path is not None and self.route_backup_path._has_data():
                                        return True

                                    if self.route_path_id is not None:
                                        return True

                                    if self.route_path_next_hop is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                    return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.InternalRoutes.InternalRoute.RoutePath']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:internal-route'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.prefix is not None:
                                    return True

                                if self.prefix_length is not None:
                                    return True

                                if self.route_area_id is not None:
                                    return True

                                if self.route_path is not None:
                                    for child_ref in self.route_path:
                                        if child_ref._has_data():
                                            return True

                                if self.route_source is not None:
                                    for child_ref in self.route_source:
                                        if child_ref._has_data():
                                            return True

                                if self.route_topology is not None and self.route_topology._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.InternalRoutes.InternalRoute']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:internal-routes'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.internal_route is not None:
                                for child_ref in self.internal_route:
                                    if child_ref._has_data():
                                        return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                            return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.InternalRoutes']['meta_info']


                    class ProtocolAreas(object):
                        """
                        Protocol area table 
                        
                        .. attribute:: protocol_area
                        
                        	Area information 
                        	**type**\: list of    :py:class:`ProtocolArea <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.ProtocolAreas.ProtocolArea>`
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.protocol_area = YList()
                            self.protocol_area.parent = self
                            self.protocol_area.name = 'protocol_area'


                        class ProtocolArea(object):
                            """
                            Area information 
                            
                            .. attribute:: area_id  <key>
                            
                            	Area ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: distribute_list_in
                            
                            	Distribute List In
                            	**type**\:  str
                            
                            .. attribute:: protocol_area_id
                            
                            	Area ID string in decimal and dotted\-decimal format
                            	**type**\:  str
                            
                            	**length:** 0..16
                            
                            .. attribute:: protocol_interface
                            
                            	Interface list
                            	**type**\: list of    :py:class:`ProtocolInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.ProtocolAreas.ProtocolArea.ProtocolInterface>`
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.area_id = None
                                self.distribute_list_in = None
                                self.protocol_area_id = None
                                self.protocol_interface = YList()
                                self.protocol_interface.parent = self
                                self.protocol_interface.name = 'protocol_interface'


                            class ProtocolInterface(object):
                                """
                                Interface list
                                
                                .. attribute:: distribute_list_in
                                
                                	Distribute List In
                                	**type**\:  str
                                
                                .. attribute:: interface_name
                                
                                	Protocol interface name 
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.distribute_list_in = None
                                    self.interface_name = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:protocol-interface'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.distribute_list_in is not None:
                                        return True

                                    if self.interface_name is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                    return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.ProtocolAreas.ProtocolArea.ProtocolInterface']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')
                                if self.area_id is None:
                                    raise YPYModelError('Key property area_id is None')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:protocol-area[Cisco-IOS-XR-ipv6-ospfv3-oper:area-id = ' + str(self.area_id) + ']'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.area_id is not None:
                                    return True

                                if self.distribute_list_in is not None:
                                    return True

                                if self.protocol_area_id is not None:
                                    return True

                                if self.protocol_interface is not None:
                                    for child_ref in self.protocol_interface:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.ProtocolAreas.ProtocolArea']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:protocol-areas'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.protocol_area is not None:
                                for child_ref in self.protocol_area:
                                    if child_ref._has_data():
                                        return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                            return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.ProtocolAreas']['meta_info']


                    class ConnectedRoutes(object):
                        """
                        OSPFv3 connected route information table
                        
                        .. attribute:: connected_route
                        
                        	OSPFv3 connected route information
                        	**type**\: list of    :py:class:`ConnectedRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.ConnectedRoutes.ConnectedRoute>`
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.connected_route = YList()
                            self.connected_route.parent = self
                            self.connected_route.name = 'connected_route'


                        class ConnectedRoute(object):
                            """
                            OSPFv3 connected route information
                            
                            .. attribute:: prefix
                            
                            	Route prefix
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: prefix_length
                            
                            	Prefix length
                            	**type**\:  int
                            
                            	**range:** 0..128
                            
                            .. attribute:: route_path
                            
                            	List of paths to this route
                            	**type**\: list of    :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.ConnectedRoutes.ConnectedRoute.RoutePath>`
                            
                            .. attribute:: route_topology
                            
                            	Common Route topology information
                            	**type**\:   :py:class:`RouteTopology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.ConnectedRoutes.ConnectedRoute.RouteTopology>`
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.prefix = None
                                self.prefix_length = None
                                self.route_path = YList()
                                self.route_path.parent = self
                                self.route_path.name = 'route_path'
                                self.route_topology = Ospfv3.Processes.Process.Vrfs.Vrf.ConnectedRoutes.ConnectedRoute.RouteTopology()
                                self.route_topology.parent = self


                            class RouteTopology(object):
                                """
                                Common Route topology information
                                
                                .. attribute:: route_cost
                                
                                	Route cost 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: route_distance
                                
                                	Route distance 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: route_id
                                
                                	Route ID 
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: route_type
                                
                                	Route type
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.route_cost = None
                                    self.route_distance = None
                                    self.route_id = None
                                    self.route_type = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:route-topology'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.route_cost is not None:
                                        return True

                                    if self.route_distance is not None:
                                        return True

                                    if self.route_id is not None:
                                        return True

                                    if self.route_type is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                    return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.ConnectedRoutes.ConnectedRoute.RouteTopology']['meta_info']


                            class RoutePath(object):
                                """
                                List of paths to this route
                                
                                .. attribute:: interface_name
                                
                                	Route path interface name 
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: route_backup_path
                                
                                	Backup Path Info
                                	**type**\:   :py:class:`RouteBackupPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.ConnectedRoutes.ConnectedRoute.RoutePath.RouteBackupPath>`
                                
                                .. attribute:: route_path_id
                                
                                	Path ID of path
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: route_path_next_hop
                                
                                	Route path next hop 
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.interface_name = None
                                    self.route_backup_path = Ospfv3.Processes.Process.Vrfs.Vrf.ConnectedRoutes.ConnectedRoute.RoutePath.RouteBackupPath()
                                    self.route_backup_path.parent = self
                                    self.route_path_id = None
                                    self.route_path_next_hop = None


                                class RouteBackupPath(object):
                                    """
                                    Backup Path Info
                                    
                                    .. attribute:: backup_metric
                                    
                                    	Metric
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: backup_route_interface_name
                                    
                                    	Next hop Interface
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                    
                                    .. attribute:: backup_route_next_hop_address
                                    
                                    	Nexthop IP address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: backup_route_source
                                    
                                    	IP address of source of route
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: downstream
                                    
                                    	Downstream
                                    	**type**\:  bool
                                    
                                    .. attribute:: line_card_disjoint
                                    
                                    	Line Card Disjoint
                                    	**type**\:  bool
                                    
                                    .. attribute:: node_protect
                                    
                                    	Node Protect
                                    	**type**\:  bool
                                    
                                    .. attribute:: primary_path
                                    
                                    	Primary Path
                                    	**type**\:  bool
                                    
                                    .. attribute:: srlg_disjoint
                                    
                                    	SRLG Disjoint
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.backup_metric = None
                                        self.backup_route_interface_name = None
                                        self.backup_route_next_hop_address = None
                                        self.backup_route_source = None
                                        self.downstream = None
                                        self.line_card_disjoint = None
                                        self.node_protect = None
                                        self.primary_path = None
                                        self.srlg_disjoint = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:route-backup-path'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.backup_metric is not None:
                                            return True

                                        if self.backup_route_interface_name is not None:
                                            return True

                                        if self.backup_route_next_hop_address is not None:
                                            return True

                                        if self.backup_route_source is not None:
                                            return True

                                        if self.downstream is not None:
                                            return True

                                        if self.line_card_disjoint is not None:
                                            return True

                                        if self.node_protect is not None:
                                            return True

                                        if self.primary_path is not None:
                                            return True

                                        if self.srlg_disjoint is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                        return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.ConnectedRoutes.ConnectedRoute.RoutePath.RouteBackupPath']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:route-path'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.interface_name is not None:
                                        return True

                                    if self.route_backup_path is not None and self.route_backup_path._has_data():
                                        return True

                                    if self.route_path_id is not None:
                                        return True

                                    if self.route_path_next_hop is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                    return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.ConnectedRoutes.ConnectedRoute.RoutePath']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:connected-route'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.prefix is not None:
                                    return True

                                if self.prefix_length is not None:
                                    return True

                                if self.route_path is not None:
                                    for child_ref in self.route_path:
                                        if child_ref._has_data():
                                            return True

                                if self.route_topology is not None and self.route_topology._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.ConnectedRoutes.ConnectedRoute']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:connected-routes'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.connected_route is not None:
                                for child_ref in self.connected_route:
                                    if child_ref._has_data():
                                        return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                            return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.ConnectedRoutes']['meta_info']


                    class VrfStatistics(object):
                        """
                        Container for Statistics
                        
                        .. attribute:: prefix_priority_stats
                        
                        	OSPF Prefix SPF Prioritization statistics
                        	**type**\:   :py:class:`PrefixPriorityStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics.PrefixPriorityStats>`
                        
                        .. attribute:: protocol_stats
                        
                        	Protocol table
                        	**type**\:   :py:class:`ProtocolStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics.ProtocolStats>`
                        
                        .. attribute:: rawio_stats
                        
                        	OSPF Prefix SPF Prioritization statistics
                        	**type**\:   :py:class:`RawioStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics.RawioStats>`
                        
                        .. attribute:: spf_stats
                        
                        	OSPFv3 RIB batch statistics
                        	**type**\:   :py:class:`SpfStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics.SpfStats>`
                        
                        .. attribute:: vrf_rib_batch_stats
                        
                        	OSPFv3 RIB batch statistics
                        	**type**\:   :py:class:`VrfRibBatchStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics.VrfRibBatchStats>`
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.prefix_priority_stats = Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics.PrefixPriorityStats()
                            self.prefix_priority_stats.parent = self
                            self.protocol_stats = Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics.ProtocolStats()
                            self.protocol_stats.parent = self
                            self.rawio_stats = Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics.RawioStats()
                            self.rawio_stats.parent = self
                            self.spf_stats = Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics.SpfStats()
                            self.spf_stats.parent = self
                            self.vrf_rib_batch_stats = Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics.VrfRibBatchStats()
                            self.vrf_rib_batch_stats.parent = self


                        class ProtocolStats(object):
                            """
                            Protocol table
                            
                            .. attribute:: protocol_stat
                            
                            	Protocol statistics for an interface
                            	**type**\: list of    :py:class:`ProtocolStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics.ProtocolStats.ProtocolStat>`
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.protocol_stat = YList()
                                self.protocol_stat.parent = self
                                self.protocol_stat.name = 'protocol_stat'


                            class ProtocolStat(object):
                                """
                                Protocol statistics for an interface
                                
                                .. attribute:: interface_name  <key>
                                
                                	Interface name
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: checksum_err
                                
                                	Checksum Errors
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: dbdes_in_ls_as
                                
                                	Database Description LSAs in
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: dbdes_in_packets
                                
                                	Database Description Packets in
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: dbdes_out_ls_as
                                
                                	Database Description LSAs out
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: dbdes_out_packets
                                
                                	Database Description Packets out
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: dropped_in_gs
                                
                                	Dropped in GS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: hello_in_packets
                                
                                	Hello packets in
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: hello_out_packets
                                
                                	Hello Out Packets
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: ls_ack_in_ls_as
                                
                                	LS Ack LSAs in
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: ls_ack_in_packets
                                
                                	LS Acks Packets in
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: ls_ack_out_ls_as
                                
                                	LS Ack LSAs out
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: ls_ack_out_packets
                                
                                	LS Ack Packets out
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: ls_req_in_ls_as
                                
                                	LS Requests in
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: ls_req_in_packets
                                
                                	LSA Requests in
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: ls_req_out_ls_as
                                
                                	LS Reuqests LSAs out
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: ls_req_out_packets
                                
                                	LS Request Packets out
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: ls_upd_in_ignored
                                
                                	LS Updates ignored
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: ls_upd_in_ls_as
                                
                                	LS Updates LSAs in
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: ls_upd_in_packets
                                
                                	LS Updates Packets in
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: ls_upd_out_ls_as
                                
                                	LS Update LSAs out
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: ls_upd_out_packets
                                
                                	LS Update Packets out
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: total_in_packets
                                
                                	Total inputs packets
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: total_out_packets
                                
                                	Total Out Packets
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.interface_name = None
                                    self.checksum_err = None
                                    self.dbdes_in_ls_as = None
                                    self.dbdes_in_packets = None
                                    self.dbdes_out_ls_as = None
                                    self.dbdes_out_packets = None
                                    self.dropped_in_gs = None
                                    self.hello_in_packets = None
                                    self.hello_out_packets = None
                                    self.ls_ack_in_ls_as = None
                                    self.ls_ack_in_packets = None
                                    self.ls_ack_out_ls_as = None
                                    self.ls_ack_out_packets = None
                                    self.ls_req_in_ls_as = None
                                    self.ls_req_in_packets = None
                                    self.ls_req_out_ls_as = None
                                    self.ls_req_out_packets = None
                                    self.ls_upd_in_ignored = None
                                    self.ls_upd_in_ls_as = None
                                    self.ls_upd_in_packets = None
                                    self.ls_upd_out_ls_as = None
                                    self.ls_upd_out_packets = None
                                    self.total_in_packets = None
                                    self.total_out_packets = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')
                                    if self.interface_name is None:
                                        raise YPYModelError('Key property interface_name is None')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:protocol-stat[Cisco-IOS-XR-ipv6-ospfv3-oper:interface-name = ' + str(self.interface_name) + ']'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.interface_name is not None:
                                        return True

                                    if self.checksum_err is not None:
                                        return True

                                    if self.dbdes_in_ls_as is not None:
                                        return True

                                    if self.dbdes_in_packets is not None:
                                        return True

                                    if self.dbdes_out_ls_as is not None:
                                        return True

                                    if self.dbdes_out_packets is not None:
                                        return True

                                    if self.dropped_in_gs is not None:
                                        return True

                                    if self.hello_in_packets is not None:
                                        return True

                                    if self.hello_out_packets is not None:
                                        return True

                                    if self.ls_ack_in_ls_as is not None:
                                        return True

                                    if self.ls_ack_in_packets is not None:
                                        return True

                                    if self.ls_ack_out_ls_as is not None:
                                        return True

                                    if self.ls_ack_out_packets is not None:
                                        return True

                                    if self.ls_req_in_ls_as is not None:
                                        return True

                                    if self.ls_req_in_packets is not None:
                                        return True

                                    if self.ls_req_out_ls_as is not None:
                                        return True

                                    if self.ls_req_out_packets is not None:
                                        return True

                                    if self.ls_upd_in_ignored is not None:
                                        return True

                                    if self.ls_upd_in_ls_as is not None:
                                        return True

                                    if self.ls_upd_in_packets is not None:
                                        return True

                                    if self.ls_upd_out_ls_as is not None:
                                        return True

                                    if self.ls_upd_out_packets is not None:
                                        return True

                                    if self.total_in_packets is not None:
                                        return True

                                    if self.total_out_packets is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                    return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics.ProtocolStats.ProtocolStat']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:protocol-stats'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.protocol_stat is not None:
                                    for child_ref in self.protocol_stat:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics.ProtocolStats']['meta_info']


                        class SpfStats(object):
                            """
                            OSPFv3 RIB batch statistics
                            
                            .. attribute:: spf_header
                            
                            	SPF statistics header
                            	**type**\:   :py:class:`SpfHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics.SpfStats.SpfHeader>`
                            
                            .. attribute:: spf_runtime
                            
                            	List of SPF run\-time statistics
                            	**type**\: list of    :py:class:`SpfRuntime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics.SpfStats.SpfRuntime>`
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.spf_header = Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics.SpfStats.SpfHeader()
                                self.spf_header.parent = self
                                self.spf_runtime = YList()
                                self.spf_runtime.parent = self
                                self.spf_runtime.name = 'spf_runtime'


                            class SpfHeader(object):
                                """
                                SPF statistics header
                                
                                .. attribute:: area_summary
                                
                                	List of Areas with SPF statistics
                                	**type**\: list of    :py:class:`AreaSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics.SpfStats.SpfHeader.AreaSummary>`
                                
                                .. attribute:: header_router_id
                                
                                	Router ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: header_sp_fs
                                
                                	Number of SPF calculations
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.area_summary = YList()
                                    self.area_summary.parent = self
                                    self.area_summary.name = 'area_summary'
                                    self.header_router_id = None
                                    self.header_sp_fs = None


                                class AreaSummary(object):
                                    """
                                    List of Areas with SPF statistics
                                    
                                    .. attribute:: area_id
                                    
                                    	Area ID of the area SPF statistics
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sp_fs
                                    
                                    	Number of SPF calculations
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.area_id = None
                                        self.sp_fs = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:area-summary'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.area_id is not None:
                                            return True

                                        if self.sp_fs is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                        return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics.SpfStats.SpfHeader.AreaSummary']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:spf-header'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.area_summary is not None:
                                        for child_ref in self.area_summary:
                                            if child_ref._has_data():
                                                return True

                                    if self.header_router_id is not None:
                                        return True

                                    if self.header_sp_fs is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                    return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics.SpfStats.SpfHeader']['meta_info']


                            class SpfRuntime(object):
                                """
                                List of SPF run\-time statistics
                                
                                .. attribute:: area_stat
                                
                                	List of per\-area SPF statistics
                                	**type**\: list of    :py:class:`AreaStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics.SpfStats.SpfRuntime.AreaStat>`
                                
                                .. attribute:: global_time
                                
                                	Global SPF times
                                	**type**\:   :py:class:`GlobalTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics.SpfStats.SpfRuntime.GlobalTime>`
                                
                                .. attribute:: lsa
                                
                                	List of LSAs triggering the SPF calculation
                                	**type**\: list of    :py:class:`Lsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics.SpfStats.SpfRuntime.Lsa>`
                                
                                .. attribute:: lsa_changes
                                
                                	Number of LSA changes triggering an SPF calculation
                                	**type**\:  int
                                
                                	**range:** \-32768..32767
                                
                                .. attribute:: reason_flags
                                
                                	Reasons for triggering an SPF calculation Bit 1 \- Router LSA update Bit 2 \- Network LSA update Bit 3 \- Inter\-Area Prefix LSA update Bit 4 \- Inter\-Area Router LSA update Bit 5 \- AS External LSA update Bit 6 \- MOSPF LSA update Bit 7 \- Type 7 AS External LSA update Bit 8 \- Link LSA update Bit 9 \- Prefix LSA update
                                	**type**\:  str
                                
                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                
                                .. attribute:: rib_add_routes
                                
                                	Number of routes added to RIB
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rib_delete_routes
                                
                                	Number of routes deleted from RIB
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: start_time
                                
                                	SPF calculation start time
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.area_stat = YList()
                                    self.area_stat.parent = self
                                    self.area_stat.name = 'area_stat'
                                    self.global_time = Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics.SpfStats.SpfRuntime.GlobalTime()
                                    self.global_time.parent = self
                                    self.lsa = YList()
                                    self.lsa.parent = self
                                    self.lsa.name = 'lsa'
                                    self.lsa_changes = None
                                    self.reason_flags = None
                                    self.rib_add_routes = None
                                    self.rib_delete_routes = None
                                    self.start_time = None


                                class GlobalTime(object):
                                    """
                                    Global SPF times
                                    
                                    .. attribute:: dijkstra
                                    
                                    	Dijkstra time in msec
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: external_prefix
                                    
                                    	External prefix processing time in msec
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: external_prefix_del
                                    
                                    	External prefix deletion time in msec
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: inter_prefix
                                    
                                    	Inter\-prefix processing time in msec
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: inter_prefix_del
                                    
                                    	Intra\-prefix deletion time in msec
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: intra_prefix
                                    
                                    	Intra\-prefix processing time in msec
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: intra_prefix_del
                                    
                                    	Intra\-prefix deletion time in msec
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rib_add
                                    
                                    	RIB add processing time in msec
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rib_del
                                    
                                    	RIB deletion time in msec
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.dijkstra = None
                                        self.external_prefix = None
                                        self.external_prefix_del = None
                                        self.inter_prefix = None
                                        self.inter_prefix_del = None
                                        self.intra_prefix = None
                                        self.intra_prefix_del = None
                                        self.rib_add = None
                                        self.rib_del = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:global-time'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.dijkstra is not None:
                                            return True

                                        if self.external_prefix is not None:
                                            return True

                                        if self.external_prefix_del is not None:
                                            return True

                                        if self.inter_prefix is not None:
                                            return True

                                        if self.inter_prefix_del is not None:
                                            return True

                                        if self.intra_prefix is not None:
                                            return True

                                        if self.intra_prefix_del is not None:
                                            return True

                                        if self.rib_add is not None:
                                            return True

                                        if self.rib_del is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                        return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics.SpfStats.SpfRuntime.GlobalTime']['meta_info']


                                class Lsa(object):
                                    """
                                    List of LSAs triggering the SPF calculation
                                    
                                    .. attribute:: lsa_advertising_router
                                    
                                    	Advertising router ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: lsa_area_id
                                    
                                    	Area ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: lsa_flush
                                    
                                    	If true, the LSA change is a flush
                                    	**type**\:  bool
                                    
                                    .. attribute:: lsa_id
                                    
                                    	LSA ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: lsa_type
                                    
                                    	LSA type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.lsa_advertising_router = None
                                        self.lsa_area_id = None
                                        self.lsa_flush = None
                                        self.lsa_id = None
                                        self.lsa_type = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.lsa_advertising_router is not None:
                                            return True

                                        if self.lsa_area_id is not None:
                                            return True

                                        if self.lsa_flush is not None:
                                            return True

                                        if self.lsa_id is not None:
                                            return True

                                        if self.lsa_type is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                        return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics.SpfStats.SpfRuntime.Lsa']['meta_info']


                                class AreaStat(object):
                                    """
                                    List of per\-area SPF statistics
                                    
                                    .. attribute:: spf_stat_area_id
                                    
                                    	Area ID for area of these SPF statistics
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: spf_stat_lsa_type_count
                                    
                                    	Counts of LSA types triggering an SPF calculation
                                    	**type**\:  list of int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: spf_stat_time
                                    
                                    	SPF time calculations
                                    	**type**\:   :py:class:`SpfStatTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics.SpfStats.SpfRuntime.AreaStat.SpfStatTime>`
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.spf_stat_area_id = None
                                        self.spf_stat_lsa_type_count = YLeafList()
                                        self.spf_stat_lsa_type_count.parent = self
                                        self.spf_stat_lsa_type_count.name = 'spf_stat_lsa_type_count'
                                        self.spf_stat_time = Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics.SpfStats.SpfRuntime.AreaStat.SpfStatTime()
                                        self.spf_stat_time.parent = self


                                    class SpfStatTime(object):
                                        """
                                        SPF time calculations
                                        
                                        .. attribute:: dijkstra
                                        
                                        	Dijkstra time in msec
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: external_prefix
                                        
                                        	External prefix processing time in msec
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: external_prefix_del
                                        
                                        	External prefix deletion time in msec
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: inter_prefix
                                        
                                        	Inter\-prefix processing time in msec
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: inter_prefix_del
                                        
                                        	Intra\-prefix deletion time in msec
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: intra_prefix
                                        
                                        	Intra\-prefix processing time in msec
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: intra_prefix_del
                                        
                                        	Intra\-prefix deletion time in msec
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_add
                                        
                                        	RIB add processing time in msec
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_del
                                        
                                        	RIB deletion time in msec
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.dijkstra = None
                                            self.external_prefix = None
                                            self.external_prefix_del = None
                                            self.inter_prefix = None
                                            self.inter_prefix_del = None
                                            self.intra_prefix = None
                                            self.intra_prefix_del = None
                                            self.rib_add = None
                                            self.rib_del = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:spf-stat-time'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.dijkstra is not None:
                                                return True

                                            if self.external_prefix is not None:
                                                return True

                                            if self.external_prefix_del is not None:
                                                return True

                                            if self.inter_prefix is not None:
                                                return True

                                            if self.inter_prefix_del is not None:
                                                return True

                                            if self.intra_prefix is not None:
                                                return True

                                            if self.intra_prefix_del is not None:
                                                return True

                                            if self.rib_add is not None:
                                                return True

                                            if self.rib_del is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics.SpfStats.SpfRuntime.AreaStat.SpfStatTime']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:area-stat'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.spf_stat_area_id is not None:
                                            return True

                                        if self.spf_stat_lsa_type_count is not None:
                                            for child in self.spf_stat_lsa_type_count:
                                                if child is not None:
                                                    return True

                                        if self.spf_stat_time is not None and self.spf_stat_time._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                        return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics.SpfStats.SpfRuntime.AreaStat']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:spf-runtime'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.area_stat is not None:
                                        for child_ref in self.area_stat:
                                            if child_ref._has_data():
                                                return True

                                    if self.global_time is not None and self.global_time._has_data():
                                        return True

                                    if self.lsa is not None:
                                        for child_ref in self.lsa:
                                            if child_ref._has_data():
                                                return True

                                    if self.lsa_changes is not None:
                                        return True

                                    if self.reason_flags is not None:
                                        return True

                                    if self.rib_add_routes is not None:
                                        return True

                                    if self.rib_delete_routes is not None:
                                        return True

                                    if self.start_time is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                    return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics.SpfStats.SpfRuntime']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:spf-stats'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.spf_header is not None and self.spf_header._has_data():
                                    return True

                                if self.spf_runtime is not None:
                                    for child_ref in self.spf_runtime:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics.SpfStats']['meta_info']


                        class RawioStats(object):
                            """
                            OSPF Prefix SPF Prioritization statistics
                            
                            .. attribute:: in_bytes
                            
                            	Received Bytes
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: byte
                            
                            .. attribute:: in_error_drops
                            
                            	In Error Drops
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: in_handle_drops
                            
                            	In Handle Drops
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: in_ipsec_drops
                            
                            	In IPSEC Drops
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: in_long_packets
                            
                            	Received Long Packets
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: in_malloc_drops
                            
                            	In Malloc Drops
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: in_packets
                            
                            	Received Packets
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: in_queue_drops
                            
                            	In Queue Drops
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: in_short_drops
                            
                            	In Short Drops
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: out_bytes
                            
                            	Sent Bytes
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: byte
                            
                            .. attribute:: out_error_drops
                            
                            	Error Drops
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: out_ipsec_drops
                            
                            	Out IPSEC Drops
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: out_nofd_drops
                            
                            	No FileDescriptor Drops
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: out_nopak_drops
                            
                            	No Packet Buffers
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: out_packets
                            
                            	Packets Sent
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: out_pakapi_errors
                            
                            	PAK API Errors
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: raw_conn_close
                            
                            	Raw Connections Close
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: raw_conn_error
                            
                            	Raw Connections Error
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: raw_conn_open
                            
                            	Raw Connections Open
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: raw_conn_state
                            
                            	Raw Connection State
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.in_bytes = None
                                self.in_error_drops = None
                                self.in_handle_drops = None
                                self.in_ipsec_drops = None
                                self.in_long_packets = None
                                self.in_malloc_drops = None
                                self.in_packets = None
                                self.in_queue_drops = None
                                self.in_short_drops = None
                                self.out_bytes = None
                                self.out_error_drops = None
                                self.out_ipsec_drops = None
                                self.out_nofd_drops = None
                                self.out_nopak_drops = None
                                self.out_packets = None
                                self.out_pakapi_errors = None
                                self.raw_conn_close = None
                                self.raw_conn_error = None
                                self.raw_conn_open = None
                                self.raw_conn_state = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:rawio-stats'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.in_bytes is not None:
                                    return True

                                if self.in_error_drops is not None:
                                    return True

                                if self.in_handle_drops is not None:
                                    return True

                                if self.in_ipsec_drops is not None:
                                    return True

                                if self.in_long_packets is not None:
                                    return True

                                if self.in_malloc_drops is not None:
                                    return True

                                if self.in_packets is not None:
                                    return True

                                if self.in_queue_drops is not None:
                                    return True

                                if self.in_short_drops is not None:
                                    return True

                                if self.out_bytes is not None:
                                    return True

                                if self.out_error_drops is not None:
                                    return True

                                if self.out_ipsec_drops is not None:
                                    return True

                                if self.out_nofd_drops is not None:
                                    return True

                                if self.out_nopak_drops is not None:
                                    return True

                                if self.out_packets is not None:
                                    return True

                                if self.out_pakapi_errors is not None:
                                    return True

                                if self.raw_conn_close is not None:
                                    return True

                                if self.raw_conn_error is not None:
                                    return True

                                if self.raw_conn_open is not None:
                                    return True

                                if self.raw_conn_state is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics.RawioStats']['meta_info']


                        class PrefixPriorityStats(object):
                            """
                            OSPF Prefix SPF Prioritization statistics
                            
                            .. attribute:: critical
                            
                            	Critical priority classifications
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: high
                            
                            	High priority classifications
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: low
                            
                            	Low priority classifications
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: medium
                            
                            	Medium priority classifications
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.critical = None
                                self.high = None
                                self.low = None
                                self.medium = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:prefix-priority-stats'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.critical is not None:
                                    return True

                                if self.high is not None:
                                    return True

                                if self.low is not None:
                                    return True

                                if self.medium is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics.PrefixPriorityStats']['meta_info']


                        class VrfRibBatchStats(object):
                            """
                            OSPFv3 RIB batch statistics
                            
                            .. attribute:: batches_sent
                            
                            	No. of RIB batches sent
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: max_routes
                            
                            	Max No. of Routes in a batch
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: paths_add
                            
                            	No. of paths added to RIB
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: paths_add_errs
                            
                            	No. of paths add errors
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: paths_del
                            
                            	No. of paths del sent to RIB
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: paths_del_errs
                            
                            	No. of Paths del errors
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: paths_pending
                            
                            	No. of paths waiting to be sent to RIB
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: paths_sent
                            
                            	No. of Paths sent to RIB
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: routes_pending
                            
                            	No of Pending Routes
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: routes_sent
                            
                            	No. of Routes sent to RIB
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.batches_sent = None
                                self.max_routes = None
                                self.paths_add = None
                                self.paths_add_errs = None
                                self.paths_del = None
                                self.paths_del_errs = None
                                self.paths_pending = None
                                self.paths_sent = None
                                self.routes_pending = None
                                self.routes_sent = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:vrf-rib-batch-stats'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.batches_sent is not None:
                                    return True

                                if self.max_routes is not None:
                                    return True

                                if self.paths_add is not None:
                                    return True

                                if self.paths_add_errs is not None:
                                    return True

                                if self.paths_del is not None:
                                    return True

                                if self.paths_del_errs is not None:
                                    return True

                                if self.paths_pending is not None:
                                    return True

                                if self.paths_sent is not None:
                                    return True

                                if self.routes_pending is not None:
                                    return True

                                if self.routes_sent is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics.VrfRibBatchStats']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:vrf-statistics'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.prefix_priority_stats is not None and self.prefix_priority_stats._has_data():
                                return True

                            if self.protocol_stats is not None and self.protocol_stats._has_data():
                                return True

                            if self.rawio_stats is not None and self.rawio_stats._has_data():
                                return True

                            if self.spf_stats is not None and self.spf_stats._has_data():
                                return True

                            if self.vrf_rib_batch_stats is not None and self.vrf_rib_batch_stats._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                            return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics']['meta_info']


                    class Summary(object):
                        """
                        OSPFv3 summary
                        
                        .. attribute:: ospfv3
                        
                        	OSPFv3 summary
                        	**type**\:   :py:class:`Ospfv3_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Ospfv3_>`
                        
                        .. attribute:: protocol
                        
                        	OSPFv3 protocol summary
                        	**type**\:   :py:class:`Protocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Protocol>`
                        
                        .. attribute:: route
                        
                        	OSPFv3 route summary
                        	**type**\:   :py:class:`Route <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Route>`
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.ospfv3 = Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Ospfv3_()
                            self.ospfv3.parent = self
                            self.protocol = Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Protocol()
                            self.protocol.parent = self
                            self.route = Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Route()
                            self.route.parent = self


                        class Protocol(object):
                            """
                            OSPFv3 protocol summary
                            
                            .. attribute:: administrative_distance
                            
                            	Administrative distance
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: administrative_distance_external
                            
                            	Administrative Distance for External routes
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: administrative_distance_inter_area
                            
                            	Administrative Distance for Inter Area routes
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: distribute_list_in
                            
                            	Distribute List In
                            	**type**\:  str
                            
                            .. attribute:: is_graceful_restart
                            
                            	If true, Graceful restart is enabled 
                            	**type**\:  bool
                            
                            .. attribute:: protocol_router_id
                            
                            	Protocol router ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.administrative_distance = None
                                self.administrative_distance_external = None
                                self.administrative_distance_inter_area = None
                                self.distribute_list_in = None
                                self.is_graceful_restart = None
                                self.protocol_router_id = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:protocol'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.administrative_distance is not None:
                                    return True

                                if self.administrative_distance_external is not None:
                                    return True

                                if self.administrative_distance_inter_area is not None:
                                    return True

                                if self.distribute_list_in is not None:
                                    return True

                                if self.is_graceful_restart is not None:
                                    return True

                                if self.protocol_router_id is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Protocol']['meta_info']


                        class Ospfv3_(object):
                            """
                            OSPFv3 summary
                            
                            .. attribute:: areas
                            
                            	Number of areas
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: as_dc_bitless_ls_as
                            
                            	Number of external and AS opaque LSAs with demand circut bit not set
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: as_do_not_age_ls_as
                            
                            	Number of external and AS opaque LSAs with do not age set 
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: as_ls_as
                            
                            	Number of AS scope LSAs
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: as_lsa_flood_list_length
                            
                            	Length of AS LSAs flood list
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: context_name
                            
                            	Context name
                            	**type**\:  str
                            
                            	**length:** 0..32
                            
                            .. attribute:: default_metric
                            
                            	Default metric 
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: default_metric_type
                            
                            	Default metric type 
                            	**type**\:   :py:class:`Ospfv3DefaultMetricEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3DefaultMetricEnum>`
                            
                            .. attribute:: default_policy_name
                            
                            	Default policy name 
                            	**type**\:  str
                            
                            .. attribute:: default_tag
                            
                            	Default tag 
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: domain_id
                            
                            	Domain ID information
                            	**type**\:   :py:class:`DomainId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Ospfv3_.DomainId>`
                            
                            .. attribute:: grace_resync_time
                            
                            	Grace time to resync 
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: graceful_shutdown_state
                            
                            	Graceful shutdown state
                            	**type**\:   :py:class:`Ospfv3GracefulShutdownStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3GracefulShutdownStateEnum>`
                            
                            .. attribute:: ipfrr_tiebreakers
                            
                            	IPFRR\-Tiebreakers list
                            	**type**\: list of    :py:class:`IpfrrTiebreakers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Ospfv3_.IpfrrTiebreakers>`
                            
                            .. attribute:: is_area_border_router
                            
                            	If true, is an area border router
                            	**type**\:  bool
                            
                            .. attribute:: is_as_border_router
                            
                            	If true, is an AS border router
                            	**type**\:  bool
                            
                            .. attribute:: is_auto_cost
                            
                            	If true, auto cost is enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_default_always
                            
                            	If true, default always 
                            	**type**\:  bool
                            
                            .. attribute:: is_default_originated
                            
                            	If true, origin is by default 
                            	**type**\:  bool
                            
                            .. attribute:: is_default_policy
                            
                            	If true, is a default policy 
                            	**type**\:  bool
                            
                            .. attribute:: is_grace_restart_enabled
                            
                            	If true, grace restart is enabled 
                            	**type**\:  bool
                            
                            .. attribute:: is_nsr_enabled
                            
                            	If true, NSR is enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_nsr_switchover_on_restart
                            
                            	Trigger RP Switchover on detectable process restart
                            	**type**\:  bool
                            
                            .. attribute:: is_opaque_capable
                            
                            	Opaque LSA capable 
                            	**type**\:  bool
                            
                            .. attribute:: is_role_standby
                            
                            	If true, the process is running as stanby role
                            	**type**\:  bool
                            
                            .. attribute:: is_router_id_stalled
                            
                            	Stalled Router ID 
                            	**type**\:  bool
                            
                            .. attribute:: last_nsf_time
                            
                            	 Length of time since the last NSF (s)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: lsa_flood_pacing_interval
                            
                            	LSA flood pacing timer (ms)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: lsa_group_interval
                            
                            	LSA refresh interval (sec)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: lsa_hold_time
                            
                            	Second delay before generating next LSA (ms)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: lsa_maximum_time
                            
                            	Maximum delay before generating an LSA (ms)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: lsa_retransmission_pacing_interval
                            
                            	LSA retransmission pacing timer (ms)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: lsa_start_time
                            
                            	Initial LSA throttle delay (ms)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: maximum_interfaces
                            
                            	Maximum number of interfaces
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: maximum_paths
                            
                            	Maximum number of paths
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: metric
                            
                            	Redistribution metric 
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: minimum_lsa_interval
                            
                            	Minimum time between LSA regeneration (ms)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: normal_areas
                            
                            	Number of normal areas
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: nssa_areas
                            
                            	Number of NSSA areas
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: opaque_lsa_checksum
                            
                            	Sum of opaque LSA checksum
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: opaque_lsas
                            
                            	Number of opaque LSAs
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: redistribution_limit
                            
                            	The number of redistributed prefixes allowed
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: redistribution_threshold
                            
                            	When the number of redistributed prefixes reaches this threshold, a warning message is issued 
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: reference_bandwidth
                            
                            	Reference Bandwdith
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: role
                            
                            	Role, V1/V2 Active/Standby
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: router_id
                            
                            	Router ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: snmp_trap_enabled
                            
                            	If true, snmp trap is enabled
                            	**type**\:  bool
                            
                            .. attribute:: spf_hold_time
                            
                            	Minimum delay time between SPF runs (ms)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: spf_maximum_time
                            
                            	Maximum delay time between SPF runs (ms)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: spf_start_time
                            
                            	Scheduling delay for SPF (ms)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: stub_areas
                            
                            	Number of stub and total stub areas
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: stub_router
                            
                            	Stub Router Information
                            	**type**\: list of    :py:class:`StubRouter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Ospfv3_.StubRouter>`
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.areas = None
                                self.as_dc_bitless_ls_as = None
                                self.as_do_not_age_ls_as = None
                                self.as_ls_as = None
                                self.as_lsa_flood_list_length = None
                                self.context_name = None
                                self.default_metric = None
                                self.default_metric_type = None
                                self.default_policy_name = None
                                self.default_tag = None
                                self.domain_id = Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Ospfv3_.DomainId()
                                self.domain_id.parent = self
                                self.grace_resync_time = None
                                self.graceful_shutdown_state = None
                                self.ipfrr_tiebreakers = YList()
                                self.ipfrr_tiebreakers.parent = self
                                self.ipfrr_tiebreakers.name = 'ipfrr_tiebreakers'
                                self.is_area_border_router = None
                                self.is_as_border_router = None
                                self.is_auto_cost = None
                                self.is_default_always = None
                                self.is_default_originated = None
                                self.is_default_policy = None
                                self.is_grace_restart_enabled = None
                                self.is_nsr_enabled = None
                                self.is_nsr_switchover_on_restart = None
                                self.is_opaque_capable = None
                                self.is_role_standby = None
                                self.is_router_id_stalled = None
                                self.last_nsf_time = None
                                self.lsa_flood_pacing_interval = None
                                self.lsa_group_interval = None
                                self.lsa_hold_time = None
                                self.lsa_maximum_time = None
                                self.lsa_retransmission_pacing_interval = None
                                self.lsa_start_time = None
                                self.maximum_interfaces = None
                                self.maximum_paths = None
                                self.metric = None
                                self.minimum_lsa_interval = None
                                self.normal_areas = None
                                self.nssa_areas = None
                                self.opaque_lsa_checksum = None
                                self.opaque_lsas = None
                                self.redistribution_limit = None
                                self.redistribution_threshold = None
                                self.reference_bandwidth = None
                                self.role = None
                                self.router_id = None
                                self.snmp_trap_enabled = None
                                self.spf_hold_time = None
                                self.spf_maximum_time = None
                                self.spf_start_time = None
                                self.stub_areas = None
                                self.stub_router = YList()
                                self.stub_router.parent = self
                                self.stub_router.name = 'stub_router'


                            class DomainId(object):
                                """
                                Domain ID information
                                
                                .. attribute:: primary_domain_id
                                
                                	Primary Domain ID
                                	**type**\:   :py:class:`PrimaryDomainId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Ospfv3_.DomainId.PrimaryDomainId>`
                                
                                .. attribute:: secondary_domain_id
                                
                                	List of secondary domain IDs
                                	**type**\: list of    :py:class:`SecondaryDomainId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Ospfv3_.DomainId.SecondaryDomainId>`
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.primary_domain_id = Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Ospfv3_.DomainId.PrimaryDomainId()
                                    self.primary_domain_id.parent = self
                                    self.secondary_domain_id = YList()
                                    self.secondary_domain_id.parent = self
                                    self.secondary_domain_id.name = 'secondary_domain_id'


                                class PrimaryDomainId(object):
                                    """
                                    Primary Domain ID
                                    
                                    .. attribute:: domain_id_type
                                    
                                    	Domain ID Type
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: domain_id_value
                                    
                                    	Domain ID value
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.domain_id_type = None
                                        self.domain_id_value = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:primary-domain-id'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.domain_id_type is not None:
                                            return True

                                        if self.domain_id_value is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                        return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Ospfv3_.DomainId.PrimaryDomainId']['meta_info']


                                class SecondaryDomainId(object):
                                    """
                                    List of secondary domain IDs
                                    
                                    .. attribute:: domain_id_type
                                    
                                    	Domain ID Type
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: domain_id_value
                                    
                                    	Domain ID value
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.domain_id_type = None
                                        self.domain_id_value = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:secondary-domain-id'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.domain_id_type is not None:
                                            return True

                                        if self.domain_id_value is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                        return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Ospfv3_.DomainId.SecondaryDomainId']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:domain-id'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.primary_domain_id is not None and self.primary_domain_id._has_data():
                                        return True

                                    if self.secondary_domain_id is not None:
                                        for child_ref in self.secondary_domain_id:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                    return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Ospfv3_.DomainId']['meta_info']


                            class StubRouter(object):
                                """
                                Stub Router Information
                                
                                .. attribute:: abr_off_reason
                                
                                	Reason for being in ABR off mode
                                	**type**\:   :py:class:`StubRouterAbrOffReasonEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.StubRouterAbrOffReasonEnum>`
                                
                                .. attribute:: abr_resume_time
                                
                                	Timestamp (relative to 1970/1/1 00\:00) when ABR duties were resumed
                                	**type**\:   :py:class:`AbrResumeTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Ospfv3_.StubRouter.AbrResumeTime>`
                                
                                .. attribute:: active
                                
                                	If true, stub router mode is active
                                	**type**\:  bool
                                
                                .. attribute:: external_lsa_metric
                                
                                	Metric for external LSAs in max\-metric mode
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: include_stub_links
                                
                                	If true, advertise maximum metric for stub links
                                	**type**\:  bool
                                
                                .. attribute:: mode
                                
                                	Stub router mode
                                	**type**\:   :py:class:`StubRouterModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.StubRouterModeEnum>`
                                
                                .. attribute:: remaining_time
                                
                                	Remaining time (in seconds) in stub router mode
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: set_reason
                                
                                	Reason for entering stub router mode
                                	**type**\:   :py:class:`StubRouterTriggerEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.StubRouterTriggerEnum>`
                                
                                .. attribute:: start_time
                                
                                	Timestamp (relative to 1970/1/1 00\:00) when stub router mode was activated
                                	**type**\:   :py:class:`StartTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Ospfv3_.StubRouter.StartTime>`
                                
                                .. attribute:: summary_lsa_metric
                                
                                	Metric for summary LSAs in max\-metric mode
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: trigger
                                
                                	Triggers for entering stub router mode
                                	**type**\: list of    :py:class:`Trigger <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Ospfv3_.StubRouter.Trigger>`
                                
                                .. attribute:: unset_reason
                                
                                	Reason for clearing stub router condition
                                	**type**\:   :py:class:`StubRouterExitReasonEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.StubRouterExitReasonEnum>`
                                
                                .. attribute:: unset_time
                                
                                	Timestamp (relative to 1970/1/1 00\:00) when stub router condition was cleared
                                	**type**\:   :py:class:`UnsetTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Ospfv3_.StubRouter.UnsetTime>`
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.abr_off_reason = None
                                    self.abr_resume_time = Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Ospfv3_.StubRouter.AbrResumeTime()
                                    self.abr_resume_time.parent = self
                                    self.active = None
                                    self.external_lsa_metric = None
                                    self.include_stub_links = None
                                    self.mode = None
                                    self.remaining_time = None
                                    self.set_reason = None
                                    self.start_time = Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Ospfv3_.StubRouter.StartTime()
                                    self.start_time.parent = self
                                    self.summary_lsa_metric = None
                                    self.trigger = YList()
                                    self.trigger.parent = self
                                    self.trigger.name = 'trigger'
                                    self.unset_reason = None
                                    self.unset_time = Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Ospfv3_.StubRouter.UnsetTime()
                                    self.unset_time.parent = self


                                class UnsetTime(object):
                                    """
                                    Timestamp (relative to 1970/1/1 00\:00) when stub
                                    router condition was cleared
                                    
                                    .. attribute:: nanosecond
                                    
                                    	Nano seconds 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: nanosecond
                                    
                                    .. attribute:: second
                                    
                                    	Seconds 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.nanosecond = None
                                        self.second = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:unset-time'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.nanosecond is not None:
                                            return True

                                        if self.second is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                        return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Ospfv3_.StubRouter.UnsetTime']['meta_info']


                                class StartTime(object):
                                    """
                                    Timestamp (relative to 1970/1/1 00\:00) when stub
                                    router mode was activated
                                    
                                    .. attribute:: nanosecond
                                    
                                    	Nano seconds 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: nanosecond
                                    
                                    .. attribute:: second
                                    
                                    	Seconds 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.nanosecond = None
                                        self.second = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:start-time'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.nanosecond is not None:
                                            return True

                                        if self.second is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                        return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Ospfv3_.StubRouter.StartTime']['meta_info']


                                class AbrResumeTime(object):
                                    """
                                    Timestamp (relative to 1970/1/1 00\:00) when ABR
                                    duties were resumed
                                    
                                    .. attribute:: nanosecond
                                    
                                    	Nano seconds 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: nanosecond
                                    
                                    .. attribute:: second
                                    
                                    	Seconds 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.nanosecond = None
                                        self.second = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:abr-resume-time'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.nanosecond is not None:
                                            return True

                                        if self.second is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                        return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Ospfv3_.StubRouter.AbrResumeTime']['meta_info']


                                class Trigger(object):
                                    """
                                    Triggers for entering stub router mode
                                    
                                    .. attribute:: start_time
                                    
                                    	Timestamp (relative to 1970/1/1 00\:00) when stub router mode was activated
                                    	**type**\:   :py:class:`StartTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Ospfv3_.StubRouter.Trigger.StartTime>`
                                    
                                    .. attribute:: time
                                    
                                    	Time (in seconds) to stay in stub router mode
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: trigger
                                    
                                    	Stub Router Trigger type
                                    	**type**\:   :py:class:`StubRouterTriggerEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.StubRouterTriggerEnum>`
                                    
                                    .. attribute:: unset_reason
                                    
                                    	Reason for clearing stub router condition
                                    	**type**\:   :py:class:`StubRouterExitReasonEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.StubRouterExitReasonEnum>`
                                    
                                    .. attribute:: unset_time
                                    
                                    	Timestamp (relative to 1970/1/1 00\:00) when stub router condition was cleared
                                    	**type**\:   :py:class:`UnsetTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Ospfv3_.StubRouter.Trigger.UnsetTime>`
                                    
                                    .. attribute:: wait_for_bgp
                                    
                                    	If true, stub router is terminated when BGP converges
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.start_time = Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Ospfv3_.StubRouter.Trigger.StartTime()
                                        self.start_time.parent = self
                                        self.time = None
                                        self.trigger = None
                                        self.unset_reason = None
                                        self.unset_time = Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Ospfv3_.StubRouter.Trigger.UnsetTime()
                                        self.unset_time.parent = self
                                        self.wait_for_bgp = None


                                    class UnsetTime(object):
                                        """
                                        Timestamp (relative to 1970/1/1 00\:00) when stub
                                        router condition was cleared
                                        
                                        .. attribute:: nanosecond
                                        
                                        	Nano seconds 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: second
                                        
                                        	Seconds 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.nanosecond = None
                                            self.second = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:unset-time'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.nanosecond is not None:
                                                return True

                                            if self.second is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Ospfv3_.StubRouter.Trigger.UnsetTime']['meta_info']


                                    class StartTime(object):
                                        """
                                        Timestamp (relative to 1970/1/1 00\:00) when stub
                                        router mode was activated
                                        
                                        .. attribute:: nanosecond
                                        
                                        	Nano seconds 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: second
                                        
                                        	Seconds 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.nanosecond = None
                                            self.second = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:start-time'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.nanosecond is not None:
                                                return True

                                            if self.second is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Ospfv3_.StubRouter.Trigger.StartTime']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:trigger'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.start_time is not None and self.start_time._has_data():
                                            return True

                                        if self.time is not None:
                                            return True

                                        if self.trigger is not None:
                                            return True

                                        if self.unset_reason is not None:
                                            return True

                                        if self.unset_time is not None and self.unset_time._has_data():
                                            return True

                                        if self.wait_for_bgp is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                        return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Ospfv3_.StubRouter.Trigger']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:stub-router'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.abr_off_reason is not None:
                                        return True

                                    if self.abr_resume_time is not None and self.abr_resume_time._has_data():
                                        return True

                                    if self.active is not None:
                                        return True

                                    if self.external_lsa_metric is not None:
                                        return True

                                    if self.include_stub_links is not None:
                                        return True

                                    if self.mode is not None:
                                        return True

                                    if self.remaining_time is not None:
                                        return True

                                    if self.set_reason is not None:
                                        return True

                                    if self.start_time is not None and self.start_time._has_data():
                                        return True

                                    if self.summary_lsa_metric is not None:
                                        return True

                                    if self.trigger is not None:
                                        for child_ref in self.trigger:
                                            if child_ref._has_data():
                                                return True

                                    if self.unset_reason is not None:
                                        return True

                                    if self.unset_time is not None and self.unset_time._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                    return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Ospfv3_.StubRouter']['meta_info']


                            class IpfrrTiebreakers(object):
                                """
                                IPFRR\-Tiebreakers list
                                
                                .. attribute:: tiebreaker_index
                                
                                	Tiebreaker Index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: tiebreaker_type
                                
                                	Tiebreaker Type
                                	**type**\:   :py:class:`IpfrrTbrkrEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.IpfrrTbrkrEnum>`
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.tiebreaker_index = None
                                    self.tiebreaker_type = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:ipfrr-tiebreakers'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.tiebreaker_index is not None:
                                        return True

                                    if self.tiebreaker_type is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                    return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Ospfv3_.IpfrrTiebreakers']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:ospfv3'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.areas is not None:
                                    return True

                                if self.as_dc_bitless_ls_as is not None:
                                    return True

                                if self.as_do_not_age_ls_as is not None:
                                    return True

                                if self.as_ls_as is not None:
                                    return True

                                if self.as_lsa_flood_list_length is not None:
                                    return True

                                if self.context_name is not None:
                                    return True

                                if self.default_metric is not None:
                                    return True

                                if self.default_metric_type is not None:
                                    return True

                                if self.default_policy_name is not None:
                                    return True

                                if self.default_tag is not None:
                                    return True

                                if self.domain_id is not None and self.domain_id._has_data():
                                    return True

                                if self.grace_resync_time is not None:
                                    return True

                                if self.graceful_shutdown_state is not None:
                                    return True

                                if self.ipfrr_tiebreakers is not None:
                                    for child_ref in self.ipfrr_tiebreakers:
                                        if child_ref._has_data():
                                            return True

                                if self.is_area_border_router is not None:
                                    return True

                                if self.is_as_border_router is not None:
                                    return True

                                if self.is_auto_cost is not None:
                                    return True

                                if self.is_default_always is not None:
                                    return True

                                if self.is_default_originated is not None:
                                    return True

                                if self.is_default_policy is not None:
                                    return True

                                if self.is_grace_restart_enabled is not None:
                                    return True

                                if self.is_nsr_enabled is not None:
                                    return True

                                if self.is_nsr_switchover_on_restart is not None:
                                    return True

                                if self.is_opaque_capable is not None:
                                    return True

                                if self.is_role_standby is not None:
                                    return True

                                if self.is_router_id_stalled is not None:
                                    return True

                                if self.last_nsf_time is not None:
                                    return True

                                if self.lsa_flood_pacing_interval is not None:
                                    return True

                                if self.lsa_group_interval is not None:
                                    return True

                                if self.lsa_hold_time is not None:
                                    return True

                                if self.lsa_maximum_time is not None:
                                    return True

                                if self.lsa_retransmission_pacing_interval is not None:
                                    return True

                                if self.lsa_start_time is not None:
                                    return True

                                if self.maximum_interfaces is not None:
                                    return True

                                if self.maximum_paths is not None:
                                    return True

                                if self.metric is not None:
                                    return True

                                if self.minimum_lsa_interval is not None:
                                    return True

                                if self.normal_areas is not None:
                                    return True

                                if self.nssa_areas is not None:
                                    return True

                                if self.opaque_lsa_checksum is not None:
                                    return True

                                if self.opaque_lsas is not None:
                                    return True

                                if self.redistribution_limit is not None:
                                    return True

                                if self.redistribution_threshold is not None:
                                    return True

                                if self.reference_bandwidth is not None:
                                    return True

                                if self.role is not None:
                                    return True

                                if self.router_id is not None:
                                    return True

                                if self.snmp_trap_enabled is not None:
                                    return True

                                if self.spf_hold_time is not None:
                                    return True

                                if self.spf_maximum_time is not None:
                                    return True

                                if self.spf_start_time is not None:
                                    return True

                                if self.stub_areas is not None:
                                    return True

                                if self.stub_router is not None:
                                    for child_ref in self.stub_router:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Ospfv3_']['meta_info']


                        class Route(object):
                            """
                            OSPFv3 route summary
                            
                            .. attribute:: extern_one_route
                            
                            	Extern 1 route summary 
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: extern_two_route
                            
                            	Extern 2 route summary 
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: inter_area_route
                            
                            	Inter route summary 
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: intra_area_route
                            
                            	Intra route summary 
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nssa_one_route
                            
                            	NSSA 1 route summary 
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nssa_two_route
                            
                            	NSSA 2 route summary 
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: redistribution_route
                            
                            	Redistribution route summary 
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: route_connected
                            
                            	Route connected 
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: route_id
                            
                            	Route summary of a route ID 
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: total_received_route
                            
                            	Total route received summary
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: total_sent_route
                            
                            	Total route summary 
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.extern_one_route = None
                                self.extern_two_route = None
                                self.inter_area_route = None
                                self.intra_area_route = None
                                self.nssa_one_route = None
                                self.nssa_two_route = None
                                self.redistribution_route = None
                                self.route_connected = None
                                self.route_id = None
                                self.total_received_route = None
                                self.total_sent_route = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:route'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.extern_one_route is not None:
                                    return True

                                if self.extern_two_route is not None:
                                    return True

                                if self.inter_area_route is not None:
                                    return True

                                if self.intra_area_route is not None:
                                    return True

                                if self.nssa_one_route is not None:
                                    return True

                                if self.nssa_two_route is not None:
                                    return True

                                if self.redistribution_route is not None:
                                    return True

                                if self.route_connected is not None:
                                    return True

                                if self.route_id is not None:
                                    return True

                                if self.total_received_route is not None:
                                    return True

                                if self.total_sent_route is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Route']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:summary'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.ospfv3 is not None and self.ospfv3._has_data():
                                return True

                            if self.protocol is not None and self.protocol._has_data():
                                return True

                            if self.route is not None and self.route._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                            return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.Summary']['meta_info']


                    class RetransmissionListProcessTable(object):
                        """
                        OSPFv3 retransmission list information table for
                        all areas
                        
                        .. attribute:: retransmission
                        
                        	OSPFv3 retransmission list information
                        	**type**\: list of    :py:class:`Retransmission <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.RetransmissionListProcessTable.Retransmission>`
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.retransmission = YList()
                            self.retransmission.parent = self
                            self.retransmission.name = 'retransmission'


                        class Retransmission(object):
                            """
                            OSPFv3 retransmission list information
                            
                            .. attribute:: interface_name
                            
                            	Interface name
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: is_retransmission_sham_link
                            
                            	If true, sham link is retransmitted 
                            	**type**\:  bool
                            
                            .. attribute:: is_retransmissionvirtual_link
                            
                            	If true, virtual link is retransmitted 
                            	**type**\:  bool
                            
                            .. attribute:: neighbor_address
                            
                            	Neighbor address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: retransmission_area_db
                            
                            	List of area scope entries
                            	**type**\: list of    :py:class:`RetransmissionAreaDb <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.RetransmissionListProcessTable.Retransmission.RetransmissionAreaDb>`
                            
                            .. attribute:: retransmission_asdb
                            
                            	List of AS scope entries
                            	**type**\: list of    :py:class:`RetransmissionAsdb <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.RetransmissionListProcessTable.Retransmission.RetransmissionAsdb>`
                            
                            .. attribute:: retransmission_length
                            
                            	Retransmission queue length
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: retransmission_neighbor_address
                            
                            	Neighbor IP address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: retransmission_sham_link_id
                            
                            	Retransmission sham link ID 
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: retransmission_timer
                            
                            	Amount of time remaining on retransmission timer (ms)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: retransmissionvirtual_link_db
                            
                            	List of virtual link scope entries 
                            	**type**\: list of    :py:class:`RetransmissionvirtualLinkDb <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.RetransmissionListProcessTable.Retransmission.RetransmissionvirtualLinkDb>`
                            
                            .. attribute:: retransmissionvirtual_link_id
                            
                            	Retransmission virtual link ID 
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.interface_name = None
                                self.is_retransmission_sham_link = None
                                self.is_retransmissionvirtual_link = None
                                self.neighbor_address = None
                                self.retransmission_area_db = YList()
                                self.retransmission_area_db.parent = self
                                self.retransmission_area_db.name = 'retransmission_area_db'
                                self.retransmission_asdb = YList()
                                self.retransmission_asdb.parent = self
                                self.retransmission_asdb.name = 'retransmission_asdb'
                                self.retransmission_length = None
                                self.retransmission_neighbor_address = None
                                self.retransmission_sham_link_id = None
                                self.retransmission_timer = None
                                self.retransmissionvirtual_link_db = YList()
                                self.retransmissionvirtual_link_db.parent = self
                                self.retransmissionvirtual_link_db.name = 'retransmissionvirtual_link_db'
                                self.retransmissionvirtual_link_id = None


                            class RetransmissionvirtualLinkDb(object):
                                """
                                List of virtual link scope entries 
                                
                                .. attribute:: header_advertising_router
                                
                                	Router ID of the advertising router
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: header_lsa_age
                                
                                	Age of the LSA (seconds)
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                	**units**\: second
                                
                                .. attribute:: header_lsa_id
                                
                                	LSA ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: header_lsa_type
                                
                                	LSA type
                                	**type**\:   :py:class:`Ospfv3Lsa1Enum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Lsa1Enum>`
                                
                                .. attribute:: header_sequence_number
                                
                                	Current LSA sequence number
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.header_advertising_router = None
                                    self.header_lsa_age = None
                                    self.header_lsa_id = None
                                    self.header_lsa_type = None
                                    self.header_sequence_number = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:retransmissionvirtual-link-db'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.header_advertising_router is not None:
                                        return True

                                    if self.header_lsa_age is not None:
                                        return True

                                    if self.header_lsa_id is not None:
                                        return True

                                    if self.header_lsa_type is not None:
                                        return True

                                    if self.header_sequence_number is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                    return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.RetransmissionListProcessTable.Retransmission.RetransmissionvirtualLinkDb']['meta_info']


                            class RetransmissionAreaDb(object):
                                """
                                List of area scope entries
                                
                                .. attribute:: header_advertising_router
                                
                                	Router ID of the advertising router
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: header_lsa_age
                                
                                	Age of the LSA (seconds)
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                	**units**\: second
                                
                                .. attribute:: header_lsa_id
                                
                                	LSA ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: header_lsa_type
                                
                                	LSA type
                                	**type**\:   :py:class:`Ospfv3Lsa1Enum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Lsa1Enum>`
                                
                                .. attribute:: header_sequence_number
                                
                                	Current LSA sequence number
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.header_advertising_router = None
                                    self.header_lsa_age = None
                                    self.header_lsa_id = None
                                    self.header_lsa_type = None
                                    self.header_sequence_number = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:retransmission-area-db'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.header_advertising_router is not None:
                                        return True

                                    if self.header_lsa_age is not None:
                                        return True

                                    if self.header_lsa_id is not None:
                                        return True

                                    if self.header_lsa_type is not None:
                                        return True

                                    if self.header_sequence_number is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                    return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.RetransmissionListProcessTable.Retransmission.RetransmissionAreaDb']['meta_info']


                            class RetransmissionAsdb(object):
                                """
                                List of AS scope entries
                                
                                .. attribute:: header_advertising_router
                                
                                	Router ID of the advertising router
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: header_lsa_age
                                
                                	Age of the LSA (seconds)
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                	**units**\: second
                                
                                .. attribute:: header_lsa_id
                                
                                	LSA ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: header_lsa_type
                                
                                	LSA type
                                	**type**\:   :py:class:`Ospfv3Lsa1Enum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Lsa1Enum>`
                                
                                .. attribute:: header_sequence_number
                                
                                	Current LSA sequence number
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.header_advertising_router = None
                                    self.header_lsa_age = None
                                    self.header_lsa_id = None
                                    self.header_lsa_type = None
                                    self.header_sequence_number = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:retransmission-asdb'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.header_advertising_router is not None:
                                        return True

                                    if self.header_lsa_age is not None:
                                        return True

                                    if self.header_lsa_id is not None:
                                        return True

                                    if self.header_lsa_type is not None:
                                        return True

                                    if self.header_sequence_number is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                    return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.RetransmissionListProcessTable.Retransmission.RetransmissionAsdb']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:retransmission'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.interface_name is not None:
                                    return True

                                if self.is_retransmission_sham_link is not None:
                                    return True

                                if self.is_retransmissionvirtual_link is not None:
                                    return True

                                if self.neighbor_address is not None:
                                    return True

                                if self.retransmission_area_db is not None:
                                    for child_ref in self.retransmission_area_db:
                                        if child_ref._has_data():
                                            return True

                                if self.retransmission_asdb is not None:
                                    for child_ref in self.retransmission_asdb:
                                        if child_ref._has_data():
                                            return True

                                if self.retransmission_length is not None:
                                    return True

                                if self.retransmission_neighbor_address is not None:
                                    return True

                                if self.retransmission_sham_link_id is not None:
                                    return True

                                if self.retransmission_timer is not None:
                                    return True

                                if self.retransmissionvirtual_link_db is not None:
                                    for child_ref in self.retransmissionvirtual_link_db:
                                        if child_ref._has_data():
                                            return True

                                if self.retransmissionvirtual_link_id is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.RetransmissionListProcessTable.Retransmission']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:retransmission-list-process-table'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.retransmission is not None:
                                for child_ref in self.retransmission:
                                    if child_ref._has_data():
                                        return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                            return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.RetransmissionListProcessTable']['meta_info']


                    class BadChecksums(object):
                        """
                        Bad Checksum Packets information table
                        
                        .. attribute:: bad_checksum
                        
                        	Bad Checksum Packet information
                        	**type**\: list of    :py:class:`BadChecksum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.BadChecksums.BadChecksum>`
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.bad_checksum = YList()
                            self.bad_checksum.parent = self
                            self.bad_checksum.name = 'bad_checksum'


                        class BadChecksum(object):
                            """
                            Bad Checksum Packet information
                            
                            .. attribute:: packet_number  <key>
                            
                            	Bad Checksum Packets number
                            	**type**\:  int
                            
                            	**range:** 0..9
                            
                            .. attribute:: computed_checksum
                            
                            	Computed Checksum
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: received_checksum
                            
                            	Received Checksum
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: received_data
                            
                            	Received Hexadecimal Data
                            	**type**\:  str
                            
                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                            
                            .. attribute:: timestamp
                            
                            	Packet Timestamp (relative to 1970/1/1 00\:00)
                            	**type**\:   :py:class:`Timestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.BadChecksums.BadChecksum.Timestamp>`
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.packet_number = None
                                self.computed_checksum = None
                                self.received_checksum = None
                                self.received_data = None
                                self.timestamp = Ospfv3.Processes.Process.Vrfs.Vrf.BadChecksums.BadChecksum.Timestamp()
                                self.timestamp.parent = self


                            class Timestamp(object):
                                """
                                Packet Timestamp (relative to 1970/1/1 00\:00)
                                
                                .. attribute:: nanosecond
                                
                                	Nano seconds 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: nanosecond
                                
                                .. attribute:: second
                                
                                	Seconds 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.nanosecond = None
                                    self.second = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:timestamp'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.nanosecond is not None:
                                        return True

                                    if self.second is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                    return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.BadChecksums.BadChecksum.Timestamp']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')
                                if self.packet_number is None:
                                    raise YPYModelError('Key property packet_number is None')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:bad-checksum[Cisco-IOS-XR-ipv6-ospfv3-oper:packet-number = ' + str(self.packet_number) + ']'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.packet_number is not None:
                                    return True

                                if self.computed_checksum is not None:
                                    return True

                                if self.received_checksum is not None:
                                    return True

                                if self.received_data is not None:
                                    return True

                                if self.timestamp is not None and self.timestamp._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.BadChecksums.BadChecksum']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:bad-checksums'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.bad_checksum is not None:
                                for child_ref in self.bad_checksum:
                                    if child_ref._has_data():
                                        return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                            return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.BadChecksums']['meta_info']


                    class DatabaseSummaryTable(object):
                        """
                        Database summary table
                        
                        .. attribute:: database_summary
                        
                        	Database Summary information
                        	**type**\:   :py:class:`DatabaseSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseSummaryTable.DatabaseSummary>`
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.database_summary = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseSummaryTable.DatabaseSummary()
                            self.database_summary.parent = self


                        class DatabaseSummary(object):
                            """
                            Database Summary information
                            
                            .. attribute:: area_database
                            
                            	OSPFv3 Area Database list 
                            	**type**\: list of    :py:class:`AreaDatabase <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseSummaryTable.DatabaseSummary.AreaDatabase>`
                            
                            .. attribute:: database_counters
                            
                            	OSPFv3 database counters 
                            	**type**\:   :py:class:`DatabaseCounters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseSummaryTable.DatabaseSummary.DatabaseCounters>`
                            
                            .. attribute:: database_router_id
                            
                            	Database router ID 
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: is_opaque_database_capable
                            
                            	If true, opaque database is capable 
                            	**type**\:  bool
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.area_database = YList()
                                self.area_database.parent = self
                                self.area_database.name = 'area_database'
                                self.database_counters = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseSummaryTable.DatabaseSummary.DatabaseCounters()
                                self.database_counters.parent = self
                                self.database_router_id = None
                                self.is_opaque_database_capable = None


                            class DatabaseCounters(object):
                                """
                                OSPFv3 database counters 
                                
                                .. attribute:: deleted_lsa
                                
                                	deleted lsa
                                	**type**\:  list of int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: lsa
                                
                                	lsa
                                	**type**\:  list of int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: lsa_checksum
                                
                                	lsa checksum
                                	**type**\:  list of int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: max_age_lsa
                                
                                	max age lsa
                                	**type**\:  list of int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.deleted_lsa = YLeafList()
                                    self.deleted_lsa.parent = self
                                    self.deleted_lsa.name = 'deleted_lsa'
                                    self.lsa = YLeafList()
                                    self.lsa.parent = self
                                    self.lsa.name = 'lsa'
                                    self.lsa_checksum = YLeafList()
                                    self.lsa_checksum.parent = self
                                    self.lsa_checksum.name = 'lsa_checksum'
                                    self.max_age_lsa = YLeafList()
                                    self.max_age_lsa.parent = self
                                    self.max_age_lsa.name = 'max_age_lsa'

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:database-counters'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.deleted_lsa is not None:
                                        for child in self.deleted_lsa:
                                            if child is not None:
                                                return True

                                    if self.lsa is not None:
                                        for child in self.lsa:
                                            if child is not None:
                                                return True

                                    if self.lsa_checksum is not None:
                                        for child in self.lsa_checksum:
                                            if child is not None:
                                                return True

                                    if self.max_age_lsa is not None:
                                        for child in self.max_age_lsa:
                                            if child is not None:
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                    return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseSummaryTable.DatabaseSummary.DatabaseCounters']['meta_info']


                            class AreaDatabase(object):
                                """
                                OSPFv3 Area Database list 
                                
                                .. attribute:: area_database_summary
                                
                                	Area database summary 
                                	**type**\:   :py:class:`AreaDatabaseSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseSummaryTable.DatabaseSummary.AreaDatabase.AreaDatabaseSummary>`
                                
                                .. attribute:: lsa_area_id
                                
                                	Area ID in decimal or dotted\-decimal format
                                	**type**\:  str
                                
                                	**length:** 0..16
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.area_database_summary = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseSummaryTable.DatabaseSummary.AreaDatabase.AreaDatabaseSummary()
                                    self.area_database_summary.parent = self
                                    self.lsa_area_id = None


                                class AreaDatabaseSummary(object):
                                    """
                                    Area database summary 
                                    
                                    .. attribute:: deleted_lsa
                                    
                                    	deleted lsa
                                    	**type**\:  list of int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: lsa
                                    
                                    	lsa
                                    	**type**\:  list of int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: lsa_checksum
                                    
                                    	lsa checksum
                                    	**type**\:  list of int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: max_age_lsa
                                    
                                    	max age lsa
                                    	**type**\:  list of int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.deleted_lsa = YLeafList()
                                        self.deleted_lsa.parent = self
                                        self.deleted_lsa.name = 'deleted_lsa'
                                        self.lsa = YLeafList()
                                        self.lsa.parent = self
                                        self.lsa.name = 'lsa'
                                        self.lsa_checksum = YLeafList()
                                        self.lsa_checksum.parent = self
                                        self.lsa_checksum.name = 'lsa_checksum'
                                        self.max_age_lsa = YLeafList()
                                        self.max_age_lsa.parent = self
                                        self.max_age_lsa.name = 'max_age_lsa'

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:area-database-summary'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.deleted_lsa is not None:
                                            for child in self.deleted_lsa:
                                                if child is not None:
                                                    return True

                                        if self.lsa is not None:
                                            for child in self.lsa:
                                                if child is not None:
                                                    return True

                                        if self.lsa_checksum is not None:
                                            for child in self.lsa_checksum:
                                                if child is not None:
                                                    return True

                                        if self.max_age_lsa is not None:
                                            for child in self.max_age_lsa:
                                                if child is not None:
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                        return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseSummaryTable.DatabaseSummary.AreaDatabase.AreaDatabaseSummary']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:area-database'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.area_database_summary is not None and self.area_database_summary._has_data():
                                        return True

                                    if self.lsa_area_id is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                    return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseSummaryTable.DatabaseSummary.AreaDatabase']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:database-summary'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.area_database is not None:
                                    for child_ref in self.area_database:
                                        if child_ref._has_data():
                                            return True

                                if self.database_counters is not None and self.database_counters._has_data():
                                    return True

                                if self.database_router_id is not None:
                                    return True

                                if self.is_opaque_database_capable is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseSummaryTable.DatabaseSummary']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:database-summary-table'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.database_summary is not None and self.database_summary._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                            return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseSummaryTable']['meta_info']


                    class NeighborProcessTable(object):
                        """
                        OSPFv3 neighbor information table for all areas
                        
                        .. attribute:: neighbor
                        
                        	OSPFv3 neighbor detail information
                        	**type**\: list of    :py:class:`Neighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.NeighborProcessTable.Neighbor>`
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.neighbor = YList()
                            self.neighbor.parent = self
                            self.neighbor.name = 'neighbor'


                        class Neighbor(object):
                            """
                            OSPFv3 neighbor detail information
                            
                            .. attribute:: interface_name
                            
                            	Interface name
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: is_neighbor_sham_link
                            
                            	If true, neighbor is on a sham link 
                            	**type**\:  bool
                            
                            .. attribute:: is_neighbor_virtual_link
                            
                            	If true, neighbor is on a virtual link 
                            	**type**\:  bool
                            
                            .. attribute:: neighbor_address
                            
                            	Neighbor ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: neighbor_address_xr
                            
                            	Neighbor IP Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: neighbor_bfd_info
                            
                            	Neighbor BFD information
                            	**type**\:   :py:class:`NeighborBfdInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.NeighborProcessTable.Neighbor.NeighborBfdInfo>`
                            
                            .. attribute:: neighbor_dead_timer
                            
                            	Time until neighbor's dead timer expires (seconds)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: neighbor_designated_router
                            
                            	Designated router 
                            	**type**\:  str
                            
                            	**length:** 0..9
                            
                            .. attribute:: neighbor_detail
                            
                            	Detailed OSPFv3 neighbor information 
                            	**type**\:   :py:class:`NeighborDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.NeighborProcessTable.Neighbor.NeighborDetail>`
                            
                            .. attribute:: neighbor_dr_priority
                            
                            	Neighbor's DR priority
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: neighbor_interface_id
                            
                            	Neighbor interface ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: neighbor_sham_link_id
                            
                            	Neighbor sham link id 
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: neighbor_state
                            
                            	Neighbor's state
                            	**type**\:   :py:class:`Ospfv3NeighborStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3NeighborStateEnum>`
                            
                            .. attribute:: neighbor_up_time
                            
                            	Amount of time since the adjacency is up (seconds)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: neighbor_virtual_link_id
                            
                            	Neighbor virtual link id 
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.interface_name = None
                                self.is_neighbor_sham_link = None
                                self.is_neighbor_virtual_link = None
                                self.neighbor_address = None
                                self.neighbor_address_xr = None
                                self.neighbor_bfd_info = Ospfv3.Processes.Process.Vrfs.Vrf.NeighborProcessTable.Neighbor.NeighborBfdInfo()
                                self.neighbor_bfd_info.parent = self
                                self.neighbor_dead_timer = None
                                self.neighbor_designated_router = None
                                self.neighbor_detail = Ospfv3.Processes.Process.Vrfs.Vrf.NeighborProcessTable.Neighbor.NeighborDetail()
                                self.neighbor_detail.parent = self
                                self.neighbor_dr_priority = None
                                self.neighbor_interface_id = None
                                self.neighbor_sham_link_id = None
                                self.neighbor_state = None
                                self.neighbor_up_time = None
                                self.neighbor_virtual_link_id = None


                            class NeighborDetail(object):
                                """
                                Detailed OSPFv3 neighbor information 
                                
                                .. attribute:: interface_type
                                
                                	Interface type
                                	**type**\:   :py:class:`Ospfv3InterfaceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3InterfaceEnum>`
                                
                                .. attribute:: is_neighbor_filtered
                                
                                	If true, filter outgoing LSAs 
                                	**type**\:  bool
                                
                                .. attribute:: neighbor_backup_designated_router_address
                                
                                	Address of backup designated router
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: neighbor_cost
                                
                                	Cost of path to this neighbor 
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: neighbor_designated_router_address
                                
                                	Address of designated router
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: neighbor_ignore_timer
                                
                                	Remaining time when ignore timer is running 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: neighbor_option
                                
                                	 This is bitmask of neighbor's option field received 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: neighbor_retransmission
                                
                                	Retransmission information with this neighbor
                                	**type**\:   :py:class:`NeighborRetransmission <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.NeighborProcessTable.Neighbor.NeighborDetail.NeighborRetransmission>`
                                
                                .. attribute:: next_poll_interval
                                
                                	For NBMA networks, amount of time remaining in seconds before the next poll interval expires and Hello is sent (s)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: pending_events
                                
                                	Number of pending events 
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: poll_interval
                                
                                	Poll interval (s)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: state_changes
                                
                                	Number of state changes 
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.interface_type = None
                                    self.is_neighbor_filtered = None
                                    self.neighbor_backup_designated_router_address = None
                                    self.neighbor_cost = None
                                    self.neighbor_designated_router_address = None
                                    self.neighbor_ignore_timer = None
                                    self.neighbor_option = None
                                    self.neighbor_retransmission = Ospfv3.Processes.Process.Vrfs.Vrf.NeighborProcessTable.Neighbor.NeighborDetail.NeighborRetransmission()
                                    self.neighbor_retransmission.parent = self
                                    self.next_poll_interval = None
                                    self.pending_events = None
                                    self.poll_interval = None
                                    self.state_changes = None


                                class NeighborRetransmission(object):
                                    """
                                    Retransmission information with this neighbor
                                    
                                    .. attribute:: area_first_flood
                                    
                                    	First flood item for area scope LSAs
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: area_first_flood_index
                                    
                                    	Index of the first flood item for area scope LSAs
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: area_flood_index
                                    
                                    	Area scope LSA's flood index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: area_next_flood
                                    
                                    	Next flood item for area scope LSAs
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: area_next_flood_index
                                    
                                    	Index of next flood item for Area scope LSAs
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: as_first_flood
                                    
                                    	First flood item for AS scope LSAs
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: as_first_flood_index
                                    
                                    	Index for first flood item for AS scope LSAs
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: as_flood_index
                                    
                                    	AS scope LSA's flood index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: as_next_flood
                                    
                                    	Next flood item for AS scope LSAs
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: as_next_flood_index
                                    
                                    	Index of next flood item for AS scope LSAs
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: database_descriptor_retransmissions
                                    
                                    	Number of database descriptor retransmissions during last exchange
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: last_retransmission_length
                                    
                                    	Number of LSAs sent in last retransmission
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: last_retransmission_time
                                    
                                    	Last retransmission scan time (ms)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: link_first_flood
                                    
                                    	Link first flood information 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: link_first_flood_index
                                    
                                    	Link first flood information index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: link_flood_index
                                    
                                    	Link flood index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: link_next_flood
                                    
                                    	Link next flood information 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: link_next_flood_index
                                    
                                    	Link next flood information index 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: lsa_retransmission_timer
                                    
                                    	Time until next LSA retransmission (ms)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: maximum_retransmission_length
                                    
                                    	Maximum number of LSAs sent in a retransmission
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: maximum_retransmission_time
                                    
                                    	Maximum retransmission scan time (ms)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: neighbor_retransmissions
                                    
                                    	Number of neighbor retransmissions 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: retransmissions
                                    
                                    	Number of retransmissions for this neighbor
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.area_first_flood = None
                                        self.area_first_flood_index = None
                                        self.area_flood_index = None
                                        self.area_next_flood = None
                                        self.area_next_flood_index = None
                                        self.as_first_flood = None
                                        self.as_first_flood_index = None
                                        self.as_flood_index = None
                                        self.as_next_flood = None
                                        self.as_next_flood_index = None
                                        self.database_descriptor_retransmissions = None
                                        self.last_retransmission_length = None
                                        self.last_retransmission_time = None
                                        self.link_first_flood = None
                                        self.link_first_flood_index = None
                                        self.link_flood_index = None
                                        self.link_next_flood = None
                                        self.link_next_flood_index = None
                                        self.lsa_retransmission_timer = None
                                        self.maximum_retransmission_length = None
                                        self.maximum_retransmission_time = None
                                        self.neighbor_retransmissions = None
                                        self.retransmissions = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:neighbor-retransmission'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.area_first_flood is not None:
                                            return True

                                        if self.area_first_flood_index is not None:
                                            return True

                                        if self.area_flood_index is not None:
                                            return True

                                        if self.area_next_flood is not None:
                                            return True

                                        if self.area_next_flood_index is not None:
                                            return True

                                        if self.as_first_flood is not None:
                                            return True

                                        if self.as_first_flood_index is not None:
                                            return True

                                        if self.as_flood_index is not None:
                                            return True

                                        if self.as_next_flood is not None:
                                            return True

                                        if self.as_next_flood_index is not None:
                                            return True

                                        if self.database_descriptor_retransmissions is not None:
                                            return True

                                        if self.last_retransmission_length is not None:
                                            return True

                                        if self.last_retransmission_time is not None:
                                            return True

                                        if self.link_first_flood is not None:
                                            return True

                                        if self.link_first_flood_index is not None:
                                            return True

                                        if self.link_flood_index is not None:
                                            return True

                                        if self.link_next_flood is not None:
                                            return True

                                        if self.link_next_flood_index is not None:
                                            return True

                                        if self.lsa_retransmission_timer is not None:
                                            return True

                                        if self.maximum_retransmission_length is not None:
                                            return True

                                        if self.maximum_retransmission_time is not None:
                                            return True

                                        if self.neighbor_retransmissions is not None:
                                            return True

                                        if self.retransmissions is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                        return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.NeighborProcessTable.Neighbor.NeighborDetail.NeighborRetransmission']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:neighbor-detail'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.interface_type is not None:
                                        return True

                                    if self.is_neighbor_filtered is not None:
                                        return True

                                    if self.neighbor_backup_designated_router_address is not None:
                                        return True

                                    if self.neighbor_cost is not None:
                                        return True

                                    if self.neighbor_designated_router_address is not None:
                                        return True

                                    if self.neighbor_ignore_timer is not None:
                                        return True

                                    if self.neighbor_option is not None:
                                        return True

                                    if self.neighbor_retransmission is not None and self.neighbor_retransmission._has_data():
                                        return True

                                    if self.next_poll_interval is not None:
                                        return True

                                    if self.pending_events is not None:
                                        return True

                                    if self.poll_interval is not None:
                                        return True

                                    if self.state_changes is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                    return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.NeighborProcessTable.Neighbor.NeighborDetail']['meta_info']


                            class NeighborBfdInfo(object):
                                """
                                Neighbor BFD information
                                
                                .. attribute:: bfd_intf_enable_mode
                                
                                	BFD enable mode \- Default/Strict
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bfd_status_flag
                                
                                	Status of the BFD Session
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.bfd_intf_enable_mode = None
                                    self.bfd_status_flag = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:neighbor-bfd-info'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.bfd_intf_enable_mode is not None:
                                        return True

                                    if self.bfd_status_flag is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                    return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.NeighborProcessTable.Neighbor.NeighborBfdInfo']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:neighbor'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.interface_name is not None:
                                    return True

                                if self.is_neighbor_sham_link is not None:
                                    return True

                                if self.is_neighbor_virtual_link is not None:
                                    return True

                                if self.neighbor_address is not None:
                                    return True

                                if self.neighbor_address_xr is not None:
                                    return True

                                if self.neighbor_bfd_info is not None and self.neighbor_bfd_info._has_data():
                                    return True

                                if self.neighbor_dead_timer is not None:
                                    return True

                                if self.neighbor_designated_router is not None:
                                    return True

                                if self.neighbor_detail is not None and self.neighbor_detail._has_data():
                                    return True

                                if self.neighbor_dr_priority is not None:
                                    return True

                                if self.neighbor_interface_id is not None:
                                    return True

                                if self.neighbor_sham_link_id is not None:
                                    return True

                                if self.neighbor_state is not None:
                                    return True

                                if self.neighbor_up_time is not None:
                                    return True

                                if self.neighbor_virtual_link_id is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.NeighborProcessTable.Neighbor']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:neighbor-process-table'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.neighbor is not None:
                                for child_ref in self.neighbor:
                                    if child_ref._has_data():
                                        return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                            return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.NeighborProcessTable']['meta_info']


                    class FastReroutes(object):
                        """
                        OSPFv3 fast reroute topology information table
                        
                        .. attribute:: fast_reroute
                        
                        	OSPFv3 fast reroute topology information
                        	**type**\: list of    :py:class:`FastReroute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.FastReroutes.FastReroute>`
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.fast_reroute = YList()
                            self.fast_reroute.parent = self
                            self.fast_reroute.name = 'fast_reroute'


                        class FastReroute(object):
                            """
                            OSPFv3 fast reroute topology information
                            
                            .. attribute:: area_id
                            
                            	AreaID
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: ipfrr_area_revision
                            
                            	IPFRR Topology Revision
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ipfrr_router_id
                            
                            	OSPF Router ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipfrr_topo
                            
                            	IPFRR Topology entries
                            	**type**\: list of    :py:class:`IpfrrTopo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.FastReroutes.FastReroute.IpfrrTopo>`
                            
                            .. attribute:: ipfrr_topo_area_id
                            
                            	Area ID string in decimal or dotted decimal format
                            	**type**\:  str
                            
                            	**length:** 0..16
                            
                            .. attribute:: router_id
                            
                            	Router ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.area_id = None
                                self.ipfrr_area_revision = None
                                self.ipfrr_router_id = None
                                self.ipfrr_topo = YList()
                                self.ipfrr_topo.parent = self
                                self.ipfrr_topo.name = 'ipfrr_topo'
                                self.ipfrr_topo_area_id = None
                                self.router_id = None


                            class IpfrrTopo(object):
                                """
                                IPFRR Topology entries
                                
                                .. attribute:: distance
                                
                                	IPFRR Topology Distance
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: dr
                                
                                	IPFRR Topology DR entry
                                	**type**\:  bool
                                
                                .. attribute:: lsaid
                                
                                	IPFRR Topology LSA ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: neighbor_sourced
                                
                                	IPFRR Topology Neighbor Sourced
                                	**type**\:  bool
                                
                                .. attribute:: node_id
                                
                                	IPFRR Topology Node ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: revision
                                
                                	IPFRR Topology Revision
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: type4
                                
                                	IPFRR Topoogy Type\-4 entry
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.distance = None
                                    self.dr = None
                                    self.lsaid = None
                                    self.neighbor_sourced = None
                                    self.node_id = None
                                    self.revision = None
                                    self.type4 = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:ipfrr-topo'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.distance is not None:
                                        return True

                                    if self.dr is not None:
                                        return True

                                    if self.lsaid is not None:
                                        return True

                                    if self.neighbor_sourced is not None:
                                        return True

                                    if self.node_id is not None:
                                        return True

                                    if self.revision is not None:
                                        return True

                                    if self.type4 is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                    return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.FastReroutes.FastReroute.IpfrrTopo']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:fast-reroute'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.area_id is not None:
                                    return True

                                if self.ipfrr_area_revision is not None:
                                    return True

                                if self.ipfrr_router_id is not None:
                                    return True

                                if self.ipfrr_topo is not None:
                                    for child_ref in self.ipfrr_topo:
                                        if child_ref._has_data():
                                            return True

                                if self.ipfrr_topo_area_id is not None:
                                    return True

                                if self.router_id is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.FastReroutes.FastReroute']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:fast-reroutes'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.fast_reroute is not None:
                                for child_ref in self.fast_reroute:
                                    if child_ref._has_data():
                                        return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                            return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.FastReroutes']['meta_info']


                    class InterfaceBriefProcessTable(object):
                        """
                        OSPFv3 interface brief information table for all
                        areas
                        
                        .. attribute:: interface_brief
                        
                        	Interface brief information
                        	**type**\: list of    :py:class:`InterfaceBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.InterfaceBriefProcessTable.InterfaceBrief>`
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.interface_brief = YList()
                            self.interface_brief.parent = self
                            self.interface_brief.name = 'interface_brief'


                        class InterfaceBrief(object):
                            """
                            Interface brief information
                            
                            .. attribute:: interface_name  <key>
                            
                            	Interface name
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: interface_address
                            
                            	Interface IP address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: interface_adjacent_neighbors
                            
                            	Total number of adjacent neighbors
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: interface_link_cost
                            
                            	Interface link cost
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: interface_neighbors
                            
                            	Total number of neighbors 
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: network_type
                            
                            	Network type
                            	**type**\:   :py:class:`Ospfv3InterfaceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3InterfaceEnum>`
                            
                            .. attribute:: ospf_interface_state
                            
                            	Interface OSPF state
                            	**type**\:   :py:class:`Ospfv3InterfaceStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3InterfaceStateEnum>`
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.interface_name = None
                                self.interface_address = None
                                self.interface_adjacent_neighbors = None
                                self.interface_link_cost = None
                                self.interface_neighbors = None
                                self.network_type = None
                                self.ospf_interface_state = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')
                                if self.interface_name is None:
                                    raise YPYModelError('Key property interface_name is None')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:interface-brief[Cisco-IOS-XR-ipv6-ospfv3-oper:interface-name = ' + str(self.interface_name) + ']'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.interface_name is not None:
                                    return True

                                if self.interface_address is not None:
                                    return True

                                if self.interface_adjacent_neighbors is not None:
                                    return True

                                if self.interface_link_cost is not None:
                                    return True

                                if self.interface_neighbors is not None:
                                    return True

                                if self.network_type is not None:
                                    return True

                                if self.ospf_interface_state is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.InterfaceBriefProcessTable.InterfaceBrief']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:interface-brief-process-table'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.interface_brief is not None:
                                for child_ref in self.interface_brief:
                                    if child_ref._has_data():
                                        return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                            return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.InterfaceBriefProcessTable']['meta_info']


                    class NeighborDetailProcessTable(object):
                        """
                        OSPFv3 neighbor information table for all areas
                        
                        .. attribute:: neighbor_detail
                        
                        	OSPFv3 neighbor detail information
                        	**type**\: list of    :py:class:`NeighborDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.NeighborDetailProcessTable.NeighborDetail>`
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.neighbor_detail = YList()
                            self.neighbor_detail.parent = self
                            self.neighbor_detail.name = 'neighbor_detail'


                        class NeighborDetail(object):
                            """
                            OSPFv3 neighbor detail information
                            
                            .. attribute:: interface_name
                            
                            	Interface name
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: is_neighbor_sham_link
                            
                            	If true, neighbor is on a sham link 
                            	**type**\:  bool
                            
                            .. attribute:: is_neighbor_virtual_link
                            
                            	If true, neighbor is on a virtual link 
                            	**type**\:  bool
                            
                            .. attribute:: neighbor_address
                            
                            	Neighbor ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: neighbor_address_xr
                            
                            	Neighbor IP Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: neighbor_bfd_info
                            
                            	Neighbor BFD information
                            	**type**\:   :py:class:`NeighborBfdInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.NeighborDetailProcessTable.NeighborDetail.NeighborBfdInfo>`
                            
                            .. attribute:: neighbor_dead_timer
                            
                            	Time until neighbor's dead timer expires (seconds)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: neighbor_designated_router
                            
                            	Designated router 
                            	**type**\:  str
                            
                            	**length:** 0..9
                            
                            .. attribute:: neighbor_detail
                            
                            	Detailed OSPFv3 neighbor information 
                            	**type**\:   :py:class:`NeighborDetail_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.NeighborDetailProcessTable.NeighborDetail.NeighborDetail_>`
                            
                            .. attribute:: neighbor_dr_priority
                            
                            	Neighbor's DR priority
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: neighbor_interface_id
                            
                            	Neighbor interface ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: neighbor_sham_link_id
                            
                            	Neighbor sham link id 
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: neighbor_state
                            
                            	Neighbor's state
                            	**type**\:   :py:class:`Ospfv3NeighborStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3NeighborStateEnum>`
                            
                            .. attribute:: neighbor_up_time
                            
                            	Amount of time since the adjacency is up (seconds)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: neighbor_virtual_link_id
                            
                            	Neighbor virtual link id 
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.interface_name = None
                                self.is_neighbor_sham_link = None
                                self.is_neighbor_virtual_link = None
                                self.neighbor_address = None
                                self.neighbor_address_xr = None
                                self.neighbor_bfd_info = Ospfv3.Processes.Process.Vrfs.Vrf.NeighborDetailProcessTable.NeighborDetail.NeighborBfdInfo()
                                self.neighbor_bfd_info.parent = self
                                self.neighbor_dead_timer = None
                                self.neighbor_designated_router = None
                                self.neighbor_detail = Ospfv3.Processes.Process.Vrfs.Vrf.NeighborDetailProcessTable.NeighborDetail.NeighborDetail_()
                                self.neighbor_detail.parent = self
                                self.neighbor_dr_priority = None
                                self.neighbor_interface_id = None
                                self.neighbor_sham_link_id = None
                                self.neighbor_state = None
                                self.neighbor_up_time = None
                                self.neighbor_virtual_link_id = None


                            class NeighborDetail_(object):
                                """
                                Detailed OSPFv3 neighbor information 
                                
                                .. attribute:: interface_type
                                
                                	Interface type
                                	**type**\:   :py:class:`Ospfv3InterfaceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3InterfaceEnum>`
                                
                                .. attribute:: is_neighbor_filtered
                                
                                	If true, filter outgoing LSAs 
                                	**type**\:  bool
                                
                                .. attribute:: neighbor_backup_designated_router_address
                                
                                	Address of backup designated router
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: neighbor_cost
                                
                                	Cost of path to this neighbor 
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: neighbor_designated_router_address
                                
                                	Address of designated router
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: neighbor_ignore_timer
                                
                                	Remaining time when ignore timer is running 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: neighbor_option
                                
                                	 This is bitmask of neighbor's option field received 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: neighbor_retransmission
                                
                                	Retransmission information with this neighbor
                                	**type**\:   :py:class:`NeighborRetransmission <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.NeighborDetailProcessTable.NeighborDetail.NeighborDetail_.NeighborRetransmission>`
                                
                                .. attribute:: next_poll_interval
                                
                                	For NBMA networks, amount of time remaining in seconds before the next poll interval expires and Hello is sent (s)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: pending_events
                                
                                	Number of pending events 
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: poll_interval
                                
                                	Poll interval (s)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: state_changes
                                
                                	Number of state changes 
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.interface_type = None
                                    self.is_neighbor_filtered = None
                                    self.neighbor_backup_designated_router_address = None
                                    self.neighbor_cost = None
                                    self.neighbor_designated_router_address = None
                                    self.neighbor_ignore_timer = None
                                    self.neighbor_option = None
                                    self.neighbor_retransmission = Ospfv3.Processes.Process.Vrfs.Vrf.NeighborDetailProcessTable.NeighborDetail.NeighborDetail_.NeighborRetransmission()
                                    self.neighbor_retransmission.parent = self
                                    self.next_poll_interval = None
                                    self.pending_events = None
                                    self.poll_interval = None
                                    self.state_changes = None


                                class NeighborRetransmission(object):
                                    """
                                    Retransmission information with this neighbor
                                    
                                    .. attribute:: area_first_flood
                                    
                                    	First flood item for area scope LSAs
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: area_first_flood_index
                                    
                                    	Index of the first flood item for area scope LSAs
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: area_flood_index
                                    
                                    	Area scope LSA's flood index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: area_next_flood
                                    
                                    	Next flood item for area scope LSAs
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: area_next_flood_index
                                    
                                    	Index of next flood item for Area scope LSAs
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: as_first_flood
                                    
                                    	First flood item for AS scope LSAs
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: as_first_flood_index
                                    
                                    	Index for first flood item for AS scope LSAs
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: as_flood_index
                                    
                                    	AS scope LSA's flood index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: as_next_flood
                                    
                                    	Next flood item for AS scope LSAs
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: as_next_flood_index
                                    
                                    	Index of next flood item for AS scope LSAs
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: database_descriptor_retransmissions
                                    
                                    	Number of database descriptor retransmissions during last exchange
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: last_retransmission_length
                                    
                                    	Number of LSAs sent in last retransmission
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: last_retransmission_time
                                    
                                    	Last retransmission scan time (ms)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: link_first_flood
                                    
                                    	Link first flood information 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: link_first_flood_index
                                    
                                    	Link first flood information index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: link_flood_index
                                    
                                    	Link flood index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: link_next_flood
                                    
                                    	Link next flood information 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: link_next_flood_index
                                    
                                    	Link next flood information index 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: lsa_retransmission_timer
                                    
                                    	Time until next LSA retransmission (ms)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: maximum_retransmission_length
                                    
                                    	Maximum number of LSAs sent in a retransmission
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: maximum_retransmission_time
                                    
                                    	Maximum retransmission scan time (ms)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: neighbor_retransmissions
                                    
                                    	Number of neighbor retransmissions 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: retransmissions
                                    
                                    	Number of retransmissions for this neighbor
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.area_first_flood = None
                                        self.area_first_flood_index = None
                                        self.area_flood_index = None
                                        self.area_next_flood = None
                                        self.area_next_flood_index = None
                                        self.as_first_flood = None
                                        self.as_first_flood_index = None
                                        self.as_flood_index = None
                                        self.as_next_flood = None
                                        self.as_next_flood_index = None
                                        self.database_descriptor_retransmissions = None
                                        self.last_retransmission_length = None
                                        self.last_retransmission_time = None
                                        self.link_first_flood = None
                                        self.link_first_flood_index = None
                                        self.link_flood_index = None
                                        self.link_next_flood = None
                                        self.link_next_flood_index = None
                                        self.lsa_retransmission_timer = None
                                        self.maximum_retransmission_length = None
                                        self.maximum_retransmission_time = None
                                        self.neighbor_retransmissions = None
                                        self.retransmissions = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:neighbor-retransmission'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.area_first_flood is not None:
                                            return True

                                        if self.area_first_flood_index is not None:
                                            return True

                                        if self.area_flood_index is not None:
                                            return True

                                        if self.area_next_flood is not None:
                                            return True

                                        if self.area_next_flood_index is not None:
                                            return True

                                        if self.as_first_flood is not None:
                                            return True

                                        if self.as_first_flood_index is not None:
                                            return True

                                        if self.as_flood_index is not None:
                                            return True

                                        if self.as_next_flood is not None:
                                            return True

                                        if self.as_next_flood_index is not None:
                                            return True

                                        if self.database_descriptor_retransmissions is not None:
                                            return True

                                        if self.last_retransmission_length is not None:
                                            return True

                                        if self.last_retransmission_time is not None:
                                            return True

                                        if self.link_first_flood is not None:
                                            return True

                                        if self.link_first_flood_index is not None:
                                            return True

                                        if self.link_flood_index is not None:
                                            return True

                                        if self.link_next_flood is not None:
                                            return True

                                        if self.link_next_flood_index is not None:
                                            return True

                                        if self.lsa_retransmission_timer is not None:
                                            return True

                                        if self.maximum_retransmission_length is not None:
                                            return True

                                        if self.maximum_retransmission_time is not None:
                                            return True

                                        if self.neighbor_retransmissions is not None:
                                            return True

                                        if self.retransmissions is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                        return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.NeighborDetailProcessTable.NeighborDetail.NeighborDetail_.NeighborRetransmission']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:neighbor-detail'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.interface_type is not None:
                                        return True

                                    if self.is_neighbor_filtered is not None:
                                        return True

                                    if self.neighbor_backup_designated_router_address is not None:
                                        return True

                                    if self.neighbor_cost is not None:
                                        return True

                                    if self.neighbor_designated_router_address is not None:
                                        return True

                                    if self.neighbor_ignore_timer is not None:
                                        return True

                                    if self.neighbor_option is not None:
                                        return True

                                    if self.neighbor_retransmission is not None and self.neighbor_retransmission._has_data():
                                        return True

                                    if self.next_poll_interval is not None:
                                        return True

                                    if self.pending_events is not None:
                                        return True

                                    if self.poll_interval is not None:
                                        return True

                                    if self.state_changes is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                    return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.NeighborDetailProcessTable.NeighborDetail.NeighborDetail_']['meta_info']


                            class NeighborBfdInfo(object):
                                """
                                Neighbor BFD information
                                
                                .. attribute:: bfd_intf_enable_mode
                                
                                	BFD enable mode \- Default/Strict
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bfd_status_flag
                                
                                	Status of the BFD Session
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.bfd_intf_enable_mode = None
                                    self.bfd_status_flag = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:neighbor-bfd-info'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.bfd_intf_enable_mode is not None:
                                        return True

                                    if self.bfd_status_flag is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                    return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.NeighborDetailProcessTable.NeighborDetail.NeighborBfdInfo']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:neighbor-detail'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.interface_name is not None:
                                    return True

                                if self.is_neighbor_sham_link is not None:
                                    return True

                                if self.is_neighbor_virtual_link is not None:
                                    return True

                                if self.neighbor_address is not None:
                                    return True

                                if self.neighbor_address_xr is not None:
                                    return True

                                if self.neighbor_bfd_info is not None and self.neighbor_bfd_info._has_data():
                                    return True

                                if self.neighbor_dead_timer is not None:
                                    return True

                                if self.neighbor_designated_router is not None:
                                    return True

                                if self.neighbor_detail is not None and self.neighbor_detail._has_data():
                                    return True

                                if self.neighbor_dr_priority is not None:
                                    return True

                                if self.neighbor_interface_id is not None:
                                    return True

                                if self.neighbor_sham_link_id is not None:
                                    return True

                                if self.neighbor_state is not None:
                                    return True

                                if self.neighbor_up_time is not None:
                                    return True

                                if self.neighbor_virtual_link_id is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.NeighborDetailProcessTable.NeighborDetail']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:neighbor-detail-process-table'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.neighbor_detail is not None:
                                for child_ref in self.neighbor_detail:
                                    if child_ref._has_data():
                                        return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                            return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf.NeighborDetailProcessTable']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')
                        if self.vrf_name is None:
                            raise YPYModelError('Key property vrf_name is None')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:vrf[Cisco-IOS-XR-ipv6-ospfv3-oper:vrf-name = ' + str(self.vrf_name) + ']'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.vrf_name is not None:
                            return True

                        if self.area_informations is not None and self.area_informations._has_data():
                            return True

                        if self.areas is not None and self.areas._has_data():
                            return True

                        if self.bad_checksums is not None and self.bad_checksums._has_data():
                            return True

                        if self.border_routers is not None and self.border_routers._has_data():
                            return True

                        if self.connected_routes is not None and self.connected_routes._has_data():
                            return True

                        if self.database_summary_table is not None and self.database_summary_table._has_data():
                            return True

                        if self.database_table is not None and self.database_table._has_data():
                            return True

                        if self.external_routes is not None and self.external_routes._has_data():
                            return True

                        if self.fast_reroutes is not None and self.fast_reroutes._has_data():
                            return True

                        if self.flood_list_process_table is not None and self.flood_list_process_table._has_data():
                            return True

                        if self.interface_brief_process_table is not None and self.interface_brief_process_table._has_data():
                            return True

                        if self.interface_process_table is not None and self.interface_process_table._has_data():
                            return True

                        if self.internal_routes is not None and self.internal_routes._has_data():
                            return True

                        if self.neighbor_detail_process_table is not None and self.neighbor_detail_process_table._has_data():
                            return True

                        if self.neighbor_process_table is not None and self.neighbor_process_table._has_data():
                            return True

                        if self.protocol_areas is not None and self.protocol_areas._has_data():
                            return True

                        if self.redistributions is not None and self.redistributions._has_data():
                            return True

                        if self.request_list_process_table is not None and self.request_list_process_table._has_data():
                            return True

                        if self.retransmission_list_process_table is not None and self.retransmission_list_process_table._has_data():
                            return True

                        if self.route_summary is not None and self.route_summary._has_data():
                            return True

                        if self.sham_link_table is not None and self.sham_link_table._has_data():
                            return True

                        if self.summary is not None and self.summary._has_data():
                            return True

                        if self.summary_prefixes is not None and self.summary_prefixes._has_data():
                            return True

                        if self.virtual_link is not None and self.virtual_link._has_data():
                            return True

                        if self.vrf_statistics is not None and self.vrf_statistics._has_data():
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                        return meta._meta_table['Ospfv3.Processes.Process.Vrfs.Vrf']['meta_info']

                @property
                def _common_path(self):
                    if self.parent is None:
                        raise YPYModelError('parent is not set . Cannot derive path.')

                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:vrfs'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.vrf is not None:
                        for child_ref in self.vrf:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                    return meta._meta_table['Ospfv3.Processes.Process.Vrfs']['meta_info']


            class Statistics(object):
                """
                Container for Statistics
                
                .. attribute:: issu_stats
                
                	OSPF ISSU statistics
                	**type**\:   :py:class:`IssuStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Statistics.IssuStats>`
                
                .. attribute:: nsr_pl_stats
                
                	OSPF NSR packet library statistics
                	**type**\:   :py:class:`NsrPlStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Statistics.NsrPlStats>`
                
                .. attribute:: nsr_stats
                
                	OSPF NSR statistics
                	**type**\:   :py:class:`NsrStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Statistics.NsrStats>`
                
                .. attribute:: prefix_priority_stats
                
                	OSPF Prefix SPF Prioritization statistics
                	**type**\:   :py:class:`PrefixPriorityStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Statistics.PrefixPriorityStats>`
                
                .. attribute:: protocol_stats
                
                	Protocol table
                	**type**\:   :py:class:`ProtocolStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Statistics.ProtocolStats>`
                
                .. attribute:: rawio_stats
                
                	OSPF Prefix SPF Prioritization statistics
                	**type**\:   :py:class:`RawioStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Statistics.RawioStats>`
                
                .. attribute:: rib_thread_stats
                
                	OSPFv3 RIB thread statistics
                	**type**\:   :py:class:`RibThreadStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Statistics.RibThreadStats>`
                
                .. attribute:: spf_stats
                
                	OSPFv3 RIB batch statistics
                	**type**\:   :py:class:`SpfStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Statistics.SpfStats>`
                
                .. attribute:: vrf_rib_batch_stats
                
                	OSPFv3 RIB batch statistics
                	**type**\:   :py:class:`VrfRibBatchStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Statistics.VrfRibBatchStats>`
                
                

                """

                _prefix = 'ipv6-ospfv3-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.issu_stats = Ospfv3.Processes.Process.Statistics.IssuStats()
                    self.issu_stats.parent = self
                    self.nsr_pl_stats = Ospfv3.Processes.Process.Statistics.NsrPlStats()
                    self.nsr_pl_stats.parent = self
                    self.nsr_stats = Ospfv3.Processes.Process.Statistics.NsrStats()
                    self.nsr_stats.parent = self
                    self.prefix_priority_stats = Ospfv3.Processes.Process.Statistics.PrefixPriorityStats()
                    self.prefix_priority_stats.parent = self
                    self.protocol_stats = Ospfv3.Processes.Process.Statistics.ProtocolStats()
                    self.protocol_stats.parent = self
                    self.rawio_stats = Ospfv3.Processes.Process.Statistics.RawioStats()
                    self.rawio_stats.parent = self
                    self.rib_thread_stats = Ospfv3.Processes.Process.Statistics.RibThreadStats()
                    self.rib_thread_stats.parent = self
                    self.spf_stats = Ospfv3.Processes.Process.Statistics.SpfStats()
                    self.spf_stats.parent = self
                    self.vrf_rib_batch_stats = Ospfv3.Processes.Process.Statistics.VrfRibBatchStats()
                    self.vrf_rib_batch_stats.parent = self


                class NsrStats(object):
                    """
                    OSPF NSR statistics
                    
                    .. attribute:: nsr_conn_to_active_attempts
                    
                    	Attempts to connect to active
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: nsr_conn_to_active_closes
                    
                    	Conn to active closes
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: nsr_conn_to_active_errors
                    
                    	Conn to active errors
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: nsr_conn_to_active_fails
                    
                    	Failures to connect to active
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: nsr_conn_to_active_opens
                    
                    	Conn to active opens
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: nsr_fsm_state
                    
                    	FSM state
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: nsr_intf_seq_no
                    
                    	Interface TLV sequence no
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: nsr_lsa_init_sync_pend_count
                    
                    	Pending init\-sync LSA msgs
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: nsr_lsa_qad_mdata_count
                    
                    	LSA QAD pending msgs
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: nsr_lsa_qad_qid
                    
                    	LSA QAD queue id
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: nsr_mtu
                    
                    	Fabric MTU
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: nsr_nbr_init_sync_pend_count
                    
                    	Pending init\-sync NBR msgs
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: nsr_nbr_qad_mdata_count
                    
                    	NBR QAD pending msg
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: nsr_nbr_qad_qid
                    
                    	NBR QAD queue id
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: nsr_nbr_seq_no
                    
                    	Neighbor TLV sequence no
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: nsr_node_id
                    
                    	My nodeid
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: nsr_peer_node_id
                    
                    	Partner NodeID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: nsr_peer_version
                    
                    	Partner NSR version
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: nsr_revision
                    
                    	NSR revision
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: nsr_rtr_thd_sched
                    
                    	Rtr thread NSR pulse handler stats
                    	**type**\:   :py:class:`NsrRtrThdSched <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Statistics.NsrStats.NsrRtrThdSched>`
                    
                    .. attribute:: nsr_thd_stats
                    
                    	NSR thread scheduler stats
                    	**type**\:   :py:class:`NsrThdStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Statistics.NsrStats.NsrThdStats>`
                    
                    .. attribute:: nsr_tmr_quant
                    
                    	Timers processed per pulse
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: nsr_version
                    
                    	NSR version
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv6-ospfv3-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.nsr_conn_to_active_attempts = None
                        self.nsr_conn_to_active_closes = None
                        self.nsr_conn_to_active_errors = None
                        self.nsr_conn_to_active_fails = None
                        self.nsr_conn_to_active_opens = None
                        self.nsr_fsm_state = None
                        self.nsr_intf_seq_no = None
                        self.nsr_lsa_init_sync_pend_count = None
                        self.nsr_lsa_qad_mdata_count = None
                        self.nsr_lsa_qad_qid = None
                        self.nsr_mtu = None
                        self.nsr_nbr_init_sync_pend_count = None
                        self.nsr_nbr_qad_mdata_count = None
                        self.nsr_nbr_qad_qid = None
                        self.nsr_nbr_seq_no = None
                        self.nsr_node_id = None
                        self.nsr_peer_node_id = None
                        self.nsr_peer_version = None
                        self.nsr_revision = None
                        self.nsr_rtr_thd_sched = Ospfv3.Processes.Process.Statistics.NsrStats.NsrRtrThdSched()
                        self.nsr_rtr_thd_sched.parent = self
                        self.nsr_thd_stats = Ospfv3.Processes.Process.Statistics.NsrStats.NsrThdStats()
                        self.nsr_thd_stats.parent = self
                        self.nsr_tmr_quant = None
                        self.nsr_version = None


                    class NsrThdStats(object):
                        """
                        NSR thread scheduler stats
                        
                        .. attribute:: nsr_bad_pulses_rx
                        
                        	Bad pulses received
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: nsr_events_in_q
                        
                        	Events pending
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: nsr_events_rx
                        
                        	Events processed
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: nsr_events_tx
                        
                        	Events to Router thread
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: nsr_good_pulses_rx
                        
                        	Good pulses received
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: nsr_pri
                        
                        	nsr pri
                        	**type**\: list of    :py:class:`NsrPri <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Statistics.NsrStats.NsrThdStats.NsrPri>`
                        
                        .. attribute:: nsr_pulse_quant
                        
                        	Events processed per pulse
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: nsr_pulse_tx_fails
                        
                        	Pulse send failures
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: nsr_pulses_tx
                        
                        	Pulses to Router thread
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.nsr_bad_pulses_rx = None
                            self.nsr_events_in_q = None
                            self.nsr_events_rx = None
                            self.nsr_events_tx = None
                            self.nsr_good_pulses_rx = None
                            self.nsr_pri = YList()
                            self.nsr_pri.parent = self
                            self.nsr_pri.name = 'nsr_pri'
                            self.nsr_pulse_quant = None
                            self.nsr_pulse_tx_fails = None
                            self.nsr_pulses_tx = None


                        class NsrPri(object):
                            """
                            nsr pri
                            
                            .. attribute:: nsr_sched_enq_fails
                            
                            	Event enqueue fails
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: nsr_sched_evs_deqd
                            
                            	Events dequeued
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: nsr_sched_evs_in_q
                            
                            	Events pending
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: nsr_sched_evs_qd
                            
                            	Events queued
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: nsr_sched_max_evs
                            
                            	Max Queued
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: nsr_sched_peak_q_len
                            
                            	Peak queue length
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: nsr_sched_pri
                            
                            	Priority Type
                            	**type**\:   :py:class:`OspfNsrSchedPriEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfNsrSchedPriEnum>`
                            
                            .. attribute:: nsr_sched_quant
                            
                            	Priority Queue
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: nsr_sched_remain_quant
                            
                            	Remaining quantum
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.nsr_sched_enq_fails = None
                                self.nsr_sched_evs_deqd = None
                                self.nsr_sched_evs_in_q = None
                                self.nsr_sched_evs_qd = None
                                self.nsr_sched_max_evs = None
                                self.nsr_sched_peak_q_len = None
                                self.nsr_sched_pri = None
                                self.nsr_sched_quant = None
                                self.nsr_sched_remain_quant = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:nsr-pri'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.nsr_sched_enq_fails is not None:
                                    return True

                                if self.nsr_sched_evs_deqd is not None:
                                    return True

                                if self.nsr_sched_evs_in_q is not None:
                                    return True

                                if self.nsr_sched_evs_qd is not None:
                                    return True

                                if self.nsr_sched_max_evs is not None:
                                    return True

                                if self.nsr_sched_peak_q_len is not None:
                                    return True

                                if self.nsr_sched_pri is not None:
                                    return True

                                if self.nsr_sched_quant is not None:
                                    return True

                                if self.nsr_sched_remain_quant is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                return meta._meta_table['Ospfv3.Processes.Process.Statistics.NsrStats.NsrThdStats.NsrPri']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:nsr-thd-stats'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.nsr_bad_pulses_rx is not None:
                                return True

                            if self.nsr_events_in_q is not None:
                                return True

                            if self.nsr_events_rx is not None:
                                return True

                            if self.nsr_events_tx is not None:
                                return True

                            if self.nsr_good_pulses_rx is not None:
                                return True

                            if self.nsr_pri is not None:
                                for child_ref in self.nsr_pri:
                                    if child_ref._has_data():
                                        return True

                            if self.nsr_pulse_quant is not None:
                                return True

                            if self.nsr_pulse_tx_fails is not None:
                                return True

                            if self.nsr_pulses_tx is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                            return meta._meta_table['Ospfv3.Processes.Process.Statistics.NsrStats.NsrThdStats']['meta_info']


                    class NsrRtrThdSched(object):
                        """
                        Rtr thread NSR pulse handler stats
                        
                        .. attribute:: nsr_bad_pulses_rx
                        
                        	Bad pulses received
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: nsr_events_in_q
                        
                        	Events pending
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: nsr_events_rx
                        
                        	Events processed
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: nsr_events_tx
                        
                        	Events to Router thread
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: nsr_good_pulses_rx
                        
                        	Good pulses received
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: nsr_pri
                        
                        	nsr pri
                        	**type**\: list of    :py:class:`NsrPri <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Statistics.NsrStats.NsrRtrThdSched.NsrPri>`
                        
                        .. attribute:: nsr_pulse_quant
                        
                        	Events processed per pulse
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: nsr_pulse_tx_fails
                        
                        	Pulse send failures
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: nsr_pulses_tx
                        
                        	Pulses to Router thread
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.nsr_bad_pulses_rx = None
                            self.nsr_events_in_q = None
                            self.nsr_events_rx = None
                            self.nsr_events_tx = None
                            self.nsr_good_pulses_rx = None
                            self.nsr_pri = YList()
                            self.nsr_pri.parent = self
                            self.nsr_pri.name = 'nsr_pri'
                            self.nsr_pulse_quant = None
                            self.nsr_pulse_tx_fails = None
                            self.nsr_pulses_tx = None


                        class NsrPri(object):
                            """
                            nsr pri
                            
                            .. attribute:: nsr_sched_enq_fails
                            
                            	Event enqueue fails
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: nsr_sched_evs_deqd
                            
                            	Events dequeued
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: nsr_sched_evs_in_q
                            
                            	Events pending
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: nsr_sched_evs_qd
                            
                            	Events queued
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: nsr_sched_max_evs
                            
                            	Max Queued
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: nsr_sched_peak_q_len
                            
                            	Peak queue length
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: nsr_sched_pri
                            
                            	Priority Type
                            	**type**\:   :py:class:`OspfNsrSchedPriEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfNsrSchedPriEnum>`
                            
                            .. attribute:: nsr_sched_quant
                            
                            	Priority Queue
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: nsr_sched_remain_quant
                            
                            	Remaining quantum
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.nsr_sched_enq_fails = None
                                self.nsr_sched_evs_deqd = None
                                self.nsr_sched_evs_in_q = None
                                self.nsr_sched_evs_qd = None
                                self.nsr_sched_max_evs = None
                                self.nsr_sched_peak_q_len = None
                                self.nsr_sched_pri = None
                                self.nsr_sched_quant = None
                                self.nsr_sched_remain_quant = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:nsr-pri'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.nsr_sched_enq_fails is not None:
                                    return True

                                if self.nsr_sched_evs_deqd is not None:
                                    return True

                                if self.nsr_sched_evs_in_q is not None:
                                    return True

                                if self.nsr_sched_evs_qd is not None:
                                    return True

                                if self.nsr_sched_max_evs is not None:
                                    return True

                                if self.nsr_sched_peak_q_len is not None:
                                    return True

                                if self.nsr_sched_pri is not None:
                                    return True

                                if self.nsr_sched_quant is not None:
                                    return True

                                if self.nsr_sched_remain_quant is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                return meta._meta_table['Ospfv3.Processes.Process.Statistics.NsrStats.NsrRtrThdSched.NsrPri']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:nsr-rtr-thd-sched'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.nsr_bad_pulses_rx is not None:
                                return True

                            if self.nsr_events_in_q is not None:
                                return True

                            if self.nsr_events_rx is not None:
                                return True

                            if self.nsr_events_tx is not None:
                                return True

                            if self.nsr_good_pulses_rx is not None:
                                return True

                            if self.nsr_pri is not None:
                                for child_ref in self.nsr_pri:
                                    if child_ref._has_data():
                                        return True

                            if self.nsr_pulse_quant is not None:
                                return True

                            if self.nsr_pulse_tx_fails is not None:
                                return True

                            if self.nsr_pulses_tx is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                            return meta._meta_table['Ospfv3.Processes.Process.Statistics.NsrStats.NsrRtrThdSched']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:nsr-stats'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.nsr_conn_to_active_attempts is not None:
                            return True

                        if self.nsr_conn_to_active_closes is not None:
                            return True

                        if self.nsr_conn_to_active_errors is not None:
                            return True

                        if self.nsr_conn_to_active_fails is not None:
                            return True

                        if self.nsr_conn_to_active_opens is not None:
                            return True

                        if self.nsr_fsm_state is not None:
                            return True

                        if self.nsr_intf_seq_no is not None:
                            return True

                        if self.nsr_lsa_init_sync_pend_count is not None:
                            return True

                        if self.nsr_lsa_qad_mdata_count is not None:
                            return True

                        if self.nsr_lsa_qad_qid is not None:
                            return True

                        if self.nsr_mtu is not None:
                            return True

                        if self.nsr_nbr_init_sync_pend_count is not None:
                            return True

                        if self.nsr_nbr_qad_mdata_count is not None:
                            return True

                        if self.nsr_nbr_qad_qid is not None:
                            return True

                        if self.nsr_nbr_seq_no is not None:
                            return True

                        if self.nsr_node_id is not None:
                            return True

                        if self.nsr_peer_node_id is not None:
                            return True

                        if self.nsr_peer_version is not None:
                            return True

                        if self.nsr_revision is not None:
                            return True

                        if self.nsr_rtr_thd_sched is not None and self.nsr_rtr_thd_sched._has_data():
                            return True

                        if self.nsr_thd_stats is not None and self.nsr_thd_stats._has_data():
                            return True

                        if self.nsr_tmr_quant is not None:
                            return True

                        if self.nsr_version is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                        return meta._meta_table['Ospfv3.Processes.Process.Statistics.NsrStats']['meta_info']


                class RibThreadStats(object):
                    """
                    OSPFv3 RIB thread statistics
                    
                    .. attribute:: holdq
                    
                    	holdq
                    	**type**\: list of    :py:class:`Holdq <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Statistics.RibThreadStats.Holdq>`
                    
                    .. attribute:: rib_base_clock
                    
                    	Rib Base Clock
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: rib_base_time
                    
                    	rib base time
                    	**type**\:   :py:class:`RibBaseTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Statistics.RibThreadStats.RibBaseTime>`
                    
                    .. attribute:: rib_batch_backup
                    
                    	Rib Batches Back up
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rib_batch_err
                    
                    	Batch errors
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rib_batch_limit
                    
                    	Rib Batches Limit
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rib_batch_no_table
                    
                    	Batches no table
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rib_batch_ok
                    
                    	Rib Batches Ok
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rib_batch_purged
                    
                    	No. of Rib batches purged
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rib_batch_sent
                    
                    	No. of Rib batches sent
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rib_batch_some_err
                    
                    	Batches with some error
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rib_drop_conn
                    
                    	Rib drop connections
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rib_drop_version
                    
                    	Rib drop version
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rib_max_latency
                    
                    	Max time entry was in queue
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: rib_path_err
                    
                    	Route path errors
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rib_path_limit
                    
                    	Route path limits
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rib_route_err
                    
                    	Route Errors
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rib_route_limit
                    
                    	Route table limit
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rib_route_some_err
                    
                    	Route some errors
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rib_sum_latency
                    
                    	Sum latencies to calc average
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: thread_q
                    
                    	Inter Thread Queue
                    	**type**\:   :py:class:`ThreadQ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Statistics.RibThreadStats.ThreadQ>`
                    
                    .. attribute:: wq_signals
                    
                    	Signals sent to RIB Thread
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: wq_thread_active
                    
                    	RIB Thread Active Indicator
                    	**type**\:  bool
                    
                    

                    """

                    _prefix = 'ipv6-ospfv3-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.holdq = YList()
                        self.holdq.parent = self
                        self.holdq.name = 'holdq'
                        self.rib_base_clock = None
                        self.rib_base_time = Ospfv3.Processes.Process.Statistics.RibThreadStats.RibBaseTime()
                        self.rib_base_time.parent = self
                        self.rib_batch_backup = None
                        self.rib_batch_err = None
                        self.rib_batch_limit = None
                        self.rib_batch_no_table = None
                        self.rib_batch_ok = None
                        self.rib_batch_purged = None
                        self.rib_batch_sent = None
                        self.rib_batch_some_err = None
                        self.rib_drop_conn = None
                        self.rib_drop_version = None
                        self.rib_max_latency = None
                        self.rib_path_err = None
                        self.rib_path_limit = None
                        self.rib_route_err = None
                        self.rib_route_limit = None
                        self.rib_route_some_err = None
                        self.rib_sum_latency = None
                        self.thread_q = Ospfv3.Processes.Process.Statistics.RibThreadStats.ThreadQ()
                        self.thread_q.parent = self
                        self.wq_signals = None
                        self.wq_thread_active = None


                    class ThreadQ(object):
                        """
                        Inter Thread Queue
                        
                        .. attribute:: wq_dequeue_errs
                        
                        	Dequeue Errors
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: wq_dqtime
                        
                        	Last Entry Dequeue
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: wq_eneueue_errs
                        
                        	Enqueue Errors
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: wq_eqtime
                        
                        	Head Entry Enqueue
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: wq_first_eqtime
                        
                        	First Entry Enqueue
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: wq_len_cur
                        
                        	Current Work Queue Length
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: wq_len_max
                        
                        	Largest Work Queue Length
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: wq_max_latency
                        
                        	Max Time Entry Was In Q
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: wq_sum_latency
                        
                        	Sum Latencies To Calc Average
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: wq_total_dequeued
                        
                        	Total Entries Dequeued
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: wq_total_enqueued
                        
                        	Total Entries Enqueued
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.wq_dequeue_errs = None
                            self.wq_dqtime = None
                            self.wq_eneueue_errs = None
                            self.wq_eqtime = None
                            self.wq_first_eqtime = None
                            self.wq_len_cur = None
                            self.wq_len_max = None
                            self.wq_max_latency = None
                            self.wq_sum_latency = None
                            self.wq_total_dequeued = None
                            self.wq_total_enqueued = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:thread-q'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.wq_dequeue_errs is not None:
                                return True

                            if self.wq_dqtime is not None:
                                return True

                            if self.wq_eneueue_errs is not None:
                                return True

                            if self.wq_eqtime is not None:
                                return True

                            if self.wq_first_eqtime is not None:
                                return True

                            if self.wq_len_cur is not None:
                                return True

                            if self.wq_len_max is not None:
                                return True

                            if self.wq_max_latency is not None:
                                return True

                            if self.wq_sum_latency is not None:
                                return True

                            if self.wq_total_dequeued is not None:
                                return True

                            if self.wq_total_enqueued is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                            return meta._meta_table['Ospfv3.Processes.Process.Statistics.RibThreadStats.ThreadQ']['meta_info']


                    class RibBaseTime(object):
                        """
                        rib base time
                        
                        .. attribute:: nanosecond
                        
                        	Nano seconds 
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: nanosecond
                        
                        .. attribute:: second
                        
                        	Seconds 
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.nanosecond = None
                            self.second = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:rib-base-time'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.nanosecond is not None:
                                return True

                            if self.second is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                            return meta._meta_table['Ospfv3.Processes.Process.Statistics.RibThreadStats.RibBaseTime']['meta_info']


                    class Holdq(object):
                        """
                        holdq
                        
                        .. attribute:: wq_dequeue_errs
                        
                        	Dequeue Errors
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: wq_dqtime
                        
                        	Last Entry Dequeue
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: wq_eneueue_errs
                        
                        	Enqueue Errors
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: wq_eqtime
                        
                        	Head Entry Enqueue
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: wq_first_eqtime
                        
                        	First Entry Enqueue
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: wq_len_cur
                        
                        	Current Work Queue Length
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: wq_len_max
                        
                        	Largest Work Queue Length
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: wq_max_latency
                        
                        	Max Time Entry Was In Q
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: wq_sum_latency
                        
                        	Sum Latencies To Calc Average
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: wq_total_dequeued
                        
                        	Total Entries Dequeued
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: wq_total_enqueued
                        
                        	Total Entries Enqueued
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.wq_dequeue_errs = None
                            self.wq_dqtime = None
                            self.wq_eneueue_errs = None
                            self.wq_eqtime = None
                            self.wq_first_eqtime = None
                            self.wq_len_cur = None
                            self.wq_len_max = None
                            self.wq_max_latency = None
                            self.wq_sum_latency = None
                            self.wq_total_dequeued = None
                            self.wq_total_enqueued = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:holdq'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.wq_dequeue_errs is not None:
                                return True

                            if self.wq_dqtime is not None:
                                return True

                            if self.wq_eneueue_errs is not None:
                                return True

                            if self.wq_eqtime is not None:
                                return True

                            if self.wq_first_eqtime is not None:
                                return True

                            if self.wq_len_cur is not None:
                                return True

                            if self.wq_len_max is not None:
                                return True

                            if self.wq_max_latency is not None:
                                return True

                            if self.wq_sum_latency is not None:
                                return True

                            if self.wq_total_dequeued is not None:
                                return True

                            if self.wq_total_enqueued is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                            return meta._meta_table['Ospfv3.Processes.Process.Statistics.RibThreadStats.Holdq']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:rib-thread-stats'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.holdq is not None:
                            for child_ref in self.holdq:
                                if child_ref._has_data():
                                    return True

                        if self.rib_base_clock is not None:
                            return True

                        if self.rib_base_time is not None and self.rib_base_time._has_data():
                            return True

                        if self.rib_batch_backup is not None:
                            return True

                        if self.rib_batch_err is not None:
                            return True

                        if self.rib_batch_limit is not None:
                            return True

                        if self.rib_batch_no_table is not None:
                            return True

                        if self.rib_batch_ok is not None:
                            return True

                        if self.rib_batch_purged is not None:
                            return True

                        if self.rib_batch_sent is not None:
                            return True

                        if self.rib_batch_some_err is not None:
                            return True

                        if self.rib_drop_conn is not None:
                            return True

                        if self.rib_drop_version is not None:
                            return True

                        if self.rib_max_latency is not None:
                            return True

                        if self.rib_path_err is not None:
                            return True

                        if self.rib_path_limit is not None:
                            return True

                        if self.rib_route_err is not None:
                            return True

                        if self.rib_route_limit is not None:
                            return True

                        if self.rib_route_some_err is not None:
                            return True

                        if self.rib_sum_latency is not None:
                            return True

                        if self.thread_q is not None and self.thread_q._has_data():
                            return True

                        if self.wq_signals is not None:
                            return True

                        if self.wq_thread_active is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                        return meta._meta_table['Ospfv3.Processes.Process.Statistics.RibThreadStats']['meta_info']


                class IssuStats(object):
                    """
                    OSPF ISSU statistics
                    
                    .. attribute:: nsr_conn_to_active_attempts
                    
                    	Attempts to connect to active
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: nsr_conn_to_active_closes
                    
                    	Conn to active closes
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: nsr_conn_to_active_errors
                    
                    	Conn to active errors
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: nsr_conn_to_active_fails
                    
                    	Failures to connect to active
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: nsr_conn_to_active_opens
                    
                    	Conn to active opens
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: nsr_fsm_state
                    
                    	FSM state
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: nsr_intf_seq_no
                    
                    	Interface TLV sequence no
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: nsr_lsa_init_sync_pend_count
                    
                    	Pending init\-sync LSA msgs
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: nsr_lsa_qad_mdata_count
                    
                    	LSA QAD pending msgs
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: nsr_lsa_qad_qid
                    
                    	LSA QAD queue id
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: nsr_mtu
                    
                    	Fabric MTU
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: nsr_nbr_init_sync_pend_count
                    
                    	Pending init\-sync NBR msgs
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: nsr_nbr_qad_mdata_count
                    
                    	NBR QAD pending msg
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: nsr_nbr_qad_qid
                    
                    	NBR QAD queue id
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: nsr_nbr_seq_no
                    
                    	Neighbor TLV sequence no
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: nsr_node_id
                    
                    	My nodeid
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: nsr_peer_node_id
                    
                    	Partner NodeID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: nsr_peer_version
                    
                    	Partner NSR version
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: nsr_revision
                    
                    	NSR revision
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: nsr_rtr_thd_sched
                    
                    	Rtr thread NSR pulse handler stats
                    	**type**\:   :py:class:`NsrRtrThdSched <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Statistics.IssuStats.NsrRtrThdSched>`
                    
                    .. attribute:: nsr_thd_stats
                    
                    	NSR thread scheduler stats
                    	**type**\:   :py:class:`NsrThdStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Statistics.IssuStats.NsrThdStats>`
                    
                    .. attribute:: nsr_tmr_quant
                    
                    	Timers processed per pulse
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: nsr_version
                    
                    	NSR version
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv6-ospfv3-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.nsr_conn_to_active_attempts = None
                        self.nsr_conn_to_active_closes = None
                        self.nsr_conn_to_active_errors = None
                        self.nsr_conn_to_active_fails = None
                        self.nsr_conn_to_active_opens = None
                        self.nsr_fsm_state = None
                        self.nsr_intf_seq_no = None
                        self.nsr_lsa_init_sync_pend_count = None
                        self.nsr_lsa_qad_mdata_count = None
                        self.nsr_lsa_qad_qid = None
                        self.nsr_mtu = None
                        self.nsr_nbr_init_sync_pend_count = None
                        self.nsr_nbr_qad_mdata_count = None
                        self.nsr_nbr_qad_qid = None
                        self.nsr_nbr_seq_no = None
                        self.nsr_node_id = None
                        self.nsr_peer_node_id = None
                        self.nsr_peer_version = None
                        self.nsr_revision = None
                        self.nsr_rtr_thd_sched = Ospfv3.Processes.Process.Statistics.IssuStats.NsrRtrThdSched()
                        self.nsr_rtr_thd_sched.parent = self
                        self.nsr_thd_stats = Ospfv3.Processes.Process.Statistics.IssuStats.NsrThdStats()
                        self.nsr_thd_stats.parent = self
                        self.nsr_tmr_quant = None
                        self.nsr_version = None


                    class NsrThdStats(object):
                        """
                        NSR thread scheduler stats
                        
                        .. attribute:: nsr_bad_pulses_rx
                        
                        	Bad pulses received
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: nsr_events_in_q
                        
                        	Events pending
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: nsr_events_rx
                        
                        	Events processed
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: nsr_events_tx
                        
                        	Events to Router thread
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: nsr_good_pulses_rx
                        
                        	Good pulses received
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: nsr_pri
                        
                        	nsr pri
                        	**type**\: list of    :py:class:`NsrPri <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Statistics.IssuStats.NsrThdStats.NsrPri>`
                        
                        .. attribute:: nsr_pulse_quant
                        
                        	Events processed per pulse
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: nsr_pulse_tx_fails
                        
                        	Pulse send failures
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: nsr_pulses_tx
                        
                        	Pulses to Router thread
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.nsr_bad_pulses_rx = None
                            self.nsr_events_in_q = None
                            self.nsr_events_rx = None
                            self.nsr_events_tx = None
                            self.nsr_good_pulses_rx = None
                            self.nsr_pri = YList()
                            self.nsr_pri.parent = self
                            self.nsr_pri.name = 'nsr_pri'
                            self.nsr_pulse_quant = None
                            self.nsr_pulse_tx_fails = None
                            self.nsr_pulses_tx = None


                        class NsrPri(object):
                            """
                            nsr pri
                            
                            .. attribute:: nsr_sched_enq_fails
                            
                            	Event enqueue fails
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: nsr_sched_evs_deqd
                            
                            	Events dequeued
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: nsr_sched_evs_in_q
                            
                            	Events pending
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: nsr_sched_evs_qd
                            
                            	Events queued
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: nsr_sched_max_evs
                            
                            	Max Queued
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: nsr_sched_peak_q_len
                            
                            	Peak queue length
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: nsr_sched_pri
                            
                            	Priority Type
                            	**type**\:   :py:class:`OspfNsrSchedPriEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfNsrSchedPriEnum>`
                            
                            .. attribute:: nsr_sched_quant
                            
                            	Priority Queue
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: nsr_sched_remain_quant
                            
                            	Remaining quantum
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.nsr_sched_enq_fails = None
                                self.nsr_sched_evs_deqd = None
                                self.nsr_sched_evs_in_q = None
                                self.nsr_sched_evs_qd = None
                                self.nsr_sched_max_evs = None
                                self.nsr_sched_peak_q_len = None
                                self.nsr_sched_pri = None
                                self.nsr_sched_quant = None
                                self.nsr_sched_remain_quant = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:nsr-pri'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.nsr_sched_enq_fails is not None:
                                    return True

                                if self.nsr_sched_evs_deqd is not None:
                                    return True

                                if self.nsr_sched_evs_in_q is not None:
                                    return True

                                if self.nsr_sched_evs_qd is not None:
                                    return True

                                if self.nsr_sched_max_evs is not None:
                                    return True

                                if self.nsr_sched_peak_q_len is not None:
                                    return True

                                if self.nsr_sched_pri is not None:
                                    return True

                                if self.nsr_sched_quant is not None:
                                    return True

                                if self.nsr_sched_remain_quant is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                return meta._meta_table['Ospfv3.Processes.Process.Statistics.IssuStats.NsrThdStats.NsrPri']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:nsr-thd-stats'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.nsr_bad_pulses_rx is not None:
                                return True

                            if self.nsr_events_in_q is not None:
                                return True

                            if self.nsr_events_rx is not None:
                                return True

                            if self.nsr_events_tx is not None:
                                return True

                            if self.nsr_good_pulses_rx is not None:
                                return True

                            if self.nsr_pri is not None:
                                for child_ref in self.nsr_pri:
                                    if child_ref._has_data():
                                        return True

                            if self.nsr_pulse_quant is not None:
                                return True

                            if self.nsr_pulse_tx_fails is not None:
                                return True

                            if self.nsr_pulses_tx is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                            return meta._meta_table['Ospfv3.Processes.Process.Statistics.IssuStats.NsrThdStats']['meta_info']


                    class NsrRtrThdSched(object):
                        """
                        Rtr thread NSR pulse handler stats
                        
                        .. attribute:: nsr_bad_pulses_rx
                        
                        	Bad pulses received
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: nsr_events_in_q
                        
                        	Events pending
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: nsr_events_rx
                        
                        	Events processed
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: nsr_events_tx
                        
                        	Events to Router thread
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: nsr_good_pulses_rx
                        
                        	Good pulses received
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: nsr_pri
                        
                        	nsr pri
                        	**type**\: list of    :py:class:`NsrPri <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Statistics.IssuStats.NsrRtrThdSched.NsrPri>`
                        
                        .. attribute:: nsr_pulse_quant
                        
                        	Events processed per pulse
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: nsr_pulse_tx_fails
                        
                        	Pulse send failures
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: nsr_pulses_tx
                        
                        	Pulses to Router thread
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.nsr_bad_pulses_rx = None
                            self.nsr_events_in_q = None
                            self.nsr_events_rx = None
                            self.nsr_events_tx = None
                            self.nsr_good_pulses_rx = None
                            self.nsr_pri = YList()
                            self.nsr_pri.parent = self
                            self.nsr_pri.name = 'nsr_pri'
                            self.nsr_pulse_quant = None
                            self.nsr_pulse_tx_fails = None
                            self.nsr_pulses_tx = None


                        class NsrPri(object):
                            """
                            nsr pri
                            
                            .. attribute:: nsr_sched_enq_fails
                            
                            	Event enqueue fails
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: nsr_sched_evs_deqd
                            
                            	Events dequeued
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: nsr_sched_evs_in_q
                            
                            	Events pending
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: nsr_sched_evs_qd
                            
                            	Events queued
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: nsr_sched_max_evs
                            
                            	Max Queued
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: nsr_sched_peak_q_len
                            
                            	Peak queue length
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: nsr_sched_pri
                            
                            	Priority Type
                            	**type**\:   :py:class:`OspfNsrSchedPriEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfNsrSchedPriEnum>`
                            
                            .. attribute:: nsr_sched_quant
                            
                            	Priority Queue
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: nsr_sched_remain_quant
                            
                            	Remaining quantum
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.nsr_sched_enq_fails = None
                                self.nsr_sched_evs_deqd = None
                                self.nsr_sched_evs_in_q = None
                                self.nsr_sched_evs_qd = None
                                self.nsr_sched_max_evs = None
                                self.nsr_sched_peak_q_len = None
                                self.nsr_sched_pri = None
                                self.nsr_sched_quant = None
                                self.nsr_sched_remain_quant = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:nsr-pri'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.nsr_sched_enq_fails is not None:
                                    return True

                                if self.nsr_sched_evs_deqd is not None:
                                    return True

                                if self.nsr_sched_evs_in_q is not None:
                                    return True

                                if self.nsr_sched_evs_qd is not None:
                                    return True

                                if self.nsr_sched_max_evs is not None:
                                    return True

                                if self.nsr_sched_peak_q_len is not None:
                                    return True

                                if self.nsr_sched_pri is not None:
                                    return True

                                if self.nsr_sched_quant is not None:
                                    return True

                                if self.nsr_sched_remain_quant is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                return meta._meta_table['Ospfv3.Processes.Process.Statistics.IssuStats.NsrRtrThdSched.NsrPri']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:nsr-rtr-thd-sched'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.nsr_bad_pulses_rx is not None:
                                return True

                            if self.nsr_events_in_q is not None:
                                return True

                            if self.nsr_events_rx is not None:
                                return True

                            if self.nsr_events_tx is not None:
                                return True

                            if self.nsr_good_pulses_rx is not None:
                                return True

                            if self.nsr_pri is not None:
                                for child_ref in self.nsr_pri:
                                    if child_ref._has_data():
                                        return True

                            if self.nsr_pulse_quant is not None:
                                return True

                            if self.nsr_pulse_tx_fails is not None:
                                return True

                            if self.nsr_pulses_tx is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                            return meta._meta_table['Ospfv3.Processes.Process.Statistics.IssuStats.NsrRtrThdSched']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:issu-stats'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.nsr_conn_to_active_attempts is not None:
                            return True

                        if self.nsr_conn_to_active_closes is not None:
                            return True

                        if self.nsr_conn_to_active_errors is not None:
                            return True

                        if self.nsr_conn_to_active_fails is not None:
                            return True

                        if self.nsr_conn_to_active_opens is not None:
                            return True

                        if self.nsr_fsm_state is not None:
                            return True

                        if self.nsr_intf_seq_no is not None:
                            return True

                        if self.nsr_lsa_init_sync_pend_count is not None:
                            return True

                        if self.nsr_lsa_qad_mdata_count is not None:
                            return True

                        if self.nsr_lsa_qad_qid is not None:
                            return True

                        if self.nsr_mtu is not None:
                            return True

                        if self.nsr_nbr_init_sync_pend_count is not None:
                            return True

                        if self.nsr_nbr_qad_mdata_count is not None:
                            return True

                        if self.nsr_nbr_qad_qid is not None:
                            return True

                        if self.nsr_nbr_seq_no is not None:
                            return True

                        if self.nsr_node_id is not None:
                            return True

                        if self.nsr_peer_node_id is not None:
                            return True

                        if self.nsr_peer_version is not None:
                            return True

                        if self.nsr_revision is not None:
                            return True

                        if self.nsr_rtr_thd_sched is not None and self.nsr_rtr_thd_sched._has_data():
                            return True

                        if self.nsr_thd_stats is not None and self.nsr_thd_stats._has_data():
                            return True

                        if self.nsr_tmr_quant is not None:
                            return True

                        if self.nsr_version is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                        return meta._meta_table['Ospfv3.Processes.Process.Statistics.IssuStats']['meta_info']


                class NsrPlStats(object):
                    """
                    OSPF NSR packet library statistics
                    
                    .. attribute:: ncd_pri
                    
                    	ncd pri
                    	**type**\: list of    :py:class:`NcdPri <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Statistics.NsrPlStats.NcdPri>`
                    
                    

                    """

                    _prefix = 'ipv6-ospfv3-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.ncd_pri = YList()
                        self.ncd_pri.parent = self
                        self.ncd_pri.name = 'ncd_pri'


                    class NcdPri(object):
                        """
                        ncd pri
                        
                        .. attribute:: num_recv
                        
                        	Total recvd
                        	**type**\:  list of int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: num_recv_drop
                        
                        	Recv Errors/drops
                        	**type**\: list of    :py:class:`NumRecvDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Statistics.NsrPlStats.NcdPri.NumRecvDrop>`
                        
                        .. attribute:: num_sent
                        
                        	Total sent
                        	**type**\:  list of int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: num_sent_drop
                        
                        	Sent Error/drops
                        	**type**\: list of    :py:class:`NumSentDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Statistics.NsrPlStats.NcdPri.NumSentDrop>`
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.num_recv = YLeafList()
                            self.num_recv.parent = self
                            self.num_recv.name = 'num_recv'
                            self.num_recv_drop = YList()
                            self.num_recv_drop.parent = self
                            self.num_recv_drop.name = 'num_recv_drop'
                            self.num_sent = YLeafList()
                            self.num_sent.parent = self
                            self.num_sent.name = 'num_sent'
                            self.num_sent_drop = YList()
                            self.num_sent_drop.parent = self
                            self.num_sent_drop.name = 'num_sent_drop'


                        class NumSentDrop(object):
                            """
                            Sent Error/drops
                            
                            .. attribute:: nsr_pl_send_drop_array
                            
                            	nsr pl send drop array
                            	**type**\:  list of int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.nsr_pl_send_drop_array = YLeafList()
                                self.nsr_pl_send_drop_array.parent = self
                                self.nsr_pl_send_drop_array.name = 'nsr_pl_send_drop_array'

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:num-sent-drop'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.nsr_pl_send_drop_array is not None:
                                    for child in self.nsr_pl_send_drop_array:
                                        if child is not None:
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                return meta._meta_table['Ospfv3.Processes.Process.Statistics.NsrPlStats.NcdPri.NumSentDrop']['meta_info']


                        class NumRecvDrop(object):
                            """
                            Recv Errors/drops
                            
                            .. attribute:: nsr_pl_recv_drop_array
                            
                            	nsr pl recv drop array
                            	**type**\:  list of int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.nsr_pl_recv_drop_array = YLeafList()
                                self.nsr_pl_recv_drop_array.parent = self
                                self.nsr_pl_recv_drop_array.name = 'nsr_pl_recv_drop_array'

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:num-recv-drop'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.nsr_pl_recv_drop_array is not None:
                                    for child in self.nsr_pl_recv_drop_array:
                                        if child is not None:
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                return meta._meta_table['Ospfv3.Processes.Process.Statistics.NsrPlStats.NcdPri.NumRecvDrop']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:ncd-pri'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.num_recv is not None:
                                for child in self.num_recv:
                                    if child is not None:
                                        return True

                            if self.num_recv_drop is not None:
                                for child_ref in self.num_recv_drop:
                                    if child_ref._has_data():
                                        return True

                            if self.num_sent is not None:
                                for child in self.num_sent:
                                    if child is not None:
                                        return True

                            if self.num_sent_drop is not None:
                                for child_ref in self.num_sent_drop:
                                    if child_ref._has_data():
                                        return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                            return meta._meta_table['Ospfv3.Processes.Process.Statistics.NsrPlStats.NcdPri']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:nsr-pl-stats'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.ncd_pri is not None:
                            for child_ref in self.ncd_pri:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                        return meta._meta_table['Ospfv3.Processes.Process.Statistics.NsrPlStats']['meta_info']


                class ProtocolStats(object):
                    """
                    Protocol table
                    
                    .. attribute:: protocol_stat
                    
                    	Protocol statistics for an interface
                    	**type**\: list of    :py:class:`ProtocolStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Statistics.ProtocolStats.ProtocolStat>`
                    
                    

                    """

                    _prefix = 'ipv6-ospfv3-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.protocol_stat = YList()
                        self.protocol_stat.parent = self
                        self.protocol_stat.name = 'protocol_stat'


                    class ProtocolStat(object):
                        """
                        Protocol statistics for an interface
                        
                        .. attribute:: interface_name  <key>
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: checksum_err
                        
                        	Checksum Errors
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: dbdes_in_ls_as
                        
                        	Database Description LSAs in
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: dbdes_in_packets
                        
                        	Database Description Packets in
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: dbdes_out_ls_as
                        
                        	Database Description LSAs out
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: dbdes_out_packets
                        
                        	Database Description Packets out
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: dropped_in_gs
                        
                        	Dropped in GS
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: hello_in_packets
                        
                        	Hello packets in
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: hello_out_packets
                        
                        	Hello Out Packets
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: ls_ack_in_ls_as
                        
                        	LS Ack LSAs in
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: ls_ack_in_packets
                        
                        	LS Acks Packets in
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: ls_ack_out_ls_as
                        
                        	LS Ack LSAs out
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: ls_ack_out_packets
                        
                        	LS Ack Packets out
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: ls_req_in_ls_as
                        
                        	LS Requests in
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: ls_req_in_packets
                        
                        	LSA Requests in
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: ls_req_out_ls_as
                        
                        	LS Reuqests LSAs out
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: ls_req_out_packets
                        
                        	LS Request Packets out
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: ls_upd_in_ignored
                        
                        	LS Updates ignored
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: ls_upd_in_ls_as
                        
                        	LS Updates LSAs in
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: ls_upd_in_packets
                        
                        	LS Updates Packets in
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: ls_upd_out_ls_as
                        
                        	LS Update LSAs out
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: ls_upd_out_packets
                        
                        	LS Update Packets out
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: total_in_packets
                        
                        	Total inputs packets
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: total_out_packets
                        
                        	Total Out Packets
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.interface_name = None
                            self.checksum_err = None
                            self.dbdes_in_ls_as = None
                            self.dbdes_in_packets = None
                            self.dbdes_out_ls_as = None
                            self.dbdes_out_packets = None
                            self.dropped_in_gs = None
                            self.hello_in_packets = None
                            self.hello_out_packets = None
                            self.ls_ack_in_ls_as = None
                            self.ls_ack_in_packets = None
                            self.ls_ack_out_ls_as = None
                            self.ls_ack_out_packets = None
                            self.ls_req_in_ls_as = None
                            self.ls_req_in_packets = None
                            self.ls_req_out_ls_as = None
                            self.ls_req_out_packets = None
                            self.ls_upd_in_ignored = None
                            self.ls_upd_in_ls_as = None
                            self.ls_upd_in_packets = None
                            self.ls_upd_out_ls_as = None
                            self.ls_upd_out_packets = None
                            self.total_in_packets = None
                            self.total_out_packets = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')
                            if self.interface_name is None:
                                raise YPYModelError('Key property interface_name is None')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:protocol-stat[Cisco-IOS-XR-ipv6-ospfv3-oper:interface-name = ' + str(self.interface_name) + ']'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.interface_name is not None:
                                return True

                            if self.checksum_err is not None:
                                return True

                            if self.dbdes_in_ls_as is not None:
                                return True

                            if self.dbdes_in_packets is not None:
                                return True

                            if self.dbdes_out_ls_as is not None:
                                return True

                            if self.dbdes_out_packets is not None:
                                return True

                            if self.dropped_in_gs is not None:
                                return True

                            if self.hello_in_packets is not None:
                                return True

                            if self.hello_out_packets is not None:
                                return True

                            if self.ls_ack_in_ls_as is not None:
                                return True

                            if self.ls_ack_in_packets is not None:
                                return True

                            if self.ls_ack_out_ls_as is not None:
                                return True

                            if self.ls_ack_out_packets is not None:
                                return True

                            if self.ls_req_in_ls_as is not None:
                                return True

                            if self.ls_req_in_packets is not None:
                                return True

                            if self.ls_req_out_ls_as is not None:
                                return True

                            if self.ls_req_out_packets is not None:
                                return True

                            if self.ls_upd_in_ignored is not None:
                                return True

                            if self.ls_upd_in_ls_as is not None:
                                return True

                            if self.ls_upd_in_packets is not None:
                                return True

                            if self.ls_upd_out_ls_as is not None:
                                return True

                            if self.ls_upd_out_packets is not None:
                                return True

                            if self.total_in_packets is not None:
                                return True

                            if self.total_out_packets is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                            return meta._meta_table['Ospfv3.Processes.Process.Statistics.ProtocolStats.ProtocolStat']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:protocol-stats'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.protocol_stat is not None:
                            for child_ref in self.protocol_stat:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                        return meta._meta_table['Ospfv3.Processes.Process.Statistics.ProtocolStats']['meta_info']


                class SpfStats(object):
                    """
                    OSPFv3 RIB batch statistics
                    
                    .. attribute:: spf_header
                    
                    	SPF statistics header
                    	**type**\:   :py:class:`SpfHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Statistics.SpfStats.SpfHeader>`
                    
                    .. attribute:: spf_runtime
                    
                    	List of SPF run\-time statistics
                    	**type**\: list of    :py:class:`SpfRuntime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Statistics.SpfStats.SpfRuntime>`
                    
                    

                    """

                    _prefix = 'ipv6-ospfv3-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.spf_header = Ospfv3.Processes.Process.Statistics.SpfStats.SpfHeader()
                        self.spf_header.parent = self
                        self.spf_runtime = YList()
                        self.spf_runtime.parent = self
                        self.spf_runtime.name = 'spf_runtime'


                    class SpfHeader(object):
                        """
                        SPF statistics header
                        
                        .. attribute:: area_summary
                        
                        	List of Areas with SPF statistics
                        	**type**\: list of    :py:class:`AreaSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Statistics.SpfStats.SpfHeader.AreaSummary>`
                        
                        .. attribute:: header_router_id
                        
                        	Router ID
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: header_sp_fs
                        
                        	Number of SPF calculations
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.area_summary = YList()
                            self.area_summary.parent = self
                            self.area_summary.name = 'area_summary'
                            self.header_router_id = None
                            self.header_sp_fs = None


                        class AreaSummary(object):
                            """
                            List of Areas with SPF statistics
                            
                            .. attribute:: area_id
                            
                            	Area ID of the area SPF statistics
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: sp_fs
                            
                            	Number of SPF calculations
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.area_id = None
                                self.sp_fs = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:area-summary'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.area_id is not None:
                                    return True

                                if self.sp_fs is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                return meta._meta_table['Ospfv3.Processes.Process.Statistics.SpfStats.SpfHeader.AreaSummary']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:spf-header'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.area_summary is not None:
                                for child_ref in self.area_summary:
                                    if child_ref._has_data():
                                        return True

                            if self.header_router_id is not None:
                                return True

                            if self.header_sp_fs is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                            return meta._meta_table['Ospfv3.Processes.Process.Statistics.SpfStats.SpfHeader']['meta_info']


                    class SpfRuntime(object):
                        """
                        List of SPF run\-time statistics
                        
                        .. attribute:: area_stat
                        
                        	List of per\-area SPF statistics
                        	**type**\: list of    :py:class:`AreaStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Statistics.SpfStats.SpfRuntime.AreaStat>`
                        
                        .. attribute:: global_time
                        
                        	Global SPF times
                        	**type**\:   :py:class:`GlobalTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Statistics.SpfStats.SpfRuntime.GlobalTime>`
                        
                        .. attribute:: lsa
                        
                        	List of LSAs triggering the SPF calculation
                        	**type**\: list of    :py:class:`Lsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Statistics.SpfStats.SpfRuntime.Lsa>`
                        
                        .. attribute:: lsa_changes
                        
                        	Number of LSA changes triggering an SPF calculation
                        	**type**\:  int
                        
                        	**range:** \-32768..32767
                        
                        .. attribute:: reason_flags
                        
                        	Reasons for triggering an SPF calculation Bit 1 \- Router LSA update Bit 2 \- Network LSA update Bit 3 \- Inter\-Area Prefix LSA update Bit 4 \- Inter\-Area Router LSA update Bit 5 \- AS External LSA update Bit 6 \- MOSPF LSA update Bit 7 \- Type 7 AS External LSA update Bit 8 \- Link LSA update Bit 9 \- Prefix LSA update
                        	**type**\:  str
                        
                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                        
                        .. attribute:: rib_add_routes
                        
                        	Number of routes added to RIB
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: rib_delete_routes
                        
                        	Number of routes deleted from RIB
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: start_time
                        
                        	SPF calculation start time
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.area_stat = YList()
                            self.area_stat.parent = self
                            self.area_stat.name = 'area_stat'
                            self.global_time = Ospfv3.Processes.Process.Statistics.SpfStats.SpfRuntime.GlobalTime()
                            self.global_time.parent = self
                            self.lsa = YList()
                            self.lsa.parent = self
                            self.lsa.name = 'lsa'
                            self.lsa_changes = None
                            self.reason_flags = None
                            self.rib_add_routes = None
                            self.rib_delete_routes = None
                            self.start_time = None


                        class GlobalTime(object):
                            """
                            Global SPF times
                            
                            .. attribute:: dijkstra
                            
                            	Dijkstra time in msec
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: external_prefix
                            
                            	External prefix processing time in msec
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: external_prefix_del
                            
                            	External prefix deletion time in msec
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: inter_prefix
                            
                            	Inter\-prefix processing time in msec
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: inter_prefix_del
                            
                            	Intra\-prefix deletion time in msec
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: intra_prefix
                            
                            	Intra\-prefix processing time in msec
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: intra_prefix_del
                            
                            	Intra\-prefix deletion time in msec
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: rib_add
                            
                            	RIB add processing time in msec
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: rib_del
                            
                            	RIB deletion time in msec
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.dijkstra = None
                                self.external_prefix = None
                                self.external_prefix_del = None
                                self.inter_prefix = None
                                self.inter_prefix_del = None
                                self.intra_prefix = None
                                self.intra_prefix_del = None
                                self.rib_add = None
                                self.rib_del = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:global-time'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.dijkstra is not None:
                                    return True

                                if self.external_prefix is not None:
                                    return True

                                if self.external_prefix_del is not None:
                                    return True

                                if self.inter_prefix is not None:
                                    return True

                                if self.inter_prefix_del is not None:
                                    return True

                                if self.intra_prefix is not None:
                                    return True

                                if self.intra_prefix_del is not None:
                                    return True

                                if self.rib_add is not None:
                                    return True

                                if self.rib_del is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                return meta._meta_table['Ospfv3.Processes.Process.Statistics.SpfStats.SpfRuntime.GlobalTime']['meta_info']


                        class Lsa(object):
                            """
                            List of LSAs triggering the SPF calculation
                            
                            .. attribute:: lsa_advertising_router
                            
                            	Advertising router ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: lsa_area_id
                            
                            	Area ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: lsa_flush
                            
                            	If true, the LSA change is a flush
                            	**type**\:  bool
                            
                            .. attribute:: lsa_id
                            
                            	LSA ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: lsa_type
                            
                            	LSA type
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.lsa_advertising_router = None
                                self.lsa_area_id = None
                                self.lsa_flush = None
                                self.lsa_id = None
                                self.lsa_type = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.lsa_advertising_router is not None:
                                    return True

                                if self.lsa_area_id is not None:
                                    return True

                                if self.lsa_flush is not None:
                                    return True

                                if self.lsa_id is not None:
                                    return True

                                if self.lsa_type is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                return meta._meta_table['Ospfv3.Processes.Process.Statistics.SpfStats.SpfRuntime.Lsa']['meta_info']


                        class AreaStat(object):
                            """
                            List of per\-area SPF statistics
                            
                            .. attribute:: spf_stat_area_id
                            
                            	Area ID for area of these SPF statistics
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: spf_stat_lsa_type_count
                            
                            	Counts of LSA types triggering an SPF calculation
                            	**type**\:  list of int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: spf_stat_time
                            
                            	SPF time calculations
                            	**type**\:   :py:class:`SpfStatTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Statistics.SpfStats.SpfRuntime.AreaStat.SpfStatTime>`
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.spf_stat_area_id = None
                                self.spf_stat_lsa_type_count = YLeafList()
                                self.spf_stat_lsa_type_count.parent = self
                                self.spf_stat_lsa_type_count.name = 'spf_stat_lsa_type_count'
                                self.spf_stat_time = Ospfv3.Processes.Process.Statistics.SpfStats.SpfRuntime.AreaStat.SpfStatTime()
                                self.spf_stat_time.parent = self


                            class SpfStatTime(object):
                                """
                                SPF time calculations
                                
                                .. attribute:: dijkstra
                                
                                	Dijkstra time in msec
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: external_prefix
                                
                                	External prefix processing time in msec
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: external_prefix_del
                                
                                	External prefix deletion time in msec
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: inter_prefix
                                
                                	Inter\-prefix processing time in msec
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: inter_prefix_del
                                
                                	Intra\-prefix deletion time in msec
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: intra_prefix
                                
                                	Intra\-prefix processing time in msec
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: intra_prefix_del
                                
                                	Intra\-prefix deletion time in msec
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rib_add
                                
                                	RIB add processing time in msec
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rib_del
                                
                                	RIB deletion time in msec
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.dijkstra = None
                                    self.external_prefix = None
                                    self.external_prefix_del = None
                                    self.inter_prefix = None
                                    self.inter_prefix_del = None
                                    self.intra_prefix = None
                                    self.intra_prefix_del = None
                                    self.rib_add = None
                                    self.rib_del = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:spf-stat-time'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.dijkstra is not None:
                                        return True

                                    if self.external_prefix is not None:
                                        return True

                                    if self.external_prefix_del is not None:
                                        return True

                                    if self.inter_prefix is not None:
                                        return True

                                    if self.inter_prefix_del is not None:
                                        return True

                                    if self.intra_prefix is not None:
                                        return True

                                    if self.intra_prefix_del is not None:
                                        return True

                                    if self.rib_add is not None:
                                        return True

                                    if self.rib_del is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                    return meta._meta_table['Ospfv3.Processes.Process.Statistics.SpfStats.SpfRuntime.AreaStat.SpfStatTime']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:area-stat'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.spf_stat_area_id is not None:
                                    return True

                                if self.spf_stat_lsa_type_count is not None:
                                    for child in self.spf_stat_lsa_type_count:
                                        if child is not None:
                                            return True

                                if self.spf_stat_time is not None and self.spf_stat_time._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                return meta._meta_table['Ospfv3.Processes.Process.Statistics.SpfStats.SpfRuntime.AreaStat']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:spf-runtime'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.area_stat is not None:
                                for child_ref in self.area_stat:
                                    if child_ref._has_data():
                                        return True

                            if self.global_time is not None and self.global_time._has_data():
                                return True

                            if self.lsa is not None:
                                for child_ref in self.lsa:
                                    if child_ref._has_data():
                                        return True

                            if self.lsa_changes is not None:
                                return True

                            if self.reason_flags is not None:
                                return True

                            if self.rib_add_routes is not None:
                                return True

                            if self.rib_delete_routes is not None:
                                return True

                            if self.start_time is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                            return meta._meta_table['Ospfv3.Processes.Process.Statistics.SpfStats.SpfRuntime']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:spf-stats'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.spf_header is not None and self.spf_header._has_data():
                            return True

                        if self.spf_runtime is not None:
                            for child_ref in self.spf_runtime:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                        return meta._meta_table['Ospfv3.Processes.Process.Statistics.SpfStats']['meta_info']


                class RawioStats(object):
                    """
                    OSPF Prefix SPF Prioritization statistics
                    
                    .. attribute:: in_bytes
                    
                    	Received Bytes
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: byte
                    
                    .. attribute:: in_error_drops
                    
                    	In Error Drops
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: in_handle_drops
                    
                    	In Handle Drops
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: in_ipsec_drops
                    
                    	In IPSEC Drops
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: in_long_packets
                    
                    	Received Long Packets
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: in_malloc_drops
                    
                    	In Malloc Drops
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: in_packets
                    
                    	Received Packets
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: in_queue_drops
                    
                    	In Queue Drops
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: in_short_drops
                    
                    	In Short Drops
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: out_bytes
                    
                    	Sent Bytes
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: byte
                    
                    .. attribute:: out_error_drops
                    
                    	Error Drops
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: out_ipsec_drops
                    
                    	Out IPSEC Drops
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: out_nofd_drops
                    
                    	No FileDescriptor Drops
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: out_nopak_drops
                    
                    	No Packet Buffers
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: out_packets
                    
                    	Packets Sent
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: out_pakapi_errors
                    
                    	PAK API Errors
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: raw_conn_close
                    
                    	Raw Connections Close
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: raw_conn_error
                    
                    	Raw Connections Error
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: raw_conn_open
                    
                    	Raw Connections Open
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: raw_conn_state
                    
                    	Raw Connection State
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv6-ospfv3-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.in_bytes = None
                        self.in_error_drops = None
                        self.in_handle_drops = None
                        self.in_ipsec_drops = None
                        self.in_long_packets = None
                        self.in_malloc_drops = None
                        self.in_packets = None
                        self.in_queue_drops = None
                        self.in_short_drops = None
                        self.out_bytes = None
                        self.out_error_drops = None
                        self.out_ipsec_drops = None
                        self.out_nofd_drops = None
                        self.out_nopak_drops = None
                        self.out_packets = None
                        self.out_pakapi_errors = None
                        self.raw_conn_close = None
                        self.raw_conn_error = None
                        self.raw_conn_open = None
                        self.raw_conn_state = None

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:rawio-stats'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.in_bytes is not None:
                            return True

                        if self.in_error_drops is not None:
                            return True

                        if self.in_handle_drops is not None:
                            return True

                        if self.in_ipsec_drops is not None:
                            return True

                        if self.in_long_packets is not None:
                            return True

                        if self.in_malloc_drops is not None:
                            return True

                        if self.in_packets is not None:
                            return True

                        if self.in_queue_drops is not None:
                            return True

                        if self.in_short_drops is not None:
                            return True

                        if self.out_bytes is not None:
                            return True

                        if self.out_error_drops is not None:
                            return True

                        if self.out_ipsec_drops is not None:
                            return True

                        if self.out_nofd_drops is not None:
                            return True

                        if self.out_nopak_drops is not None:
                            return True

                        if self.out_packets is not None:
                            return True

                        if self.out_pakapi_errors is not None:
                            return True

                        if self.raw_conn_close is not None:
                            return True

                        if self.raw_conn_error is not None:
                            return True

                        if self.raw_conn_open is not None:
                            return True

                        if self.raw_conn_state is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                        return meta._meta_table['Ospfv3.Processes.Process.Statistics.RawioStats']['meta_info']


                class PrefixPriorityStats(object):
                    """
                    OSPF Prefix SPF Prioritization statistics
                    
                    .. attribute:: critical
                    
                    	Critical priority classifications
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: high
                    
                    	High priority classifications
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: low
                    
                    	Low priority classifications
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: medium
                    
                    	Medium priority classifications
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv6-ospfv3-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.critical = None
                        self.high = None
                        self.low = None
                        self.medium = None

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:prefix-priority-stats'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.critical is not None:
                            return True

                        if self.high is not None:
                            return True

                        if self.low is not None:
                            return True

                        if self.medium is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                        return meta._meta_table['Ospfv3.Processes.Process.Statistics.PrefixPriorityStats']['meta_info']


                class VrfRibBatchStats(object):
                    """
                    OSPFv3 RIB batch statistics
                    
                    .. attribute:: batches_sent
                    
                    	No. of RIB batches sent
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: max_routes
                    
                    	Max No. of Routes in a batch
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: paths_add
                    
                    	No. of paths added to RIB
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: paths_add_errs
                    
                    	No. of paths add errors
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: paths_del
                    
                    	No. of paths del sent to RIB
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: paths_del_errs
                    
                    	No. of Paths del errors
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: paths_pending
                    
                    	No. of paths waiting to be sent to RIB
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: paths_sent
                    
                    	No. of Paths sent to RIB
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: routes_pending
                    
                    	No of Pending Routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: routes_sent
                    
                    	No. of Routes sent to RIB
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv6-ospfv3-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.batches_sent = None
                        self.max_routes = None
                        self.paths_add = None
                        self.paths_add_errs = None
                        self.paths_del = None
                        self.paths_del_errs = None
                        self.paths_pending = None
                        self.paths_sent = None
                        self.routes_pending = None
                        self.routes_sent = None

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:vrf-rib-batch-stats'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.batches_sent is not None:
                            return True

                        if self.max_routes is not None:
                            return True

                        if self.paths_add is not None:
                            return True

                        if self.paths_add_errs is not None:
                            return True

                        if self.paths_del is not None:
                            return True

                        if self.paths_del_errs is not None:
                            return True

                        if self.paths_pending is not None:
                            return True

                        if self.paths_sent is not None:
                            return True

                        if self.routes_pending is not None:
                            return True

                        if self.routes_sent is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                        return meta._meta_table['Ospfv3.Processes.Process.Statistics.VrfRibBatchStats']['meta_info']

                @property
                def _common_path(self):
                    if self.parent is None:
                        raise YPYModelError('parent is not set . Cannot derive path.')

                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:statistics'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.issu_stats is not None and self.issu_stats._has_data():
                        return True

                    if self.nsr_pl_stats is not None and self.nsr_pl_stats._has_data():
                        return True

                    if self.nsr_stats is not None and self.nsr_stats._has_data():
                        return True

                    if self.prefix_priority_stats is not None and self.prefix_priority_stats._has_data():
                        return True

                    if self.protocol_stats is not None and self.protocol_stats._has_data():
                        return True

                    if self.rawio_stats is not None and self.rawio_stats._has_data():
                        return True

                    if self.rib_thread_stats is not None and self.rib_thread_stats._has_data():
                        return True

                    if self.spf_stats is not None and self.spf_stats._has_data():
                        return True

                    if self.vrf_rib_batch_stats is not None and self.vrf_rib_batch_stats._has_data():
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                    return meta._meta_table['Ospfv3.Processes.Process.Statistics']['meta_info']


            class DefaultVrf(object):
                """
                Operational data for the default VRF
                (instance) in the OSPFv3 process
                
                .. attribute:: area_informations
                
                	OSPFv3 area information table
                	**type**\:   :py:class:`AreaInformations <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.AreaInformations>`
                
                .. attribute:: areas
                
                	OSPFv3 area table
                	**type**\:   :py:class:`Areas <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas>`
                
                .. attribute:: bad_checksums
                
                	Bad Checksum Packets information table
                	**type**\:   :py:class:`BadChecksums <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.BadChecksums>`
                
                .. attribute:: border_routers
                
                	OSPFv3 border router information table
                	**type**\:   :py:class:`BorderRouters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.BorderRouters>`
                
                .. attribute:: connected_routes
                
                	OSPFv3 connected route information table
                	**type**\:   :py:class:`ConnectedRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.ConnectedRoutes>`
                
                .. attribute:: database_summary_table
                
                	Database summary table
                	**type**\:   :py:class:`DatabaseSummaryTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseSummaryTable>`
                
                .. attribute:: database_table
                
                	OSPF Link State Database
                	**type**\:   :py:class:`DatabaseTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable>`
                
                .. attribute:: external_routes
                
                	OSPFv3 external route information table
                	**type**\:   :py:class:`ExternalRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.ExternalRoutes>`
                
                .. attribute:: fast_reroutes
                
                	OSPFv3 fast reroute topology information table
                	**type**\:   :py:class:`FastReroutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.FastReroutes>`
                
                .. attribute:: flood_list_process_table
                
                	OSPFv3 flood list information table for all areas
                	**type**\:   :py:class:`FloodListProcessTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.FloodListProcessTable>`
                
                .. attribute:: interface_brief_process_table
                
                	OSPFv3 interface brief information table for all areas
                	**type**\:   :py:class:`InterfaceBriefProcessTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.InterfaceBriefProcessTable>`
                
                .. attribute:: interface_process_table
                
                	OSPFv3 interface information table for all areas
                	**type**\:   :py:class:`InterfaceProcessTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.InterfaceProcessTable>`
                
                .. attribute:: internal_routes
                
                	OSPFv3 internal route information table
                	**type**\:   :py:class:`InternalRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.InternalRoutes>`
                
                .. attribute:: neighbor_detail_process_table
                
                	OSPFv3 neighbor information table for all areas
                	**type**\:   :py:class:`NeighborDetailProcessTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.NeighborDetailProcessTable>`
                
                .. attribute:: neighbor_process_table
                
                	OSPFv3 neighbor information table for all areas
                	**type**\:   :py:class:`NeighborProcessTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.NeighborProcessTable>`
                
                .. attribute:: protocol_areas
                
                	Protocol area table 
                	**type**\:   :py:class:`ProtocolAreas <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.ProtocolAreas>`
                
                .. attribute:: redistributions
                
                	Redistribution information table
                	**type**\:   :py:class:`Redistributions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Redistributions>`
                
                .. attribute:: request_list_process_table
                
                	OSPFv3 request list information for all areas
                	**type**\:   :py:class:`RequestListProcessTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.RequestListProcessTable>`
                
                .. attribute:: retransmission_list_process_table
                
                	OSPFv3 retransmission list information table for all areas
                	**type**\:   :py:class:`RetransmissionListProcessTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.RetransmissionListProcessTable>`
                
                .. attribute:: route_summary
                
                	Summarize OSPFv3 local RIB tables
                	**type**\:   :py:class:`RouteSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.RouteSummary>`
                
                .. attribute:: sham_link_table
                
                	Sham link information
                	**type**\:   :py:class:`ShamLinkTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.ShamLinkTable>`
                
                .. attribute:: summary
                
                	OSPFv3 summary
                	**type**\:   :py:class:`Summary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Summary>`
                
                .. attribute:: summary_prefixes
                
                	Summary prefix information table
                	**type**\:   :py:class:`SummaryPrefixes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.SummaryPrefixes>`
                
                .. attribute:: virtual_link
                
                	Virtual link information
                	**type**\:   :py:class:`VirtualLink <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.VirtualLink>`
                
                .. attribute:: vrf_statistics
                
                	Container for Statistics
                	**type**\:   :py:class:`VrfStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.VrfStatistics>`
                
                

                """

                _prefix = 'ipv6-ospfv3-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.area_informations = Ospfv3.Processes.Process.DefaultVrf.AreaInformations()
                    self.area_informations.parent = self
                    self.areas = Ospfv3.Processes.Process.DefaultVrf.Areas()
                    self.areas.parent = self
                    self.bad_checksums = Ospfv3.Processes.Process.DefaultVrf.BadChecksums()
                    self.bad_checksums.parent = self
                    self.border_routers = Ospfv3.Processes.Process.DefaultVrf.BorderRouters()
                    self.border_routers.parent = self
                    self.connected_routes = Ospfv3.Processes.Process.DefaultVrf.ConnectedRoutes()
                    self.connected_routes.parent = self
                    self.database_summary_table = Ospfv3.Processes.Process.DefaultVrf.DatabaseSummaryTable()
                    self.database_summary_table.parent = self
                    self.database_table = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable()
                    self.database_table.parent = self
                    self.external_routes = Ospfv3.Processes.Process.DefaultVrf.ExternalRoutes()
                    self.external_routes.parent = self
                    self.fast_reroutes = Ospfv3.Processes.Process.DefaultVrf.FastReroutes()
                    self.fast_reroutes.parent = self
                    self.flood_list_process_table = Ospfv3.Processes.Process.DefaultVrf.FloodListProcessTable()
                    self.flood_list_process_table.parent = self
                    self.interface_brief_process_table = Ospfv3.Processes.Process.DefaultVrf.InterfaceBriefProcessTable()
                    self.interface_brief_process_table.parent = self
                    self.interface_process_table = Ospfv3.Processes.Process.DefaultVrf.InterfaceProcessTable()
                    self.interface_process_table.parent = self
                    self.internal_routes = Ospfv3.Processes.Process.DefaultVrf.InternalRoutes()
                    self.internal_routes.parent = self
                    self.neighbor_detail_process_table = Ospfv3.Processes.Process.DefaultVrf.NeighborDetailProcessTable()
                    self.neighbor_detail_process_table.parent = self
                    self.neighbor_process_table = Ospfv3.Processes.Process.DefaultVrf.NeighborProcessTable()
                    self.neighbor_process_table.parent = self
                    self.protocol_areas = Ospfv3.Processes.Process.DefaultVrf.ProtocolAreas()
                    self.protocol_areas.parent = self
                    self.redistributions = Ospfv3.Processes.Process.DefaultVrf.Redistributions()
                    self.redistributions.parent = self
                    self.request_list_process_table = Ospfv3.Processes.Process.DefaultVrf.RequestListProcessTable()
                    self.request_list_process_table.parent = self
                    self.retransmission_list_process_table = Ospfv3.Processes.Process.DefaultVrf.RetransmissionListProcessTable()
                    self.retransmission_list_process_table.parent = self
                    self.route_summary = Ospfv3.Processes.Process.DefaultVrf.RouteSummary()
                    self.route_summary.parent = self
                    self.sham_link_table = Ospfv3.Processes.Process.DefaultVrf.ShamLinkTable()
                    self.sham_link_table.parent = self
                    self.summary = Ospfv3.Processes.Process.DefaultVrf.Summary()
                    self.summary.parent = self
                    self.summary_prefixes = Ospfv3.Processes.Process.DefaultVrf.SummaryPrefixes()
                    self.summary_prefixes.parent = self
                    self.virtual_link = Ospfv3.Processes.Process.DefaultVrf.VirtualLink()
                    self.virtual_link.parent = self
                    self.vrf_statistics = Ospfv3.Processes.Process.DefaultVrf.VrfStatistics()
                    self.vrf_statistics.parent = self


                class SummaryPrefixes(object):
                    """
                    Summary prefix information table
                    
                    .. attribute:: summary_prefix
                    
                    	Summary prefix information
                    	**type**\: list of    :py:class:`SummaryPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.SummaryPrefixes.SummaryPrefix>`
                    
                    

                    """

                    _prefix = 'ipv6-ospfv3-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.summary_prefix = YList()
                        self.summary_prefix.parent = self
                        self.summary_prefix.name = 'summary_prefix'


                    class SummaryPrefix(object):
                        """
                        Summary prefix information
                        
                        .. attribute:: prefix
                        
                        	Summary prefix
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: prefix_length
                        
                        	Prefix length
                        	**type**\:  int
                        
                        	**range:** 0..128
                        
                        .. attribute:: prefix_metric
                        
                        	Prefix metric
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: prefix_metric_type
                        
                        	Prefix metric type
                        	**type**\:   :py:class:`Ospfv3DefaultMetricEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3DefaultMetricEnum>`
                        
                        .. attribute:: tag
                        
                        	Tag
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.prefix = None
                            self.prefix_length = None
                            self.prefix_metric = None
                            self.prefix_metric_type = None
                            self.tag = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:summary-prefix'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.prefix is not None:
                                return True

                            if self.prefix_length is not None:
                                return True

                            if self.prefix_metric is not None:
                                return True

                            if self.prefix_metric_type is not None:
                                return True

                            if self.tag is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                            return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.SummaryPrefixes.SummaryPrefix']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:summary-prefixes'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.summary_prefix is not None:
                            for child_ref in self.summary_prefix:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                        return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.SummaryPrefixes']['meta_info']


                class BorderRouters(object):
                    """
                    OSPFv3 border router information table
                    
                    .. attribute:: border_router
                    
                    	OSPFv3 border router information
                    	**type**\: list of    :py:class:`BorderRouter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.BorderRouters.BorderRouter>`
                    
                    

                    """

                    _prefix = 'ipv6-ospfv3-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.border_router = YList()
                        self.border_router.parent = self
                        self.border_router.name = 'border_router'


                    class BorderRouter(object):
                        """
                        OSPFv3 border router information
                        
                        .. attribute:: border_router_id  <key>
                        
                        	Router address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: border_router_path
                        
                        	List of border router paths
                        	**type**\: list of    :py:class:`BorderRouterPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.BorderRouters.BorderRouter.BorderRouterPath>`
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.border_router_id = None
                            self.border_router_path = YList()
                            self.border_router_path.parent = self
                            self.border_router_path.name = 'border_router_path'


                        class BorderRouterPath(object):
                            """
                            List of border router paths
                            
                            .. attribute:: border_router_area_id
                            
                            	Area string in decimal or dotted\-decimal format 
                            	**type**\:  str
                            
                            	**length:** 0..16
                            
                            .. attribute:: border_router_next_hop
                            
                            	Next hop address 
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: border_router_route_metric
                            
                            	Metric
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: border_router_type
                            
                            	Border router type 
                            	**type**\:   :py:class:`Ospfv3BorderRouteEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3BorderRouteEnum>`
                            
                            .. attribute:: interface_name
                            
                            	Next hop interface name
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: is_intra_area_router
                            
                            	If true, intra\-area router else inter\-area router
                            	**type**\:  bool
                            
                            .. attribute:: spf_version
                            
                            	SPF version
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.border_router_area_id = None
                                self.border_router_next_hop = None
                                self.border_router_route_metric = None
                                self.border_router_type = None
                                self.interface_name = None
                                self.is_intra_area_router = None
                                self.spf_version = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:border-router-path'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.border_router_area_id is not None:
                                    return True

                                if self.border_router_next_hop is not None:
                                    return True

                                if self.border_router_route_metric is not None:
                                    return True

                                if self.border_router_type is not None:
                                    return True

                                if self.interface_name is not None:
                                    return True

                                if self.is_intra_area_router is not None:
                                    return True

                                if self.spf_version is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.BorderRouters.BorderRouter.BorderRouterPath']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')
                            if self.border_router_id is None:
                                raise YPYModelError('Key property border_router_id is None')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:border-router[Cisco-IOS-XR-ipv6-ospfv3-oper:border-router-id = ' + str(self.border_router_id) + ']'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.border_router_id is not None:
                                return True

                            if self.border_router_path is not None:
                                for child_ref in self.border_router_path:
                                    if child_ref._has_data():
                                        return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                            return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.BorderRouters.BorderRouter']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:border-routers'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.border_router is not None:
                            for child_ref in self.border_router:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                        return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.BorderRouters']['meta_info']


                class ShamLinkTable(object):
                    """
                    Sham link information
                    
                    .. attribute:: is_sham_link_authentication_enabled
                    
                    	If true, sham link authentication is enabled 
                    	**type**\:  bool
                    
                    .. attribute:: is_sham_link_encryption_enabled
                    
                    	If true, sham link encryption is enabled 
                    	**type**\:  bool
                    
                    .. attribute:: is_sham_link_ip_security_active
                    
                    	If true, Sham link IP security is active 
                    	**type**\:  bool
                    
                    .. attribute:: is_sham_link_ip_security_required
                    
                    	If true, sham link IP security is required 
                    	**type**\:  bool
                    
                    .. attribute:: sham_link_area
                    
                    	Area id
                    	**type**\:  str
                    
                    .. attribute:: sham_link_authentication_transmit
                    
                    	Sham link authentication transmit 
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sham_link_cost
                    
                    	Cost of the sham link
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: sham_link_dc_bitless_lsa
                    
                    	Number of LSA's with demand circuit bit not set
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sham_link_dead_interval
                    
                    	Dead interval (s)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sham_link_demand_circuit
                    
                    	If true, the link runs as demand circuit
                    	**type**\:  bool
                    
                    .. attribute:: sham_link_dest_address
                    
                    	Sham\-link dest
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: sham_link_encrypted_authentication_transmitted
                    
                    	Sham link encrypted authentication transmitted 
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sham_link_encryption_spi
                    
                    	Sham link encryption spi
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sham_link_encryption_transmitted
                    
                    	Sham link encryption transmitted 
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sham_link_gr
                    
                    	If true, Gracefule restart in progress
                    	**type**\:  bool
                    
                    .. attribute:: sham_link_gr_enabled
                    
                    	If true,  enabled
                    	**type**\:  bool
                    
                    .. attribute:: sham_link_hello_interval
                    
                    	Hello interval (s)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sham_link_ifindex
                    
                    	Sham\-link ifindex
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sham_link_last_gr
                    
                    	Time in seconds since last GR
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: sham_link_neighbor
                    
                    	Neighbor information
                    	**type**\:   :py:class:`ShamLinkNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.ShamLinkTable.ShamLinkNeighbor>`
                    
                    .. attribute:: sham_link_neighbor_id
                    
                    	Neighbor on other end of this sham link
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: sham_link_next_hello
                    
                    	Time until next hello (s)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sham_link_passive
                    
                    	If true, interface is passive
                    	**type**\:  bool
                    
                    .. attribute:: sham_link_retransmission_interval
                    
                    	Retransmission interval (s)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sham_link_source_address
                    
                    	Sham\-link source
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: sham_link_state
                    
                    	OSPF interface state for the sham link
                    	**type**\:   :py:class:`Ospfv3InterfaceStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3InterfaceStateEnum>`
                    
                    .. attribute:: sham_link_transmission_delay
                    
                    	Transmission delay in seconds
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    	**units**\: second
                    
                    .. attribute:: sham_link_wait_interval
                    
                    	Wait interval (s)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: virtual_link_authentication_spi
                    
                    	Sham link authentication spi 
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv6-ospfv3-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.is_sham_link_authentication_enabled = None
                        self.is_sham_link_encryption_enabled = None
                        self.is_sham_link_ip_security_active = None
                        self.is_sham_link_ip_security_required = None
                        self.sham_link_area = None
                        self.sham_link_authentication_transmit = None
                        self.sham_link_cost = None
                        self.sham_link_dc_bitless_lsa = None
                        self.sham_link_dead_interval = None
                        self.sham_link_demand_circuit = None
                        self.sham_link_dest_address = None
                        self.sham_link_encrypted_authentication_transmitted = None
                        self.sham_link_encryption_spi = None
                        self.sham_link_encryption_transmitted = None
                        self.sham_link_gr = None
                        self.sham_link_gr_enabled = None
                        self.sham_link_hello_interval = None
                        self.sham_link_ifindex = None
                        self.sham_link_last_gr = None
                        self.sham_link_neighbor = Ospfv3.Processes.Process.DefaultVrf.ShamLinkTable.ShamLinkNeighbor()
                        self.sham_link_neighbor.parent = self
                        self.sham_link_neighbor_id = None
                        self.sham_link_next_hello = None
                        self.sham_link_passive = None
                        self.sham_link_retransmission_interval = None
                        self.sham_link_source_address = None
                        self.sham_link_state = None
                        self.sham_link_transmission_delay = None
                        self.sham_link_wait_interval = None
                        self.virtual_link_authentication_spi = None


                    class ShamLinkNeighbor(object):
                        """
                        Neighbor information
                        
                        .. attribute:: sham_link_retransmission
                        
                        	Neighbor retransmission info
                        	**type**\:   :py:class:`ShamLinkRetransmission <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.ShamLinkTable.ShamLinkNeighbor.ShamLinkRetransmission>`
                        
                        .. attribute:: sham_link_state
                        
                        	Adjacency state
                        	**type**\:   :py:class:`Ospfv3NeighborStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3NeighborStateEnum>`
                        
                        .. attribute:: sham_link_suppress_hello
                        
                        	If true Hellos suppressed
                        	**type**\:  bool
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.sham_link_retransmission = Ospfv3.Processes.Process.DefaultVrf.ShamLinkTable.ShamLinkNeighbor.ShamLinkRetransmission()
                            self.sham_link_retransmission.parent = self
                            self.sham_link_state = None
                            self.sham_link_suppress_hello = None


                        class ShamLinkRetransmission(object):
                            """
                            Neighbor retransmission info
                            
                            .. attribute:: area_first_flood
                            
                            	First flood item for area scope LSAs
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: area_first_flood_index
                            
                            	Index of the first flood item for area scope LSAs
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: area_flood_index
                            
                            	Area scope LSA's flood index
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: area_next_flood
                            
                            	Next flood item for area scope LSAs
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: area_next_flood_index
                            
                            	Index of next flood item for Area scope LSAs
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: as_first_flood
                            
                            	First flood item for AS scope LSAs
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: as_first_flood_index
                            
                            	Index for first flood item for AS scope LSAs
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: as_flood_index
                            
                            	AS scope LSA's flood index
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: as_next_flood
                            
                            	Next flood item for AS scope LSAs
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: as_next_flood_index
                            
                            	Index of next flood item for AS scope LSAs
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: database_descriptor_retransmissions
                            
                            	Number of database descriptor retransmissions during last exchange
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: last_retransmission_length
                            
                            	Number of LSAs sent in last retransmission
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: last_retransmission_time
                            
                            	Last retransmission scan time (ms)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: link_first_flood
                            
                            	Link first flood information 
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: link_first_flood_index
                            
                            	Link first flood information index
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: link_flood_index
                            
                            	Link flood index
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: link_next_flood
                            
                            	Link next flood information 
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: link_next_flood_index
                            
                            	Link next flood information index 
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: lsa_retransmission_timer
                            
                            	Time until next LSA retransmission (ms)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: maximum_retransmission_length
                            
                            	Maximum number of LSAs sent in a retransmission
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: maximum_retransmission_time
                            
                            	Maximum retransmission scan time (ms)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: neighbor_retransmissions
                            
                            	Number of neighbor retransmissions 
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: retransmissions
                            
                            	Number of retransmissions for this neighbor
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.area_first_flood = None
                                self.area_first_flood_index = None
                                self.area_flood_index = None
                                self.area_next_flood = None
                                self.area_next_flood_index = None
                                self.as_first_flood = None
                                self.as_first_flood_index = None
                                self.as_flood_index = None
                                self.as_next_flood = None
                                self.as_next_flood_index = None
                                self.database_descriptor_retransmissions = None
                                self.last_retransmission_length = None
                                self.last_retransmission_time = None
                                self.link_first_flood = None
                                self.link_first_flood_index = None
                                self.link_flood_index = None
                                self.link_next_flood = None
                                self.link_next_flood_index = None
                                self.lsa_retransmission_timer = None
                                self.maximum_retransmission_length = None
                                self.maximum_retransmission_time = None
                                self.neighbor_retransmissions = None
                                self.retransmissions = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:sham-link-retransmission'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.area_first_flood is not None:
                                    return True

                                if self.area_first_flood_index is not None:
                                    return True

                                if self.area_flood_index is not None:
                                    return True

                                if self.area_next_flood is not None:
                                    return True

                                if self.area_next_flood_index is not None:
                                    return True

                                if self.as_first_flood is not None:
                                    return True

                                if self.as_first_flood_index is not None:
                                    return True

                                if self.as_flood_index is not None:
                                    return True

                                if self.as_next_flood is not None:
                                    return True

                                if self.as_next_flood_index is not None:
                                    return True

                                if self.database_descriptor_retransmissions is not None:
                                    return True

                                if self.last_retransmission_length is not None:
                                    return True

                                if self.last_retransmission_time is not None:
                                    return True

                                if self.link_first_flood is not None:
                                    return True

                                if self.link_first_flood_index is not None:
                                    return True

                                if self.link_flood_index is not None:
                                    return True

                                if self.link_next_flood is not None:
                                    return True

                                if self.link_next_flood_index is not None:
                                    return True

                                if self.lsa_retransmission_timer is not None:
                                    return True

                                if self.maximum_retransmission_length is not None:
                                    return True

                                if self.maximum_retransmission_time is not None:
                                    return True

                                if self.neighbor_retransmissions is not None:
                                    return True

                                if self.retransmissions is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.ShamLinkTable.ShamLinkNeighbor.ShamLinkRetransmission']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:sham-link-neighbor'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.sham_link_retransmission is not None and self.sham_link_retransmission._has_data():
                                return True

                            if self.sham_link_state is not None:
                                return True

                            if self.sham_link_suppress_hello is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                            return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.ShamLinkTable.ShamLinkNeighbor']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:sham-link-table'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.is_sham_link_authentication_enabled is not None:
                            return True

                        if self.is_sham_link_encryption_enabled is not None:
                            return True

                        if self.is_sham_link_ip_security_active is not None:
                            return True

                        if self.is_sham_link_ip_security_required is not None:
                            return True

                        if self.sham_link_area is not None:
                            return True

                        if self.sham_link_authentication_transmit is not None:
                            return True

                        if self.sham_link_cost is not None:
                            return True

                        if self.sham_link_dc_bitless_lsa is not None:
                            return True

                        if self.sham_link_dead_interval is not None:
                            return True

                        if self.sham_link_demand_circuit is not None:
                            return True

                        if self.sham_link_dest_address is not None:
                            return True

                        if self.sham_link_encrypted_authentication_transmitted is not None:
                            return True

                        if self.sham_link_encryption_spi is not None:
                            return True

                        if self.sham_link_encryption_transmitted is not None:
                            return True

                        if self.sham_link_gr is not None:
                            return True

                        if self.sham_link_gr_enabled is not None:
                            return True

                        if self.sham_link_hello_interval is not None:
                            return True

                        if self.sham_link_ifindex is not None:
                            return True

                        if self.sham_link_last_gr is not None:
                            return True

                        if self.sham_link_neighbor is not None and self.sham_link_neighbor._has_data():
                            return True

                        if self.sham_link_neighbor_id is not None:
                            return True

                        if self.sham_link_next_hello is not None:
                            return True

                        if self.sham_link_passive is not None:
                            return True

                        if self.sham_link_retransmission_interval is not None:
                            return True

                        if self.sham_link_source_address is not None:
                            return True

                        if self.sham_link_state is not None:
                            return True

                        if self.sham_link_transmission_delay is not None:
                            return True

                        if self.sham_link_wait_interval is not None:
                            return True

                        if self.virtual_link_authentication_spi is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                        return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.ShamLinkTable']['meta_info']


                class AreaInformations(object):
                    """
                    OSPFv3 area information table
                    
                    .. attribute:: area_information
                    
                    	OSPFv3 area information
                    	**type**\: list of    :py:class:`AreaInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.AreaInformations.AreaInformation>`
                    
                    

                    """

                    _prefix = 'ipv6-ospfv3-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.area_information = YList()
                        self.area_information.parent = self
                        self.area_information.name = 'area_information'


                    class AreaInformation(object):
                        """
                        OSPFv3 area information
                        
                        .. attribute:: area_id  <key>
                        
                        	Area ID
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: area_dc_bitless_ls_as
                        
                        	Number of LSA with demand circuit bit not set
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: area_interfaces
                        
                        	Number of interfaces in the area
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: area_lfa_interface_count
                        
                        	Number of LFA enabled interfaces
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: area_lfa_revision
                        
                        	Area LFA revision
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: area_opaque_lsa_checksum
                        
                        	Sum of opaque LSA checksums
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: area_opaque_lsas
                        
                        	Number of opaque LSAs in the area
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: area_per_prefix_lfa_interface_count
                        
                        	Number of Per Prefix LFA enabled interfaces
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: area_range
                        
                        	List of ranges to summarize
                        	**type**\: list of    :py:class:`AreaRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.AreaInformations.AreaInformation.AreaRange>`
                        
                        .. attribute:: do_not_age_ls_as
                        
                        	Number of do not age LSAs
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: flood_list_length
                        
                        	Number of LSAs which need to be flooded
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: indication_ls_as
                        
                        	Number of indication LSAs
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_area_nssa
                        
                        	If true, area is a NSSA
                        	**type**\:  bool
                        
                        .. attribute:: is_area_stubbed
                        
                        	If true, stub area
                        	**type**\:  bool
                        
                        .. attribute:: is_area_total_stubbed
                        
                        	If true, totally stubby area
                        	**type**\:  bool
                        
                        .. attribute:: is_backbone_area_active
                        
                        	If true, Backbone area is active
                        	**type**\:  bool
                        
                        .. attribute:: is_nssa_default
                        
                        	If true, generate NSSA default route
                        	**type**\:  bool
                        
                        .. attribute:: is_nssa_translated
                        
                        	If true, perform 7/5 translation
                        	**type**\:  bool
                        
                        .. attribute:: is_rrr_enabled
                        
                        	If true, RRR is enabled
                        	**type**\:  bool
                        
                        .. attribute:: nssa_no_redistribution
                        
                        	If true, No redistribution into this NSSA area
                        	**type**\:  bool
                        
                        .. attribute:: sp_fs
                        
                        	Number of SPF calculations run
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: stub_default_cost
                        
                        	Default cost for Stub or NSSA area
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.area_id = None
                            self.area_dc_bitless_ls_as = None
                            self.area_interfaces = None
                            self.area_lfa_interface_count = None
                            self.area_lfa_revision = None
                            self.area_opaque_lsa_checksum = None
                            self.area_opaque_lsas = None
                            self.area_per_prefix_lfa_interface_count = None
                            self.area_range = YList()
                            self.area_range.parent = self
                            self.area_range.name = 'area_range'
                            self.do_not_age_ls_as = None
                            self.flood_list_length = None
                            self.indication_ls_as = None
                            self.is_area_nssa = None
                            self.is_area_stubbed = None
                            self.is_area_total_stubbed = None
                            self.is_backbone_area_active = None
                            self.is_nssa_default = None
                            self.is_nssa_translated = None
                            self.is_rrr_enabled = None
                            self.nssa_no_redistribution = None
                            self.sp_fs = None
                            self.stub_default_cost = None


                        class AreaRange(object):
                            """
                            List of ranges to summarize
                            
                            .. attribute:: is_cost_configured
                            
                            	If true, cost is configured 
                            	**type**\:  bool
                            
                            .. attribute:: net_cost
                            
                            	Net cost 
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: range_prefix
                            
                            	IP prefix for summarization
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: range_prefix_length
                            
                            	IP prefix length for summarization
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: status
                            
                            	Area range status 
                            	**type**\:   :py:class:`Ospfv3AreaRangeStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3AreaRangeStatusEnum>`
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.is_cost_configured = None
                                self.net_cost = None
                                self.range_prefix = None
                                self.range_prefix_length = None
                                self.status = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:area-range'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.is_cost_configured is not None:
                                    return True

                                if self.net_cost is not None:
                                    return True

                                if self.range_prefix is not None:
                                    return True

                                if self.range_prefix_length is not None:
                                    return True

                                if self.status is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.AreaInformations.AreaInformation.AreaRange']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')
                            if self.area_id is None:
                                raise YPYModelError('Key property area_id is None')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:area-information[Cisco-IOS-XR-ipv6-ospfv3-oper:area-id = ' + str(self.area_id) + ']'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.area_id is not None:
                                return True

                            if self.area_dc_bitless_ls_as is not None:
                                return True

                            if self.area_interfaces is not None:
                                return True

                            if self.area_lfa_interface_count is not None:
                                return True

                            if self.area_lfa_revision is not None:
                                return True

                            if self.area_opaque_lsa_checksum is not None:
                                return True

                            if self.area_opaque_lsas is not None:
                                return True

                            if self.area_per_prefix_lfa_interface_count is not None:
                                return True

                            if self.area_range is not None:
                                for child_ref in self.area_range:
                                    if child_ref._has_data():
                                        return True

                            if self.do_not_age_ls_as is not None:
                                return True

                            if self.flood_list_length is not None:
                                return True

                            if self.indication_ls_as is not None:
                                return True

                            if self.is_area_nssa is not None:
                                return True

                            if self.is_area_stubbed is not None:
                                return True

                            if self.is_area_total_stubbed is not None:
                                return True

                            if self.is_backbone_area_active is not None:
                                return True

                            if self.is_nssa_default is not None:
                                return True

                            if self.is_nssa_translated is not None:
                                return True

                            if self.is_rrr_enabled is not None:
                                return True

                            if self.nssa_no_redistribution is not None:
                                return True

                            if self.sp_fs is not None:
                                return True

                            if self.stub_default_cost is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                            return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.AreaInformations.AreaInformation']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:area-informations'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.area_information is not None:
                            for child_ref in self.area_information:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                        return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.AreaInformations']['meta_info']


                class DatabaseTable(object):
                    """
                    OSPF Link State Database
                    
                    .. attribute:: lsa_internal_table
                    
                    	Database LSA information
                    	**type**\:   :py:class:`LsaInternalTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable>`
                    
                    .. attribute:: lsa_table
                    
                    	Database LSA information
                    	**type**\:   :py:class:`LsaTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable>`
                    
                    

                    """

                    _prefix = 'ipv6-ospfv3-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.lsa_internal_table = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable()
                        self.lsa_internal_table.parent = self
                        self.lsa_table = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable()
                        self.lsa_table.parent = self


                    class LsaTable(object):
                        """
                        Database LSA information
                        
                        .. attribute:: lsa
                        
                        	Database LSA information
                        	**type**\: list of    :py:class:`Lsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa>`
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.lsa = YList()
                            self.lsa.parent = self
                            self.lsa.name = 'lsa'


                        class Lsa(object):
                            """
                            Database LSA information
                            
                            .. attribute:: advertising_router
                            
                            	Advertising Router ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: area_id
                            
                            	Area ID
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: interface_name
                            
                            	InterfaceName
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: ls_id
                            
                            	Link state ID
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: ls_type
                            
                            	LSA type
                            	**type**\:   :py:class:`Ospfv3LsaEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3LsaEnum>`
                            
                            .. attribute:: lsa_info
                            
                            	Summary of all LSAs or LSA specific information 
                            	**type**\:   :py:class:`LsaInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo>`
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.advertising_router = None
                                self.area_id = None
                                self.interface_name = None
                                self.ls_id = None
                                self.ls_type = None
                                self.lsa_info = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo()
                                self.lsa_info.parent = self


                            class LsaInfo(object):
                                """
                                Summary of all LSAs or LSA specific information 
                                
                                .. attribute:: external_lsa_type
                                
                                	External LSA
                                	**type**\:   :py:class:`ExternalLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType>`
                                
                                .. attribute:: grace_lsa
                                
                                	Grace LSA
                                	**type**\:   :py:class:`GraceLsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa>`
                                
                                .. attribute:: inter_area_prefix_lsa_type
                                
                                	Inter Area Prefix LSA
                                	**type**\:   :py:class:`InterAreaPrefixLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType>`
                                
                                .. attribute:: inter_area_router_lsa_type
                                
                                	Inter Area Router LSA
                                	**type**\:   :py:class:`InterAreaRouterLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType>`
                                
                                .. attribute:: intra_area_prefix_lsa_type
                                
                                	Intra Area Prefix LSA
                                	**type**\:   :py:class:`IntraAreaPrefixLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType>`
                                
                                .. attribute:: link_lsa_type
                                
                                	Link LSA
                                	**type**\:   :py:class:`LinkLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType>`
                                
                                .. attribute:: lsa_info_type
                                
                                	LSAInfoType
                                	**type**\:   :py:class:`Ospfv3LsaInfoTypesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3LsaInfoTypesEnum>`
                                
                                .. attribute:: lsa_summary_info
                                
                                	Summary information of LSAs
                                	**type**\:   :py:class:`LsaSummaryInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo>`
                                
                                .. attribute:: network_lsa_type
                                
                                	Network LSA
                                	**type**\:   :py:class:`NetworkLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType>`
                                
                                .. attribute:: nssalsa_type
                                
                                	NSSA External LSA
                                	**type**\:   :py:class:`NssalsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType>`
                                
                                .. attribute:: router_lsa_type
                                
                                	Router LSA
                                	**type**\:   :py:class:`RouterLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType>`
                                
                                .. attribute:: unknown_area_lsa_type
                                
                                	Unknown\-Area scope LSA
                                	**type**\:   :py:class:`UnknownAreaLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType>`
                                
                                .. attribute:: unknown_aslsa_type
                                
                                	Unknown\-AS scope LSA
                                	**type**\:   :py:class:`UnknownAslsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType>`
                                
                                .. attribute:: unknown_link_lsa_type
                                
                                	Unknown Link Scope LSA
                                	**type**\:   :py:class:`UnknownLinkLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType>`
                                
                                .. attribute:: unknown_lsa_type
                                
                                	Unknown LSA
                                	**type**\:   :py:class:`UnknownLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType>`
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.external_lsa_type = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType()
                                    self.external_lsa_type.parent = self
                                    self.grace_lsa = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa()
                                    self.grace_lsa.parent = self
                                    self.inter_area_prefix_lsa_type = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType()
                                    self.inter_area_prefix_lsa_type.parent = self
                                    self.inter_area_router_lsa_type = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType()
                                    self.inter_area_router_lsa_type.parent = self
                                    self.intra_area_prefix_lsa_type = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType()
                                    self.intra_area_prefix_lsa_type.parent = self
                                    self.link_lsa_type = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType()
                                    self.link_lsa_type.parent = self
                                    self.lsa_info_type = None
                                    self.lsa_summary_info = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo()
                                    self.lsa_summary_info.parent = self
                                    self.network_lsa_type = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType()
                                    self.network_lsa_type.parent = self
                                    self.nssalsa_type = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType()
                                    self.nssalsa_type.parent = self
                                    self.router_lsa_type = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType()
                                    self.router_lsa_type.parent = self
                                    self.unknown_area_lsa_type = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType()
                                    self.unknown_area_lsa_type.parent = self
                                    self.unknown_aslsa_type = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType()
                                    self.unknown_aslsa_type.parent = self
                                    self.unknown_link_lsa_type = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType()
                                    self.unknown_link_lsa_type.parent = self
                                    self.unknown_lsa_type = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType()
                                    self.unknown_lsa_type.parent = self


                                class LsaSummaryInfo(object):
                                    """
                                    Summary information of LSAs
                                    
                                    .. attribute:: interface_name
                                    
                                    	LSA interface name 
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                    
                                    .. attribute:: is_sham_link
                                    
                                    	If true, it is a sham link 
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_virtual_link
                                    
                                    	If true, it is a virtual link 
                                    	**type**\:  bool
                                    
                                    .. attribute:: links
                                    
                                    	Number of links
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: lsa_detail
                                    
                                    	Detailed LSA information
                                    	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo.LsaDetail>`
                                    
                                    .. attribute:: lsa_header
                                    
                                    	Header information 
                                    	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo.LsaHeader>`
                                    
                                    .. attribute:: lsa_router_id
                                    
                                    	LSA router ID 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: prefix
                                    
                                    	OSPFv3 address Prefix 
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: prefix_length
                                    
                                    	Prefix length 
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: reference_lsa_id
                                    
                                    	Reference LSA ID 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: reference_type
                                    
                                    	Reference type 
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: router_la_bits
                                    
                                    	Router LA bits 
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: sham_link_id
                                    
                                    	Sham link ID 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: virtual_link_id
                                    
                                    	Virtual link ID 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.interface_name = None
                                        self.is_sham_link = None
                                        self.is_virtual_link = None
                                        self.links = None
                                        self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo.LsaDetail()
                                        self.lsa_detail.parent = self
                                        self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo.LsaHeader()
                                        self.lsa_header.parent = self
                                        self.lsa_router_id = None
                                        self.prefix = None
                                        self.prefix_length = None
                                        self.reference_lsa_id = None
                                        self.reference_type = None
                                        self.router_la_bits = None
                                        self.sham_link_id = None
                                        self.virtual_link_id = None


                                    class LsaHeader(object):
                                        """
                                        Header information 
                                        
                                        .. attribute:: advertising_router
                                        
                                        	Router ID of Advertising Router
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: checksum
                                        
                                        	Checksum value
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: is_do_not_age_lsa
                                        
                                        	If true, Do Not Age this LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_graceful_restart_active
                                        
                                        	If true, if grace restart is active 
                                        	**type**\:  bool
                                        
                                        .. attribute:: ls_id
                                        
                                        	LS ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: lsa_age
                                        
                                        	LSA's Age (s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_area_id
                                        
                                        	Area ID in decimal or dotted\-decimal format
                                        	**type**\:  str
                                        
                                        	**length:** 0..16
                                        
                                        .. attribute:: lsa_type
                                        
                                        	LSA type
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: sequence_number
                                        
                                        	Current Sequence number
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.advertising_router = None
                                            self.checksum = None
                                            self.is_do_not_age_lsa = None
                                            self.is_graceful_restart_active = None
                                            self.ls_id = None
                                            self.lsa_age = None
                                            self.lsa_area_id = None
                                            self.lsa_type = None
                                            self.sequence_number = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-header'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.advertising_router is not None:
                                                return True

                                            if self.checksum is not None:
                                                return True

                                            if self.is_do_not_age_lsa is not None:
                                                return True

                                            if self.is_graceful_restart_active is not None:
                                                return True

                                            if self.ls_id is not None:
                                                return True

                                            if self.lsa_age is not None:
                                                return True

                                            if self.lsa_area_id is not None:
                                                return True

                                            if self.lsa_type is not None:
                                                return True

                                            if self.sequence_number is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo.LsaHeader']['meta_info']


                                    class LsaDetail(object):
                                        """
                                        Detailed LSA information
                                        
                                        .. attribute:: free_time
                                        
                                        	The amount of time since the last check was made to free this LSA (s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_acknowledged
                                        
                                        	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_advertising_router_reachable
                                        
                                        	If true, Advertising Router is reachable
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_deleted
                                        
                                        	If true, flag is set to delete this LSA 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_flood_pending
                                        
                                        	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_maximum_aged
                                        
                                        	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_neighbor_exchange
                                        
                                        	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_no_delete
                                        
                                        	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_nsr_ack_pending
                                        
                                        	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_partial_spf
                                        
                                        	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_routing_bit
                                        
                                        	If true, Routing Bit set on the LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_routing_table
                                        
                                        	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                        	**type**\:  bool
                                        
                                        .. attribute:: lsa_flood_required_post_fail_over
                                        
                                        	LSA flood required after FO
                                        	**type**\:  bool
                                        
                                        .. attribute:: lsa_length
                                        
                                        	Length of the LSA
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_sync_state
                                        
                                        	State of LSA sync with active
                                        	**type**\:   :py:class:`OspfLsaSyncStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncStateEnum>`
                                        
                                        .. attribute:: minute_table_index
                                        
                                        	Minute table index
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: nsr_flood_required
                                        
                                        	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                        	**type**\:  bool
                                        
                                        .. attribute:: rate_limit
                                        
                                        	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                        	**type**\:  bool
                                        
                                        .. attribute:: second_table_index
                                        
                                        	Second table index
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.free_time = None
                                            self.is_acknowledged = None
                                            self.is_advertising_router_reachable = None
                                            self.is_deleted = None
                                            self.is_flood_pending = None
                                            self.is_maximum_aged = None
                                            self.is_neighbor_exchange = None
                                            self.is_no_delete = None
                                            self.is_nsr_ack_pending = None
                                            self.is_partial_spf = None
                                            self.is_routing_bit = None
                                            self.is_routing_table = None
                                            self.lsa_flood_required_post_fail_over = None
                                            self.lsa_length = None
                                            self.lsa_sync_state = None
                                            self.minute_table_index = None
                                            self.nsr_flood_required = None
                                            self.rate_limit = None
                                            self.second_table_index = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-detail'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.free_time is not None:
                                                return True

                                            if self.is_acknowledged is not None:
                                                return True

                                            if self.is_advertising_router_reachable is not None:
                                                return True

                                            if self.is_deleted is not None:
                                                return True

                                            if self.is_flood_pending is not None:
                                                return True

                                            if self.is_maximum_aged is not None:
                                                return True

                                            if self.is_neighbor_exchange is not None:
                                                return True

                                            if self.is_no_delete is not None:
                                                return True

                                            if self.is_nsr_ack_pending is not None:
                                                return True

                                            if self.is_partial_spf is not None:
                                                return True

                                            if self.is_routing_bit is not None:
                                                return True

                                            if self.is_routing_table is not None:
                                                return True

                                            if self.lsa_flood_required_post_fail_over is not None:
                                                return True

                                            if self.lsa_length is not None:
                                                return True

                                            if self.lsa_sync_state is not None:
                                                return True

                                            if self.minute_table_index is not None:
                                                return True

                                            if self.nsr_flood_required is not None:
                                                return True

                                            if self.rate_limit is not None:
                                                return True

                                            if self.second_table_index is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo.LsaDetail']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-summary-info'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.interface_name is not None:
                                            return True

                                        if self.is_sham_link is not None:
                                            return True

                                        if self.is_virtual_link is not None:
                                            return True

                                        if self.links is not None:
                                            return True

                                        if self.lsa_detail is not None and self.lsa_detail._has_data():
                                            return True

                                        if self.lsa_header is not None and self.lsa_header._has_data():
                                            return True

                                        if self.lsa_router_id is not None:
                                            return True

                                        if self.prefix is not None:
                                            return True

                                        if self.prefix_length is not None:
                                            return True

                                        if self.reference_lsa_id is not None:
                                            return True

                                        if self.reference_type is not None:
                                            return True

                                        if self.router_la_bits is not None:
                                            return True

                                        if self.sham_link_id is not None:
                                            return True

                                        if self.virtual_link_id is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                        return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo']['meta_info']


                                class RouterLsaType(object):
                                    """
                                    Router LSA
                                    
                                    .. attribute:: link
                                    
                                    	List of links in this LSA
                                    	**type**\: list of    :py:class:`Link <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.Link>`
                                    
                                    .. attribute:: lsa_detail
                                    
                                    	Detailed LSA information
                                    	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.LsaDetail>`
                                    
                                    .. attribute:: lsa_header
                                    
                                    	Header information 
                                    	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.LsaHeader>`
                                    
                                    .. attribute:: router_la_bits
                                    
                                    	Router LA bits 
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: rpf_path
                                    
                                    	Router LSA Reverse\-Path Forwarding information 
                                    	**type**\:   :py:class:`RpfPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.RpfPath>`
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.link = YList()
                                        self.link.parent = self
                                        self.link.name = 'link'
                                        self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.LsaDetail()
                                        self.lsa_detail.parent = self
                                        self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.LsaHeader()
                                        self.lsa_header.parent = self
                                        self.router_la_bits = None
                                        self.rpf_path = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.RpfPath()
                                        self.rpf_path.parent = self


                                    class LsaHeader(object):
                                        """
                                        Header information 
                                        
                                        .. attribute:: advertising_router
                                        
                                        	Router ID of Advertising Router
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: checksum
                                        
                                        	Checksum value
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: is_do_not_age_lsa
                                        
                                        	If true, Do Not Age this LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_graceful_restart_active
                                        
                                        	If true, if grace restart is active 
                                        	**type**\:  bool
                                        
                                        .. attribute:: ls_id
                                        
                                        	LS ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: lsa_age
                                        
                                        	LSA's Age (s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_area_id
                                        
                                        	Area ID in decimal or dotted\-decimal format
                                        	**type**\:  str
                                        
                                        	**length:** 0..16
                                        
                                        .. attribute:: lsa_type
                                        
                                        	LSA type
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: sequence_number
                                        
                                        	Current Sequence number
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.advertising_router = None
                                            self.checksum = None
                                            self.is_do_not_age_lsa = None
                                            self.is_graceful_restart_active = None
                                            self.ls_id = None
                                            self.lsa_age = None
                                            self.lsa_area_id = None
                                            self.lsa_type = None
                                            self.sequence_number = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-header'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.advertising_router is not None:
                                                return True

                                            if self.checksum is not None:
                                                return True

                                            if self.is_do_not_age_lsa is not None:
                                                return True

                                            if self.is_graceful_restart_active is not None:
                                                return True

                                            if self.ls_id is not None:
                                                return True

                                            if self.lsa_age is not None:
                                                return True

                                            if self.lsa_area_id is not None:
                                                return True

                                            if self.lsa_type is not None:
                                                return True

                                            if self.sequence_number is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.LsaHeader']['meta_info']


                                    class LsaDetail(object):
                                        """
                                        Detailed LSA information
                                        
                                        .. attribute:: free_time
                                        
                                        	The amount of time since the last check was made to free this LSA (s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_acknowledged
                                        
                                        	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_advertising_router_reachable
                                        
                                        	If true, Advertising Router is reachable
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_deleted
                                        
                                        	If true, flag is set to delete this LSA 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_flood_pending
                                        
                                        	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_maximum_aged
                                        
                                        	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_neighbor_exchange
                                        
                                        	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_no_delete
                                        
                                        	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_nsr_ack_pending
                                        
                                        	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_partial_spf
                                        
                                        	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_routing_bit
                                        
                                        	If true, Routing Bit set on the LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_routing_table
                                        
                                        	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                        	**type**\:  bool
                                        
                                        .. attribute:: lsa_flood_required_post_fail_over
                                        
                                        	LSA flood required after FO
                                        	**type**\:  bool
                                        
                                        .. attribute:: lsa_length
                                        
                                        	Length of the LSA
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_sync_state
                                        
                                        	State of LSA sync with active
                                        	**type**\:   :py:class:`OspfLsaSyncStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncStateEnum>`
                                        
                                        .. attribute:: minute_table_index
                                        
                                        	Minute table index
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: nsr_flood_required
                                        
                                        	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                        	**type**\:  bool
                                        
                                        .. attribute:: rate_limit
                                        
                                        	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                        	**type**\:  bool
                                        
                                        .. attribute:: second_table_index
                                        
                                        	Second table index
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.free_time = None
                                            self.is_acknowledged = None
                                            self.is_advertising_router_reachable = None
                                            self.is_deleted = None
                                            self.is_flood_pending = None
                                            self.is_maximum_aged = None
                                            self.is_neighbor_exchange = None
                                            self.is_no_delete = None
                                            self.is_nsr_ack_pending = None
                                            self.is_partial_spf = None
                                            self.is_routing_bit = None
                                            self.is_routing_table = None
                                            self.lsa_flood_required_post_fail_over = None
                                            self.lsa_length = None
                                            self.lsa_sync_state = None
                                            self.minute_table_index = None
                                            self.nsr_flood_required = None
                                            self.rate_limit = None
                                            self.second_table_index = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-detail'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.free_time is not None:
                                                return True

                                            if self.is_acknowledged is not None:
                                                return True

                                            if self.is_advertising_router_reachable is not None:
                                                return True

                                            if self.is_deleted is not None:
                                                return True

                                            if self.is_flood_pending is not None:
                                                return True

                                            if self.is_maximum_aged is not None:
                                                return True

                                            if self.is_neighbor_exchange is not None:
                                                return True

                                            if self.is_no_delete is not None:
                                                return True

                                            if self.is_nsr_ack_pending is not None:
                                                return True

                                            if self.is_partial_spf is not None:
                                                return True

                                            if self.is_routing_bit is not None:
                                                return True

                                            if self.is_routing_table is not None:
                                                return True

                                            if self.lsa_flood_required_post_fail_over is not None:
                                                return True

                                            if self.lsa_length is not None:
                                                return True

                                            if self.lsa_sync_state is not None:
                                                return True

                                            if self.minute_table_index is not None:
                                                return True

                                            if self.nsr_flood_required is not None:
                                                return True

                                            if self.rate_limit is not None:
                                                return True

                                            if self.second_table_index is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.LsaDetail']['meta_info']


                                    class RpfPath(object):
                                        """
                                        Router LSA Reverse\-Path Forwarding information 
                                        
                                        .. attribute:: interface_name
                                        
                                        	RPF multicast IDB 
                                        	**type**\:  str
                                        
                                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                        
                                        .. attribute:: rpf_multicast_next_hop
                                        
                                        	RPF multicast next hop 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface_name = None
                                            self.rpf_multicast_next_hop = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:rpf-path'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface_name is not None:
                                                return True

                                            if self.rpf_multicast_next_hop is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.RpfPath']['meta_info']


                                    class Link(object):
                                        """
                                        List of links in this LSA
                                        
                                        .. attribute:: link_interface_id
                                        
                                        	LSA link interface ID 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: link_metric
                                        
                                        	LSA link metric 
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: link_neighbor_interface_id
                                        
                                        	LSA link neighbor interface ID 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: link_neighbor_router_id
                                        
                                        	LSA link neigbhor router id 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: link_type
                                        
                                        	Type of link
                                        	**type**\:   :py:class:`Ospfv3LinkEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3LinkEnum>`
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.link_interface_id = None
                                            self.link_metric = None
                                            self.link_neighbor_interface_id = None
                                            self.link_neighbor_router_id = None
                                            self.link_type = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:link'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.link_interface_id is not None:
                                                return True

                                            if self.link_metric is not None:
                                                return True

                                            if self.link_neighbor_interface_id is not None:
                                                return True

                                            if self.link_neighbor_router_id is not None:
                                                return True

                                            if self.link_type is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.Link']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:router-lsa-type'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.link is not None:
                                            for child_ref in self.link:
                                                if child_ref._has_data():
                                                    return True

                                        if self.lsa_detail is not None and self.lsa_detail._has_data():
                                            return True

                                        if self.lsa_header is not None and self.lsa_header._has_data():
                                            return True

                                        if self.router_la_bits is not None:
                                            return True

                                        if self.rpf_path is not None and self.rpf_path._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                        return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType']['meta_info']


                                class NetworkLsaType(object):
                                    """
                                    Network LSA
                                    
                                    .. attribute:: lsa_detail
                                    
                                    	Detailed LSA information
                                    	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType.LsaDetail>`
                                    
                                    .. attribute:: lsa_header
                                    
                                    	Header information 
                                    	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType.LsaHeader>`
                                    
                                    .. attribute:: neighbor_router
                                    
                                    	Neighbor router list
                                    	**type**\:  list of str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType.LsaDetail()
                                        self.lsa_detail.parent = self
                                        self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType.LsaHeader()
                                        self.lsa_header.parent = self
                                        self.neighbor_router = YLeafList()
                                        self.neighbor_router.parent = self
                                        self.neighbor_router.name = 'neighbor_router'


                                    class LsaHeader(object):
                                        """
                                        Header information 
                                        
                                        .. attribute:: advertising_router
                                        
                                        	Router ID of Advertising Router
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: checksum
                                        
                                        	Checksum value
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: is_do_not_age_lsa
                                        
                                        	If true, Do Not Age this LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_graceful_restart_active
                                        
                                        	If true, if grace restart is active 
                                        	**type**\:  bool
                                        
                                        .. attribute:: ls_id
                                        
                                        	LS ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: lsa_age
                                        
                                        	LSA's Age (s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_area_id
                                        
                                        	Area ID in decimal or dotted\-decimal format
                                        	**type**\:  str
                                        
                                        	**length:** 0..16
                                        
                                        .. attribute:: lsa_type
                                        
                                        	LSA type
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: sequence_number
                                        
                                        	Current Sequence number
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.advertising_router = None
                                            self.checksum = None
                                            self.is_do_not_age_lsa = None
                                            self.is_graceful_restart_active = None
                                            self.ls_id = None
                                            self.lsa_age = None
                                            self.lsa_area_id = None
                                            self.lsa_type = None
                                            self.sequence_number = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-header'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.advertising_router is not None:
                                                return True

                                            if self.checksum is not None:
                                                return True

                                            if self.is_do_not_age_lsa is not None:
                                                return True

                                            if self.is_graceful_restart_active is not None:
                                                return True

                                            if self.ls_id is not None:
                                                return True

                                            if self.lsa_age is not None:
                                                return True

                                            if self.lsa_area_id is not None:
                                                return True

                                            if self.lsa_type is not None:
                                                return True

                                            if self.sequence_number is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType.LsaHeader']['meta_info']


                                    class LsaDetail(object):
                                        """
                                        Detailed LSA information
                                        
                                        .. attribute:: free_time
                                        
                                        	The amount of time since the last check was made to free this LSA (s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_acknowledged
                                        
                                        	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_advertising_router_reachable
                                        
                                        	If true, Advertising Router is reachable
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_deleted
                                        
                                        	If true, flag is set to delete this LSA 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_flood_pending
                                        
                                        	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_maximum_aged
                                        
                                        	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_neighbor_exchange
                                        
                                        	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_no_delete
                                        
                                        	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_nsr_ack_pending
                                        
                                        	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_partial_spf
                                        
                                        	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_routing_bit
                                        
                                        	If true, Routing Bit set on the LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_routing_table
                                        
                                        	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                        	**type**\:  bool
                                        
                                        .. attribute:: lsa_flood_required_post_fail_over
                                        
                                        	LSA flood required after FO
                                        	**type**\:  bool
                                        
                                        .. attribute:: lsa_length
                                        
                                        	Length of the LSA
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_sync_state
                                        
                                        	State of LSA sync with active
                                        	**type**\:   :py:class:`OspfLsaSyncStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncStateEnum>`
                                        
                                        .. attribute:: minute_table_index
                                        
                                        	Minute table index
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: nsr_flood_required
                                        
                                        	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                        	**type**\:  bool
                                        
                                        .. attribute:: rate_limit
                                        
                                        	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                        	**type**\:  bool
                                        
                                        .. attribute:: second_table_index
                                        
                                        	Second table index
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.free_time = None
                                            self.is_acknowledged = None
                                            self.is_advertising_router_reachable = None
                                            self.is_deleted = None
                                            self.is_flood_pending = None
                                            self.is_maximum_aged = None
                                            self.is_neighbor_exchange = None
                                            self.is_no_delete = None
                                            self.is_nsr_ack_pending = None
                                            self.is_partial_spf = None
                                            self.is_routing_bit = None
                                            self.is_routing_table = None
                                            self.lsa_flood_required_post_fail_over = None
                                            self.lsa_length = None
                                            self.lsa_sync_state = None
                                            self.minute_table_index = None
                                            self.nsr_flood_required = None
                                            self.rate_limit = None
                                            self.second_table_index = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-detail'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.free_time is not None:
                                                return True

                                            if self.is_acknowledged is not None:
                                                return True

                                            if self.is_advertising_router_reachable is not None:
                                                return True

                                            if self.is_deleted is not None:
                                                return True

                                            if self.is_flood_pending is not None:
                                                return True

                                            if self.is_maximum_aged is not None:
                                                return True

                                            if self.is_neighbor_exchange is not None:
                                                return True

                                            if self.is_no_delete is not None:
                                                return True

                                            if self.is_nsr_ack_pending is not None:
                                                return True

                                            if self.is_partial_spf is not None:
                                                return True

                                            if self.is_routing_bit is not None:
                                                return True

                                            if self.is_routing_table is not None:
                                                return True

                                            if self.lsa_flood_required_post_fail_over is not None:
                                                return True

                                            if self.lsa_length is not None:
                                                return True

                                            if self.lsa_sync_state is not None:
                                                return True

                                            if self.minute_table_index is not None:
                                                return True

                                            if self.nsr_flood_required is not None:
                                                return True

                                            if self.rate_limit is not None:
                                                return True

                                            if self.second_table_index is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType.LsaDetail']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:network-lsa-type'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.lsa_detail is not None and self.lsa_detail._has_data():
                                            return True

                                        if self.lsa_header is not None and self.lsa_header._has_data():
                                            return True

                                        if self.neighbor_router is not None:
                                            for child in self.neighbor_router:
                                                if child is not None:
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                        return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType']['meta_info']


                                class InterAreaPrefixLsaType(object):
                                    """
                                    Inter Area Prefix LSA
                                    
                                    .. attribute:: lsa_detail
                                    
                                    	Detailed LSA Information
                                    	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaDetail>`
                                    
                                    .. attribute:: lsa_header
                                    
                                    	Header information 
                                    	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaHeader>`
                                    
                                    .. attribute:: prefix
                                    
                                    	LSA address prefix 
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: prefix_length
                                    
                                    	Prefix length 
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: priority
                                    
                                    	Prefix priority
                                    	**type**\:   :py:class:`PrefixPriorityEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.PrefixPriorityEnum>`
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaDetail()
                                        self.lsa_detail.parent = self
                                        self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaHeader()
                                        self.lsa_header.parent = self
                                        self.prefix = None
                                        self.prefix_length = None
                                        self.priority = None


                                    class LsaHeader(object):
                                        """
                                        Header information 
                                        
                                        .. attribute:: advertising_router
                                        
                                        	Router ID of Advertising Router
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: checksum
                                        
                                        	Checksum value
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: is_do_not_age_lsa
                                        
                                        	If true, Do Not Age this LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_graceful_restart_active
                                        
                                        	If true, if grace restart is active 
                                        	**type**\:  bool
                                        
                                        .. attribute:: ls_id
                                        
                                        	LS ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: lsa_age
                                        
                                        	LSA's Age (s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_area_id
                                        
                                        	Area ID in decimal or dotted\-decimal format
                                        	**type**\:  str
                                        
                                        	**length:** 0..16
                                        
                                        .. attribute:: lsa_type
                                        
                                        	LSA type
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: sequence_number
                                        
                                        	Current Sequence number
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.advertising_router = None
                                            self.checksum = None
                                            self.is_do_not_age_lsa = None
                                            self.is_graceful_restart_active = None
                                            self.ls_id = None
                                            self.lsa_age = None
                                            self.lsa_area_id = None
                                            self.lsa_type = None
                                            self.sequence_number = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-header'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.advertising_router is not None:
                                                return True

                                            if self.checksum is not None:
                                                return True

                                            if self.is_do_not_age_lsa is not None:
                                                return True

                                            if self.is_graceful_restart_active is not None:
                                                return True

                                            if self.ls_id is not None:
                                                return True

                                            if self.lsa_age is not None:
                                                return True

                                            if self.lsa_area_id is not None:
                                                return True

                                            if self.lsa_type is not None:
                                                return True

                                            if self.sequence_number is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaHeader']['meta_info']


                                    class LsaDetail(object):
                                        """
                                        Detailed LSA Information
                                        
                                        .. attribute:: free_time
                                        
                                        	The amount of time since the last check was made to free this LSA (s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_acknowledged
                                        
                                        	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_advertising_router_reachable
                                        
                                        	If true, Advertising Router is reachable
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_deleted
                                        
                                        	If true, flag is set to delete this LSA 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_flood_pending
                                        
                                        	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_maximum_aged
                                        
                                        	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_neighbor_exchange
                                        
                                        	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_no_delete
                                        
                                        	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_nsr_ack_pending
                                        
                                        	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_partial_spf
                                        
                                        	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_routing_bit
                                        
                                        	If true, Routing Bit set on the LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_routing_table
                                        
                                        	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                        	**type**\:  bool
                                        
                                        .. attribute:: lsa_flood_required_post_fail_over
                                        
                                        	LSA flood required after FO
                                        	**type**\:  bool
                                        
                                        .. attribute:: lsa_length
                                        
                                        	Length of the LSA
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_sync_state
                                        
                                        	State of LSA sync with active
                                        	**type**\:   :py:class:`OspfLsaSyncStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncStateEnum>`
                                        
                                        .. attribute:: minute_table_index
                                        
                                        	Minute table index
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: nsr_flood_required
                                        
                                        	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                        	**type**\:  bool
                                        
                                        .. attribute:: rate_limit
                                        
                                        	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                        	**type**\:  bool
                                        
                                        .. attribute:: second_table_index
                                        
                                        	Second table index
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.free_time = None
                                            self.is_acknowledged = None
                                            self.is_advertising_router_reachable = None
                                            self.is_deleted = None
                                            self.is_flood_pending = None
                                            self.is_maximum_aged = None
                                            self.is_neighbor_exchange = None
                                            self.is_no_delete = None
                                            self.is_nsr_ack_pending = None
                                            self.is_partial_spf = None
                                            self.is_routing_bit = None
                                            self.is_routing_table = None
                                            self.lsa_flood_required_post_fail_over = None
                                            self.lsa_length = None
                                            self.lsa_sync_state = None
                                            self.minute_table_index = None
                                            self.nsr_flood_required = None
                                            self.rate_limit = None
                                            self.second_table_index = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-detail'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.free_time is not None:
                                                return True

                                            if self.is_acknowledged is not None:
                                                return True

                                            if self.is_advertising_router_reachable is not None:
                                                return True

                                            if self.is_deleted is not None:
                                                return True

                                            if self.is_flood_pending is not None:
                                                return True

                                            if self.is_maximum_aged is not None:
                                                return True

                                            if self.is_neighbor_exchange is not None:
                                                return True

                                            if self.is_no_delete is not None:
                                                return True

                                            if self.is_nsr_ack_pending is not None:
                                                return True

                                            if self.is_partial_spf is not None:
                                                return True

                                            if self.is_routing_bit is not None:
                                                return True

                                            if self.is_routing_table is not None:
                                                return True

                                            if self.lsa_flood_required_post_fail_over is not None:
                                                return True

                                            if self.lsa_length is not None:
                                                return True

                                            if self.lsa_sync_state is not None:
                                                return True

                                            if self.minute_table_index is not None:
                                                return True

                                            if self.nsr_flood_required is not None:
                                                return True

                                            if self.rate_limit is not None:
                                                return True

                                            if self.second_table_index is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaDetail']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:inter-area-prefix-lsa-type'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.lsa_detail is not None and self.lsa_detail._has_data():
                                            return True

                                        if self.lsa_header is not None and self.lsa_header._has_data():
                                            return True

                                        if self.prefix is not None:
                                            return True

                                        if self.prefix_length is not None:
                                            return True

                                        if self.priority is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                        return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType']['meta_info']


                                class InterAreaRouterLsaType(object):
                                    """
                                    Inter Area Router LSA
                                    
                                    .. attribute:: lsa_detail
                                    
                                    	Detailed LSA information
                                    	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaDetail>`
                                    
                                    .. attribute:: lsa_header
                                    
                                    	Header information 
                                    	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaHeader>`
                                    
                                    .. attribute:: lsa_router_id
                                    
                                    	LSA router ID 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaDetail()
                                        self.lsa_detail.parent = self
                                        self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaHeader()
                                        self.lsa_header.parent = self
                                        self.lsa_router_id = None


                                    class LsaHeader(object):
                                        """
                                        Header information 
                                        
                                        .. attribute:: advertising_router
                                        
                                        	Router ID of Advertising Router
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: checksum
                                        
                                        	Checksum value
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: is_do_not_age_lsa
                                        
                                        	If true, Do Not Age this LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_graceful_restart_active
                                        
                                        	If true, if grace restart is active 
                                        	**type**\:  bool
                                        
                                        .. attribute:: ls_id
                                        
                                        	LS ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: lsa_age
                                        
                                        	LSA's Age (s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_area_id
                                        
                                        	Area ID in decimal or dotted\-decimal format
                                        	**type**\:  str
                                        
                                        	**length:** 0..16
                                        
                                        .. attribute:: lsa_type
                                        
                                        	LSA type
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: sequence_number
                                        
                                        	Current Sequence number
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.advertising_router = None
                                            self.checksum = None
                                            self.is_do_not_age_lsa = None
                                            self.is_graceful_restart_active = None
                                            self.ls_id = None
                                            self.lsa_age = None
                                            self.lsa_area_id = None
                                            self.lsa_type = None
                                            self.sequence_number = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-header'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.advertising_router is not None:
                                                return True

                                            if self.checksum is not None:
                                                return True

                                            if self.is_do_not_age_lsa is not None:
                                                return True

                                            if self.is_graceful_restart_active is not None:
                                                return True

                                            if self.ls_id is not None:
                                                return True

                                            if self.lsa_age is not None:
                                                return True

                                            if self.lsa_area_id is not None:
                                                return True

                                            if self.lsa_type is not None:
                                                return True

                                            if self.sequence_number is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaHeader']['meta_info']


                                    class LsaDetail(object):
                                        """
                                        Detailed LSA information
                                        
                                        .. attribute:: free_time
                                        
                                        	The amount of time since the last check was made to free this LSA (s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_acknowledged
                                        
                                        	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_advertising_router_reachable
                                        
                                        	If true, Advertising Router is reachable
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_deleted
                                        
                                        	If true, flag is set to delete this LSA 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_flood_pending
                                        
                                        	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_maximum_aged
                                        
                                        	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_neighbor_exchange
                                        
                                        	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_no_delete
                                        
                                        	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_nsr_ack_pending
                                        
                                        	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_partial_spf
                                        
                                        	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_routing_bit
                                        
                                        	If true, Routing Bit set on the LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_routing_table
                                        
                                        	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                        	**type**\:  bool
                                        
                                        .. attribute:: lsa_flood_required_post_fail_over
                                        
                                        	LSA flood required after FO
                                        	**type**\:  bool
                                        
                                        .. attribute:: lsa_length
                                        
                                        	Length of the LSA
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_sync_state
                                        
                                        	State of LSA sync with active
                                        	**type**\:   :py:class:`OspfLsaSyncStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncStateEnum>`
                                        
                                        .. attribute:: minute_table_index
                                        
                                        	Minute table index
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: nsr_flood_required
                                        
                                        	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                        	**type**\:  bool
                                        
                                        .. attribute:: rate_limit
                                        
                                        	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                        	**type**\:  bool
                                        
                                        .. attribute:: second_table_index
                                        
                                        	Second table index
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.free_time = None
                                            self.is_acknowledged = None
                                            self.is_advertising_router_reachable = None
                                            self.is_deleted = None
                                            self.is_flood_pending = None
                                            self.is_maximum_aged = None
                                            self.is_neighbor_exchange = None
                                            self.is_no_delete = None
                                            self.is_nsr_ack_pending = None
                                            self.is_partial_spf = None
                                            self.is_routing_bit = None
                                            self.is_routing_table = None
                                            self.lsa_flood_required_post_fail_over = None
                                            self.lsa_length = None
                                            self.lsa_sync_state = None
                                            self.minute_table_index = None
                                            self.nsr_flood_required = None
                                            self.rate_limit = None
                                            self.second_table_index = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-detail'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.free_time is not None:
                                                return True

                                            if self.is_acknowledged is not None:
                                                return True

                                            if self.is_advertising_router_reachable is not None:
                                                return True

                                            if self.is_deleted is not None:
                                                return True

                                            if self.is_flood_pending is not None:
                                                return True

                                            if self.is_maximum_aged is not None:
                                                return True

                                            if self.is_neighbor_exchange is not None:
                                                return True

                                            if self.is_no_delete is not None:
                                                return True

                                            if self.is_nsr_ack_pending is not None:
                                                return True

                                            if self.is_partial_spf is not None:
                                                return True

                                            if self.is_routing_bit is not None:
                                                return True

                                            if self.is_routing_table is not None:
                                                return True

                                            if self.lsa_flood_required_post_fail_over is not None:
                                                return True

                                            if self.lsa_length is not None:
                                                return True

                                            if self.lsa_sync_state is not None:
                                                return True

                                            if self.minute_table_index is not None:
                                                return True

                                            if self.nsr_flood_required is not None:
                                                return True

                                            if self.rate_limit is not None:
                                                return True

                                            if self.second_table_index is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaDetail']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:inter-area-router-lsa-type'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.lsa_detail is not None and self.lsa_detail._has_data():
                                            return True

                                        if self.lsa_header is not None and self.lsa_header._has_data():
                                            return True

                                        if self.lsa_router_id is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                        return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType']['meta_info']


                                class ExternalLsaType(object):
                                    """
                                    External LSA
                                    
                                    .. attribute:: external_tag
                                    
                                    	Route Tag
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: forwarding_address
                                    
                                    	Forwarding Address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: is_forwarding_address_set
                                    
                                    	If true, forwarding address is set 
                                    	**type**\:  bool
                                    
                                    .. attribute:: lsa_detail
                                    
                                    	Detailed LSA Information
                                    	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType.LsaDetail>`
                                    
                                    .. attribute:: lsa_header
                                    
                                    	Header information 
                                    	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType.LsaHeader>`
                                    
                                    .. attribute:: metric_type
                                    
                                    	Metric type 
                                    	**type**\:   :py:class:`Ospfv3DefaultMetricEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3DefaultMetricEnum>`
                                    
                                    .. attribute:: prefix
                                    
                                    	IPV6 address prefix 
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: prefix_length
                                    
                                    	Prefix length 
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: priority
                                    
                                    	Prefix priority
                                    	**type**\:   :py:class:`PrefixPriorityEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.PrefixPriorityEnum>`
                                    
                                    .. attribute:: tos_cost
                                    
                                    	Type of service cost metric 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.external_tag = None
                                        self.forwarding_address = None
                                        self.is_forwarding_address_set = None
                                        self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType.LsaDetail()
                                        self.lsa_detail.parent = self
                                        self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType.LsaHeader()
                                        self.lsa_header.parent = self
                                        self.metric_type = None
                                        self.prefix = None
                                        self.prefix_length = None
                                        self.priority = None
                                        self.tos_cost = None


                                    class LsaHeader(object):
                                        """
                                        Header information 
                                        
                                        .. attribute:: advertising_router
                                        
                                        	Router ID of Advertising Router
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: checksum
                                        
                                        	Checksum value
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: is_do_not_age_lsa
                                        
                                        	If true, Do Not Age this LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_graceful_restart_active
                                        
                                        	If true, if grace restart is active 
                                        	**type**\:  bool
                                        
                                        .. attribute:: ls_id
                                        
                                        	LS ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: lsa_age
                                        
                                        	LSA's Age (s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_area_id
                                        
                                        	Area ID in decimal or dotted\-decimal format
                                        	**type**\:  str
                                        
                                        	**length:** 0..16
                                        
                                        .. attribute:: lsa_type
                                        
                                        	LSA type
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: sequence_number
                                        
                                        	Current Sequence number
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.advertising_router = None
                                            self.checksum = None
                                            self.is_do_not_age_lsa = None
                                            self.is_graceful_restart_active = None
                                            self.ls_id = None
                                            self.lsa_age = None
                                            self.lsa_area_id = None
                                            self.lsa_type = None
                                            self.sequence_number = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-header'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.advertising_router is not None:
                                                return True

                                            if self.checksum is not None:
                                                return True

                                            if self.is_do_not_age_lsa is not None:
                                                return True

                                            if self.is_graceful_restart_active is not None:
                                                return True

                                            if self.ls_id is not None:
                                                return True

                                            if self.lsa_age is not None:
                                                return True

                                            if self.lsa_area_id is not None:
                                                return True

                                            if self.lsa_type is not None:
                                                return True

                                            if self.sequence_number is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType.LsaHeader']['meta_info']


                                    class LsaDetail(object):
                                        """
                                        Detailed LSA Information
                                        
                                        .. attribute:: free_time
                                        
                                        	The amount of time since the last check was made to free this LSA (s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_acknowledged
                                        
                                        	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_advertising_router_reachable
                                        
                                        	If true, Advertising Router is reachable
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_deleted
                                        
                                        	If true, flag is set to delete this LSA 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_flood_pending
                                        
                                        	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_maximum_aged
                                        
                                        	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_neighbor_exchange
                                        
                                        	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_no_delete
                                        
                                        	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_nsr_ack_pending
                                        
                                        	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_partial_spf
                                        
                                        	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_routing_bit
                                        
                                        	If true, Routing Bit set on the LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_routing_table
                                        
                                        	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                        	**type**\:  bool
                                        
                                        .. attribute:: lsa_flood_required_post_fail_over
                                        
                                        	LSA flood required after FO
                                        	**type**\:  bool
                                        
                                        .. attribute:: lsa_length
                                        
                                        	Length of the LSA
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_sync_state
                                        
                                        	State of LSA sync with active
                                        	**type**\:   :py:class:`OspfLsaSyncStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncStateEnum>`
                                        
                                        .. attribute:: minute_table_index
                                        
                                        	Minute table index
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: nsr_flood_required
                                        
                                        	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                        	**type**\:  bool
                                        
                                        .. attribute:: rate_limit
                                        
                                        	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                        	**type**\:  bool
                                        
                                        .. attribute:: second_table_index
                                        
                                        	Second table index
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.free_time = None
                                            self.is_acknowledged = None
                                            self.is_advertising_router_reachable = None
                                            self.is_deleted = None
                                            self.is_flood_pending = None
                                            self.is_maximum_aged = None
                                            self.is_neighbor_exchange = None
                                            self.is_no_delete = None
                                            self.is_nsr_ack_pending = None
                                            self.is_partial_spf = None
                                            self.is_routing_bit = None
                                            self.is_routing_table = None
                                            self.lsa_flood_required_post_fail_over = None
                                            self.lsa_length = None
                                            self.lsa_sync_state = None
                                            self.minute_table_index = None
                                            self.nsr_flood_required = None
                                            self.rate_limit = None
                                            self.second_table_index = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-detail'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.free_time is not None:
                                                return True

                                            if self.is_acknowledged is not None:
                                                return True

                                            if self.is_advertising_router_reachable is not None:
                                                return True

                                            if self.is_deleted is not None:
                                                return True

                                            if self.is_flood_pending is not None:
                                                return True

                                            if self.is_maximum_aged is not None:
                                                return True

                                            if self.is_neighbor_exchange is not None:
                                                return True

                                            if self.is_no_delete is not None:
                                                return True

                                            if self.is_nsr_ack_pending is not None:
                                                return True

                                            if self.is_partial_spf is not None:
                                                return True

                                            if self.is_routing_bit is not None:
                                                return True

                                            if self.is_routing_table is not None:
                                                return True

                                            if self.lsa_flood_required_post_fail_over is not None:
                                                return True

                                            if self.lsa_length is not None:
                                                return True

                                            if self.lsa_sync_state is not None:
                                                return True

                                            if self.minute_table_index is not None:
                                                return True

                                            if self.nsr_flood_required is not None:
                                                return True

                                            if self.rate_limit is not None:
                                                return True

                                            if self.second_table_index is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType.LsaDetail']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:external-lsa-type'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.external_tag is not None:
                                            return True

                                        if self.forwarding_address is not None:
                                            return True

                                        if self.is_forwarding_address_set is not None:
                                            return True

                                        if self.lsa_detail is not None and self.lsa_detail._has_data():
                                            return True

                                        if self.lsa_header is not None and self.lsa_header._has_data():
                                            return True

                                        if self.metric_type is not None:
                                            return True

                                        if self.prefix is not None:
                                            return True

                                        if self.prefix_length is not None:
                                            return True

                                        if self.priority is not None:
                                            return True

                                        if self.tos_cost is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                        return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType']['meta_info']


                                class NssalsaType(object):
                                    """
                                    NSSA External LSA
                                    
                                    .. attribute:: external_tag
                                    
                                    	Route Tag
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: forwarding_address
                                    
                                    	Forwarding Address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: is_forwarding_address_set
                                    
                                    	If true, forwarding address is set 
                                    	**type**\:  bool
                                    
                                    .. attribute:: lsa_detail
                                    
                                    	Detailed LSA Information
                                    	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType.LsaDetail>`
                                    
                                    .. attribute:: lsa_header
                                    
                                    	Header information 
                                    	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType.LsaHeader>`
                                    
                                    .. attribute:: metric_type
                                    
                                    	Metric type 
                                    	**type**\:   :py:class:`Ospfv3DefaultMetricEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3DefaultMetricEnum>`
                                    
                                    .. attribute:: prefix
                                    
                                    	IPV6 address prefix 
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: prefix_length
                                    
                                    	Prefix length 
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: priority
                                    
                                    	Prefix priority
                                    	**type**\:   :py:class:`PrefixPriorityEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.PrefixPriorityEnum>`
                                    
                                    .. attribute:: tos_cost
                                    
                                    	Type of service cost metric 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.external_tag = None
                                        self.forwarding_address = None
                                        self.is_forwarding_address_set = None
                                        self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType.LsaDetail()
                                        self.lsa_detail.parent = self
                                        self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType.LsaHeader()
                                        self.lsa_header.parent = self
                                        self.metric_type = None
                                        self.prefix = None
                                        self.prefix_length = None
                                        self.priority = None
                                        self.tos_cost = None


                                    class LsaHeader(object):
                                        """
                                        Header information 
                                        
                                        .. attribute:: advertising_router
                                        
                                        	Router ID of Advertising Router
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: checksum
                                        
                                        	Checksum value
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: is_do_not_age_lsa
                                        
                                        	If true, Do Not Age this LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_graceful_restart_active
                                        
                                        	If true, if grace restart is active 
                                        	**type**\:  bool
                                        
                                        .. attribute:: ls_id
                                        
                                        	LS ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: lsa_age
                                        
                                        	LSA's Age (s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_area_id
                                        
                                        	Area ID in decimal or dotted\-decimal format
                                        	**type**\:  str
                                        
                                        	**length:** 0..16
                                        
                                        .. attribute:: lsa_type
                                        
                                        	LSA type
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: sequence_number
                                        
                                        	Current Sequence number
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.advertising_router = None
                                            self.checksum = None
                                            self.is_do_not_age_lsa = None
                                            self.is_graceful_restart_active = None
                                            self.ls_id = None
                                            self.lsa_age = None
                                            self.lsa_area_id = None
                                            self.lsa_type = None
                                            self.sequence_number = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-header'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.advertising_router is not None:
                                                return True

                                            if self.checksum is not None:
                                                return True

                                            if self.is_do_not_age_lsa is not None:
                                                return True

                                            if self.is_graceful_restart_active is not None:
                                                return True

                                            if self.ls_id is not None:
                                                return True

                                            if self.lsa_age is not None:
                                                return True

                                            if self.lsa_area_id is not None:
                                                return True

                                            if self.lsa_type is not None:
                                                return True

                                            if self.sequence_number is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType.LsaHeader']['meta_info']


                                    class LsaDetail(object):
                                        """
                                        Detailed LSA Information
                                        
                                        .. attribute:: free_time
                                        
                                        	The amount of time since the last check was made to free this LSA (s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_acknowledged
                                        
                                        	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_advertising_router_reachable
                                        
                                        	If true, Advertising Router is reachable
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_deleted
                                        
                                        	If true, flag is set to delete this LSA 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_flood_pending
                                        
                                        	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_maximum_aged
                                        
                                        	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_neighbor_exchange
                                        
                                        	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_no_delete
                                        
                                        	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_nsr_ack_pending
                                        
                                        	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_partial_spf
                                        
                                        	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_routing_bit
                                        
                                        	If true, Routing Bit set on the LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_routing_table
                                        
                                        	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                        	**type**\:  bool
                                        
                                        .. attribute:: lsa_flood_required_post_fail_over
                                        
                                        	LSA flood required after FO
                                        	**type**\:  bool
                                        
                                        .. attribute:: lsa_length
                                        
                                        	Length of the LSA
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_sync_state
                                        
                                        	State of LSA sync with active
                                        	**type**\:   :py:class:`OspfLsaSyncStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncStateEnum>`
                                        
                                        .. attribute:: minute_table_index
                                        
                                        	Minute table index
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: nsr_flood_required
                                        
                                        	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                        	**type**\:  bool
                                        
                                        .. attribute:: rate_limit
                                        
                                        	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                        	**type**\:  bool
                                        
                                        .. attribute:: second_table_index
                                        
                                        	Second table index
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.free_time = None
                                            self.is_acknowledged = None
                                            self.is_advertising_router_reachable = None
                                            self.is_deleted = None
                                            self.is_flood_pending = None
                                            self.is_maximum_aged = None
                                            self.is_neighbor_exchange = None
                                            self.is_no_delete = None
                                            self.is_nsr_ack_pending = None
                                            self.is_partial_spf = None
                                            self.is_routing_bit = None
                                            self.is_routing_table = None
                                            self.lsa_flood_required_post_fail_over = None
                                            self.lsa_length = None
                                            self.lsa_sync_state = None
                                            self.minute_table_index = None
                                            self.nsr_flood_required = None
                                            self.rate_limit = None
                                            self.second_table_index = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-detail'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.free_time is not None:
                                                return True

                                            if self.is_acknowledged is not None:
                                                return True

                                            if self.is_advertising_router_reachable is not None:
                                                return True

                                            if self.is_deleted is not None:
                                                return True

                                            if self.is_flood_pending is not None:
                                                return True

                                            if self.is_maximum_aged is not None:
                                                return True

                                            if self.is_neighbor_exchange is not None:
                                                return True

                                            if self.is_no_delete is not None:
                                                return True

                                            if self.is_nsr_ack_pending is not None:
                                                return True

                                            if self.is_partial_spf is not None:
                                                return True

                                            if self.is_routing_bit is not None:
                                                return True

                                            if self.is_routing_table is not None:
                                                return True

                                            if self.lsa_flood_required_post_fail_over is not None:
                                                return True

                                            if self.lsa_length is not None:
                                                return True

                                            if self.lsa_sync_state is not None:
                                                return True

                                            if self.minute_table_index is not None:
                                                return True

                                            if self.nsr_flood_required is not None:
                                                return True

                                            if self.rate_limit is not None:
                                                return True

                                            if self.second_table_index is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType.LsaDetail']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:nssalsa-type'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.external_tag is not None:
                                            return True

                                        if self.forwarding_address is not None:
                                            return True

                                        if self.is_forwarding_address_set is not None:
                                            return True

                                        if self.lsa_detail is not None and self.lsa_detail._has_data():
                                            return True

                                        if self.lsa_header is not None and self.lsa_header._has_data():
                                            return True

                                        if self.metric_type is not None:
                                            return True

                                        if self.prefix is not None:
                                            return True

                                        if self.prefix_length is not None:
                                            return True

                                        if self.priority is not None:
                                            return True

                                        if self.tos_cost is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                        return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType']['meta_info']


                                class LinkLsaType(object):
                                    """
                                    Link LSA
                                    
                                    .. attribute:: interface_name
                                    
                                    	LSA interface handle
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                    
                                    .. attribute:: is_sham_link
                                    
                                    	If true, it is a sham link
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_virtual_link
                                    
                                    	If true, it is a virtual link
                                    	**type**\:  bool
                                    
                                    .. attribute:: lsa_detail
                                    
                                    	Detailed LSA information
                                    	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType.LsaDetail>`
                                    
                                    .. attribute:: lsa_header
                                    
                                    	Header information 
                                    	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType.LsaHeader>`
                                    
                                    .. attribute:: lsa_link_local
                                    
                                    	LSA link local 
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: prefix
                                    
                                    	OSPFv3 prefix 
                                    	**type**\: list of    :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType.Prefix>`
                                    
                                    .. attribute:: router_priority
                                    
                                    	Router priority 
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: sham_link_id
                                    
                                    	Sham link ID 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: virtual_link_id
                                    
                                    	Virtual link ID 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.interface_name = None
                                        self.is_sham_link = None
                                        self.is_virtual_link = None
                                        self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType.LsaDetail()
                                        self.lsa_detail.parent = self
                                        self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType.LsaHeader()
                                        self.lsa_header.parent = self
                                        self.lsa_link_local = None
                                        self.prefix = YList()
                                        self.prefix.parent = self
                                        self.prefix.name = 'prefix'
                                        self.router_priority = None
                                        self.sham_link_id = None
                                        self.virtual_link_id = None


                                    class LsaHeader(object):
                                        """
                                        Header information 
                                        
                                        .. attribute:: advertising_router
                                        
                                        	Router ID of Advertising Router
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: checksum
                                        
                                        	Checksum value
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: is_do_not_age_lsa
                                        
                                        	If true, Do Not Age this LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_graceful_restart_active
                                        
                                        	If true, if grace restart is active 
                                        	**type**\:  bool
                                        
                                        .. attribute:: ls_id
                                        
                                        	LS ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: lsa_age
                                        
                                        	LSA's Age (s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_area_id
                                        
                                        	Area ID in decimal or dotted\-decimal format
                                        	**type**\:  str
                                        
                                        	**length:** 0..16
                                        
                                        .. attribute:: lsa_type
                                        
                                        	LSA type
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: sequence_number
                                        
                                        	Current Sequence number
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.advertising_router = None
                                            self.checksum = None
                                            self.is_do_not_age_lsa = None
                                            self.is_graceful_restart_active = None
                                            self.ls_id = None
                                            self.lsa_age = None
                                            self.lsa_area_id = None
                                            self.lsa_type = None
                                            self.sequence_number = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-header'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.advertising_router is not None:
                                                return True

                                            if self.checksum is not None:
                                                return True

                                            if self.is_do_not_age_lsa is not None:
                                                return True

                                            if self.is_graceful_restart_active is not None:
                                                return True

                                            if self.ls_id is not None:
                                                return True

                                            if self.lsa_age is not None:
                                                return True

                                            if self.lsa_area_id is not None:
                                                return True

                                            if self.lsa_type is not None:
                                                return True

                                            if self.sequence_number is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType.LsaHeader']['meta_info']


                                    class LsaDetail(object):
                                        """
                                        Detailed LSA information
                                        
                                        .. attribute:: free_time
                                        
                                        	The amount of time since the last check was made to free this LSA (s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_acknowledged
                                        
                                        	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_advertising_router_reachable
                                        
                                        	If true, Advertising Router is reachable
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_deleted
                                        
                                        	If true, flag is set to delete this LSA 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_flood_pending
                                        
                                        	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_maximum_aged
                                        
                                        	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_neighbor_exchange
                                        
                                        	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_no_delete
                                        
                                        	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_nsr_ack_pending
                                        
                                        	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_partial_spf
                                        
                                        	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_routing_bit
                                        
                                        	If true, Routing Bit set on the LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_routing_table
                                        
                                        	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                        	**type**\:  bool
                                        
                                        .. attribute:: lsa_flood_required_post_fail_over
                                        
                                        	LSA flood required after FO
                                        	**type**\:  bool
                                        
                                        .. attribute:: lsa_length
                                        
                                        	Length of the LSA
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_sync_state
                                        
                                        	State of LSA sync with active
                                        	**type**\:   :py:class:`OspfLsaSyncStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncStateEnum>`
                                        
                                        .. attribute:: minute_table_index
                                        
                                        	Minute table index
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: nsr_flood_required
                                        
                                        	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                        	**type**\:  bool
                                        
                                        .. attribute:: rate_limit
                                        
                                        	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                        	**type**\:  bool
                                        
                                        .. attribute:: second_table_index
                                        
                                        	Second table index
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.free_time = None
                                            self.is_acknowledged = None
                                            self.is_advertising_router_reachable = None
                                            self.is_deleted = None
                                            self.is_flood_pending = None
                                            self.is_maximum_aged = None
                                            self.is_neighbor_exchange = None
                                            self.is_no_delete = None
                                            self.is_nsr_ack_pending = None
                                            self.is_partial_spf = None
                                            self.is_routing_bit = None
                                            self.is_routing_table = None
                                            self.lsa_flood_required_post_fail_over = None
                                            self.lsa_length = None
                                            self.lsa_sync_state = None
                                            self.minute_table_index = None
                                            self.nsr_flood_required = None
                                            self.rate_limit = None
                                            self.second_table_index = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-detail'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.free_time is not None:
                                                return True

                                            if self.is_acknowledged is not None:
                                                return True

                                            if self.is_advertising_router_reachable is not None:
                                                return True

                                            if self.is_deleted is not None:
                                                return True

                                            if self.is_flood_pending is not None:
                                                return True

                                            if self.is_maximum_aged is not None:
                                                return True

                                            if self.is_neighbor_exchange is not None:
                                                return True

                                            if self.is_no_delete is not None:
                                                return True

                                            if self.is_nsr_ack_pending is not None:
                                                return True

                                            if self.is_partial_spf is not None:
                                                return True

                                            if self.is_routing_bit is not None:
                                                return True

                                            if self.is_routing_table is not None:
                                                return True

                                            if self.lsa_flood_required_post_fail_over is not None:
                                                return True

                                            if self.lsa_length is not None:
                                                return True

                                            if self.lsa_sync_state is not None:
                                                return True

                                            if self.minute_table_index is not None:
                                                return True

                                            if self.nsr_flood_required is not None:
                                                return True

                                            if self.rate_limit is not None:
                                                return True

                                            if self.second_table_index is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType.LsaDetail']['meta_info']


                                    class Prefix(object):
                                        """
                                        OSPFv3 prefix 
                                        
                                        .. attribute:: ospfv3_prefix_length
                                        
                                        	OSPFv3 prefix length 
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ospfv3_prefix_metric
                                        
                                        	OSPFv3 prefix metric 
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: ospfv3_prefix_options
                                        
                                        	OSPFv3 prefix options 
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: prefix
                                        
                                        	OSPFv3 prefix 
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: priority
                                        
                                        	Prefix priority
                                        	**type**\:   :py:class:`PrefixPriorityEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.PrefixPriorityEnum>`
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.ospfv3_prefix_length = None
                                            self.ospfv3_prefix_metric = None
                                            self.ospfv3_prefix_options = None
                                            self.prefix = None
                                            self.priority = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:prefix'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.ospfv3_prefix_length is not None:
                                                return True

                                            if self.ospfv3_prefix_metric is not None:
                                                return True

                                            if self.ospfv3_prefix_options is not None:
                                                return True

                                            if self.prefix is not None:
                                                return True

                                            if self.priority is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType.Prefix']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:link-lsa-type'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.interface_name is not None:
                                            return True

                                        if self.is_sham_link is not None:
                                            return True

                                        if self.is_virtual_link is not None:
                                            return True

                                        if self.lsa_detail is not None and self.lsa_detail._has_data():
                                            return True

                                        if self.lsa_header is not None and self.lsa_header._has_data():
                                            return True

                                        if self.lsa_link_local is not None:
                                            return True

                                        if self.prefix is not None:
                                            for child_ref in self.prefix:
                                                if child_ref._has_data():
                                                    return True

                                        if self.router_priority is not None:
                                            return True

                                        if self.sham_link_id is not None:
                                            return True

                                        if self.virtual_link_id is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                        return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType']['meta_info']


                                class IntraAreaPrefixLsaType(object):
                                    """
                                    Intra Area Prefix LSA
                                    
                                    .. attribute:: lsa_detail
                                    
                                    	Detailed LSA information
                                    	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaDetail>`
                                    
                                    .. attribute:: lsa_header
                                    
                                    	Header information 
                                    	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaHeader>`
                                    
                                    .. attribute:: prefix
                                    
                                    	OSPFv3 prefix 
                                    	**type**\: list of    :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.Prefix>`
                                    
                                    .. attribute:: reference_advertised_router
                                    
                                    	Reference advertised router 
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: reference_lsa_id
                                    
                                    	Reference LSA ID 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: reference_type
                                    
                                    	Reference type 
                                    	**type**\:   :py:class:`Ospfv3Lsa1Enum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Lsa1Enum>`
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaDetail()
                                        self.lsa_detail.parent = self
                                        self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaHeader()
                                        self.lsa_header.parent = self
                                        self.prefix = YList()
                                        self.prefix.parent = self
                                        self.prefix.name = 'prefix'
                                        self.reference_advertised_router = None
                                        self.reference_lsa_id = None
                                        self.reference_type = None


                                    class LsaHeader(object):
                                        """
                                        Header information 
                                        
                                        .. attribute:: advertising_router
                                        
                                        	Router ID of Advertising Router
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: checksum
                                        
                                        	Checksum value
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: is_do_not_age_lsa
                                        
                                        	If true, Do Not Age this LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_graceful_restart_active
                                        
                                        	If true, if grace restart is active 
                                        	**type**\:  bool
                                        
                                        .. attribute:: ls_id
                                        
                                        	LS ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: lsa_age
                                        
                                        	LSA's Age (s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_area_id
                                        
                                        	Area ID in decimal or dotted\-decimal format
                                        	**type**\:  str
                                        
                                        	**length:** 0..16
                                        
                                        .. attribute:: lsa_type
                                        
                                        	LSA type
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: sequence_number
                                        
                                        	Current Sequence number
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.advertising_router = None
                                            self.checksum = None
                                            self.is_do_not_age_lsa = None
                                            self.is_graceful_restart_active = None
                                            self.ls_id = None
                                            self.lsa_age = None
                                            self.lsa_area_id = None
                                            self.lsa_type = None
                                            self.sequence_number = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-header'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.advertising_router is not None:
                                                return True

                                            if self.checksum is not None:
                                                return True

                                            if self.is_do_not_age_lsa is not None:
                                                return True

                                            if self.is_graceful_restart_active is not None:
                                                return True

                                            if self.ls_id is not None:
                                                return True

                                            if self.lsa_age is not None:
                                                return True

                                            if self.lsa_area_id is not None:
                                                return True

                                            if self.lsa_type is not None:
                                                return True

                                            if self.sequence_number is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaHeader']['meta_info']


                                    class LsaDetail(object):
                                        """
                                        Detailed LSA information
                                        
                                        .. attribute:: free_time
                                        
                                        	The amount of time since the last check was made to free this LSA (s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_acknowledged
                                        
                                        	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_advertising_router_reachable
                                        
                                        	If true, Advertising Router is reachable
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_deleted
                                        
                                        	If true, flag is set to delete this LSA 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_flood_pending
                                        
                                        	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_maximum_aged
                                        
                                        	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_neighbor_exchange
                                        
                                        	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_no_delete
                                        
                                        	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_nsr_ack_pending
                                        
                                        	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_partial_spf
                                        
                                        	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_routing_bit
                                        
                                        	If true, Routing Bit set on the LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_routing_table
                                        
                                        	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                        	**type**\:  bool
                                        
                                        .. attribute:: lsa_flood_required_post_fail_over
                                        
                                        	LSA flood required after FO
                                        	**type**\:  bool
                                        
                                        .. attribute:: lsa_length
                                        
                                        	Length of the LSA
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_sync_state
                                        
                                        	State of LSA sync with active
                                        	**type**\:   :py:class:`OspfLsaSyncStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncStateEnum>`
                                        
                                        .. attribute:: minute_table_index
                                        
                                        	Minute table index
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: nsr_flood_required
                                        
                                        	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                        	**type**\:  bool
                                        
                                        .. attribute:: rate_limit
                                        
                                        	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                        	**type**\:  bool
                                        
                                        .. attribute:: second_table_index
                                        
                                        	Second table index
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.free_time = None
                                            self.is_acknowledged = None
                                            self.is_advertising_router_reachable = None
                                            self.is_deleted = None
                                            self.is_flood_pending = None
                                            self.is_maximum_aged = None
                                            self.is_neighbor_exchange = None
                                            self.is_no_delete = None
                                            self.is_nsr_ack_pending = None
                                            self.is_partial_spf = None
                                            self.is_routing_bit = None
                                            self.is_routing_table = None
                                            self.lsa_flood_required_post_fail_over = None
                                            self.lsa_length = None
                                            self.lsa_sync_state = None
                                            self.minute_table_index = None
                                            self.nsr_flood_required = None
                                            self.rate_limit = None
                                            self.second_table_index = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-detail'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.free_time is not None:
                                                return True

                                            if self.is_acknowledged is not None:
                                                return True

                                            if self.is_advertising_router_reachable is not None:
                                                return True

                                            if self.is_deleted is not None:
                                                return True

                                            if self.is_flood_pending is not None:
                                                return True

                                            if self.is_maximum_aged is not None:
                                                return True

                                            if self.is_neighbor_exchange is not None:
                                                return True

                                            if self.is_no_delete is not None:
                                                return True

                                            if self.is_nsr_ack_pending is not None:
                                                return True

                                            if self.is_partial_spf is not None:
                                                return True

                                            if self.is_routing_bit is not None:
                                                return True

                                            if self.is_routing_table is not None:
                                                return True

                                            if self.lsa_flood_required_post_fail_over is not None:
                                                return True

                                            if self.lsa_length is not None:
                                                return True

                                            if self.lsa_sync_state is not None:
                                                return True

                                            if self.minute_table_index is not None:
                                                return True

                                            if self.nsr_flood_required is not None:
                                                return True

                                            if self.rate_limit is not None:
                                                return True

                                            if self.second_table_index is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaDetail']['meta_info']


                                    class Prefix(object):
                                        """
                                        OSPFv3 prefix 
                                        
                                        .. attribute:: ospfv3_prefix_length
                                        
                                        	OSPFv3 prefix length 
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ospfv3_prefix_metric
                                        
                                        	OSPFv3 prefix metric 
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: ospfv3_prefix_options
                                        
                                        	OSPFv3 prefix options 
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: prefix
                                        
                                        	OSPFv3 prefix 
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: priority
                                        
                                        	Prefix priority
                                        	**type**\:   :py:class:`PrefixPriorityEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.PrefixPriorityEnum>`
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.ospfv3_prefix_length = None
                                            self.ospfv3_prefix_metric = None
                                            self.ospfv3_prefix_options = None
                                            self.prefix = None
                                            self.priority = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:prefix'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.ospfv3_prefix_length is not None:
                                                return True

                                            if self.ospfv3_prefix_metric is not None:
                                                return True

                                            if self.ospfv3_prefix_options is not None:
                                                return True

                                            if self.prefix is not None:
                                                return True

                                            if self.priority is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.Prefix']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:intra-area-prefix-lsa-type'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.lsa_detail is not None and self.lsa_detail._has_data():
                                            return True

                                        if self.lsa_header is not None and self.lsa_header._has_data():
                                            return True

                                        if self.prefix is not None:
                                            for child_ref in self.prefix:
                                                if child_ref._has_data():
                                                    return True

                                        if self.reference_advertised_router is not None:
                                            return True

                                        if self.reference_lsa_id is not None:
                                            return True

                                        if self.reference_type is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                        return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType']['meta_info']


                                class GraceLsa(object):
                                    """
                                    Grace LSA
                                    
                                    .. attribute:: grace_period
                                    
                                    	The grace periord where helper routers should wait before advertising it fully adjacent(s) 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: grace_reason
                                    
                                    	Reason for router restart
                                    	**type**\:   :py:class:`Ospfv3GracefulRestartReasonEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3GracefulRestartReasonEnum>`
                                    
                                    .. attribute:: lsa_detail
                                    
                                    	Detailed LSA information
                                    	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa.LsaDetail>`
                                    
                                    .. attribute:: lsa_header
                                    
                                    	Header information 
                                    	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa.LsaHeader>`
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.grace_period = None
                                        self.grace_reason = None
                                        self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa.LsaDetail()
                                        self.lsa_detail.parent = self
                                        self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa.LsaHeader()
                                        self.lsa_header.parent = self


                                    class LsaHeader(object):
                                        """
                                        Header information 
                                        
                                        .. attribute:: advertising_router
                                        
                                        	Router ID of Advertising Router
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: checksum
                                        
                                        	Checksum value
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: is_do_not_age_lsa
                                        
                                        	If true, Do Not Age this LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_graceful_restart_active
                                        
                                        	If true, if grace restart is active 
                                        	**type**\:  bool
                                        
                                        .. attribute:: ls_id
                                        
                                        	LS ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: lsa_age
                                        
                                        	LSA's Age (s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_area_id
                                        
                                        	Area ID in decimal or dotted\-decimal format
                                        	**type**\:  str
                                        
                                        	**length:** 0..16
                                        
                                        .. attribute:: lsa_type
                                        
                                        	LSA type
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: sequence_number
                                        
                                        	Current Sequence number
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.advertising_router = None
                                            self.checksum = None
                                            self.is_do_not_age_lsa = None
                                            self.is_graceful_restart_active = None
                                            self.ls_id = None
                                            self.lsa_age = None
                                            self.lsa_area_id = None
                                            self.lsa_type = None
                                            self.sequence_number = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-header'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.advertising_router is not None:
                                                return True

                                            if self.checksum is not None:
                                                return True

                                            if self.is_do_not_age_lsa is not None:
                                                return True

                                            if self.is_graceful_restart_active is not None:
                                                return True

                                            if self.ls_id is not None:
                                                return True

                                            if self.lsa_age is not None:
                                                return True

                                            if self.lsa_area_id is not None:
                                                return True

                                            if self.lsa_type is not None:
                                                return True

                                            if self.sequence_number is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa.LsaHeader']['meta_info']


                                    class LsaDetail(object):
                                        """
                                        Detailed LSA information
                                        
                                        .. attribute:: free_time
                                        
                                        	The amount of time since the last check was made to free this LSA (s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_acknowledged
                                        
                                        	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_advertising_router_reachable
                                        
                                        	If true, Advertising Router is reachable
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_deleted
                                        
                                        	If true, flag is set to delete this LSA 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_flood_pending
                                        
                                        	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_maximum_aged
                                        
                                        	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_neighbor_exchange
                                        
                                        	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_no_delete
                                        
                                        	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_nsr_ack_pending
                                        
                                        	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_partial_spf
                                        
                                        	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_routing_bit
                                        
                                        	If true, Routing Bit set on the LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_routing_table
                                        
                                        	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                        	**type**\:  bool
                                        
                                        .. attribute:: lsa_flood_required_post_fail_over
                                        
                                        	LSA flood required after FO
                                        	**type**\:  bool
                                        
                                        .. attribute:: lsa_length
                                        
                                        	Length of the LSA
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_sync_state
                                        
                                        	State of LSA sync with active
                                        	**type**\:   :py:class:`OspfLsaSyncStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncStateEnum>`
                                        
                                        .. attribute:: minute_table_index
                                        
                                        	Minute table index
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: nsr_flood_required
                                        
                                        	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                        	**type**\:  bool
                                        
                                        .. attribute:: rate_limit
                                        
                                        	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                        	**type**\:  bool
                                        
                                        .. attribute:: second_table_index
                                        
                                        	Second table index
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.free_time = None
                                            self.is_acknowledged = None
                                            self.is_advertising_router_reachable = None
                                            self.is_deleted = None
                                            self.is_flood_pending = None
                                            self.is_maximum_aged = None
                                            self.is_neighbor_exchange = None
                                            self.is_no_delete = None
                                            self.is_nsr_ack_pending = None
                                            self.is_partial_spf = None
                                            self.is_routing_bit = None
                                            self.is_routing_table = None
                                            self.lsa_flood_required_post_fail_over = None
                                            self.lsa_length = None
                                            self.lsa_sync_state = None
                                            self.minute_table_index = None
                                            self.nsr_flood_required = None
                                            self.rate_limit = None
                                            self.second_table_index = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-detail'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.free_time is not None:
                                                return True

                                            if self.is_acknowledged is not None:
                                                return True

                                            if self.is_advertising_router_reachable is not None:
                                                return True

                                            if self.is_deleted is not None:
                                                return True

                                            if self.is_flood_pending is not None:
                                                return True

                                            if self.is_maximum_aged is not None:
                                                return True

                                            if self.is_neighbor_exchange is not None:
                                                return True

                                            if self.is_no_delete is not None:
                                                return True

                                            if self.is_nsr_ack_pending is not None:
                                                return True

                                            if self.is_partial_spf is not None:
                                                return True

                                            if self.is_routing_bit is not None:
                                                return True

                                            if self.is_routing_table is not None:
                                                return True

                                            if self.lsa_flood_required_post_fail_over is not None:
                                                return True

                                            if self.lsa_length is not None:
                                                return True

                                            if self.lsa_sync_state is not None:
                                                return True

                                            if self.minute_table_index is not None:
                                                return True

                                            if self.nsr_flood_required is not None:
                                                return True

                                            if self.rate_limit is not None:
                                                return True

                                            if self.second_table_index is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa.LsaDetail']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:grace-lsa'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.grace_period is not None:
                                            return True

                                        if self.grace_reason is not None:
                                            return True

                                        if self.lsa_detail is not None and self.lsa_detail._has_data():
                                            return True

                                        if self.lsa_header is not None and self.lsa_header._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                        return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa']['meta_info']


                                class UnknownLinkLsaType(object):
                                    """
                                    Unknown Link Scope LSA
                                    
                                    .. attribute:: interface_name
                                    
                                    	LSA interface name 
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                    
                                    .. attribute:: is_sham_link
                                    
                                    	If true, it is a sham link 
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_virtual_link
                                    
                                    	If true, it is a virtual link 
                                    	**type**\:  bool
                                    
                                    .. attribute:: lsa_detail
                                    
                                    	Detailed LSA information
                                    	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaDetail>`
                                    
                                    .. attribute:: lsa_header
                                    
                                    	Header information 
                                    	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaHeader>`
                                    
                                    .. attribute:: sham_link_id
                                    
                                    	Shamlink ID 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: virtual_link_id
                                    
                                    	Virtual link ID 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.interface_name = None
                                        self.is_sham_link = None
                                        self.is_virtual_link = None
                                        self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaDetail()
                                        self.lsa_detail.parent = self
                                        self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaHeader()
                                        self.lsa_header.parent = self
                                        self.sham_link_id = None
                                        self.virtual_link_id = None


                                    class LsaHeader(object):
                                        """
                                        Header information 
                                        
                                        .. attribute:: advertising_router
                                        
                                        	Router ID of Advertising Router
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: checksum
                                        
                                        	Checksum value
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: is_do_not_age_lsa
                                        
                                        	If true, Do Not Age this LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_graceful_restart_active
                                        
                                        	If true, if grace restart is active 
                                        	**type**\:  bool
                                        
                                        .. attribute:: ls_id
                                        
                                        	LS ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: lsa_age
                                        
                                        	LSA's Age (s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_area_id
                                        
                                        	Area ID in decimal or dotted\-decimal format
                                        	**type**\:  str
                                        
                                        	**length:** 0..16
                                        
                                        .. attribute:: lsa_type
                                        
                                        	LSA type
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: sequence_number
                                        
                                        	Current Sequence number
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.advertising_router = None
                                            self.checksum = None
                                            self.is_do_not_age_lsa = None
                                            self.is_graceful_restart_active = None
                                            self.ls_id = None
                                            self.lsa_age = None
                                            self.lsa_area_id = None
                                            self.lsa_type = None
                                            self.sequence_number = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-header'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.advertising_router is not None:
                                                return True

                                            if self.checksum is not None:
                                                return True

                                            if self.is_do_not_age_lsa is not None:
                                                return True

                                            if self.is_graceful_restart_active is not None:
                                                return True

                                            if self.ls_id is not None:
                                                return True

                                            if self.lsa_age is not None:
                                                return True

                                            if self.lsa_area_id is not None:
                                                return True

                                            if self.lsa_type is not None:
                                                return True

                                            if self.sequence_number is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaHeader']['meta_info']


                                    class LsaDetail(object):
                                        """
                                        Detailed LSA information
                                        
                                        .. attribute:: free_time
                                        
                                        	The amount of time since the last check was made to free this LSA (s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_acknowledged
                                        
                                        	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_advertising_router_reachable
                                        
                                        	If true, Advertising Router is reachable
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_deleted
                                        
                                        	If true, flag is set to delete this LSA 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_flood_pending
                                        
                                        	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_maximum_aged
                                        
                                        	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_neighbor_exchange
                                        
                                        	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_no_delete
                                        
                                        	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_nsr_ack_pending
                                        
                                        	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_partial_spf
                                        
                                        	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_routing_bit
                                        
                                        	If true, Routing Bit set on the LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_routing_table
                                        
                                        	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                        	**type**\:  bool
                                        
                                        .. attribute:: lsa_flood_required_post_fail_over
                                        
                                        	LSA flood required after FO
                                        	**type**\:  bool
                                        
                                        .. attribute:: lsa_length
                                        
                                        	Length of the LSA
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_sync_state
                                        
                                        	State of LSA sync with active
                                        	**type**\:   :py:class:`OspfLsaSyncStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncStateEnum>`
                                        
                                        .. attribute:: minute_table_index
                                        
                                        	Minute table index
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: nsr_flood_required
                                        
                                        	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                        	**type**\:  bool
                                        
                                        .. attribute:: rate_limit
                                        
                                        	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                        	**type**\:  bool
                                        
                                        .. attribute:: second_table_index
                                        
                                        	Second table index
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.free_time = None
                                            self.is_acknowledged = None
                                            self.is_advertising_router_reachable = None
                                            self.is_deleted = None
                                            self.is_flood_pending = None
                                            self.is_maximum_aged = None
                                            self.is_neighbor_exchange = None
                                            self.is_no_delete = None
                                            self.is_nsr_ack_pending = None
                                            self.is_partial_spf = None
                                            self.is_routing_bit = None
                                            self.is_routing_table = None
                                            self.lsa_flood_required_post_fail_over = None
                                            self.lsa_length = None
                                            self.lsa_sync_state = None
                                            self.minute_table_index = None
                                            self.nsr_flood_required = None
                                            self.rate_limit = None
                                            self.second_table_index = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-detail'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.free_time is not None:
                                                return True

                                            if self.is_acknowledged is not None:
                                                return True

                                            if self.is_advertising_router_reachable is not None:
                                                return True

                                            if self.is_deleted is not None:
                                                return True

                                            if self.is_flood_pending is not None:
                                                return True

                                            if self.is_maximum_aged is not None:
                                                return True

                                            if self.is_neighbor_exchange is not None:
                                                return True

                                            if self.is_no_delete is not None:
                                                return True

                                            if self.is_nsr_ack_pending is not None:
                                                return True

                                            if self.is_partial_spf is not None:
                                                return True

                                            if self.is_routing_bit is not None:
                                                return True

                                            if self.is_routing_table is not None:
                                                return True

                                            if self.lsa_flood_required_post_fail_over is not None:
                                                return True

                                            if self.lsa_length is not None:
                                                return True

                                            if self.lsa_sync_state is not None:
                                                return True

                                            if self.minute_table_index is not None:
                                                return True

                                            if self.nsr_flood_required is not None:
                                                return True

                                            if self.rate_limit is not None:
                                                return True

                                            if self.second_table_index is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaDetail']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:unknown-link-lsa-type'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.interface_name is not None:
                                            return True

                                        if self.is_sham_link is not None:
                                            return True

                                        if self.is_virtual_link is not None:
                                            return True

                                        if self.lsa_detail is not None and self.lsa_detail._has_data():
                                            return True

                                        if self.lsa_header is not None and self.lsa_header._has_data():
                                            return True

                                        if self.sham_link_id is not None:
                                            return True

                                        if self.virtual_link_id is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                        return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType']['meta_info']


                                class UnknownAreaLsaType(object):
                                    """
                                    Unknown\-Area scope LSA
                                    
                                    .. attribute:: interface_name
                                    
                                    	LSA interface name 
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                    
                                    .. attribute:: is_sham_link
                                    
                                    	If true, it is a sham link 
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_virtual_link
                                    
                                    	If true, it is a virtual link 
                                    	**type**\:  bool
                                    
                                    .. attribute:: lsa_detail
                                    
                                    	Detailed LSA information
                                    	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaDetail>`
                                    
                                    .. attribute:: lsa_header
                                    
                                    	Header information 
                                    	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaHeader>`
                                    
                                    .. attribute:: sham_link_id
                                    
                                    	Shamlink ID 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: virtual_link_id
                                    
                                    	Virtual link ID 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.interface_name = None
                                        self.is_sham_link = None
                                        self.is_virtual_link = None
                                        self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaDetail()
                                        self.lsa_detail.parent = self
                                        self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaHeader()
                                        self.lsa_header.parent = self
                                        self.sham_link_id = None
                                        self.virtual_link_id = None


                                    class LsaHeader(object):
                                        """
                                        Header information 
                                        
                                        .. attribute:: advertising_router
                                        
                                        	Router ID of Advertising Router
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: checksum
                                        
                                        	Checksum value
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: is_do_not_age_lsa
                                        
                                        	If true, Do Not Age this LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_graceful_restart_active
                                        
                                        	If true, if grace restart is active 
                                        	**type**\:  bool
                                        
                                        .. attribute:: ls_id
                                        
                                        	LS ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: lsa_age
                                        
                                        	LSA's Age (s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_area_id
                                        
                                        	Area ID in decimal or dotted\-decimal format
                                        	**type**\:  str
                                        
                                        	**length:** 0..16
                                        
                                        .. attribute:: lsa_type
                                        
                                        	LSA type
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: sequence_number
                                        
                                        	Current Sequence number
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.advertising_router = None
                                            self.checksum = None
                                            self.is_do_not_age_lsa = None
                                            self.is_graceful_restart_active = None
                                            self.ls_id = None
                                            self.lsa_age = None
                                            self.lsa_area_id = None
                                            self.lsa_type = None
                                            self.sequence_number = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-header'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.advertising_router is not None:
                                                return True

                                            if self.checksum is not None:
                                                return True

                                            if self.is_do_not_age_lsa is not None:
                                                return True

                                            if self.is_graceful_restart_active is not None:
                                                return True

                                            if self.ls_id is not None:
                                                return True

                                            if self.lsa_age is not None:
                                                return True

                                            if self.lsa_area_id is not None:
                                                return True

                                            if self.lsa_type is not None:
                                                return True

                                            if self.sequence_number is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaHeader']['meta_info']


                                    class LsaDetail(object):
                                        """
                                        Detailed LSA information
                                        
                                        .. attribute:: free_time
                                        
                                        	The amount of time since the last check was made to free this LSA (s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_acknowledged
                                        
                                        	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_advertising_router_reachable
                                        
                                        	If true, Advertising Router is reachable
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_deleted
                                        
                                        	If true, flag is set to delete this LSA 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_flood_pending
                                        
                                        	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_maximum_aged
                                        
                                        	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_neighbor_exchange
                                        
                                        	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_no_delete
                                        
                                        	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_nsr_ack_pending
                                        
                                        	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_partial_spf
                                        
                                        	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_routing_bit
                                        
                                        	If true, Routing Bit set on the LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_routing_table
                                        
                                        	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                        	**type**\:  bool
                                        
                                        .. attribute:: lsa_flood_required_post_fail_over
                                        
                                        	LSA flood required after FO
                                        	**type**\:  bool
                                        
                                        .. attribute:: lsa_length
                                        
                                        	Length of the LSA
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_sync_state
                                        
                                        	State of LSA sync with active
                                        	**type**\:   :py:class:`OspfLsaSyncStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncStateEnum>`
                                        
                                        .. attribute:: minute_table_index
                                        
                                        	Minute table index
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: nsr_flood_required
                                        
                                        	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                        	**type**\:  bool
                                        
                                        .. attribute:: rate_limit
                                        
                                        	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                        	**type**\:  bool
                                        
                                        .. attribute:: second_table_index
                                        
                                        	Second table index
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.free_time = None
                                            self.is_acknowledged = None
                                            self.is_advertising_router_reachable = None
                                            self.is_deleted = None
                                            self.is_flood_pending = None
                                            self.is_maximum_aged = None
                                            self.is_neighbor_exchange = None
                                            self.is_no_delete = None
                                            self.is_nsr_ack_pending = None
                                            self.is_partial_spf = None
                                            self.is_routing_bit = None
                                            self.is_routing_table = None
                                            self.lsa_flood_required_post_fail_over = None
                                            self.lsa_length = None
                                            self.lsa_sync_state = None
                                            self.minute_table_index = None
                                            self.nsr_flood_required = None
                                            self.rate_limit = None
                                            self.second_table_index = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-detail'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.free_time is not None:
                                                return True

                                            if self.is_acknowledged is not None:
                                                return True

                                            if self.is_advertising_router_reachable is not None:
                                                return True

                                            if self.is_deleted is not None:
                                                return True

                                            if self.is_flood_pending is not None:
                                                return True

                                            if self.is_maximum_aged is not None:
                                                return True

                                            if self.is_neighbor_exchange is not None:
                                                return True

                                            if self.is_no_delete is not None:
                                                return True

                                            if self.is_nsr_ack_pending is not None:
                                                return True

                                            if self.is_partial_spf is not None:
                                                return True

                                            if self.is_routing_bit is not None:
                                                return True

                                            if self.is_routing_table is not None:
                                                return True

                                            if self.lsa_flood_required_post_fail_over is not None:
                                                return True

                                            if self.lsa_length is not None:
                                                return True

                                            if self.lsa_sync_state is not None:
                                                return True

                                            if self.minute_table_index is not None:
                                                return True

                                            if self.nsr_flood_required is not None:
                                                return True

                                            if self.rate_limit is not None:
                                                return True

                                            if self.second_table_index is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaDetail']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:unknown-area-lsa-type'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.interface_name is not None:
                                            return True

                                        if self.is_sham_link is not None:
                                            return True

                                        if self.is_virtual_link is not None:
                                            return True

                                        if self.lsa_detail is not None and self.lsa_detail._has_data():
                                            return True

                                        if self.lsa_header is not None and self.lsa_header._has_data():
                                            return True

                                        if self.sham_link_id is not None:
                                            return True

                                        if self.virtual_link_id is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                        return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType']['meta_info']


                                class UnknownAslsaType(object):
                                    """
                                    Unknown\-AS scope LSA
                                    
                                    .. attribute:: interface_name
                                    
                                    	LSA interface name 
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                    
                                    .. attribute:: is_sham_link
                                    
                                    	If true, it is a sham link 
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_virtual_link
                                    
                                    	If true, it is a virtual link 
                                    	**type**\:  bool
                                    
                                    .. attribute:: lsa_detail
                                    
                                    	Detailed LSA information
                                    	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType.LsaDetail>`
                                    
                                    .. attribute:: lsa_header
                                    
                                    	Header information 
                                    	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType.LsaHeader>`
                                    
                                    .. attribute:: sham_link_id
                                    
                                    	Shamlink ID 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: virtual_link_id
                                    
                                    	Virtual link ID 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.interface_name = None
                                        self.is_sham_link = None
                                        self.is_virtual_link = None
                                        self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType.LsaDetail()
                                        self.lsa_detail.parent = self
                                        self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType.LsaHeader()
                                        self.lsa_header.parent = self
                                        self.sham_link_id = None
                                        self.virtual_link_id = None


                                    class LsaHeader(object):
                                        """
                                        Header information 
                                        
                                        .. attribute:: advertising_router
                                        
                                        	Router ID of Advertising Router
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: checksum
                                        
                                        	Checksum value
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: is_do_not_age_lsa
                                        
                                        	If true, Do Not Age this LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_graceful_restart_active
                                        
                                        	If true, if grace restart is active 
                                        	**type**\:  bool
                                        
                                        .. attribute:: ls_id
                                        
                                        	LS ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: lsa_age
                                        
                                        	LSA's Age (s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_area_id
                                        
                                        	Area ID in decimal or dotted\-decimal format
                                        	**type**\:  str
                                        
                                        	**length:** 0..16
                                        
                                        .. attribute:: lsa_type
                                        
                                        	LSA type
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: sequence_number
                                        
                                        	Current Sequence number
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.advertising_router = None
                                            self.checksum = None
                                            self.is_do_not_age_lsa = None
                                            self.is_graceful_restart_active = None
                                            self.ls_id = None
                                            self.lsa_age = None
                                            self.lsa_area_id = None
                                            self.lsa_type = None
                                            self.sequence_number = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-header'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.advertising_router is not None:
                                                return True

                                            if self.checksum is not None:
                                                return True

                                            if self.is_do_not_age_lsa is not None:
                                                return True

                                            if self.is_graceful_restart_active is not None:
                                                return True

                                            if self.ls_id is not None:
                                                return True

                                            if self.lsa_age is not None:
                                                return True

                                            if self.lsa_area_id is not None:
                                                return True

                                            if self.lsa_type is not None:
                                                return True

                                            if self.sequence_number is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType.LsaHeader']['meta_info']


                                    class LsaDetail(object):
                                        """
                                        Detailed LSA information
                                        
                                        .. attribute:: free_time
                                        
                                        	The amount of time since the last check was made to free this LSA (s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_acknowledged
                                        
                                        	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_advertising_router_reachable
                                        
                                        	If true, Advertising Router is reachable
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_deleted
                                        
                                        	If true, flag is set to delete this LSA 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_flood_pending
                                        
                                        	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_maximum_aged
                                        
                                        	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_neighbor_exchange
                                        
                                        	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_no_delete
                                        
                                        	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_nsr_ack_pending
                                        
                                        	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_partial_spf
                                        
                                        	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_routing_bit
                                        
                                        	If true, Routing Bit set on the LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_routing_table
                                        
                                        	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                        	**type**\:  bool
                                        
                                        .. attribute:: lsa_flood_required_post_fail_over
                                        
                                        	LSA flood required after FO
                                        	**type**\:  bool
                                        
                                        .. attribute:: lsa_length
                                        
                                        	Length of the LSA
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_sync_state
                                        
                                        	State of LSA sync with active
                                        	**type**\:   :py:class:`OspfLsaSyncStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncStateEnum>`
                                        
                                        .. attribute:: minute_table_index
                                        
                                        	Minute table index
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: nsr_flood_required
                                        
                                        	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                        	**type**\:  bool
                                        
                                        .. attribute:: rate_limit
                                        
                                        	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                        	**type**\:  bool
                                        
                                        .. attribute:: second_table_index
                                        
                                        	Second table index
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.free_time = None
                                            self.is_acknowledged = None
                                            self.is_advertising_router_reachable = None
                                            self.is_deleted = None
                                            self.is_flood_pending = None
                                            self.is_maximum_aged = None
                                            self.is_neighbor_exchange = None
                                            self.is_no_delete = None
                                            self.is_nsr_ack_pending = None
                                            self.is_partial_spf = None
                                            self.is_routing_bit = None
                                            self.is_routing_table = None
                                            self.lsa_flood_required_post_fail_over = None
                                            self.lsa_length = None
                                            self.lsa_sync_state = None
                                            self.minute_table_index = None
                                            self.nsr_flood_required = None
                                            self.rate_limit = None
                                            self.second_table_index = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-detail'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.free_time is not None:
                                                return True

                                            if self.is_acknowledged is not None:
                                                return True

                                            if self.is_advertising_router_reachable is not None:
                                                return True

                                            if self.is_deleted is not None:
                                                return True

                                            if self.is_flood_pending is not None:
                                                return True

                                            if self.is_maximum_aged is not None:
                                                return True

                                            if self.is_neighbor_exchange is not None:
                                                return True

                                            if self.is_no_delete is not None:
                                                return True

                                            if self.is_nsr_ack_pending is not None:
                                                return True

                                            if self.is_partial_spf is not None:
                                                return True

                                            if self.is_routing_bit is not None:
                                                return True

                                            if self.is_routing_table is not None:
                                                return True

                                            if self.lsa_flood_required_post_fail_over is not None:
                                                return True

                                            if self.lsa_length is not None:
                                                return True

                                            if self.lsa_sync_state is not None:
                                                return True

                                            if self.minute_table_index is not None:
                                                return True

                                            if self.nsr_flood_required is not None:
                                                return True

                                            if self.rate_limit is not None:
                                                return True

                                            if self.second_table_index is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType.LsaDetail']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:unknown-aslsa-type'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.interface_name is not None:
                                            return True

                                        if self.is_sham_link is not None:
                                            return True

                                        if self.is_virtual_link is not None:
                                            return True

                                        if self.lsa_detail is not None and self.lsa_detail._has_data():
                                            return True

                                        if self.lsa_header is not None and self.lsa_header._has_data():
                                            return True

                                        if self.sham_link_id is not None:
                                            return True

                                        if self.virtual_link_id is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                        return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType']['meta_info']


                                class UnknownLsaType(object):
                                    """
                                    Unknown LSA
                                    
                                    .. attribute:: interface_name
                                    
                                    	LSA interface name 
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                    
                                    .. attribute:: is_sham_link
                                    
                                    	If true, it is a sham link 
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_virtual_link
                                    
                                    	If true, it is a virtual link 
                                    	**type**\:  bool
                                    
                                    .. attribute:: lsa_detail
                                    
                                    	Detailed LSA information
                                    	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType.LsaDetail>`
                                    
                                    .. attribute:: lsa_header
                                    
                                    	Header information 
                                    	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType.LsaHeader>`
                                    
                                    .. attribute:: sham_link_id
                                    
                                    	Shamlink ID 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: virtual_link_id
                                    
                                    	Virtual link ID 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.interface_name = None
                                        self.is_sham_link = None
                                        self.is_virtual_link = None
                                        self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType.LsaDetail()
                                        self.lsa_detail.parent = self
                                        self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType.LsaHeader()
                                        self.lsa_header.parent = self
                                        self.sham_link_id = None
                                        self.virtual_link_id = None


                                    class LsaHeader(object):
                                        """
                                        Header information 
                                        
                                        .. attribute:: advertising_router
                                        
                                        	Router ID of Advertising Router
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: checksum
                                        
                                        	Checksum value
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: is_do_not_age_lsa
                                        
                                        	If true, Do Not Age this LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_graceful_restart_active
                                        
                                        	If true, if grace restart is active 
                                        	**type**\:  bool
                                        
                                        .. attribute:: ls_id
                                        
                                        	LS ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: lsa_age
                                        
                                        	LSA's Age (s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_area_id
                                        
                                        	Area ID in decimal or dotted\-decimal format
                                        	**type**\:  str
                                        
                                        	**length:** 0..16
                                        
                                        .. attribute:: lsa_type
                                        
                                        	LSA type
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: sequence_number
                                        
                                        	Current Sequence number
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.advertising_router = None
                                            self.checksum = None
                                            self.is_do_not_age_lsa = None
                                            self.is_graceful_restart_active = None
                                            self.ls_id = None
                                            self.lsa_age = None
                                            self.lsa_area_id = None
                                            self.lsa_type = None
                                            self.sequence_number = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-header'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.advertising_router is not None:
                                                return True

                                            if self.checksum is not None:
                                                return True

                                            if self.is_do_not_age_lsa is not None:
                                                return True

                                            if self.is_graceful_restart_active is not None:
                                                return True

                                            if self.ls_id is not None:
                                                return True

                                            if self.lsa_age is not None:
                                                return True

                                            if self.lsa_area_id is not None:
                                                return True

                                            if self.lsa_type is not None:
                                                return True

                                            if self.sequence_number is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType.LsaHeader']['meta_info']


                                    class LsaDetail(object):
                                        """
                                        Detailed LSA information
                                        
                                        .. attribute:: free_time
                                        
                                        	The amount of time since the last check was made to free this LSA (s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_acknowledged
                                        
                                        	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_advertising_router_reachable
                                        
                                        	If true, Advertising Router is reachable
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_deleted
                                        
                                        	If true, flag is set to delete this LSA 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_flood_pending
                                        
                                        	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_maximum_aged
                                        
                                        	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_neighbor_exchange
                                        
                                        	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_no_delete
                                        
                                        	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_nsr_ack_pending
                                        
                                        	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_partial_spf
                                        
                                        	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_routing_bit
                                        
                                        	If true, Routing Bit set on the LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_routing_table
                                        
                                        	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                        	**type**\:  bool
                                        
                                        .. attribute:: lsa_flood_required_post_fail_over
                                        
                                        	LSA flood required after FO
                                        	**type**\:  bool
                                        
                                        .. attribute:: lsa_length
                                        
                                        	Length of the LSA
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_sync_state
                                        
                                        	State of LSA sync with active
                                        	**type**\:   :py:class:`OspfLsaSyncStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncStateEnum>`
                                        
                                        .. attribute:: minute_table_index
                                        
                                        	Minute table index
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: nsr_flood_required
                                        
                                        	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                        	**type**\:  bool
                                        
                                        .. attribute:: rate_limit
                                        
                                        	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                        	**type**\:  bool
                                        
                                        .. attribute:: second_table_index
                                        
                                        	Second table index
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.free_time = None
                                            self.is_acknowledged = None
                                            self.is_advertising_router_reachable = None
                                            self.is_deleted = None
                                            self.is_flood_pending = None
                                            self.is_maximum_aged = None
                                            self.is_neighbor_exchange = None
                                            self.is_no_delete = None
                                            self.is_nsr_ack_pending = None
                                            self.is_partial_spf = None
                                            self.is_routing_bit = None
                                            self.is_routing_table = None
                                            self.lsa_flood_required_post_fail_over = None
                                            self.lsa_length = None
                                            self.lsa_sync_state = None
                                            self.minute_table_index = None
                                            self.nsr_flood_required = None
                                            self.rate_limit = None
                                            self.second_table_index = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-detail'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.free_time is not None:
                                                return True

                                            if self.is_acknowledged is not None:
                                                return True

                                            if self.is_advertising_router_reachable is not None:
                                                return True

                                            if self.is_deleted is not None:
                                                return True

                                            if self.is_flood_pending is not None:
                                                return True

                                            if self.is_maximum_aged is not None:
                                                return True

                                            if self.is_neighbor_exchange is not None:
                                                return True

                                            if self.is_no_delete is not None:
                                                return True

                                            if self.is_nsr_ack_pending is not None:
                                                return True

                                            if self.is_partial_spf is not None:
                                                return True

                                            if self.is_routing_bit is not None:
                                                return True

                                            if self.is_routing_table is not None:
                                                return True

                                            if self.lsa_flood_required_post_fail_over is not None:
                                                return True

                                            if self.lsa_length is not None:
                                                return True

                                            if self.lsa_sync_state is not None:
                                                return True

                                            if self.minute_table_index is not None:
                                                return True

                                            if self.nsr_flood_required is not None:
                                                return True

                                            if self.rate_limit is not None:
                                                return True

                                            if self.second_table_index is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType.LsaDetail']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:unknown-lsa-type'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.interface_name is not None:
                                            return True

                                        if self.is_sham_link is not None:
                                            return True

                                        if self.is_virtual_link is not None:
                                            return True

                                        if self.lsa_detail is not None and self.lsa_detail._has_data():
                                            return True

                                        if self.lsa_header is not None and self.lsa_header._has_data():
                                            return True

                                        if self.sham_link_id is not None:
                                            return True

                                        if self.virtual_link_id is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                        return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-info'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.external_lsa_type is not None and self.external_lsa_type._has_data():
                                        return True

                                    if self.grace_lsa is not None and self.grace_lsa._has_data():
                                        return True

                                    if self.inter_area_prefix_lsa_type is not None and self.inter_area_prefix_lsa_type._has_data():
                                        return True

                                    if self.inter_area_router_lsa_type is not None and self.inter_area_router_lsa_type._has_data():
                                        return True

                                    if self.intra_area_prefix_lsa_type is not None and self.intra_area_prefix_lsa_type._has_data():
                                        return True

                                    if self.link_lsa_type is not None and self.link_lsa_type._has_data():
                                        return True

                                    if self.lsa_info_type is not None:
                                        return True

                                    if self.lsa_summary_info is not None and self.lsa_summary_info._has_data():
                                        return True

                                    if self.network_lsa_type is not None and self.network_lsa_type._has_data():
                                        return True

                                    if self.nssalsa_type is not None and self.nssalsa_type._has_data():
                                        return True

                                    if self.router_lsa_type is not None and self.router_lsa_type._has_data():
                                        return True

                                    if self.unknown_area_lsa_type is not None and self.unknown_area_lsa_type._has_data():
                                        return True

                                    if self.unknown_aslsa_type is not None and self.unknown_aslsa_type._has_data():
                                        return True

                                    if self.unknown_link_lsa_type is not None and self.unknown_link_lsa_type._has_data():
                                        return True

                                    if self.unknown_lsa_type is not None and self.unknown_lsa_type._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                    return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.advertising_router is not None:
                                    return True

                                if self.area_id is not None:
                                    return True

                                if self.interface_name is not None:
                                    return True

                                if self.ls_id is not None:
                                    return True

                                if self.ls_type is not None:
                                    return True

                                if self.lsa_info is not None and self.lsa_info._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-table'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.lsa is not None:
                                for child_ref in self.lsa:
                                    if child_ref._has_data():
                                        return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                            return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable']['meta_info']


                    class LsaInternalTable(object):
                        """
                        Database LSA information
                        
                        .. attribute:: lsa
                        
                        	Database LSA information
                        	**type**\: list of    :py:class:`Lsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa>`
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.lsa = YList()
                            self.lsa.parent = self
                            self.lsa.name = 'lsa'


                        class Lsa(object):
                            """
                            Database LSA information
                            
                            .. attribute:: advertising_router
                            
                            	Advertising Router ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: area_id
                            
                            	Area ID
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: interface_name
                            
                            	InterfaceName
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: ls_id
                            
                            	Link state ID
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: ls_type
                            
                            	LSA type
                            	**type**\:   :py:class:`Ospfv3LsaEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3LsaEnum>`
                            
                            .. attribute:: lsa_info
                            
                            	Summary of all LSAs or LSA specific information 
                            	**type**\:   :py:class:`LsaInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo>`
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.advertising_router = None
                                self.area_id = None
                                self.interface_name = None
                                self.ls_id = None
                                self.ls_type = None
                                self.lsa_info = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo()
                                self.lsa_info.parent = self


                            class LsaInfo(object):
                                """
                                Summary of all LSAs or LSA specific information 
                                
                                .. attribute:: external_lsa_type
                                
                                	External LSA
                                	**type**\:   :py:class:`ExternalLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType>`
                                
                                .. attribute:: grace_lsa
                                
                                	Grace LSA
                                	**type**\:   :py:class:`GraceLsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa>`
                                
                                .. attribute:: inter_area_prefix_lsa_type
                                
                                	Inter Area Prefix LSA
                                	**type**\:   :py:class:`InterAreaPrefixLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType>`
                                
                                .. attribute:: inter_area_router_lsa_type
                                
                                	Inter Area Router LSA
                                	**type**\:   :py:class:`InterAreaRouterLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType>`
                                
                                .. attribute:: intra_area_prefix_lsa_type
                                
                                	Intra Area Prefix LSA
                                	**type**\:   :py:class:`IntraAreaPrefixLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType>`
                                
                                .. attribute:: link_lsa_type
                                
                                	Link LSA
                                	**type**\:   :py:class:`LinkLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType>`
                                
                                .. attribute:: lsa_info_type
                                
                                	LSAInfoType
                                	**type**\:   :py:class:`Ospfv3LsaInfoTypesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3LsaInfoTypesEnum>`
                                
                                .. attribute:: lsa_summary_info
                                
                                	Summary information of LSAs
                                	**type**\:   :py:class:`LsaSummaryInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo>`
                                
                                .. attribute:: network_lsa_type
                                
                                	Network LSA
                                	**type**\:   :py:class:`NetworkLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType>`
                                
                                .. attribute:: nssalsa_type
                                
                                	NSSA External LSA
                                	**type**\:   :py:class:`NssalsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType>`
                                
                                .. attribute:: router_lsa_type
                                
                                	Router LSA
                                	**type**\:   :py:class:`RouterLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType>`
                                
                                .. attribute:: unknown_area_lsa_type
                                
                                	Unknown\-Area scope LSA
                                	**type**\:   :py:class:`UnknownAreaLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType>`
                                
                                .. attribute:: unknown_aslsa_type
                                
                                	Unknown\-AS scope LSA
                                	**type**\:   :py:class:`UnknownAslsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType>`
                                
                                .. attribute:: unknown_link_lsa_type
                                
                                	Unknown Link Scope LSA
                                	**type**\:   :py:class:`UnknownLinkLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType>`
                                
                                .. attribute:: unknown_lsa_type
                                
                                	Unknown LSA
                                	**type**\:   :py:class:`UnknownLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType>`
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.external_lsa_type = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType()
                                    self.external_lsa_type.parent = self
                                    self.grace_lsa = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa()
                                    self.grace_lsa.parent = self
                                    self.inter_area_prefix_lsa_type = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType()
                                    self.inter_area_prefix_lsa_type.parent = self
                                    self.inter_area_router_lsa_type = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType()
                                    self.inter_area_router_lsa_type.parent = self
                                    self.intra_area_prefix_lsa_type = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType()
                                    self.intra_area_prefix_lsa_type.parent = self
                                    self.link_lsa_type = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType()
                                    self.link_lsa_type.parent = self
                                    self.lsa_info_type = None
                                    self.lsa_summary_info = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo()
                                    self.lsa_summary_info.parent = self
                                    self.network_lsa_type = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType()
                                    self.network_lsa_type.parent = self
                                    self.nssalsa_type = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType()
                                    self.nssalsa_type.parent = self
                                    self.router_lsa_type = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType()
                                    self.router_lsa_type.parent = self
                                    self.unknown_area_lsa_type = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType()
                                    self.unknown_area_lsa_type.parent = self
                                    self.unknown_aslsa_type = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType()
                                    self.unknown_aslsa_type.parent = self
                                    self.unknown_link_lsa_type = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType()
                                    self.unknown_link_lsa_type.parent = self
                                    self.unknown_lsa_type = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType()
                                    self.unknown_lsa_type.parent = self


                                class LsaSummaryInfo(object):
                                    """
                                    Summary information of LSAs
                                    
                                    .. attribute:: interface_name
                                    
                                    	LSA interface name 
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                    
                                    .. attribute:: is_sham_link
                                    
                                    	If true, it is a sham link 
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_virtual_link
                                    
                                    	If true, it is a virtual link 
                                    	**type**\:  bool
                                    
                                    .. attribute:: links
                                    
                                    	Number of links
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: lsa_detail
                                    
                                    	Detailed LSA information
                                    	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo.LsaDetail>`
                                    
                                    .. attribute:: lsa_header
                                    
                                    	Header information 
                                    	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo.LsaHeader>`
                                    
                                    .. attribute:: lsa_router_id
                                    
                                    	LSA router ID 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: prefix
                                    
                                    	OSPFv3 address Prefix 
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: prefix_length
                                    
                                    	Prefix length 
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: reference_lsa_id
                                    
                                    	Reference LSA ID 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: reference_type
                                    
                                    	Reference type 
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: router_la_bits
                                    
                                    	Router LA bits 
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: sham_link_id
                                    
                                    	Sham link ID 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: virtual_link_id
                                    
                                    	Virtual link ID 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.interface_name = None
                                        self.is_sham_link = None
                                        self.is_virtual_link = None
                                        self.links = None
                                        self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo.LsaDetail()
                                        self.lsa_detail.parent = self
                                        self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo.LsaHeader()
                                        self.lsa_header.parent = self
                                        self.lsa_router_id = None
                                        self.prefix = None
                                        self.prefix_length = None
                                        self.reference_lsa_id = None
                                        self.reference_type = None
                                        self.router_la_bits = None
                                        self.sham_link_id = None
                                        self.virtual_link_id = None


                                    class LsaHeader(object):
                                        """
                                        Header information 
                                        
                                        .. attribute:: advertising_router
                                        
                                        	Router ID of Advertising Router
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: checksum
                                        
                                        	Checksum value
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: is_do_not_age_lsa
                                        
                                        	If true, Do Not Age this LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_graceful_restart_active
                                        
                                        	If true, if grace restart is active 
                                        	**type**\:  bool
                                        
                                        .. attribute:: ls_id
                                        
                                        	LS ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: lsa_age
                                        
                                        	LSA's Age (s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_area_id
                                        
                                        	Area ID in decimal or dotted\-decimal format
                                        	**type**\:  str
                                        
                                        	**length:** 0..16
                                        
                                        .. attribute:: lsa_type
                                        
                                        	LSA type
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: sequence_number
                                        
                                        	Current Sequence number
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.advertising_router = None
                                            self.checksum = None
                                            self.is_do_not_age_lsa = None
                                            self.is_graceful_restart_active = None
                                            self.ls_id = None
                                            self.lsa_age = None
                                            self.lsa_area_id = None
                                            self.lsa_type = None
                                            self.sequence_number = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-header'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.advertising_router is not None:
                                                return True

                                            if self.checksum is not None:
                                                return True

                                            if self.is_do_not_age_lsa is not None:
                                                return True

                                            if self.is_graceful_restart_active is not None:
                                                return True

                                            if self.ls_id is not None:
                                                return True

                                            if self.lsa_age is not None:
                                                return True

                                            if self.lsa_area_id is not None:
                                                return True

                                            if self.lsa_type is not None:
                                                return True

                                            if self.sequence_number is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo.LsaHeader']['meta_info']


                                    class LsaDetail(object):
                                        """
                                        Detailed LSA information
                                        
                                        .. attribute:: free_time
                                        
                                        	The amount of time since the last check was made to free this LSA (s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_acknowledged
                                        
                                        	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_advertising_router_reachable
                                        
                                        	If true, Advertising Router is reachable
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_deleted
                                        
                                        	If true, flag is set to delete this LSA 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_flood_pending
                                        
                                        	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_maximum_aged
                                        
                                        	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_neighbor_exchange
                                        
                                        	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_no_delete
                                        
                                        	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_nsr_ack_pending
                                        
                                        	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_partial_spf
                                        
                                        	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_routing_bit
                                        
                                        	If true, Routing Bit set on the LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_routing_table
                                        
                                        	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                        	**type**\:  bool
                                        
                                        .. attribute:: lsa_flood_required_post_fail_over
                                        
                                        	LSA flood required after FO
                                        	**type**\:  bool
                                        
                                        .. attribute:: lsa_length
                                        
                                        	Length of the LSA
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_sync_state
                                        
                                        	State of LSA sync with active
                                        	**type**\:   :py:class:`OspfLsaSyncStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncStateEnum>`
                                        
                                        .. attribute:: minute_table_index
                                        
                                        	Minute table index
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: nsr_flood_required
                                        
                                        	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                        	**type**\:  bool
                                        
                                        .. attribute:: rate_limit
                                        
                                        	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                        	**type**\:  bool
                                        
                                        .. attribute:: second_table_index
                                        
                                        	Second table index
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.free_time = None
                                            self.is_acknowledged = None
                                            self.is_advertising_router_reachable = None
                                            self.is_deleted = None
                                            self.is_flood_pending = None
                                            self.is_maximum_aged = None
                                            self.is_neighbor_exchange = None
                                            self.is_no_delete = None
                                            self.is_nsr_ack_pending = None
                                            self.is_partial_spf = None
                                            self.is_routing_bit = None
                                            self.is_routing_table = None
                                            self.lsa_flood_required_post_fail_over = None
                                            self.lsa_length = None
                                            self.lsa_sync_state = None
                                            self.minute_table_index = None
                                            self.nsr_flood_required = None
                                            self.rate_limit = None
                                            self.second_table_index = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-detail'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.free_time is not None:
                                                return True

                                            if self.is_acknowledged is not None:
                                                return True

                                            if self.is_advertising_router_reachable is not None:
                                                return True

                                            if self.is_deleted is not None:
                                                return True

                                            if self.is_flood_pending is not None:
                                                return True

                                            if self.is_maximum_aged is not None:
                                                return True

                                            if self.is_neighbor_exchange is not None:
                                                return True

                                            if self.is_no_delete is not None:
                                                return True

                                            if self.is_nsr_ack_pending is not None:
                                                return True

                                            if self.is_partial_spf is not None:
                                                return True

                                            if self.is_routing_bit is not None:
                                                return True

                                            if self.is_routing_table is not None:
                                                return True

                                            if self.lsa_flood_required_post_fail_over is not None:
                                                return True

                                            if self.lsa_length is not None:
                                                return True

                                            if self.lsa_sync_state is not None:
                                                return True

                                            if self.minute_table_index is not None:
                                                return True

                                            if self.nsr_flood_required is not None:
                                                return True

                                            if self.rate_limit is not None:
                                                return True

                                            if self.second_table_index is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo.LsaDetail']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-summary-info'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.interface_name is not None:
                                            return True

                                        if self.is_sham_link is not None:
                                            return True

                                        if self.is_virtual_link is not None:
                                            return True

                                        if self.links is not None:
                                            return True

                                        if self.lsa_detail is not None and self.lsa_detail._has_data():
                                            return True

                                        if self.lsa_header is not None and self.lsa_header._has_data():
                                            return True

                                        if self.lsa_router_id is not None:
                                            return True

                                        if self.prefix is not None:
                                            return True

                                        if self.prefix_length is not None:
                                            return True

                                        if self.reference_lsa_id is not None:
                                            return True

                                        if self.reference_type is not None:
                                            return True

                                        if self.router_la_bits is not None:
                                            return True

                                        if self.sham_link_id is not None:
                                            return True

                                        if self.virtual_link_id is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                        return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo']['meta_info']


                                class RouterLsaType(object):
                                    """
                                    Router LSA
                                    
                                    .. attribute:: link
                                    
                                    	List of links in this LSA
                                    	**type**\: list of    :py:class:`Link <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.Link>`
                                    
                                    .. attribute:: lsa_detail
                                    
                                    	Detailed LSA information
                                    	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.LsaDetail>`
                                    
                                    .. attribute:: lsa_header
                                    
                                    	Header information 
                                    	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.LsaHeader>`
                                    
                                    .. attribute:: router_la_bits
                                    
                                    	Router LA bits 
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: rpf_path
                                    
                                    	Router LSA Reverse\-Path Forwarding information 
                                    	**type**\:   :py:class:`RpfPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.RpfPath>`
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.link = YList()
                                        self.link.parent = self
                                        self.link.name = 'link'
                                        self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.LsaDetail()
                                        self.lsa_detail.parent = self
                                        self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.LsaHeader()
                                        self.lsa_header.parent = self
                                        self.router_la_bits = None
                                        self.rpf_path = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.RpfPath()
                                        self.rpf_path.parent = self


                                    class LsaHeader(object):
                                        """
                                        Header information 
                                        
                                        .. attribute:: advertising_router
                                        
                                        	Router ID of Advertising Router
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: checksum
                                        
                                        	Checksum value
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: is_do_not_age_lsa
                                        
                                        	If true, Do Not Age this LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_graceful_restart_active
                                        
                                        	If true, if grace restart is active 
                                        	**type**\:  bool
                                        
                                        .. attribute:: ls_id
                                        
                                        	LS ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: lsa_age
                                        
                                        	LSA's Age (s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_area_id
                                        
                                        	Area ID in decimal or dotted\-decimal format
                                        	**type**\:  str
                                        
                                        	**length:** 0..16
                                        
                                        .. attribute:: lsa_type
                                        
                                        	LSA type
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: sequence_number
                                        
                                        	Current Sequence number
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.advertising_router = None
                                            self.checksum = None
                                            self.is_do_not_age_lsa = None
                                            self.is_graceful_restart_active = None
                                            self.ls_id = None
                                            self.lsa_age = None
                                            self.lsa_area_id = None
                                            self.lsa_type = None
                                            self.sequence_number = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-header'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.advertising_router is not None:
                                                return True

                                            if self.checksum is not None:
                                                return True

                                            if self.is_do_not_age_lsa is not None:
                                                return True

                                            if self.is_graceful_restart_active is not None:
                                                return True

                                            if self.ls_id is not None:
                                                return True

                                            if self.lsa_age is not None:
                                                return True

                                            if self.lsa_area_id is not None:
                                                return True

                                            if self.lsa_type is not None:
                                                return True

                                            if self.sequence_number is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.LsaHeader']['meta_info']


                                    class LsaDetail(object):
                                        """
                                        Detailed LSA information
                                        
                                        .. attribute:: free_time
                                        
                                        	The amount of time since the last check was made to free this LSA (s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_acknowledged
                                        
                                        	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_advertising_router_reachable
                                        
                                        	If true, Advertising Router is reachable
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_deleted
                                        
                                        	If true, flag is set to delete this LSA 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_flood_pending
                                        
                                        	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_maximum_aged
                                        
                                        	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_neighbor_exchange
                                        
                                        	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_no_delete
                                        
                                        	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_nsr_ack_pending
                                        
                                        	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_partial_spf
                                        
                                        	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_routing_bit
                                        
                                        	If true, Routing Bit set on the LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_routing_table
                                        
                                        	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                        	**type**\:  bool
                                        
                                        .. attribute:: lsa_flood_required_post_fail_over
                                        
                                        	LSA flood required after FO
                                        	**type**\:  bool
                                        
                                        .. attribute:: lsa_length
                                        
                                        	Length of the LSA
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_sync_state
                                        
                                        	State of LSA sync with active
                                        	**type**\:   :py:class:`OspfLsaSyncStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncStateEnum>`
                                        
                                        .. attribute:: minute_table_index
                                        
                                        	Minute table index
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: nsr_flood_required
                                        
                                        	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                        	**type**\:  bool
                                        
                                        .. attribute:: rate_limit
                                        
                                        	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                        	**type**\:  bool
                                        
                                        .. attribute:: second_table_index
                                        
                                        	Second table index
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.free_time = None
                                            self.is_acknowledged = None
                                            self.is_advertising_router_reachable = None
                                            self.is_deleted = None
                                            self.is_flood_pending = None
                                            self.is_maximum_aged = None
                                            self.is_neighbor_exchange = None
                                            self.is_no_delete = None
                                            self.is_nsr_ack_pending = None
                                            self.is_partial_spf = None
                                            self.is_routing_bit = None
                                            self.is_routing_table = None
                                            self.lsa_flood_required_post_fail_over = None
                                            self.lsa_length = None
                                            self.lsa_sync_state = None
                                            self.minute_table_index = None
                                            self.nsr_flood_required = None
                                            self.rate_limit = None
                                            self.second_table_index = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-detail'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.free_time is not None:
                                                return True

                                            if self.is_acknowledged is not None:
                                                return True

                                            if self.is_advertising_router_reachable is not None:
                                                return True

                                            if self.is_deleted is not None:
                                                return True

                                            if self.is_flood_pending is not None:
                                                return True

                                            if self.is_maximum_aged is not None:
                                                return True

                                            if self.is_neighbor_exchange is not None:
                                                return True

                                            if self.is_no_delete is not None:
                                                return True

                                            if self.is_nsr_ack_pending is not None:
                                                return True

                                            if self.is_partial_spf is not None:
                                                return True

                                            if self.is_routing_bit is not None:
                                                return True

                                            if self.is_routing_table is not None:
                                                return True

                                            if self.lsa_flood_required_post_fail_over is not None:
                                                return True

                                            if self.lsa_length is not None:
                                                return True

                                            if self.lsa_sync_state is not None:
                                                return True

                                            if self.minute_table_index is not None:
                                                return True

                                            if self.nsr_flood_required is not None:
                                                return True

                                            if self.rate_limit is not None:
                                                return True

                                            if self.second_table_index is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.LsaDetail']['meta_info']


                                    class RpfPath(object):
                                        """
                                        Router LSA Reverse\-Path Forwarding information 
                                        
                                        .. attribute:: interface_name
                                        
                                        	RPF multicast IDB 
                                        	**type**\:  str
                                        
                                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                        
                                        .. attribute:: rpf_multicast_next_hop
                                        
                                        	RPF multicast next hop 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface_name = None
                                            self.rpf_multicast_next_hop = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:rpf-path'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface_name is not None:
                                                return True

                                            if self.rpf_multicast_next_hop is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.RpfPath']['meta_info']


                                    class Link(object):
                                        """
                                        List of links in this LSA
                                        
                                        .. attribute:: link_interface_id
                                        
                                        	LSA link interface ID 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: link_metric
                                        
                                        	LSA link metric 
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: link_neighbor_interface_id
                                        
                                        	LSA link neighbor interface ID 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: link_neighbor_router_id
                                        
                                        	LSA link neigbhor router id 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: link_type
                                        
                                        	Type of link
                                        	**type**\:   :py:class:`Ospfv3LinkEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3LinkEnum>`
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.link_interface_id = None
                                            self.link_metric = None
                                            self.link_neighbor_interface_id = None
                                            self.link_neighbor_router_id = None
                                            self.link_type = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:link'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.link_interface_id is not None:
                                                return True

                                            if self.link_metric is not None:
                                                return True

                                            if self.link_neighbor_interface_id is not None:
                                                return True

                                            if self.link_neighbor_router_id is not None:
                                                return True

                                            if self.link_type is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.Link']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:router-lsa-type'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.link is not None:
                                            for child_ref in self.link:
                                                if child_ref._has_data():
                                                    return True

                                        if self.lsa_detail is not None and self.lsa_detail._has_data():
                                            return True

                                        if self.lsa_header is not None and self.lsa_header._has_data():
                                            return True

                                        if self.router_la_bits is not None:
                                            return True

                                        if self.rpf_path is not None and self.rpf_path._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                        return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType']['meta_info']


                                class NetworkLsaType(object):
                                    """
                                    Network LSA
                                    
                                    .. attribute:: lsa_detail
                                    
                                    	Detailed LSA information
                                    	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType.LsaDetail>`
                                    
                                    .. attribute:: lsa_header
                                    
                                    	Header information 
                                    	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType.LsaHeader>`
                                    
                                    .. attribute:: neighbor_router
                                    
                                    	Neighbor router list
                                    	**type**\:  list of str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType.LsaDetail()
                                        self.lsa_detail.parent = self
                                        self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType.LsaHeader()
                                        self.lsa_header.parent = self
                                        self.neighbor_router = YLeafList()
                                        self.neighbor_router.parent = self
                                        self.neighbor_router.name = 'neighbor_router'


                                    class LsaHeader(object):
                                        """
                                        Header information 
                                        
                                        .. attribute:: advertising_router
                                        
                                        	Router ID of Advertising Router
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: checksum
                                        
                                        	Checksum value
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: is_do_not_age_lsa
                                        
                                        	If true, Do Not Age this LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_graceful_restart_active
                                        
                                        	If true, if grace restart is active 
                                        	**type**\:  bool
                                        
                                        .. attribute:: ls_id
                                        
                                        	LS ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: lsa_age
                                        
                                        	LSA's Age (s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_area_id
                                        
                                        	Area ID in decimal or dotted\-decimal format
                                        	**type**\:  str
                                        
                                        	**length:** 0..16
                                        
                                        .. attribute:: lsa_type
                                        
                                        	LSA type
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: sequence_number
                                        
                                        	Current Sequence number
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.advertising_router = None
                                            self.checksum = None
                                            self.is_do_not_age_lsa = None
                                            self.is_graceful_restart_active = None
                                            self.ls_id = None
                                            self.lsa_age = None
                                            self.lsa_area_id = None
                                            self.lsa_type = None
                                            self.sequence_number = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-header'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.advertising_router is not None:
                                                return True

                                            if self.checksum is not None:
                                                return True

                                            if self.is_do_not_age_lsa is not None:
                                                return True

                                            if self.is_graceful_restart_active is not None:
                                                return True

                                            if self.ls_id is not None:
                                                return True

                                            if self.lsa_age is not None:
                                                return True

                                            if self.lsa_area_id is not None:
                                                return True

                                            if self.lsa_type is not None:
                                                return True

                                            if self.sequence_number is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType.LsaHeader']['meta_info']


                                    class LsaDetail(object):
                                        """
                                        Detailed LSA information
                                        
                                        .. attribute:: free_time
                                        
                                        	The amount of time since the last check was made to free this LSA (s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_acknowledged
                                        
                                        	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_advertising_router_reachable
                                        
                                        	If true, Advertising Router is reachable
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_deleted
                                        
                                        	If true, flag is set to delete this LSA 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_flood_pending
                                        
                                        	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_maximum_aged
                                        
                                        	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_neighbor_exchange
                                        
                                        	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_no_delete
                                        
                                        	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_nsr_ack_pending
                                        
                                        	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_partial_spf
                                        
                                        	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_routing_bit
                                        
                                        	If true, Routing Bit set on the LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_routing_table
                                        
                                        	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                        	**type**\:  bool
                                        
                                        .. attribute:: lsa_flood_required_post_fail_over
                                        
                                        	LSA flood required after FO
                                        	**type**\:  bool
                                        
                                        .. attribute:: lsa_length
                                        
                                        	Length of the LSA
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_sync_state
                                        
                                        	State of LSA sync with active
                                        	**type**\:   :py:class:`OspfLsaSyncStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncStateEnum>`
                                        
                                        .. attribute:: minute_table_index
                                        
                                        	Minute table index
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: nsr_flood_required
                                        
                                        	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                        	**type**\:  bool
                                        
                                        .. attribute:: rate_limit
                                        
                                        	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                        	**type**\:  bool
                                        
                                        .. attribute:: second_table_index
                                        
                                        	Second table index
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.free_time = None
                                            self.is_acknowledged = None
                                            self.is_advertising_router_reachable = None
                                            self.is_deleted = None
                                            self.is_flood_pending = None
                                            self.is_maximum_aged = None
                                            self.is_neighbor_exchange = None
                                            self.is_no_delete = None
                                            self.is_nsr_ack_pending = None
                                            self.is_partial_spf = None
                                            self.is_routing_bit = None
                                            self.is_routing_table = None
                                            self.lsa_flood_required_post_fail_over = None
                                            self.lsa_length = None
                                            self.lsa_sync_state = None
                                            self.minute_table_index = None
                                            self.nsr_flood_required = None
                                            self.rate_limit = None
                                            self.second_table_index = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-detail'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.free_time is not None:
                                                return True

                                            if self.is_acknowledged is not None:
                                                return True

                                            if self.is_advertising_router_reachable is not None:
                                                return True

                                            if self.is_deleted is not None:
                                                return True

                                            if self.is_flood_pending is not None:
                                                return True

                                            if self.is_maximum_aged is not None:
                                                return True

                                            if self.is_neighbor_exchange is not None:
                                                return True

                                            if self.is_no_delete is not None:
                                                return True

                                            if self.is_nsr_ack_pending is not None:
                                                return True

                                            if self.is_partial_spf is not None:
                                                return True

                                            if self.is_routing_bit is not None:
                                                return True

                                            if self.is_routing_table is not None:
                                                return True

                                            if self.lsa_flood_required_post_fail_over is not None:
                                                return True

                                            if self.lsa_length is not None:
                                                return True

                                            if self.lsa_sync_state is not None:
                                                return True

                                            if self.minute_table_index is not None:
                                                return True

                                            if self.nsr_flood_required is not None:
                                                return True

                                            if self.rate_limit is not None:
                                                return True

                                            if self.second_table_index is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType.LsaDetail']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:network-lsa-type'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.lsa_detail is not None and self.lsa_detail._has_data():
                                            return True

                                        if self.lsa_header is not None and self.lsa_header._has_data():
                                            return True

                                        if self.neighbor_router is not None:
                                            for child in self.neighbor_router:
                                                if child is not None:
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                        return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType']['meta_info']


                                class InterAreaPrefixLsaType(object):
                                    """
                                    Inter Area Prefix LSA
                                    
                                    .. attribute:: lsa_detail
                                    
                                    	Detailed LSA Information
                                    	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaDetail>`
                                    
                                    .. attribute:: lsa_header
                                    
                                    	Header information 
                                    	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaHeader>`
                                    
                                    .. attribute:: prefix
                                    
                                    	LSA address prefix 
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: prefix_length
                                    
                                    	Prefix length 
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: priority
                                    
                                    	Prefix priority
                                    	**type**\:   :py:class:`PrefixPriorityEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.PrefixPriorityEnum>`
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaDetail()
                                        self.lsa_detail.parent = self
                                        self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaHeader()
                                        self.lsa_header.parent = self
                                        self.prefix = None
                                        self.prefix_length = None
                                        self.priority = None


                                    class LsaHeader(object):
                                        """
                                        Header information 
                                        
                                        .. attribute:: advertising_router
                                        
                                        	Router ID of Advertising Router
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: checksum
                                        
                                        	Checksum value
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: is_do_not_age_lsa
                                        
                                        	If true, Do Not Age this LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_graceful_restart_active
                                        
                                        	If true, if grace restart is active 
                                        	**type**\:  bool
                                        
                                        .. attribute:: ls_id
                                        
                                        	LS ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: lsa_age
                                        
                                        	LSA's Age (s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_area_id
                                        
                                        	Area ID in decimal or dotted\-decimal format
                                        	**type**\:  str
                                        
                                        	**length:** 0..16
                                        
                                        .. attribute:: lsa_type
                                        
                                        	LSA type
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: sequence_number
                                        
                                        	Current Sequence number
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.advertising_router = None
                                            self.checksum = None
                                            self.is_do_not_age_lsa = None
                                            self.is_graceful_restart_active = None
                                            self.ls_id = None
                                            self.lsa_age = None
                                            self.lsa_area_id = None
                                            self.lsa_type = None
                                            self.sequence_number = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-header'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.advertising_router is not None:
                                                return True

                                            if self.checksum is not None:
                                                return True

                                            if self.is_do_not_age_lsa is not None:
                                                return True

                                            if self.is_graceful_restart_active is not None:
                                                return True

                                            if self.ls_id is not None:
                                                return True

                                            if self.lsa_age is not None:
                                                return True

                                            if self.lsa_area_id is not None:
                                                return True

                                            if self.lsa_type is not None:
                                                return True

                                            if self.sequence_number is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaHeader']['meta_info']


                                    class LsaDetail(object):
                                        """
                                        Detailed LSA Information
                                        
                                        .. attribute:: free_time
                                        
                                        	The amount of time since the last check was made to free this LSA (s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_acknowledged
                                        
                                        	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_advertising_router_reachable
                                        
                                        	If true, Advertising Router is reachable
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_deleted
                                        
                                        	If true, flag is set to delete this LSA 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_flood_pending
                                        
                                        	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_maximum_aged
                                        
                                        	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_neighbor_exchange
                                        
                                        	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_no_delete
                                        
                                        	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_nsr_ack_pending
                                        
                                        	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_partial_spf
                                        
                                        	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_routing_bit
                                        
                                        	If true, Routing Bit set on the LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_routing_table
                                        
                                        	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                        	**type**\:  bool
                                        
                                        .. attribute:: lsa_flood_required_post_fail_over
                                        
                                        	LSA flood required after FO
                                        	**type**\:  bool
                                        
                                        .. attribute:: lsa_length
                                        
                                        	Length of the LSA
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_sync_state
                                        
                                        	State of LSA sync with active
                                        	**type**\:   :py:class:`OspfLsaSyncStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncStateEnum>`
                                        
                                        .. attribute:: minute_table_index
                                        
                                        	Minute table index
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: nsr_flood_required
                                        
                                        	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                        	**type**\:  bool
                                        
                                        .. attribute:: rate_limit
                                        
                                        	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                        	**type**\:  bool
                                        
                                        .. attribute:: second_table_index
                                        
                                        	Second table index
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.free_time = None
                                            self.is_acknowledged = None
                                            self.is_advertising_router_reachable = None
                                            self.is_deleted = None
                                            self.is_flood_pending = None
                                            self.is_maximum_aged = None
                                            self.is_neighbor_exchange = None
                                            self.is_no_delete = None
                                            self.is_nsr_ack_pending = None
                                            self.is_partial_spf = None
                                            self.is_routing_bit = None
                                            self.is_routing_table = None
                                            self.lsa_flood_required_post_fail_over = None
                                            self.lsa_length = None
                                            self.lsa_sync_state = None
                                            self.minute_table_index = None
                                            self.nsr_flood_required = None
                                            self.rate_limit = None
                                            self.second_table_index = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-detail'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.free_time is not None:
                                                return True

                                            if self.is_acknowledged is not None:
                                                return True

                                            if self.is_advertising_router_reachable is not None:
                                                return True

                                            if self.is_deleted is not None:
                                                return True

                                            if self.is_flood_pending is not None:
                                                return True

                                            if self.is_maximum_aged is not None:
                                                return True

                                            if self.is_neighbor_exchange is not None:
                                                return True

                                            if self.is_no_delete is not None:
                                                return True

                                            if self.is_nsr_ack_pending is not None:
                                                return True

                                            if self.is_partial_spf is not None:
                                                return True

                                            if self.is_routing_bit is not None:
                                                return True

                                            if self.is_routing_table is not None:
                                                return True

                                            if self.lsa_flood_required_post_fail_over is not None:
                                                return True

                                            if self.lsa_length is not None:
                                                return True

                                            if self.lsa_sync_state is not None:
                                                return True

                                            if self.minute_table_index is not None:
                                                return True

                                            if self.nsr_flood_required is not None:
                                                return True

                                            if self.rate_limit is not None:
                                                return True

                                            if self.second_table_index is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaDetail']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:inter-area-prefix-lsa-type'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.lsa_detail is not None and self.lsa_detail._has_data():
                                            return True

                                        if self.lsa_header is not None and self.lsa_header._has_data():
                                            return True

                                        if self.prefix is not None:
                                            return True

                                        if self.prefix_length is not None:
                                            return True

                                        if self.priority is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                        return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType']['meta_info']


                                class InterAreaRouterLsaType(object):
                                    """
                                    Inter Area Router LSA
                                    
                                    .. attribute:: lsa_detail
                                    
                                    	Detailed LSA information
                                    	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaDetail>`
                                    
                                    .. attribute:: lsa_header
                                    
                                    	Header information 
                                    	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaHeader>`
                                    
                                    .. attribute:: lsa_router_id
                                    
                                    	LSA router ID 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaDetail()
                                        self.lsa_detail.parent = self
                                        self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaHeader()
                                        self.lsa_header.parent = self
                                        self.lsa_router_id = None


                                    class LsaHeader(object):
                                        """
                                        Header information 
                                        
                                        .. attribute:: advertising_router
                                        
                                        	Router ID of Advertising Router
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: checksum
                                        
                                        	Checksum value
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: is_do_not_age_lsa
                                        
                                        	If true, Do Not Age this LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_graceful_restart_active
                                        
                                        	If true, if grace restart is active 
                                        	**type**\:  bool
                                        
                                        .. attribute:: ls_id
                                        
                                        	LS ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: lsa_age
                                        
                                        	LSA's Age (s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_area_id
                                        
                                        	Area ID in decimal or dotted\-decimal format
                                        	**type**\:  str
                                        
                                        	**length:** 0..16
                                        
                                        .. attribute:: lsa_type
                                        
                                        	LSA type
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: sequence_number
                                        
                                        	Current Sequence number
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.advertising_router = None
                                            self.checksum = None
                                            self.is_do_not_age_lsa = None
                                            self.is_graceful_restart_active = None
                                            self.ls_id = None
                                            self.lsa_age = None
                                            self.lsa_area_id = None
                                            self.lsa_type = None
                                            self.sequence_number = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-header'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.advertising_router is not None:
                                                return True

                                            if self.checksum is not None:
                                                return True

                                            if self.is_do_not_age_lsa is not None:
                                                return True

                                            if self.is_graceful_restart_active is not None:
                                                return True

                                            if self.ls_id is not None:
                                                return True

                                            if self.lsa_age is not None:
                                                return True

                                            if self.lsa_area_id is not None:
                                                return True

                                            if self.lsa_type is not None:
                                                return True

                                            if self.sequence_number is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaHeader']['meta_info']


                                    class LsaDetail(object):
                                        """
                                        Detailed LSA information
                                        
                                        .. attribute:: free_time
                                        
                                        	The amount of time since the last check was made to free this LSA (s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_acknowledged
                                        
                                        	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_advertising_router_reachable
                                        
                                        	If true, Advertising Router is reachable
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_deleted
                                        
                                        	If true, flag is set to delete this LSA 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_flood_pending
                                        
                                        	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_maximum_aged
                                        
                                        	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_neighbor_exchange
                                        
                                        	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_no_delete
                                        
                                        	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_nsr_ack_pending
                                        
                                        	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_partial_spf
                                        
                                        	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_routing_bit
                                        
                                        	If true, Routing Bit set on the LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_routing_table
                                        
                                        	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                        	**type**\:  bool
                                        
                                        .. attribute:: lsa_flood_required_post_fail_over
                                        
                                        	LSA flood required after FO
                                        	**type**\:  bool
                                        
                                        .. attribute:: lsa_length
                                        
                                        	Length of the LSA
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_sync_state
                                        
                                        	State of LSA sync with active
                                        	**type**\:   :py:class:`OspfLsaSyncStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncStateEnum>`
                                        
                                        .. attribute:: minute_table_index
                                        
                                        	Minute table index
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: nsr_flood_required
                                        
                                        	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                        	**type**\:  bool
                                        
                                        .. attribute:: rate_limit
                                        
                                        	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                        	**type**\:  bool
                                        
                                        .. attribute:: second_table_index
                                        
                                        	Second table index
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.free_time = None
                                            self.is_acknowledged = None
                                            self.is_advertising_router_reachable = None
                                            self.is_deleted = None
                                            self.is_flood_pending = None
                                            self.is_maximum_aged = None
                                            self.is_neighbor_exchange = None
                                            self.is_no_delete = None
                                            self.is_nsr_ack_pending = None
                                            self.is_partial_spf = None
                                            self.is_routing_bit = None
                                            self.is_routing_table = None
                                            self.lsa_flood_required_post_fail_over = None
                                            self.lsa_length = None
                                            self.lsa_sync_state = None
                                            self.minute_table_index = None
                                            self.nsr_flood_required = None
                                            self.rate_limit = None
                                            self.second_table_index = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-detail'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.free_time is not None:
                                                return True

                                            if self.is_acknowledged is not None:
                                                return True

                                            if self.is_advertising_router_reachable is not None:
                                                return True

                                            if self.is_deleted is not None:
                                                return True

                                            if self.is_flood_pending is not None:
                                                return True

                                            if self.is_maximum_aged is not None:
                                                return True

                                            if self.is_neighbor_exchange is not None:
                                                return True

                                            if self.is_no_delete is not None:
                                                return True

                                            if self.is_nsr_ack_pending is not None:
                                                return True

                                            if self.is_partial_spf is not None:
                                                return True

                                            if self.is_routing_bit is not None:
                                                return True

                                            if self.is_routing_table is not None:
                                                return True

                                            if self.lsa_flood_required_post_fail_over is not None:
                                                return True

                                            if self.lsa_length is not None:
                                                return True

                                            if self.lsa_sync_state is not None:
                                                return True

                                            if self.minute_table_index is not None:
                                                return True

                                            if self.nsr_flood_required is not None:
                                                return True

                                            if self.rate_limit is not None:
                                                return True

                                            if self.second_table_index is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaDetail']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:inter-area-router-lsa-type'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.lsa_detail is not None and self.lsa_detail._has_data():
                                            return True

                                        if self.lsa_header is not None and self.lsa_header._has_data():
                                            return True

                                        if self.lsa_router_id is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                        return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType']['meta_info']


                                class ExternalLsaType(object):
                                    """
                                    External LSA
                                    
                                    .. attribute:: external_tag
                                    
                                    	Route Tag
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: forwarding_address
                                    
                                    	Forwarding Address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: is_forwarding_address_set
                                    
                                    	If true, forwarding address is set 
                                    	**type**\:  bool
                                    
                                    .. attribute:: lsa_detail
                                    
                                    	Detailed LSA Information
                                    	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType.LsaDetail>`
                                    
                                    .. attribute:: lsa_header
                                    
                                    	Header information 
                                    	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType.LsaHeader>`
                                    
                                    .. attribute:: metric_type
                                    
                                    	Metric type 
                                    	**type**\:   :py:class:`Ospfv3DefaultMetricEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3DefaultMetricEnum>`
                                    
                                    .. attribute:: prefix
                                    
                                    	IPV6 address prefix 
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: prefix_length
                                    
                                    	Prefix length 
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: priority
                                    
                                    	Prefix priority
                                    	**type**\:   :py:class:`PrefixPriorityEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.PrefixPriorityEnum>`
                                    
                                    .. attribute:: tos_cost
                                    
                                    	Type of service cost metric 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.external_tag = None
                                        self.forwarding_address = None
                                        self.is_forwarding_address_set = None
                                        self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType.LsaDetail()
                                        self.lsa_detail.parent = self
                                        self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType.LsaHeader()
                                        self.lsa_header.parent = self
                                        self.metric_type = None
                                        self.prefix = None
                                        self.prefix_length = None
                                        self.priority = None
                                        self.tos_cost = None


                                    class LsaHeader(object):
                                        """
                                        Header information 
                                        
                                        .. attribute:: advertising_router
                                        
                                        	Router ID of Advertising Router
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: checksum
                                        
                                        	Checksum value
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: is_do_not_age_lsa
                                        
                                        	If true, Do Not Age this LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_graceful_restart_active
                                        
                                        	If true, if grace restart is active 
                                        	**type**\:  bool
                                        
                                        .. attribute:: ls_id
                                        
                                        	LS ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: lsa_age
                                        
                                        	LSA's Age (s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_area_id
                                        
                                        	Area ID in decimal or dotted\-decimal format
                                        	**type**\:  str
                                        
                                        	**length:** 0..16
                                        
                                        .. attribute:: lsa_type
                                        
                                        	LSA type
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: sequence_number
                                        
                                        	Current Sequence number
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.advertising_router = None
                                            self.checksum = None
                                            self.is_do_not_age_lsa = None
                                            self.is_graceful_restart_active = None
                                            self.ls_id = None
                                            self.lsa_age = None
                                            self.lsa_area_id = None
                                            self.lsa_type = None
                                            self.sequence_number = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-header'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.advertising_router is not None:
                                                return True

                                            if self.checksum is not None:
                                                return True

                                            if self.is_do_not_age_lsa is not None:
                                                return True

                                            if self.is_graceful_restart_active is not None:
                                                return True

                                            if self.ls_id is not None:
                                                return True

                                            if self.lsa_age is not None:
                                                return True

                                            if self.lsa_area_id is not None:
                                                return True

                                            if self.lsa_type is not None:
                                                return True

                                            if self.sequence_number is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType.LsaHeader']['meta_info']


                                    class LsaDetail(object):
                                        """
                                        Detailed LSA Information
                                        
                                        .. attribute:: free_time
                                        
                                        	The amount of time since the last check was made to free this LSA (s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_acknowledged
                                        
                                        	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_advertising_router_reachable
                                        
                                        	If true, Advertising Router is reachable
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_deleted
                                        
                                        	If true, flag is set to delete this LSA 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_flood_pending
                                        
                                        	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_maximum_aged
                                        
                                        	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_neighbor_exchange
                                        
                                        	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_no_delete
                                        
                                        	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_nsr_ack_pending
                                        
                                        	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_partial_spf
                                        
                                        	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_routing_bit
                                        
                                        	If true, Routing Bit set on the LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_routing_table
                                        
                                        	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                        	**type**\:  bool
                                        
                                        .. attribute:: lsa_flood_required_post_fail_over
                                        
                                        	LSA flood required after FO
                                        	**type**\:  bool
                                        
                                        .. attribute:: lsa_length
                                        
                                        	Length of the LSA
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_sync_state
                                        
                                        	State of LSA sync with active
                                        	**type**\:   :py:class:`OspfLsaSyncStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncStateEnum>`
                                        
                                        .. attribute:: minute_table_index
                                        
                                        	Minute table index
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: nsr_flood_required
                                        
                                        	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                        	**type**\:  bool
                                        
                                        .. attribute:: rate_limit
                                        
                                        	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                        	**type**\:  bool
                                        
                                        .. attribute:: second_table_index
                                        
                                        	Second table index
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.free_time = None
                                            self.is_acknowledged = None
                                            self.is_advertising_router_reachable = None
                                            self.is_deleted = None
                                            self.is_flood_pending = None
                                            self.is_maximum_aged = None
                                            self.is_neighbor_exchange = None
                                            self.is_no_delete = None
                                            self.is_nsr_ack_pending = None
                                            self.is_partial_spf = None
                                            self.is_routing_bit = None
                                            self.is_routing_table = None
                                            self.lsa_flood_required_post_fail_over = None
                                            self.lsa_length = None
                                            self.lsa_sync_state = None
                                            self.minute_table_index = None
                                            self.nsr_flood_required = None
                                            self.rate_limit = None
                                            self.second_table_index = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-detail'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.free_time is not None:
                                                return True

                                            if self.is_acknowledged is not None:
                                                return True

                                            if self.is_advertising_router_reachable is not None:
                                                return True

                                            if self.is_deleted is not None:
                                                return True

                                            if self.is_flood_pending is not None:
                                                return True

                                            if self.is_maximum_aged is not None:
                                                return True

                                            if self.is_neighbor_exchange is not None:
                                                return True

                                            if self.is_no_delete is not None:
                                                return True

                                            if self.is_nsr_ack_pending is not None:
                                                return True

                                            if self.is_partial_spf is not None:
                                                return True

                                            if self.is_routing_bit is not None:
                                                return True

                                            if self.is_routing_table is not None:
                                                return True

                                            if self.lsa_flood_required_post_fail_over is not None:
                                                return True

                                            if self.lsa_length is not None:
                                                return True

                                            if self.lsa_sync_state is not None:
                                                return True

                                            if self.minute_table_index is not None:
                                                return True

                                            if self.nsr_flood_required is not None:
                                                return True

                                            if self.rate_limit is not None:
                                                return True

                                            if self.second_table_index is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType.LsaDetail']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:external-lsa-type'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.external_tag is not None:
                                            return True

                                        if self.forwarding_address is not None:
                                            return True

                                        if self.is_forwarding_address_set is not None:
                                            return True

                                        if self.lsa_detail is not None and self.lsa_detail._has_data():
                                            return True

                                        if self.lsa_header is not None and self.lsa_header._has_data():
                                            return True

                                        if self.metric_type is not None:
                                            return True

                                        if self.prefix is not None:
                                            return True

                                        if self.prefix_length is not None:
                                            return True

                                        if self.priority is not None:
                                            return True

                                        if self.tos_cost is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                        return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType']['meta_info']


                                class NssalsaType(object):
                                    """
                                    NSSA External LSA
                                    
                                    .. attribute:: external_tag
                                    
                                    	Route Tag
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: forwarding_address
                                    
                                    	Forwarding Address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: is_forwarding_address_set
                                    
                                    	If true, forwarding address is set 
                                    	**type**\:  bool
                                    
                                    .. attribute:: lsa_detail
                                    
                                    	Detailed LSA Information
                                    	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType.LsaDetail>`
                                    
                                    .. attribute:: lsa_header
                                    
                                    	Header information 
                                    	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType.LsaHeader>`
                                    
                                    .. attribute:: metric_type
                                    
                                    	Metric type 
                                    	**type**\:   :py:class:`Ospfv3DefaultMetricEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3DefaultMetricEnum>`
                                    
                                    .. attribute:: prefix
                                    
                                    	IPV6 address prefix 
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: prefix_length
                                    
                                    	Prefix length 
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: priority
                                    
                                    	Prefix priority
                                    	**type**\:   :py:class:`PrefixPriorityEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.PrefixPriorityEnum>`
                                    
                                    .. attribute:: tos_cost
                                    
                                    	Type of service cost metric 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.external_tag = None
                                        self.forwarding_address = None
                                        self.is_forwarding_address_set = None
                                        self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType.LsaDetail()
                                        self.lsa_detail.parent = self
                                        self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType.LsaHeader()
                                        self.lsa_header.parent = self
                                        self.metric_type = None
                                        self.prefix = None
                                        self.prefix_length = None
                                        self.priority = None
                                        self.tos_cost = None


                                    class LsaHeader(object):
                                        """
                                        Header information 
                                        
                                        .. attribute:: advertising_router
                                        
                                        	Router ID of Advertising Router
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: checksum
                                        
                                        	Checksum value
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: is_do_not_age_lsa
                                        
                                        	If true, Do Not Age this LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_graceful_restart_active
                                        
                                        	If true, if grace restart is active 
                                        	**type**\:  bool
                                        
                                        .. attribute:: ls_id
                                        
                                        	LS ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: lsa_age
                                        
                                        	LSA's Age (s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_area_id
                                        
                                        	Area ID in decimal or dotted\-decimal format
                                        	**type**\:  str
                                        
                                        	**length:** 0..16
                                        
                                        .. attribute:: lsa_type
                                        
                                        	LSA type
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: sequence_number
                                        
                                        	Current Sequence number
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.advertising_router = None
                                            self.checksum = None
                                            self.is_do_not_age_lsa = None
                                            self.is_graceful_restart_active = None
                                            self.ls_id = None
                                            self.lsa_age = None
                                            self.lsa_area_id = None
                                            self.lsa_type = None
                                            self.sequence_number = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-header'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.advertising_router is not None:
                                                return True

                                            if self.checksum is not None:
                                                return True

                                            if self.is_do_not_age_lsa is not None:
                                                return True

                                            if self.is_graceful_restart_active is not None:
                                                return True

                                            if self.ls_id is not None:
                                                return True

                                            if self.lsa_age is not None:
                                                return True

                                            if self.lsa_area_id is not None:
                                                return True

                                            if self.lsa_type is not None:
                                                return True

                                            if self.sequence_number is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType.LsaHeader']['meta_info']


                                    class LsaDetail(object):
                                        """
                                        Detailed LSA Information
                                        
                                        .. attribute:: free_time
                                        
                                        	The amount of time since the last check was made to free this LSA (s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_acknowledged
                                        
                                        	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_advertising_router_reachable
                                        
                                        	If true, Advertising Router is reachable
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_deleted
                                        
                                        	If true, flag is set to delete this LSA 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_flood_pending
                                        
                                        	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_maximum_aged
                                        
                                        	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_neighbor_exchange
                                        
                                        	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_no_delete
                                        
                                        	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_nsr_ack_pending
                                        
                                        	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_partial_spf
                                        
                                        	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_routing_bit
                                        
                                        	If true, Routing Bit set on the LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_routing_table
                                        
                                        	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                        	**type**\:  bool
                                        
                                        .. attribute:: lsa_flood_required_post_fail_over
                                        
                                        	LSA flood required after FO
                                        	**type**\:  bool
                                        
                                        .. attribute:: lsa_length
                                        
                                        	Length of the LSA
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_sync_state
                                        
                                        	State of LSA sync with active
                                        	**type**\:   :py:class:`OspfLsaSyncStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncStateEnum>`
                                        
                                        .. attribute:: minute_table_index
                                        
                                        	Minute table index
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: nsr_flood_required
                                        
                                        	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                        	**type**\:  bool
                                        
                                        .. attribute:: rate_limit
                                        
                                        	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                        	**type**\:  bool
                                        
                                        .. attribute:: second_table_index
                                        
                                        	Second table index
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.free_time = None
                                            self.is_acknowledged = None
                                            self.is_advertising_router_reachable = None
                                            self.is_deleted = None
                                            self.is_flood_pending = None
                                            self.is_maximum_aged = None
                                            self.is_neighbor_exchange = None
                                            self.is_no_delete = None
                                            self.is_nsr_ack_pending = None
                                            self.is_partial_spf = None
                                            self.is_routing_bit = None
                                            self.is_routing_table = None
                                            self.lsa_flood_required_post_fail_over = None
                                            self.lsa_length = None
                                            self.lsa_sync_state = None
                                            self.minute_table_index = None
                                            self.nsr_flood_required = None
                                            self.rate_limit = None
                                            self.second_table_index = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-detail'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.free_time is not None:
                                                return True

                                            if self.is_acknowledged is not None:
                                                return True

                                            if self.is_advertising_router_reachable is not None:
                                                return True

                                            if self.is_deleted is not None:
                                                return True

                                            if self.is_flood_pending is not None:
                                                return True

                                            if self.is_maximum_aged is not None:
                                                return True

                                            if self.is_neighbor_exchange is not None:
                                                return True

                                            if self.is_no_delete is not None:
                                                return True

                                            if self.is_nsr_ack_pending is not None:
                                                return True

                                            if self.is_partial_spf is not None:
                                                return True

                                            if self.is_routing_bit is not None:
                                                return True

                                            if self.is_routing_table is not None:
                                                return True

                                            if self.lsa_flood_required_post_fail_over is not None:
                                                return True

                                            if self.lsa_length is not None:
                                                return True

                                            if self.lsa_sync_state is not None:
                                                return True

                                            if self.minute_table_index is not None:
                                                return True

                                            if self.nsr_flood_required is not None:
                                                return True

                                            if self.rate_limit is not None:
                                                return True

                                            if self.second_table_index is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType.LsaDetail']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:nssalsa-type'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.external_tag is not None:
                                            return True

                                        if self.forwarding_address is not None:
                                            return True

                                        if self.is_forwarding_address_set is not None:
                                            return True

                                        if self.lsa_detail is not None and self.lsa_detail._has_data():
                                            return True

                                        if self.lsa_header is not None and self.lsa_header._has_data():
                                            return True

                                        if self.metric_type is not None:
                                            return True

                                        if self.prefix is not None:
                                            return True

                                        if self.prefix_length is not None:
                                            return True

                                        if self.priority is not None:
                                            return True

                                        if self.tos_cost is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                        return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType']['meta_info']


                                class LinkLsaType(object):
                                    """
                                    Link LSA
                                    
                                    .. attribute:: interface_name
                                    
                                    	LSA interface handle
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                    
                                    .. attribute:: is_sham_link
                                    
                                    	If true, it is a sham link
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_virtual_link
                                    
                                    	If true, it is a virtual link
                                    	**type**\:  bool
                                    
                                    .. attribute:: lsa_detail
                                    
                                    	Detailed LSA information
                                    	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType.LsaDetail>`
                                    
                                    .. attribute:: lsa_header
                                    
                                    	Header information 
                                    	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType.LsaHeader>`
                                    
                                    .. attribute:: lsa_link_local
                                    
                                    	LSA link local 
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: prefix
                                    
                                    	OSPFv3 prefix 
                                    	**type**\: list of    :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType.Prefix>`
                                    
                                    .. attribute:: router_priority
                                    
                                    	Router priority 
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: sham_link_id
                                    
                                    	Sham link ID 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: virtual_link_id
                                    
                                    	Virtual link ID 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.interface_name = None
                                        self.is_sham_link = None
                                        self.is_virtual_link = None
                                        self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType.LsaDetail()
                                        self.lsa_detail.parent = self
                                        self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType.LsaHeader()
                                        self.lsa_header.parent = self
                                        self.lsa_link_local = None
                                        self.prefix = YList()
                                        self.prefix.parent = self
                                        self.prefix.name = 'prefix'
                                        self.router_priority = None
                                        self.sham_link_id = None
                                        self.virtual_link_id = None


                                    class LsaHeader(object):
                                        """
                                        Header information 
                                        
                                        .. attribute:: advertising_router
                                        
                                        	Router ID of Advertising Router
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: checksum
                                        
                                        	Checksum value
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: is_do_not_age_lsa
                                        
                                        	If true, Do Not Age this LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_graceful_restart_active
                                        
                                        	If true, if grace restart is active 
                                        	**type**\:  bool
                                        
                                        .. attribute:: ls_id
                                        
                                        	LS ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: lsa_age
                                        
                                        	LSA's Age (s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_area_id
                                        
                                        	Area ID in decimal or dotted\-decimal format
                                        	**type**\:  str
                                        
                                        	**length:** 0..16
                                        
                                        .. attribute:: lsa_type
                                        
                                        	LSA type
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: sequence_number
                                        
                                        	Current Sequence number
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.advertising_router = None
                                            self.checksum = None
                                            self.is_do_not_age_lsa = None
                                            self.is_graceful_restart_active = None
                                            self.ls_id = None
                                            self.lsa_age = None
                                            self.lsa_area_id = None
                                            self.lsa_type = None
                                            self.sequence_number = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-header'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.advertising_router is not None:
                                                return True

                                            if self.checksum is not None:
                                                return True

                                            if self.is_do_not_age_lsa is not None:
                                                return True

                                            if self.is_graceful_restart_active is not None:
                                                return True

                                            if self.ls_id is not None:
                                                return True

                                            if self.lsa_age is not None:
                                                return True

                                            if self.lsa_area_id is not None:
                                                return True

                                            if self.lsa_type is not None:
                                                return True

                                            if self.sequence_number is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType.LsaHeader']['meta_info']


                                    class LsaDetail(object):
                                        """
                                        Detailed LSA information
                                        
                                        .. attribute:: free_time
                                        
                                        	The amount of time since the last check was made to free this LSA (s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_acknowledged
                                        
                                        	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_advertising_router_reachable
                                        
                                        	If true, Advertising Router is reachable
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_deleted
                                        
                                        	If true, flag is set to delete this LSA 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_flood_pending
                                        
                                        	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_maximum_aged
                                        
                                        	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_neighbor_exchange
                                        
                                        	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_no_delete
                                        
                                        	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_nsr_ack_pending
                                        
                                        	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_partial_spf
                                        
                                        	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_routing_bit
                                        
                                        	If true, Routing Bit set on the LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_routing_table
                                        
                                        	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                        	**type**\:  bool
                                        
                                        .. attribute:: lsa_flood_required_post_fail_over
                                        
                                        	LSA flood required after FO
                                        	**type**\:  bool
                                        
                                        .. attribute:: lsa_length
                                        
                                        	Length of the LSA
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_sync_state
                                        
                                        	State of LSA sync with active
                                        	**type**\:   :py:class:`OspfLsaSyncStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncStateEnum>`
                                        
                                        .. attribute:: minute_table_index
                                        
                                        	Minute table index
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: nsr_flood_required
                                        
                                        	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                        	**type**\:  bool
                                        
                                        .. attribute:: rate_limit
                                        
                                        	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                        	**type**\:  bool
                                        
                                        .. attribute:: second_table_index
                                        
                                        	Second table index
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.free_time = None
                                            self.is_acknowledged = None
                                            self.is_advertising_router_reachable = None
                                            self.is_deleted = None
                                            self.is_flood_pending = None
                                            self.is_maximum_aged = None
                                            self.is_neighbor_exchange = None
                                            self.is_no_delete = None
                                            self.is_nsr_ack_pending = None
                                            self.is_partial_spf = None
                                            self.is_routing_bit = None
                                            self.is_routing_table = None
                                            self.lsa_flood_required_post_fail_over = None
                                            self.lsa_length = None
                                            self.lsa_sync_state = None
                                            self.minute_table_index = None
                                            self.nsr_flood_required = None
                                            self.rate_limit = None
                                            self.second_table_index = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-detail'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.free_time is not None:
                                                return True

                                            if self.is_acknowledged is not None:
                                                return True

                                            if self.is_advertising_router_reachable is not None:
                                                return True

                                            if self.is_deleted is not None:
                                                return True

                                            if self.is_flood_pending is not None:
                                                return True

                                            if self.is_maximum_aged is not None:
                                                return True

                                            if self.is_neighbor_exchange is not None:
                                                return True

                                            if self.is_no_delete is not None:
                                                return True

                                            if self.is_nsr_ack_pending is not None:
                                                return True

                                            if self.is_partial_spf is not None:
                                                return True

                                            if self.is_routing_bit is not None:
                                                return True

                                            if self.is_routing_table is not None:
                                                return True

                                            if self.lsa_flood_required_post_fail_over is not None:
                                                return True

                                            if self.lsa_length is not None:
                                                return True

                                            if self.lsa_sync_state is not None:
                                                return True

                                            if self.minute_table_index is not None:
                                                return True

                                            if self.nsr_flood_required is not None:
                                                return True

                                            if self.rate_limit is not None:
                                                return True

                                            if self.second_table_index is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType.LsaDetail']['meta_info']


                                    class Prefix(object):
                                        """
                                        OSPFv3 prefix 
                                        
                                        .. attribute:: ospfv3_prefix_length
                                        
                                        	OSPFv3 prefix length 
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ospfv3_prefix_metric
                                        
                                        	OSPFv3 prefix metric 
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: ospfv3_prefix_options
                                        
                                        	OSPFv3 prefix options 
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: prefix
                                        
                                        	OSPFv3 prefix 
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: priority
                                        
                                        	Prefix priority
                                        	**type**\:   :py:class:`PrefixPriorityEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.PrefixPriorityEnum>`
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.ospfv3_prefix_length = None
                                            self.ospfv3_prefix_metric = None
                                            self.ospfv3_prefix_options = None
                                            self.prefix = None
                                            self.priority = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:prefix'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.ospfv3_prefix_length is not None:
                                                return True

                                            if self.ospfv3_prefix_metric is not None:
                                                return True

                                            if self.ospfv3_prefix_options is not None:
                                                return True

                                            if self.prefix is not None:
                                                return True

                                            if self.priority is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType.Prefix']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:link-lsa-type'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.interface_name is not None:
                                            return True

                                        if self.is_sham_link is not None:
                                            return True

                                        if self.is_virtual_link is not None:
                                            return True

                                        if self.lsa_detail is not None and self.lsa_detail._has_data():
                                            return True

                                        if self.lsa_header is not None and self.lsa_header._has_data():
                                            return True

                                        if self.lsa_link_local is not None:
                                            return True

                                        if self.prefix is not None:
                                            for child_ref in self.prefix:
                                                if child_ref._has_data():
                                                    return True

                                        if self.router_priority is not None:
                                            return True

                                        if self.sham_link_id is not None:
                                            return True

                                        if self.virtual_link_id is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                        return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType']['meta_info']


                                class IntraAreaPrefixLsaType(object):
                                    """
                                    Intra Area Prefix LSA
                                    
                                    .. attribute:: lsa_detail
                                    
                                    	Detailed LSA information
                                    	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaDetail>`
                                    
                                    .. attribute:: lsa_header
                                    
                                    	Header information 
                                    	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaHeader>`
                                    
                                    .. attribute:: prefix
                                    
                                    	OSPFv3 prefix 
                                    	**type**\: list of    :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.Prefix>`
                                    
                                    .. attribute:: reference_advertised_router
                                    
                                    	Reference advertised router 
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: reference_lsa_id
                                    
                                    	Reference LSA ID 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: reference_type
                                    
                                    	Reference type 
                                    	**type**\:   :py:class:`Ospfv3Lsa1Enum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Lsa1Enum>`
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaDetail()
                                        self.lsa_detail.parent = self
                                        self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaHeader()
                                        self.lsa_header.parent = self
                                        self.prefix = YList()
                                        self.prefix.parent = self
                                        self.prefix.name = 'prefix'
                                        self.reference_advertised_router = None
                                        self.reference_lsa_id = None
                                        self.reference_type = None


                                    class LsaHeader(object):
                                        """
                                        Header information 
                                        
                                        .. attribute:: advertising_router
                                        
                                        	Router ID of Advertising Router
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: checksum
                                        
                                        	Checksum value
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: is_do_not_age_lsa
                                        
                                        	If true, Do Not Age this LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_graceful_restart_active
                                        
                                        	If true, if grace restart is active 
                                        	**type**\:  bool
                                        
                                        .. attribute:: ls_id
                                        
                                        	LS ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: lsa_age
                                        
                                        	LSA's Age (s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_area_id
                                        
                                        	Area ID in decimal or dotted\-decimal format
                                        	**type**\:  str
                                        
                                        	**length:** 0..16
                                        
                                        .. attribute:: lsa_type
                                        
                                        	LSA type
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: sequence_number
                                        
                                        	Current Sequence number
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.advertising_router = None
                                            self.checksum = None
                                            self.is_do_not_age_lsa = None
                                            self.is_graceful_restart_active = None
                                            self.ls_id = None
                                            self.lsa_age = None
                                            self.lsa_area_id = None
                                            self.lsa_type = None
                                            self.sequence_number = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-header'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.advertising_router is not None:
                                                return True

                                            if self.checksum is not None:
                                                return True

                                            if self.is_do_not_age_lsa is not None:
                                                return True

                                            if self.is_graceful_restart_active is not None:
                                                return True

                                            if self.ls_id is not None:
                                                return True

                                            if self.lsa_age is not None:
                                                return True

                                            if self.lsa_area_id is not None:
                                                return True

                                            if self.lsa_type is not None:
                                                return True

                                            if self.sequence_number is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaHeader']['meta_info']


                                    class LsaDetail(object):
                                        """
                                        Detailed LSA information
                                        
                                        .. attribute:: free_time
                                        
                                        	The amount of time since the last check was made to free this LSA (s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_acknowledged
                                        
                                        	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_advertising_router_reachable
                                        
                                        	If true, Advertising Router is reachable
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_deleted
                                        
                                        	If true, flag is set to delete this LSA 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_flood_pending
                                        
                                        	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_maximum_aged
                                        
                                        	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_neighbor_exchange
                                        
                                        	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_no_delete
                                        
                                        	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_nsr_ack_pending
                                        
                                        	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_partial_spf
                                        
                                        	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_routing_bit
                                        
                                        	If true, Routing Bit set on the LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_routing_table
                                        
                                        	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                        	**type**\:  bool
                                        
                                        .. attribute:: lsa_flood_required_post_fail_over
                                        
                                        	LSA flood required after FO
                                        	**type**\:  bool
                                        
                                        .. attribute:: lsa_length
                                        
                                        	Length of the LSA
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_sync_state
                                        
                                        	State of LSA sync with active
                                        	**type**\:   :py:class:`OspfLsaSyncStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncStateEnum>`
                                        
                                        .. attribute:: minute_table_index
                                        
                                        	Minute table index
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: nsr_flood_required
                                        
                                        	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                        	**type**\:  bool
                                        
                                        .. attribute:: rate_limit
                                        
                                        	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                        	**type**\:  bool
                                        
                                        .. attribute:: second_table_index
                                        
                                        	Second table index
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.free_time = None
                                            self.is_acknowledged = None
                                            self.is_advertising_router_reachable = None
                                            self.is_deleted = None
                                            self.is_flood_pending = None
                                            self.is_maximum_aged = None
                                            self.is_neighbor_exchange = None
                                            self.is_no_delete = None
                                            self.is_nsr_ack_pending = None
                                            self.is_partial_spf = None
                                            self.is_routing_bit = None
                                            self.is_routing_table = None
                                            self.lsa_flood_required_post_fail_over = None
                                            self.lsa_length = None
                                            self.lsa_sync_state = None
                                            self.minute_table_index = None
                                            self.nsr_flood_required = None
                                            self.rate_limit = None
                                            self.second_table_index = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-detail'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.free_time is not None:
                                                return True

                                            if self.is_acknowledged is not None:
                                                return True

                                            if self.is_advertising_router_reachable is not None:
                                                return True

                                            if self.is_deleted is not None:
                                                return True

                                            if self.is_flood_pending is not None:
                                                return True

                                            if self.is_maximum_aged is not None:
                                                return True

                                            if self.is_neighbor_exchange is not None:
                                                return True

                                            if self.is_no_delete is not None:
                                                return True

                                            if self.is_nsr_ack_pending is not None:
                                                return True

                                            if self.is_partial_spf is not None:
                                                return True

                                            if self.is_routing_bit is not None:
                                                return True

                                            if self.is_routing_table is not None:
                                                return True

                                            if self.lsa_flood_required_post_fail_over is not None:
                                                return True

                                            if self.lsa_length is not None:
                                                return True

                                            if self.lsa_sync_state is not None:
                                                return True

                                            if self.minute_table_index is not None:
                                                return True

                                            if self.nsr_flood_required is not None:
                                                return True

                                            if self.rate_limit is not None:
                                                return True

                                            if self.second_table_index is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaDetail']['meta_info']


                                    class Prefix(object):
                                        """
                                        OSPFv3 prefix 
                                        
                                        .. attribute:: ospfv3_prefix_length
                                        
                                        	OSPFv3 prefix length 
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ospfv3_prefix_metric
                                        
                                        	OSPFv3 prefix metric 
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: ospfv3_prefix_options
                                        
                                        	OSPFv3 prefix options 
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: prefix
                                        
                                        	OSPFv3 prefix 
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: priority
                                        
                                        	Prefix priority
                                        	**type**\:   :py:class:`PrefixPriorityEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.PrefixPriorityEnum>`
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.ospfv3_prefix_length = None
                                            self.ospfv3_prefix_metric = None
                                            self.ospfv3_prefix_options = None
                                            self.prefix = None
                                            self.priority = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:prefix'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.ospfv3_prefix_length is not None:
                                                return True

                                            if self.ospfv3_prefix_metric is not None:
                                                return True

                                            if self.ospfv3_prefix_options is not None:
                                                return True

                                            if self.prefix is not None:
                                                return True

                                            if self.priority is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.Prefix']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:intra-area-prefix-lsa-type'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.lsa_detail is not None and self.lsa_detail._has_data():
                                            return True

                                        if self.lsa_header is not None and self.lsa_header._has_data():
                                            return True

                                        if self.prefix is not None:
                                            for child_ref in self.prefix:
                                                if child_ref._has_data():
                                                    return True

                                        if self.reference_advertised_router is not None:
                                            return True

                                        if self.reference_lsa_id is not None:
                                            return True

                                        if self.reference_type is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                        return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType']['meta_info']


                                class GraceLsa(object):
                                    """
                                    Grace LSA
                                    
                                    .. attribute:: grace_period
                                    
                                    	The grace periord where helper routers should wait before advertising it fully adjacent(s) 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: grace_reason
                                    
                                    	Reason for router restart
                                    	**type**\:   :py:class:`Ospfv3GracefulRestartReasonEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3GracefulRestartReasonEnum>`
                                    
                                    .. attribute:: lsa_detail
                                    
                                    	Detailed LSA information
                                    	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa.LsaDetail>`
                                    
                                    .. attribute:: lsa_header
                                    
                                    	Header information 
                                    	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa.LsaHeader>`
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.grace_period = None
                                        self.grace_reason = None
                                        self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa.LsaDetail()
                                        self.lsa_detail.parent = self
                                        self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa.LsaHeader()
                                        self.lsa_header.parent = self


                                    class LsaHeader(object):
                                        """
                                        Header information 
                                        
                                        .. attribute:: advertising_router
                                        
                                        	Router ID of Advertising Router
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: checksum
                                        
                                        	Checksum value
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: is_do_not_age_lsa
                                        
                                        	If true, Do Not Age this LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_graceful_restart_active
                                        
                                        	If true, if grace restart is active 
                                        	**type**\:  bool
                                        
                                        .. attribute:: ls_id
                                        
                                        	LS ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: lsa_age
                                        
                                        	LSA's Age (s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_area_id
                                        
                                        	Area ID in decimal or dotted\-decimal format
                                        	**type**\:  str
                                        
                                        	**length:** 0..16
                                        
                                        .. attribute:: lsa_type
                                        
                                        	LSA type
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: sequence_number
                                        
                                        	Current Sequence number
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.advertising_router = None
                                            self.checksum = None
                                            self.is_do_not_age_lsa = None
                                            self.is_graceful_restart_active = None
                                            self.ls_id = None
                                            self.lsa_age = None
                                            self.lsa_area_id = None
                                            self.lsa_type = None
                                            self.sequence_number = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-header'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.advertising_router is not None:
                                                return True

                                            if self.checksum is not None:
                                                return True

                                            if self.is_do_not_age_lsa is not None:
                                                return True

                                            if self.is_graceful_restart_active is not None:
                                                return True

                                            if self.ls_id is not None:
                                                return True

                                            if self.lsa_age is not None:
                                                return True

                                            if self.lsa_area_id is not None:
                                                return True

                                            if self.lsa_type is not None:
                                                return True

                                            if self.sequence_number is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa.LsaHeader']['meta_info']


                                    class LsaDetail(object):
                                        """
                                        Detailed LSA information
                                        
                                        .. attribute:: free_time
                                        
                                        	The amount of time since the last check was made to free this LSA (s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_acknowledged
                                        
                                        	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_advertising_router_reachable
                                        
                                        	If true, Advertising Router is reachable
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_deleted
                                        
                                        	If true, flag is set to delete this LSA 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_flood_pending
                                        
                                        	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_maximum_aged
                                        
                                        	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_neighbor_exchange
                                        
                                        	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_no_delete
                                        
                                        	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_nsr_ack_pending
                                        
                                        	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_partial_spf
                                        
                                        	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_routing_bit
                                        
                                        	If true, Routing Bit set on the LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_routing_table
                                        
                                        	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                        	**type**\:  bool
                                        
                                        .. attribute:: lsa_flood_required_post_fail_over
                                        
                                        	LSA flood required after FO
                                        	**type**\:  bool
                                        
                                        .. attribute:: lsa_length
                                        
                                        	Length of the LSA
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_sync_state
                                        
                                        	State of LSA sync with active
                                        	**type**\:   :py:class:`OspfLsaSyncStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncStateEnum>`
                                        
                                        .. attribute:: minute_table_index
                                        
                                        	Minute table index
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: nsr_flood_required
                                        
                                        	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                        	**type**\:  bool
                                        
                                        .. attribute:: rate_limit
                                        
                                        	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                        	**type**\:  bool
                                        
                                        .. attribute:: second_table_index
                                        
                                        	Second table index
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.free_time = None
                                            self.is_acknowledged = None
                                            self.is_advertising_router_reachable = None
                                            self.is_deleted = None
                                            self.is_flood_pending = None
                                            self.is_maximum_aged = None
                                            self.is_neighbor_exchange = None
                                            self.is_no_delete = None
                                            self.is_nsr_ack_pending = None
                                            self.is_partial_spf = None
                                            self.is_routing_bit = None
                                            self.is_routing_table = None
                                            self.lsa_flood_required_post_fail_over = None
                                            self.lsa_length = None
                                            self.lsa_sync_state = None
                                            self.minute_table_index = None
                                            self.nsr_flood_required = None
                                            self.rate_limit = None
                                            self.second_table_index = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-detail'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.free_time is not None:
                                                return True

                                            if self.is_acknowledged is not None:
                                                return True

                                            if self.is_advertising_router_reachable is not None:
                                                return True

                                            if self.is_deleted is not None:
                                                return True

                                            if self.is_flood_pending is not None:
                                                return True

                                            if self.is_maximum_aged is not None:
                                                return True

                                            if self.is_neighbor_exchange is not None:
                                                return True

                                            if self.is_no_delete is not None:
                                                return True

                                            if self.is_nsr_ack_pending is not None:
                                                return True

                                            if self.is_partial_spf is not None:
                                                return True

                                            if self.is_routing_bit is not None:
                                                return True

                                            if self.is_routing_table is not None:
                                                return True

                                            if self.lsa_flood_required_post_fail_over is not None:
                                                return True

                                            if self.lsa_length is not None:
                                                return True

                                            if self.lsa_sync_state is not None:
                                                return True

                                            if self.minute_table_index is not None:
                                                return True

                                            if self.nsr_flood_required is not None:
                                                return True

                                            if self.rate_limit is not None:
                                                return True

                                            if self.second_table_index is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa.LsaDetail']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:grace-lsa'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.grace_period is not None:
                                            return True

                                        if self.grace_reason is not None:
                                            return True

                                        if self.lsa_detail is not None and self.lsa_detail._has_data():
                                            return True

                                        if self.lsa_header is not None and self.lsa_header._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                        return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa']['meta_info']


                                class UnknownLinkLsaType(object):
                                    """
                                    Unknown Link Scope LSA
                                    
                                    .. attribute:: interface_name
                                    
                                    	LSA interface name 
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                    
                                    .. attribute:: is_sham_link
                                    
                                    	If true, it is a sham link 
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_virtual_link
                                    
                                    	If true, it is a virtual link 
                                    	**type**\:  bool
                                    
                                    .. attribute:: lsa_detail
                                    
                                    	Detailed LSA information
                                    	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaDetail>`
                                    
                                    .. attribute:: lsa_header
                                    
                                    	Header information 
                                    	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaHeader>`
                                    
                                    .. attribute:: sham_link_id
                                    
                                    	Shamlink ID 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: virtual_link_id
                                    
                                    	Virtual link ID 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.interface_name = None
                                        self.is_sham_link = None
                                        self.is_virtual_link = None
                                        self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaDetail()
                                        self.lsa_detail.parent = self
                                        self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaHeader()
                                        self.lsa_header.parent = self
                                        self.sham_link_id = None
                                        self.virtual_link_id = None


                                    class LsaHeader(object):
                                        """
                                        Header information 
                                        
                                        .. attribute:: advertising_router
                                        
                                        	Router ID of Advertising Router
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: checksum
                                        
                                        	Checksum value
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: is_do_not_age_lsa
                                        
                                        	If true, Do Not Age this LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_graceful_restart_active
                                        
                                        	If true, if grace restart is active 
                                        	**type**\:  bool
                                        
                                        .. attribute:: ls_id
                                        
                                        	LS ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: lsa_age
                                        
                                        	LSA's Age (s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_area_id
                                        
                                        	Area ID in decimal or dotted\-decimal format
                                        	**type**\:  str
                                        
                                        	**length:** 0..16
                                        
                                        .. attribute:: lsa_type
                                        
                                        	LSA type
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: sequence_number
                                        
                                        	Current Sequence number
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.advertising_router = None
                                            self.checksum = None
                                            self.is_do_not_age_lsa = None
                                            self.is_graceful_restart_active = None
                                            self.ls_id = None
                                            self.lsa_age = None
                                            self.lsa_area_id = None
                                            self.lsa_type = None
                                            self.sequence_number = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-header'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.advertising_router is not None:
                                                return True

                                            if self.checksum is not None:
                                                return True

                                            if self.is_do_not_age_lsa is not None:
                                                return True

                                            if self.is_graceful_restart_active is not None:
                                                return True

                                            if self.ls_id is not None:
                                                return True

                                            if self.lsa_age is not None:
                                                return True

                                            if self.lsa_area_id is not None:
                                                return True

                                            if self.lsa_type is not None:
                                                return True

                                            if self.sequence_number is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaHeader']['meta_info']


                                    class LsaDetail(object):
                                        """
                                        Detailed LSA information
                                        
                                        .. attribute:: free_time
                                        
                                        	The amount of time since the last check was made to free this LSA (s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_acknowledged
                                        
                                        	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_advertising_router_reachable
                                        
                                        	If true, Advertising Router is reachable
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_deleted
                                        
                                        	If true, flag is set to delete this LSA 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_flood_pending
                                        
                                        	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_maximum_aged
                                        
                                        	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_neighbor_exchange
                                        
                                        	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_no_delete
                                        
                                        	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_nsr_ack_pending
                                        
                                        	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_partial_spf
                                        
                                        	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_routing_bit
                                        
                                        	If true, Routing Bit set on the LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_routing_table
                                        
                                        	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                        	**type**\:  bool
                                        
                                        .. attribute:: lsa_flood_required_post_fail_over
                                        
                                        	LSA flood required after FO
                                        	**type**\:  bool
                                        
                                        .. attribute:: lsa_length
                                        
                                        	Length of the LSA
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_sync_state
                                        
                                        	State of LSA sync with active
                                        	**type**\:   :py:class:`OspfLsaSyncStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncStateEnum>`
                                        
                                        .. attribute:: minute_table_index
                                        
                                        	Minute table index
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: nsr_flood_required
                                        
                                        	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                        	**type**\:  bool
                                        
                                        .. attribute:: rate_limit
                                        
                                        	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                        	**type**\:  bool
                                        
                                        .. attribute:: second_table_index
                                        
                                        	Second table index
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.free_time = None
                                            self.is_acknowledged = None
                                            self.is_advertising_router_reachable = None
                                            self.is_deleted = None
                                            self.is_flood_pending = None
                                            self.is_maximum_aged = None
                                            self.is_neighbor_exchange = None
                                            self.is_no_delete = None
                                            self.is_nsr_ack_pending = None
                                            self.is_partial_spf = None
                                            self.is_routing_bit = None
                                            self.is_routing_table = None
                                            self.lsa_flood_required_post_fail_over = None
                                            self.lsa_length = None
                                            self.lsa_sync_state = None
                                            self.minute_table_index = None
                                            self.nsr_flood_required = None
                                            self.rate_limit = None
                                            self.second_table_index = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-detail'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.free_time is not None:
                                                return True

                                            if self.is_acknowledged is not None:
                                                return True

                                            if self.is_advertising_router_reachable is not None:
                                                return True

                                            if self.is_deleted is not None:
                                                return True

                                            if self.is_flood_pending is not None:
                                                return True

                                            if self.is_maximum_aged is not None:
                                                return True

                                            if self.is_neighbor_exchange is not None:
                                                return True

                                            if self.is_no_delete is not None:
                                                return True

                                            if self.is_nsr_ack_pending is not None:
                                                return True

                                            if self.is_partial_spf is not None:
                                                return True

                                            if self.is_routing_bit is not None:
                                                return True

                                            if self.is_routing_table is not None:
                                                return True

                                            if self.lsa_flood_required_post_fail_over is not None:
                                                return True

                                            if self.lsa_length is not None:
                                                return True

                                            if self.lsa_sync_state is not None:
                                                return True

                                            if self.minute_table_index is not None:
                                                return True

                                            if self.nsr_flood_required is not None:
                                                return True

                                            if self.rate_limit is not None:
                                                return True

                                            if self.second_table_index is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaDetail']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:unknown-link-lsa-type'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.interface_name is not None:
                                            return True

                                        if self.is_sham_link is not None:
                                            return True

                                        if self.is_virtual_link is not None:
                                            return True

                                        if self.lsa_detail is not None and self.lsa_detail._has_data():
                                            return True

                                        if self.lsa_header is not None and self.lsa_header._has_data():
                                            return True

                                        if self.sham_link_id is not None:
                                            return True

                                        if self.virtual_link_id is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                        return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType']['meta_info']


                                class UnknownAreaLsaType(object):
                                    """
                                    Unknown\-Area scope LSA
                                    
                                    .. attribute:: interface_name
                                    
                                    	LSA interface name 
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                    
                                    .. attribute:: is_sham_link
                                    
                                    	If true, it is a sham link 
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_virtual_link
                                    
                                    	If true, it is a virtual link 
                                    	**type**\:  bool
                                    
                                    .. attribute:: lsa_detail
                                    
                                    	Detailed LSA information
                                    	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaDetail>`
                                    
                                    .. attribute:: lsa_header
                                    
                                    	Header information 
                                    	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaHeader>`
                                    
                                    .. attribute:: sham_link_id
                                    
                                    	Shamlink ID 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: virtual_link_id
                                    
                                    	Virtual link ID 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.interface_name = None
                                        self.is_sham_link = None
                                        self.is_virtual_link = None
                                        self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaDetail()
                                        self.lsa_detail.parent = self
                                        self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaHeader()
                                        self.lsa_header.parent = self
                                        self.sham_link_id = None
                                        self.virtual_link_id = None


                                    class LsaHeader(object):
                                        """
                                        Header information 
                                        
                                        .. attribute:: advertising_router
                                        
                                        	Router ID of Advertising Router
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: checksum
                                        
                                        	Checksum value
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: is_do_not_age_lsa
                                        
                                        	If true, Do Not Age this LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_graceful_restart_active
                                        
                                        	If true, if grace restart is active 
                                        	**type**\:  bool
                                        
                                        .. attribute:: ls_id
                                        
                                        	LS ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: lsa_age
                                        
                                        	LSA's Age (s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_area_id
                                        
                                        	Area ID in decimal or dotted\-decimal format
                                        	**type**\:  str
                                        
                                        	**length:** 0..16
                                        
                                        .. attribute:: lsa_type
                                        
                                        	LSA type
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: sequence_number
                                        
                                        	Current Sequence number
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.advertising_router = None
                                            self.checksum = None
                                            self.is_do_not_age_lsa = None
                                            self.is_graceful_restart_active = None
                                            self.ls_id = None
                                            self.lsa_age = None
                                            self.lsa_area_id = None
                                            self.lsa_type = None
                                            self.sequence_number = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-header'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.advertising_router is not None:
                                                return True

                                            if self.checksum is not None:
                                                return True

                                            if self.is_do_not_age_lsa is not None:
                                                return True

                                            if self.is_graceful_restart_active is not None:
                                                return True

                                            if self.ls_id is not None:
                                                return True

                                            if self.lsa_age is not None:
                                                return True

                                            if self.lsa_area_id is not None:
                                                return True

                                            if self.lsa_type is not None:
                                                return True

                                            if self.sequence_number is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaHeader']['meta_info']


                                    class LsaDetail(object):
                                        """
                                        Detailed LSA information
                                        
                                        .. attribute:: free_time
                                        
                                        	The amount of time since the last check was made to free this LSA (s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_acknowledged
                                        
                                        	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_advertising_router_reachable
                                        
                                        	If true, Advertising Router is reachable
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_deleted
                                        
                                        	If true, flag is set to delete this LSA 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_flood_pending
                                        
                                        	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_maximum_aged
                                        
                                        	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_neighbor_exchange
                                        
                                        	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_no_delete
                                        
                                        	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_nsr_ack_pending
                                        
                                        	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_partial_spf
                                        
                                        	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_routing_bit
                                        
                                        	If true, Routing Bit set on the LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_routing_table
                                        
                                        	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                        	**type**\:  bool
                                        
                                        .. attribute:: lsa_flood_required_post_fail_over
                                        
                                        	LSA flood required after FO
                                        	**type**\:  bool
                                        
                                        .. attribute:: lsa_length
                                        
                                        	Length of the LSA
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_sync_state
                                        
                                        	State of LSA sync with active
                                        	**type**\:   :py:class:`OspfLsaSyncStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncStateEnum>`
                                        
                                        .. attribute:: minute_table_index
                                        
                                        	Minute table index
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: nsr_flood_required
                                        
                                        	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                        	**type**\:  bool
                                        
                                        .. attribute:: rate_limit
                                        
                                        	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                        	**type**\:  bool
                                        
                                        .. attribute:: second_table_index
                                        
                                        	Second table index
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.free_time = None
                                            self.is_acknowledged = None
                                            self.is_advertising_router_reachable = None
                                            self.is_deleted = None
                                            self.is_flood_pending = None
                                            self.is_maximum_aged = None
                                            self.is_neighbor_exchange = None
                                            self.is_no_delete = None
                                            self.is_nsr_ack_pending = None
                                            self.is_partial_spf = None
                                            self.is_routing_bit = None
                                            self.is_routing_table = None
                                            self.lsa_flood_required_post_fail_over = None
                                            self.lsa_length = None
                                            self.lsa_sync_state = None
                                            self.minute_table_index = None
                                            self.nsr_flood_required = None
                                            self.rate_limit = None
                                            self.second_table_index = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-detail'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.free_time is not None:
                                                return True

                                            if self.is_acknowledged is not None:
                                                return True

                                            if self.is_advertising_router_reachable is not None:
                                                return True

                                            if self.is_deleted is not None:
                                                return True

                                            if self.is_flood_pending is not None:
                                                return True

                                            if self.is_maximum_aged is not None:
                                                return True

                                            if self.is_neighbor_exchange is not None:
                                                return True

                                            if self.is_no_delete is not None:
                                                return True

                                            if self.is_nsr_ack_pending is not None:
                                                return True

                                            if self.is_partial_spf is not None:
                                                return True

                                            if self.is_routing_bit is not None:
                                                return True

                                            if self.is_routing_table is not None:
                                                return True

                                            if self.lsa_flood_required_post_fail_over is not None:
                                                return True

                                            if self.lsa_length is not None:
                                                return True

                                            if self.lsa_sync_state is not None:
                                                return True

                                            if self.minute_table_index is not None:
                                                return True

                                            if self.nsr_flood_required is not None:
                                                return True

                                            if self.rate_limit is not None:
                                                return True

                                            if self.second_table_index is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaDetail']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:unknown-area-lsa-type'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.interface_name is not None:
                                            return True

                                        if self.is_sham_link is not None:
                                            return True

                                        if self.is_virtual_link is not None:
                                            return True

                                        if self.lsa_detail is not None and self.lsa_detail._has_data():
                                            return True

                                        if self.lsa_header is not None and self.lsa_header._has_data():
                                            return True

                                        if self.sham_link_id is not None:
                                            return True

                                        if self.virtual_link_id is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                        return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType']['meta_info']


                                class UnknownAslsaType(object):
                                    """
                                    Unknown\-AS scope LSA
                                    
                                    .. attribute:: interface_name
                                    
                                    	LSA interface name 
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                    
                                    .. attribute:: is_sham_link
                                    
                                    	If true, it is a sham link 
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_virtual_link
                                    
                                    	If true, it is a virtual link 
                                    	**type**\:  bool
                                    
                                    .. attribute:: lsa_detail
                                    
                                    	Detailed LSA information
                                    	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType.LsaDetail>`
                                    
                                    .. attribute:: lsa_header
                                    
                                    	Header information 
                                    	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType.LsaHeader>`
                                    
                                    .. attribute:: sham_link_id
                                    
                                    	Shamlink ID 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: virtual_link_id
                                    
                                    	Virtual link ID 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.interface_name = None
                                        self.is_sham_link = None
                                        self.is_virtual_link = None
                                        self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType.LsaDetail()
                                        self.lsa_detail.parent = self
                                        self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType.LsaHeader()
                                        self.lsa_header.parent = self
                                        self.sham_link_id = None
                                        self.virtual_link_id = None


                                    class LsaHeader(object):
                                        """
                                        Header information 
                                        
                                        .. attribute:: advertising_router
                                        
                                        	Router ID of Advertising Router
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: checksum
                                        
                                        	Checksum value
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: is_do_not_age_lsa
                                        
                                        	If true, Do Not Age this LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_graceful_restart_active
                                        
                                        	If true, if grace restart is active 
                                        	**type**\:  bool
                                        
                                        .. attribute:: ls_id
                                        
                                        	LS ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: lsa_age
                                        
                                        	LSA's Age (s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_area_id
                                        
                                        	Area ID in decimal or dotted\-decimal format
                                        	**type**\:  str
                                        
                                        	**length:** 0..16
                                        
                                        .. attribute:: lsa_type
                                        
                                        	LSA type
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: sequence_number
                                        
                                        	Current Sequence number
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.advertising_router = None
                                            self.checksum = None
                                            self.is_do_not_age_lsa = None
                                            self.is_graceful_restart_active = None
                                            self.ls_id = None
                                            self.lsa_age = None
                                            self.lsa_area_id = None
                                            self.lsa_type = None
                                            self.sequence_number = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-header'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.advertising_router is not None:
                                                return True

                                            if self.checksum is not None:
                                                return True

                                            if self.is_do_not_age_lsa is not None:
                                                return True

                                            if self.is_graceful_restart_active is not None:
                                                return True

                                            if self.ls_id is not None:
                                                return True

                                            if self.lsa_age is not None:
                                                return True

                                            if self.lsa_area_id is not None:
                                                return True

                                            if self.lsa_type is not None:
                                                return True

                                            if self.sequence_number is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType.LsaHeader']['meta_info']


                                    class LsaDetail(object):
                                        """
                                        Detailed LSA information
                                        
                                        .. attribute:: free_time
                                        
                                        	The amount of time since the last check was made to free this LSA (s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_acknowledged
                                        
                                        	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_advertising_router_reachable
                                        
                                        	If true, Advertising Router is reachable
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_deleted
                                        
                                        	If true, flag is set to delete this LSA 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_flood_pending
                                        
                                        	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_maximum_aged
                                        
                                        	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_neighbor_exchange
                                        
                                        	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_no_delete
                                        
                                        	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_nsr_ack_pending
                                        
                                        	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_partial_spf
                                        
                                        	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_routing_bit
                                        
                                        	If true, Routing Bit set on the LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_routing_table
                                        
                                        	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                        	**type**\:  bool
                                        
                                        .. attribute:: lsa_flood_required_post_fail_over
                                        
                                        	LSA flood required after FO
                                        	**type**\:  bool
                                        
                                        .. attribute:: lsa_length
                                        
                                        	Length of the LSA
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_sync_state
                                        
                                        	State of LSA sync with active
                                        	**type**\:   :py:class:`OspfLsaSyncStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncStateEnum>`
                                        
                                        .. attribute:: minute_table_index
                                        
                                        	Minute table index
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: nsr_flood_required
                                        
                                        	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                        	**type**\:  bool
                                        
                                        .. attribute:: rate_limit
                                        
                                        	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                        	**type**\:  bool
                                        
                                        .. attribute:: second_table_index
                                        
                                        	Second table index
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.free_time = None
                                            self.is_acknowledged = None
                                            self.is_advertising_router_reachable = None
                                            self.is_deleted = None
                                            self.is_flood_pending = None
                                            self.is_maximum_aged = None
                                            self.is_neighbor_exchange = None
                                            self.is_no_delete = None
                                            self.is_nsr_ack_pending = None
                                            self.is_partial_spf = None
                                            self.is_routing_bit = None
                                            self.is_routing_table = None
                                            self.lsa_flood_required_post_fail_over = None
                                            self.lsa_length = None
                                            self.lsa_sync_state = None
                                            self.minute_table_index = None
                                            self.nsr_flood_required = None
                                            self.rate_limit = None
                                            self.second_table_index = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-detail'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.free_time is not None:
                                                return True

                                            if self.is_acknowledged is not None:
                                                return True

                                            if self.is_advertising_router_reachable is not None:
                                                return True

                                            if self.is_deleted is not None:
                                                return True

                                            if self.is_flood_pending is not None:
                                                return True

                                            if self.is_maximum_aged is not None:
                                                return True

                                            if self.is_neighbor_exchange is not None:
                                                return True

                                            if self.is_no_delete is not None:
                                                return True

                                            if self.is_nsr_ack_pending is not None:
                                                return True

                                            if self.is_partial_spf is not None:
                                                return True

                                            if self.is_routing_bit is not None:
                                                return True

                                            if self.is_routing_table is not None:
                                                return True

                                            if self.lsa_flood_required_post_fail_over is not None:
                                                return True

                                            if self.lsa_length is not None:
                                                return True

                                            if self.lsa_sync_state is not None:
                                                return True

                                            if self.minute_table_index is not None:
                                                return True

                                            if self.nsr_flood_required is not None:
                                                return True

                                            if self.rate_limit is not None:
                                                return True

                                            if self.second_table_index is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType.LsaDetail']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:unknown-aslsa-type'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.interface_name is not None:
                                            return True

                                        if self.is_sham_link is not None:
                                            return True

                                        if self.is_virtual_link is not None:
                                            return True

                                        if self.lsa_detail is not None and self.lsa_detail._has_data():
                                            return True

                                        if self.lsa_header is not None and self.lsa_header._has_data():
                                            return True

                                        if self.sham_link_id is not None:
                                            return True

                                        if self.virtual_link_id is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                        return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType']['meta_info']


                                class UnknownLsaType(object):
                                    """
                                    Unknown LSA
                                    
                                    .. attribute:: interface_name
                                    
                                    	LSA interface name 
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                    
                                    .. attribute:: is_sham_link
                                    
                                    	If true, it is a sham link 
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_virtual_link
                                    
                                    	If true, it is a virtual link 
                                    	**type**\:  bool
                                    
                                    .. attribute:: lsa_detail
                                    
                                    	Detailed LSA information
                                    	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType.LsaDetail>`
                                    
                                    .. attribute:: lsa_header
                                    
                                    	Header information 
                                    	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType.LsaHeader>`
                                    
                                    .. attribute:: sham_link_id
                                    
                                    	Shamlink ID 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: virtual_link_id
                                    
                                    	Virtual link ID 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.interface_name = None
                                        self.is_sham_link = None
                                        self.is_virtual_link = None
                                        self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType.LsaDetail()
                                        self.lsa_detail.parent = self
                                        self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType.LsaHeader()
                                        self.lsa_header.parent = self
                                        self.sham_link_id = None
                                        self.virtual_link_id = None


                                    class LsaHeader(object):
                                        """
                                        Header information 
                                        
                                        .. attribute:: advertising_router
                                        
                                        	Router ID of Advertising Router
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: checksum
                                        
                                        	Checksum value
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: is_do_not_age_lsa
                                        
                                        	If true, Do Not Age this LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_graceful_restart_active
                                        
                                        	If true, if grace restart is active 
                                        	**type**\:  bool
                                        
                                        .. attribute:: ls_id
                                        
                                        	LS ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: lsa_age
                                        
                                        	LSA's Age (s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_area_id
                                        
                                        	Area ID in decimal or dotted\-decimal format
                                        	**type**\:  str
                                        
                                        	**length:** 0..16
                                        
                                        .. attribute:: lsa_type
                                        
                                        	LSA type
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: sequence_number
                                        
                                        	Current Sequence number
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.advertising_router = None
                                            self.checksum = None
                                            self.is_do_not_age_lsa = None
                                            self.is_graceful_restart_active = None
                                            self.ls_id = None
                                            self.lsa_age = None
                                            self.lsa_area_id = None
                                            self.lsa_type = None
                                            self.sequence_number = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-header'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.advertising_router is not None:
                                                return True

                                            if self.checksum is not None:
                                                return True

                                            if self.is_do_not_age_lsa is not None:
                                                return True

                                            if self.is_graceful_restart_active is not None:
                                                return True

                                            if self.ls_id is not None:
                                                return True

                                            if self.lsa_age is not None:
                                                return True

                                            if self.lsa_area_id is not None:
                                                return True

                                            if self.lsa_type is not None:
                                                return True

                                            if self.sequence_number is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType.LsaHeader']['meta_info']


                                    class LsaDetail(object):
                                        """
                                        Detailed LSA information
                                        
                                        .. attribute:: free_time
                                        
                                        	The amount of time since the last check was made to free this LSA (s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_acknowledged
                                        
                                        	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_advertising_router_reachable
                                        
                                        	If true, Advertising Router is reachable
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_deleted
                                        
                                        	If true, flag is set to delete this LSA 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_flood_pending
                                        
                                        	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_maximum_aged
                                        
                                        	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_neighbor_exchange
                                        
                                        	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_no_delete
                                        
                                        	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_nsr_ack_pending
                                        
                                        	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_partial_spf
                                        
                                        	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_routing_bit
                                        
                                        	If true, Routing Bit set on the LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_routing_table
                                        
                                        	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                        	**type**\:  bool
                                        
                                        .. attribute:: lsa_flood_required_post_fail_over
                                        
                                        	LSA flood required after FO
                                        	**type**\:  bool
                                        
                                        .. attribute:: lsa_length
                                        
                                        	Length of the LSA
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_sync_state
                                        
                                        	State of LSA sync with active
                                        	**type**\:   :py:class:`OspfLsaSyncStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncStateEnum>`
                                        
                                        .. attribute:: minute_table_index
                                        
                                        	Minute table index
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: nsr_flood_required
                                        
                                        	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                        	**type**\:  bool
                                        
                                        .. attribute:: rate_limit
                                        
                                        	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                        	**type**\:  bool
                                        
                                        .. attribute:: second_table_index
                                        
                                        	Second table index
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.free_time = None
                                            self.is_acknowledged = None
                                            self.is_advertising_router_reachable = None
                                            self.is_deleted = None
                                            self.is_flood_pending = None
                                            self.is_maximum_aged = None
                                            self.is_neighbor_exchange = None
                                            self.is_no_delete = None
                                            self.is_nsr_ack_pending = None
                                            self.is_partial_spf = None
                                            self.is_routing_bit = None
                                            self.is_routing_table = None
                                            self.lsa_flood_required_post_fail_over = None
                                            self.lsa_length = None
                                            self.lsa_sync_state = None
                                            self.minute_table_index = None
                                            self.nsr_flood_required = None
                                            self.rate_limit = None
                                            self.second_table_index = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-detail'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.free_time is not None:
                                                return True

                                            if self.is_acknowledged is not None:
                                                return True

                                            if self.is_advertising_router_reachable is not None:
                                                return True

                                            if self.is_deleted is not None:
                                                return True

                                            if self.is_flood_pending is not None:
                                                return True

                                            if self.is_maximum_aged is not None:
                                                return True

                                            if self.is_neighbor_exchange is not None:
                                                return True

                                            if self.is_no_delete is not None:
                                                return True

                                            if self.is_nsr_ack_pending is not None:
                                                return True

                                            if self.is_partial_spf is not None:
                                                return True

                                            if self.is_routing_bit is not None:
                                                return True

                                            if self.is_routing_table is not None:
                                                return True

                                            if self.lsa_flood_required_post_fail_over is not None:
                                                return True

                                            if self.lsa_length is not None:
                                                return True

                                            if self.lsa_sync_state is not None:
                                                return True

                                            if self.minute_table_index is not None:
                                                return True

                                            if self.nsr_flood_required is not None:
                                                return True

                                            if self.rate_limit is not None:
                                                return True

                                            if self.second_table_index is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType.LsaDetail']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:unknown-lsa-type'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.interface_name is not None:
                                            return True

                                        if self.is_sham_link is not None:
                                            return True

                                        if self.is_virtual_link is not None:
                                            return True

                                        if self.lsa_detail is not None and self.lsa_detail._has_data():
                                            return True

                                        if self.lsa_header is not None and self.lsa_header._has_data():
                                            return True

                                        if self.sham_link_id is not None:
                                            return True

                                        if self.virtual_link_id is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                        return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-info'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.external_lsa_type is not None and self.external_lsa_type._has_data():
                                        return True

                                    if self.grace_lsa is not None and self.grace_lsa._has_data():
                                        return True

                                    if self.inter_area_prefix_lsa_type is not None and self.inter_area_prefix_lsa_type._has_data():
                                        return True

                                    if self.inter_area_router_lsa_type is not None and self.inter_area_router_lsa_type._has_data():
                                        return True

                                    if self.intra_area_prefix_lsa_type is not None and self.intra_area_prefix_lsa_type._has_data():
                                        return True

                                    if self.link_lsa_type is not None and self.link_lsa_type._has_data():
                                        return True

                                    if self.lsa_info_type is not None:
                                        return True

                                    if self.lsa_summary_info is not None and self.lsa_summary_info._has_data():
                                        return True

                                    if self.network_lsa_type is not None and self.network_lsa_type._has_data():
                                        return True

                                    if self.nssalsa_type is not None and self.nssalsa_type._has_data():
                                        return True

                                    if self.router_lsa_type is not None and self.router_lsa_type._has_data():
                                        return True

                                    if self.unknown_area_lsa_type is not None and self.unknown_area_lsa_type._has_data():
                                        return True

                                    if self.unknown_aslsa_type is not None and self.unknown_aslsa_type._has_data():
                                        return True

                                    if self.unknown_link_lsa_type is not None and self.unknown_link_lsa_type._has_data():
                                        return True

                                    if self.unknown_lsa_type is not None and self.unknown_lsa_type._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                    return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.advertising_router is not None:
                                    return True

                                if self.area_id is not None:
                                    return True

                                if self.interface_name is not None:
                                    return True

                                if self.ls_id is not None:
                                    return True

                                if self.ls_type is not None:
                                    return True

                                if self.lsa_info is not None and self.lsa_info._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-internal-table'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.lsa is not None:
                                for child_ref in self.lsa:
                                    if child_ref._has_data():
                                        return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                            return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:database-table'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.lsa_internal_table is not None and self.lsa_internal_table._has_data():
                            return True

                        if self.lsa_table is not None and self.lsa_table._has_data():
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                        return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.DatabaseTable']['meta_info']


                class InterfaceProcessTable(object):
                    """
                    OSPFv3 interface information table for all areas
                    
                    .. attribute:: interface
                    
                    	OSPFv3 interface information
                    	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.InterfaceProcessTable.Interface>`
                    
                    

                    """

                    _prefix = 'ipv6-ospfv3-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.interface = YList()
                        self.interface.parent = self
                        self.interface.name = 'interface'


                    class Interface(object):
                        """
                        OSPFv3 interface information
                        
                        .. attribute:: interface_name  <key>
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: active_interface
                        
                        	Active interface details 
                        	**type**\:   :py:class:`ActiveInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.InterfaceProcessTable.Interface.ActiveInterface>`
                        
                        .. attribute:: adjacent_neighbor
                        
                        	Number of adjacent neighbors
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: backup_designated_router_address
                        
                        	Backup designated router interface address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: backup_designated_router_id
                        
                        	Backup designated router ID
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: configured_ldp_sync
                        
                        	If true, configured as LDP sync
                        	**type**\:  bool
                        
                        .. attribute:: dead_interval
                        
                        	Configured dead interval (s) 
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: designated_router_address
                        
                        	Designated router interface address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: designated_router_id
                        
                        	Designated router ID
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: hello_interval
                        
                        	Configured hello interval (s)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: interface_address
                        
                        	Interface IPv6 address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: interface_authentication_spi
                        
                        	Interface authentication spi 
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: interface_authentication_transmit
                        
                        	Interface authentication transmit 
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: interface_bfd
                        
                        	BFD information 
                        	**type**\:   :py:class:`InterfaceBfd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.InterfaceProcessTable.Interface.InterfaceBfd>`
                        
                        .. attribute:: interface_dc_bitless_ls_as
                        
                        	Number of LSAs with demand circuit bit not set for the area in which the interface is running
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: interface_encrypted_authentication_transmitted
                        
                        	Interface encrypted authentication transmitted 
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: interface_encryption_spi
                        
                        	Interface encryption spi
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: interface_encryption_transmitted
                        
                        	Interface encryption transmitted 
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: interface_ldp_sync
                        
                        	If true, interface LDP sync is achieved
                        	**type**\:  bool
                        
                        .. attribute:: interface_link_cost
                        
                        	Interface link cost
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: interface_neighbor
                        
                        	Information for neighbors on the interface
                        	**type**\: list of    :py:class:`InterfaceNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.InterfaceProcessTable.Interface.InterfaceNeighbor>`
                        
                        .. attribute:: interface_number
                        
                        	Interface number 
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: interface_priority
                        
                        	Interface priority
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: interface_references
                        
                        	Interface reference count 
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: interface_retransmission_interval
                        
                        	Configured retransmit interval (s) 
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: interface_router_id
                        
                        	Interface router ID 
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: interface_state
                        
                        	Interface state
                        	**type**\:   :py:class:`ImStateEnumEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.ImStateEnumEnum>`
                        
                        .. attribute:: is_demand_circuit_configured
                        
                        	If true, configured as demand circuit 
                        	**type**\:  bool
                        
                        .. attribute:: is_designated_router
                        
                        	If true, designated router
                        	**type**\:  bool
                        
                        .. attribute:: is_interface_demand_circuit
                        
                        	If true, interface running as demand circuit
                        	**type**\:  bool
                        
                        .. attribute:: is_interface_encryption_enabled
                        
                        	If true, interface encryption is enabled 
                        	**type**\:  bool
                        
                        .. attribute:: is_interface_flood_reduction
                        
                        	If true, interface flood reduction is active 
                        	**type**\:  bool
                        
                        .. attribute:: is_interface_ip_security_active
                        
                        	If true, interface IP security is active 
                        	**type**\:  bool
                        
                        .. attribute:: is_interface_ip_security_required
                        
                        	If true, interface IP security is required 
                        	**type**\:  bool
                        
                        .. attribute:: is_interface_line_up
                        
                        	If true, line protocol is up 
                        	**type**\:  bool
                        
                        .. attribute:: is_interface_lsa_filtered
                        
                        	Filter is configured for out going LSAs 
                        	**type**\:  bool
                        
                        .. attribute:: is_prefix_suppress
                        
                        	If true prefix suppression is enabled
                        	**type**\:  bool
                        
                        .. attribute:: network_lsa_flush_timer
                        
                        	The amount of time in seconds before flush timer for old network LSA expires 
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: network_type
                        
                        	Network type
                        	**type**\:   :py:class:`Ospfv3InterfaceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3InterfaceEnum>`
                        
                        .. attribute:: next_hello_time
                        
                        	Time until next Hello (s) 
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: ospf_interface_state
                        
                        	Interface state
                        	**type**\:   :py:class:`Ospfv3InterfaceStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3InterfaceStateEnum>`
                        
                        .. attribute:: transmission_delay
                        
                        	Interface transmission delay (sec)
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: wait_interval
                        
                        	Configured wait interval (s) 
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.interface_name = None
                            self.active_interface = Ospfv3.Processes.Process.DefaultVrf.InterfaceProcessTable.Interface.ActiveInterface()
                            self.active_interface.parent = self
                            self.adjacent_neighbor = None
                            self.backup_designated_router_address = None
                            self.backup_designated_router_id = None
                            self.configured_ldp_sync = None
                            self.dead_interval = None
                            self.designated_router_address = None
                            self.designated_router_id = None
                            self.hello_interval = None
                            self.interface_address = None
                            self.interface_authentication_spi = None
                            self.interface_authentication_transmit = None
                            self.interface_bfd = Ospfv3.Processes.Process.DefaultVrf.InterfaceProcessTable.Interface.InterfaceBfd()
                            self.interface_bfd.parent = self
                            self.interface_dc_bitless_ls_as = None
                            self.interface_encrypted_authentication_transmitted = None
                            self.interface_encryption_spi = None
                            self.interface_encryption_transmitted = None
                            self.interface_ldp_sync = None
                            self.interface_link_cost = None
                            self.interface_neighbor = YList()
                            self.interface_neighbor.parent = self
                            self.interface_neighbor.name = 'interface_neighbor'
                            self.interface_number = None
                            self.interface_priority = None
                            self.interface_references = None
                            self.interface_retransmission_interval = None
                            self.interface_router_id = None
                            self.interface_state = None
                            self.is_demand_circuit_configured = None
                            self.is_designated_router = None
                            self.is_interface_demand_circuit = None
                            self.is_interface_encryption_enabled = None
                            self.is_interface_flood_reduction = None
                            self.is_interface_ip_security_active = None
                            self.is_interface_ip_security_required = None
                            self.is_interface_line_up = None
                            self.is_interface_lsa_filtered = None
                            self.is_prefix_suppress = None
                            self.network_lsa_flush_timer = None
                            self.network_type = None
                            self.next_hello_time = None
                            self.ospf_interface_state = None
                            self.transmission_delay = None
                            self.wait_interval = None


                        class ActiveInterface(object):
                            """
                            Active interface details 
                            
                            .. attribute:: flood_queue_length
                            
                            	Flood queue length
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: flood_scan_length
                            
                            	Last flood scan length 
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: interface_area_flood_index
                            
                            	Area scope LSAs flood index
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: interface_area_next_flood
                            
                            	Next LSA to flood (Area scope)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: interface_area_next_flood_index
                            
                            	Index of next LSA to flood (Area scope) 
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: interface_as_flood_index
                            
                            	AS scope LSAs flood index 
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: interface_as_next_flood
                            
                            	Next LSA to flood (AS scope)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: interface_as_next_flood_index
                            
                            	Index of next LSA to flood (AS scope)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: interface_flood_pacing_timer
                            
                            	Time until next flood pacing timer (ms) 
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: interface_link_flood_index
                            
                            	Interface flood link index 
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: interface_link_next_flood
                            
                            	Interface link next flood information 
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: interface_link_next_index
                            
                            	Interface link next information index 
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: interface_neighbors
                            
                            	Total number of neighbors 
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: last_flood_time
                            
                            	Last flood scan time (ms)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: maximum_flood_length
                            
                            	Maximum flood length 
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: maximum_flood_time
                            
                            	Maximum flood time (ms) 
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: suppressed_hellos
                            
                            	Number of neighbors for which hellos are suppressed 
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: wait_time
                            
                            	Wait time for DR/BDR selection (s)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.flood_queue_length = None
                                self.flood_scan_length = None
                                self.interface_area_flood_index = None
                                self.interface_area_next_flood = None
                                self.interface_area_next_flood_index = None
                                self.interface_as_flood_index = None
                                self.interface_as_next_flood = None
                                self.interface_as_next_flood_index = None
                                self.interface_flood_pacing_timer = None
                                self.interface_link_flood_index = None
                                self.interface_link_next_flood = None
                                self.interface_link_next_index = None
                                self.interface_neighbors = None
                                self.last_flood_time = None
                                self.maximum_flood_length = None
                                self.maximum_flood_time = None
                                self.suppressed_hellos = None
                                self.wait_time = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:active-interface'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.flood_queue_length is not None:
                                    return True

                                if self.flood_scan_length is not None:
                                    return True

                                if self.interface_area_flood_index is not None:
                                    return True

                                if self.interface_area_next_flood is not None:
                                    return True

                                if self.interface_area_next_flood_index is not None:
                                    return True

                                if self.interface_as_flood_index is not None:
                                    return True

                                if self.interface_as_next_flood is not None:
                                    return True

                                if self.interface_as_next_flood_index is not None:
                                    return True

                                if self.interface_flood_pacing_timer is not None:
                                    return True

                                if self.interface_link_flood_index is not None:
                                    return True

                                if self.interface_link_next_flood is not None:
                                    return True

                                if self.interface_link_next_index is not None:
                                    return True

                                if self.interface_neighbors is not None:
                                    return True

                                if self.last_flood_time is not None:
                                    return True

                                if self.maximum_flood_length is not None:
                                    return True

                                if self.maximum_flood_time is not None:
                                    return True

                                if self.suppressed_hellos is not None:
                                    return True

                                if self.wait_time is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.InterfaceProcessTable.Interface.ActiveInterface']['meta_info']


                        class InterfaceBfd(object):
                            """
                            BFD information 
                            
                            .. attribute:: bfd_detection_multiplier
                            
                            	BFD detection multiplier 
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: bfd_interval
                            
                            	BFD interval (ms) 
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: bfd_intf_enable_mode
                            
                            	BFD Enable Mode on the interface \- Default/Strict
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.bfd_detection_multiplier = None
                                self.bfd_interval = None
                                self.bfd_intf_enable_mode = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:interface-bfd'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.bfd_detection_multiplier is not None:
                                    return True

                                if self.bfd_interval is not None:
                                    return True

                                if self.bfd_intf_enable_mode is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.InterfaceProcessTable.Interface.InterfaceBfd']['meta_info']


                        class InterfaceNeighbor(object):
                            """
                            Information for neighbors on the interface
                            
                            .. attribute:: interface_neighbor_cost
                            
                            	Cost of link to neighbor
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: interface_neighbor_id
                            
                            	Neighbor router ID 
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: is_hello_suppressed
                            
                            	If true, hello is suppressed 
                            	**type**\:  bool
                            
                            .. attribute:: is_neighbor_bdr
                            
                            	If true, backup designated router is found 
                            	**type**\:  bool
                            
                            .. attribute:: is_neighbor_dr
                            
                            	If true, designated router is found 
                            	**type**\:  bool
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.interface_neighbor_cost = None
                                self.interface_neighbor_id = None
                                self.is_hello_suppressed = None
                                self.is_neighbor_bdr = None
                                self.is_neighbor_dr = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:interface-neighbor'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.interface_neighbor_cost is not None:
                                    return True

                                if self.interface_neighbor_id is not None:
                                    return True

                                if self.is_hello_suppressed is not None:
                                    return True

                                if self.is_neighbor_bdr is not None:
                                    return True

                                if self.is_neighbor_dr is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.InterfaceProcessTable.Interface.InterfaceNeighbor']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')
                            if self.interface_name is None:
                                raise YPYModelError('Key property interface_name is None')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:interface[Cisco-IOS-XR-ipv6-ospfv3-oper:interface-name = ' + str(self.interface_name) + ']'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.interface_name is not None:
                                return True

                            if self.active_interface is not None and self.active_interface._has_data():
                                return True

                            if self.adjacent_neighbor is not None:
                                return True

                            if self.backup_designated_router_address is not None:
                                return True

                            if self.backup_designated_router_id is not None:
                                return True

                            if self.configured_ldp_sync is not None:
                                return True

                            if self.dead_interval is not None:
                                return True

                            if self.designated_router_address is not None:
                                return True

                            if self.designated_router_id is not None:
                                return True

                            if self.hello_interval is not None:
                                return True

                            if self.interface_address is not None:
                                return True

                            if self.interface_authentication_spi is not None:
                                return True

                            if self.interface_authentication_transmit is not None:
                                return True

                            if self.interface_bfd is not None and self.interface_bfd._has_data():
                                return True

                            if self.interface_dc_bitless_ls_as is not None:
                                return True

                            if self.interface_encrypted_authentication_transmitted is not None:
                                return True

                            if self.interface_encryption_spi is not None:
                                return True

                            if self.interface_encryption_transmitted is not None:
                                return True

                            if self.interface_ldp_sync is not None:
                                return True

                            if self.interface_link_cost is not None:
                                return True

                            if self.interface_neighbor is not None:
                                for child_ref in self.interface_neighbor:
                                    if child_ref._has_data():
                                        return True

                            if self.interface_number is not None:
                                return True

                            if self.interface_priority is not None:
                                return True

                            if self.interface_references is not None:
                                return True

                            if self.interface_retransmission_interval is not None:
                                return True

                            if self.interface_router_id is not None:
                                return True

                            if self.interface_state is not None:
                                return True

                            if self.is_demand_circuit_configured is not None:
                                return True

                            if self.is_designated_router is not None:
                                return True

                            if self.is_interface_demand_circuit is not None:
                                return True

                            if self.is_interface_encryption_enabled is not None:
                                return True

                            if self.is_interface_flood_reduction is not None:
                                return True

                            if self.is_interface_ip_security_active is not None:
                                return True

                            if self.is_interface_ip_security_required is not None:
                                return True

                            if self.is_interface_line_up is not None:
                                return True

                            if self.is_interface_lsa_filtered is not None:
                                return True

                            if self.is_prefix_suppress is not None:
                                return True

                            if self.network_lsa_flush_timer is not None:
                                return True

                            if self.network_type is not None:
                                return True

                            if self.next_hello_time is not None:
                                return True

                            if self.ospf_interface_state is not None:
                                return True

                            if self.transmission_delay is not None:
                                return True

                            if self.wait_interval is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                            return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.InterfaceProcessTable.Interface']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:interface-process-table'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.interface is not None:
                            for child_ref in self.interface:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                        return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.InterfaceProcessTable']['meta_info']


                class Redistributions(object):
                    """
                    Redistribution information table
                    
                    .. attribute:: redistribution
                    
                    	Redistribution information
                    	**type**\: list of    :py:class:`Redistribution <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Redistributions.Redistribution>`
                    
                    

                    """

                    _prefix = 'ipv6-ospfv3-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.redistribution = YList()
                        self.redistribution.parent = self
                        self.redistribution.name = 'redistribution'


                    class Redistribution(object):
                        """
                        Redistribution information
                        
                        .. attribute:: policy_name
                        
                        	Route policy name 
                        	**type**\:  str
                        
                        .. attribute:: process_id
                        
                        	Process ID 
                        	**type**\:  str
                        
                        	**length:** 0..40
                        
                        .. attribute:: process_name
                        
                        	Process name of a protocolbeing redistributed 
                        	**type**\:  str
                        
                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                        
                        .. attribute:: protocol_name
                        
                        	Protocol name that is redistributed
                        	**type**\:  str
                        
                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                        
                        .. attribute:: protocol_name_xr
                        
                        	Protocol name 
                        	**type**\:  str
                        
                        	**length:** 0..40
                        
                        .. attribute:: red_metric
                        
                        	red metric
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: red_metric_flag
                        
                        	red metric flag
                        	**type**\:  bool
                        
                        .. attribute:: red_metric_type
                        
                        	red metric type
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: red_mtype_flag
                        
                        	red mtype flag
                        	**type**\:  bool
                        
                        .. attribute:: red_tag
                        
                        	red tag
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.policy_name = None
                            self.process_id = None
                            self.process_name = None
                            self.protocol_name = None
                            self.protocol_name_xr = None
                            self.red_metric = None
                            self.red_metric_flag = None
                            self.red_metric_type = None
                            self.red_mtype_flag = None
                            self.red_tag = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:redistribution'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.policy_name is not None:
                                return True

                            if self.process_id is not None:
                                return True

                            if self.process_name is not None:
                                return True

                            if self.protocol_name is not None:
                                return True

                            if self.protocol_name_xr is not None:
                                return True

                            if self.red_metric is not None:
                                return True

                            if self.red_metric_flag is not None:
                                return True

                            if self.red_metric_type is not None:
                                return True

                            if self.red_mtype_flag is not None:
                                return True

                            if self.red_tag is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                            return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Redistributions.Redistribution']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:redistributions'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.redistribution is not None:
                            for child_ref in self.redistribution:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                        return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Redistributions']['meta_info']


                class ExternalRoutes(object):
                    """
                    OSPFv3 external route information table
                    
                    .. attribute:: external_route
                    
                    	OSPFv3 external route information
                    	**type**\: list of    :py:class:`ExternalRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.ExternalRoutes.ExternalRoute>`
                    
                    

                    """

                    _prefix = 'ipv6-ospfv3-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.external_route = YList()
                        self.external_route.parent = self
                        self.external_route.name = 'external_route'


                    class ExternalRoute(object):
                        """
                        OSPFv3 external route information
                        
                        .. attribute:: prefix
                        
                        	Route prefix
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: prefix_length
                        
                        	Prefix length
                        	**type**\:  int
                        
                        	**range:** 0..128
                        
                        .. attribute:: route_extended_community
                        
                        	Extended communities in the route
                        	**type**\:   :py:class:`RouteExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.ExternalRoutes.ExternalRoute.RouteExtendedCommunity>`
                        
                        .. attribute:: route_path
                        
                        	List of paths to this route
                        	**type**\: list of    :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.ExternalRoutes.ExternalRoute.RoutePath>`
                        
                        .. attribute:: route_topology
                        
                        	Common Route topology information
                        	**type**\:   :py:class:`RouteTopology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.ExternalRoutes.ExternalRoute.RouteTopology>`
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.prefix = None
                            self.prefix_length = None
                            self.route_extended_community = Ospfv3.Processes.Process.DefaultVrf.ExternalRoutes.ExternalRoute.RouteExtendedCommunity()
                            self.route_extended_community.parent = self
                            self.route_path = YList()
                            self.route_path.parent = self
                            self.route_path.name = 'route_path'
                            self.route_topology = Ospfv3.Processes.Process.DefaultVrf.ExternalRoutes.ExternalRoute.RouteTopology()
                            self.route_topology.parent = self


                        class RouteTopology(object):
                            """
                            Common Route topology information
                            
                            .. attribute:: route_cost
                            
                            	Route cost 
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: route_distance
                            
                            	Route distance 
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: route_id
                            
                            	Route ID 
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: route_type
                            
                            	Route type
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.route_cost = None
                                self.route_distance = None
                                self.route_id = None
                                self.route_type = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:route-topology'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.route_cost is not None:
                                    return True

                                if self.route_distance is not None:
                                    return True

                                if self.route_id is not None:
                                    return True

                                if self.route_type is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.ExternalRoutes.ExternalRoute.RouteTopology']['meta_info']


                        class RouteExtendedCommunity(object):
                            """
                            Extended communities in the route
                            
                            .. attribute:: extended_community_area_id
                            
                            	Area id
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: extended_community_domain_id_value
                            
                            	Domain ID value
                            	**type**\:  str
                            
                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                            
                            .. attribute:: extended_community_options
                            
                            	Route Options
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: extended_community_route_type
                            
                            	Route type
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: extended_community_router_id
                            
                            	Router id
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: extended_communityl_domain_id_type
                            
                            	Domain ID type
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.extended_community_area_id = None
                                self.extended_community_domain_id_value = None
                                self.extended_community_options = None
                                self.extended_community_route_type = None
                                self.extended_community_router_id = None
                                self.extended_communityl_domain_id_type = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:route-extended-community'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.extended_community_area_id is not None:
                                    return True

                                if self.extended_community_domain_id_value is not None:
                                    return True

                                if self.extended_community_options is not None:
                                    return True

                                if self.extended_community_route_type is not None:
                                    return True

                                if self.extended_community_router_id is not None:
                                    return True

                                if self.extended_communityl_domain_id_type is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.ExternalRoutes.ExternalRoute.RouteExtendedCommunity']['meta_info']


                        class RoutePath(object):
                            """
                            List of paths to this route
                            
                            .. attribute:: interface_name
                            
                            	Route path interface name 
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: route_backup_path
                            
                            	Backup Path Info
                            	**type**\:   :py:class:`RouteBackupPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.ExternalRoutes.ExternalRoute.RoutePath.RouteBackupPath>`
                            
                            .. attribute:: route_path_id
                            
                            	Path ID of path
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: route_path_next_hop
                            
                            	Route path next hop 
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.interface_name = None
                                self.route_backup_path = Ospfv3.Processes.Process.DefaultVrf.ExternalRoutes.ExternalRoute.RoutePath.RouteBackupPath()
                                self.route_backup_path.parent = self
                                self.route_path_id = None
                                self.route_path_next_hop = None


                            class RouteBackupPath(object):
                                """
                                Backup Path Info
                                
                                .. attribute:: backup_metric
                                
                                	Metric
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: backup_route_interface_name
                                
                                	Next hop Interface
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: backup_route_next_hop_address
                                
                                	Nexthop IP address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: backup_route_source
                                
                                	IP address of source of route
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: downstream
                                
                                	Downstream
                                	**type**\:  bool
                                
                                .. attribute:: line_card_disjoint
                                
                                	Line Card Disjoint
                                	**type**\:  bool
                                
                                .. attribute:: node_protect
                                
                                	Node Protect
                                	**type**\:  bool
                                
                                .. attribute:: primary_path
                                
                                	Primary Path
                                	**type**\:  bool
                                
                                .. attribute:: srlg_disjoint
                                
                                	SRLG Disjoint
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.backup_metric = None
                                    self.backup_route_interface_name = None
                                    self.backup_route_next_hop_address = None
                                    self.backup_route_source = None
                                    self.downstream = None
                                    self.line_card_disjoint = None
                                    self.node_protect = None
                                    self.primary_path = None
                                    self.srlg_disjoint = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:route-backup-path'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.backup_metric is not None:
                                        return True

                                    if self.backup_route_interface_name is not None:
                                        return True

                                    if self.backup_route_next_hop_address is not None:
                                        return True

                                    if self.backup_route_source is not None:
                                        return True

                                    if self.downstream is not None:
                                        return True

                                    if self.line_card_disjoint is not None:
                                        return True

                                    if self.node_protect is not None:
                                        return True

                                    if self.primary_path is not None:
                                        return True

                                    if self.srlg_disjoint is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                    return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.ExternalRoutes.ExternalRoute.RoutePath.RouteBackupPath']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:route-path'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.interface_name is not None:
                                    return True

                                if self.route_backup_path is not None and self.route_backup_path._has_data():
                                    return True

                                if self.route_path_id is not None:
                                    return True

                                if self.route_path_next_hop is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.ExternalRoutes.ExternalRoute.RoutePath']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:external-route'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.prefix is not None:
                                return True

                            if self.prefix_length is not None:
                                return True

                            if self.route_extended_community is not None and self.route_extended_community._has_data():
                                return True

                            if self.route_path is not None:
                                for child_ref in self.route_path:
                                    if child_ref._has_data():
                                        return True

                            if self.route_topology is not None and self.route_topology._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                            return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.ExternalRoutes.ExternalRoute']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:external-routes'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.external_route is not None:
                            for child_ref in self.external_route:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                        return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.ExternalRoutes']['meta_info']


                class RequestListProcessTable(object):
                    """
                    OSPFv3 request list information for all areas
                    
                    .. attribute:: request
                    
                    	OSPFv3 request list information
                    	**type**\: list of    :py:class:`Request <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.RequestListProcessTable.Request>`
                    
                    

                    """

                    _prefix = 'ipv6-ospfv3-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.request = YList()
                        self.request.parent = self
                        self.request.name = 'request'


                    class Request(object):
                        """
                        OSPFv3 request list information
                        
                        .. attribute:: interface_name
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: is_request_sham_link
                        
                        	If true, sham link is requested 
                        	**type**\:  bool
                        
                        .. attribute:: is_request_virtual_link
                        
                        	If true, virtual link is requested 
                        	**type**\:  bool
                        
                        .. attribute:: neighbor_address
                        
                        	Neighbor address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: request
                        
                        	List of request list entries
                        	**type**\: list of    :py:class:`Request_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.RequestListProcessTable.Request.Request_>`
                        
                        .. attribute:: request_neighbor_address
                        
                        	Neighbor IP address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: request_sham_link_id
                        
                        	Request sham link ID 
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: request_virtual_link_id
                        
                        	Request virtual link ID 
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.interface_name = None
                            self.is_request_sham_link = None
                            self.is_request_virtual_link = None
                            self.neighbor_address = None
                            self.request = YList()
                            self.request.parent = self
                            self.request.name = 'request'
                            self.request_neighbor_address = None
                            self.request_sham_link_id = None
                            self.request_virtual_link_id = None


                        class Request_(object):
                            """
                            List of request list entries
                            
                            .. attribute:: header_advertising_router
                            
                            	Router ID of the advertising router
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: header_lsa_age
                            
                            	Age of the LSA (seconds)
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: second
                            
                            .. attribute:: header_lsa_id
                            
                            	LSA ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: header_lsa_type
                            
                            	LSA type
                            	**type**\:   :py:class:`Ospfv3Lsa1Enum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Lsa1Enum>`
                            
                            .. attribute:: header_sequence_number
                            
                            	Current LSA sequence number
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.header_advertising_router = None
                                self.header_lsa_age = None
                                self.header_lsa_id = None
                                self.header_lsa_type = None
                                self.header_sequence_number = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:request'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.header_advertising_router is not None:
                                    return True

                                if self.header_lsa_age is not None:
                                    return True

                                if self.header_lsa_id is not None:
                                    return True

                                if self.header_lsa_type is not None:
                                    return True

                                if self.header_sequence_number is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.RequestListProcessTable.Request.Request_']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:request'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.interface_name is not None:
                                return True

                            if self.is_request_sham_link is not None:
                                return True

                            if self.is_request_virtual_link is not None:
                                return True

                            if self.neighbor_address is not None:
                                return True

                            if self.request is not None:
                                for child_ref in self.request:
                                    if child_ref._has_data():
                                        return True

                            if self.request_neighbor_address is not None:
                                return True

                            if self.request_sham_link_id is not None:
                                return True

                            if self.request_virtual_link_id is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                            return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.RequestListProcessTable.Request']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:request-list-process-table'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.request is not None:
                            for child_ref in self.request:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                        return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.RequestListProcessTable']['meta_info']


                class VirtualLink(object):
                    """
                    Virtual link information
                    
                    .. attribute:: interface_name
                    
                    	Interface on which this virtual link is formed
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: is_virtual_link_authentication_enabled
                    
                    	If true, virtual link authentication is enabled 
                    	**type**\:  bool
                    
                    .. attribute:: is_virtual_link_demand_circuit
                    
                    	If true, the link runs as demand circuit
                    	**type**\:  bool
                    
                    .. attribute:: is_virtual_link_encryption_enabled
                    
                    	If true, virtual link encryption is enabled 
                    	**type**\:  bool
                    
                    .. attribute:: is_virtual_link_ip_security_active
                    
                    	If true, Virtual link IP security is active 
                    	**type**\:  bool
                    
                    .. attribute:: is_virtual_link_ip_security_required
                    
                    	If true, virtual link IP security is required 
                    	**type**\:  bool
                    
                    .. attribute:: is_virtual_link_passive
                    
                    	If true, interface is passive
                    	**type**\:  bool
                    
                    .. attribute:: transit_area_id
                    
                    	Transit area id 
                    	**type**\:  str
                    
                    .. attribute:: virtual_link_authentication_spi
                    
                    	Virtual link authentication spi 
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: virtual_link_authentication_transmit
                    
                    	Virtual link authentication transmit 
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: virtual_link_cost
                    
                    	Cost of the virtual link
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: virtual_link_dc_bitless_lsa
                    
                    	Number of LSA's with demand circuit bit not set 
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: virtual_link_dead_interval
                    
                    	Dead interval (s)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: virtual_link_encrypted_authentication_transmitted
                    
                    	Virtual link encrypted authentication transmitted 
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: virtual_link_encryption_spi
                    
                    	Virtual link encryption spi
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: virtual_link_encryption_transmitted
                    
                    	Virtual link encryption transmitted 
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: virtual_link_hello_interval
                    
                    	Hello interval (s)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: virtual_link_interface_number
                    
                    	Virtual link interface number 
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: virtual_link_neighbor
                    
                    	Neighbor information 
                    	**type**\:   :py:class:`VirtualLinkNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.VirtualLink.VirtualLinkNeighbor>`
                    
                    .. attribute:: virtual_link_neighbor_address
                    
                    	Virtual link neighbor addresss 
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: virtual_link_neighbor_id
                    
                    	Neighbor on other end of this virtual link
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: virtual_link_next_hello
                    
                    	Time until next hello (s)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: virtual_link_retransmission_interval
                    
                    	Retransmission interval (s)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: virtual_link_state
                    
                    	OSPF interface state for the virtual link
                    	**type**\:   :py:class:`Ospfv3InterfaceStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3InterfaceStateEnum>`
                    
                    .. attribute:: virtual_link_wait_interval
                    
                    	Wait interval (s)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: virual_link_transmission_delay
                    
                    	Transmission delay in seconds
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'ipv6-ospfv3-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.interface_name = None
                        self.is_virtual_link_authentication_enabled = None
                        self.is_virtual_link_demand_circuit = None
                        self.is_virtual_link_encryption_enabled = None
                        self.is_virtual_link_ip_security_active = None
                        self.is_virtual_link_ip_security_required = None
                        self.is_virtual_link_passive = None
                        self.transit_area_id = None
                        self.virtual_link_authentication_spi = None
                        self.virtual_link_authentication_transmit = None
                        self.virtual_link_cost = None
                        self.virtual_link_dc_bitless_lsa = None
                        self.virtual_link_dead_interval = None
                        self.virtual_link_encrypted_authentication_transmitted = None
                        self.virtual_link_encryption_spi = None
                        self.virtual_link_encryption_transmitted = None
                        self.virtual_link_hello_interval = None
                        self.virtual_link_interface_number = None
                        self.virtual_link_neighbor = Ospfv3.Processes.Process.DefaultVrf.VirtualLink.VirtualLinkNeighbor()
                        self.virtual_link_neighbor.parent = self
                        self.virtual_link_neighbor_address = None
                        self.virtual_link_neighbor_id = None
                        self.virtual_link_next_hello = None
                        self.virtual_link_retransmission_interval = None
                        self.virtual_link_state = None
                        self.virtual_link_wait_interval = None
                        self.virual_link_transmission_delay = None


                    class VirtualLinkNeighbor(object):
                        """
                        Neighbor information 
                        
                        .. attribute:: is_virtual_link_hello_suppressed
                        
                        	If true, hello suppressed 
                        	**type**\:  bool
                        
                        .. attribute:: virtual_link_retransmission
                        
                        	Virtual link retransmission information 
                        	**type**\:   :py:class:`VirtualLinkRetransmission <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.VirtualLink.VirtualLinkNeighbor.VirtualLinkRetransmission>`
                        
                        .. attribute:: virtual_link_state
                        
                        	OSPF interface state for the virtual link
                        	**type**\:   :py:class:`Ospfv3InterfaceStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3InterfaceStateEnum>`
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.is_virtual_link_hello_suppressed = None
                            self.virtual_link_retransmission = Ospfv3.Processes.Process.DefaultVrf.VirtualLink.VirtualLinkNeighbor.VirtualLinkRetransmission()
                            self.virtual_link_retransmission.parent = self
                            self.virtual_link_state = None


                        class VirtualLinkRetransmission(object):
                            """
                            Virtual link retransmission information 
                            
                            .. attribute:: area_first_flood
                            
                            	First flood item for area scope LSAs
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: area_first_flood_index
                            
                            	Index of the first flood item for area scope LSAs
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: area_flood_index
                            
                            	Area scope LSA's flood index
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: area_next_flood
                            
                            	Next flood item for area scope LSAs
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: area_next_flood_index
                            
                            	Index of next flood item for Area scope LSAs
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: as_first_flood
                            
                            	First flood item for AS scope LSAs
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: as_first_flood_index
                            
                            	Index for first flood item for AS scope LSAs
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: as_flood_index
                            
                            	AS scope LSA's flood index
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: as_next_flood
                            
                            	Next flood item for AS scope LSAs
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: as_next_flood_index
                            
                            	Index of next flood item for AS scope LSAs
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: database_descriptor_retransmissions
                            
                            	Number of database descriptor retransmissions during last exchange
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: last_retransmission_length
                            
                            	Number of LSAs sent in last retransmission
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: last_retransmission_time
                            
                            	Last retransmission scan time (ms)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: link_first_flood
                            
                            	Link first flood information 
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: link_first_flood_index
                            
                            	Link first flood information index
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: link_flood_index
                            
                            	Link flood index
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: link_next_flood
                            
                            	Link next flood information 
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: link_next_flood_index
                            
                            	Link next flood information index 
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: lsa_retransmission_timer
                            
                            	Time until next LSA retransmission (ms)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: maximum_retransmission_length
                            
                            	Maximum number of LSAs sent in a retransmission
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: maximum_retransmission_time
                            
                            	Maximum retransmission scan time (ms)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: neighbor_retransmissions
                            
                            	Number of neighbor retransmissions 
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: retransmissions
                            
                            	Number of retransmissions for this neighbor
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.area_first_flood = None
                                self.area_first_flood_index = None
                                self.area_flood_index = None
                                self.area_next_flood = None
                                self.area_next_flood_index = None
                                self.as_first_flood = None
                                self.as_first_flood_index = None
                                self.as_flood_index = None
                                self.as_next_flood = None
                                self.as_next_flood_index = None
                                self.database_descriptor_retransmissions = None
                                self.last_retransmission_length = None
                                self.last_retransmission_time = None
                                self.link_first_flood = None
                                self.link_first_flood_index = None
                                self.link_flood_index = None
                                self.link_next_flood = None
                                self.link_next_flood_index = None
                                self.lsa_retransmission_timer = None
                                self.maximum_retransmission_length = None
                                self.maximum_retransmission_time = None
                                self.neighbor_retransmissions = None
                                self.retransmissions = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:virtual-link-retransmission'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.area_first_flood is not None:
                                    return True

                                if self.area_first_flood_index is not None:
                                    return True

                                if self.area_flood_index is not None:
                                    return True

                                if self.area_next_flood is not None:
                                    return True

                                if self.area_next_flood_index is not None:
                                    return True

                                if self.as_first_flood is not None:
                                    return True

                                if self.as_first_flood_index is not None:
                                    return True

                                if self.as_flood_index is not None:
                                    return True

                                if self.as_next_flood is not None:
                                    return True

                                if self.as_next_flood_index is not None:
                                    return True

                                if self.database_descriptor_retransmissions is not None:
                                    return True

                                if self.last_retransmission_length is not None:
                                    return True

                                if self.last_retransmission_time is not None:
                                    return True

                                if self.link_first_flood is not None:
                                    return True

                                if self.link_first_flood_index is not None:
                                    return True

                                if self.link_flood_index is not None:
                                    return True

                                if self.link_next_flood is not None:
                                    return True

                                if self.link_next_flood_index is not None:
                                    return True

                                if self.lsa_retransmission_timer is not None:
                                    return True

                                if self.maximum_retransmission_length is not None:
                                    return True

                                if self.maximum_retransmission_time is not None:
                                    return True

                                if self.neighbor_retransmissions is not None:
                                    return True

                                if self.retransmissions is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.VirtualLink.VirtualLinkNeighbor.VirtualLinkRetransmission']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:virtual-link-neighbor'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.is_virtual_link_hello_suppressed is not None:
                                return True

                            if self.virtual_link_retransmission is not None and self.virtual_link_retransmission._has_data():
                                return True

                            if self.virtual_link_state is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                            return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.VirtualLink.VirtualLinkNeighbor']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:virtual-link'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.interface_name is not None:
                            return True

                        if self.is_virtual_link_authentication_enabled is not None:
                            return True

                        if self.is_virtual_link_demand_circuit is not None:
                            return True

                        if self.is_virtual_link_encryption_enabled is not None:
                            return True

                        if self.is_virtual_link_ip_security_active is not None:
                            return True

                        if self.is_virtual_link_ip_security_required is not None:
                            return True

                        if self.is_virtual_link_passive is not None:
                            return True

                        if self.transit_area_id is not None:
                            return True

                        if self.virtual_link_authentication_spi is not None:
                            return True

                        if self.virtual_link_authentication_transmit is not None:
                            return True

                        if self.virtual_link_cost is not None:
                            return True

                        if self.virtual_link_dc_bitless_lsa is not None:
                            return True

                        if self.virtual_link_dead_interval is not None:
                            return True

                        if self.virtual_link_encrypted_authentication_transmitted is not None:
                            return True

                        if self.virtual_link_encryption_spi is not None:
                            return True

                        if self.virtual_link_encryption_transmitted is not None:
                            return True

                        if self.virtual_link_hello_interval is not None:
                            return True

                        if self.virtual_link_interface_number is not None:
                            return True

                        if self.virtual_link_neighbor is not None and self.virtual_link_neighbor._has_data():
                            return True

                        if self.virtual_link_neighbor_address is not None:
                            return True

                        if self.virtual_link_neighbor_id is not None:
                            return True

                        if self.virtual_link_next_hello is not None:
                            return True

                        if self.virtual_link_retransmission_interval is not None:
                            return True

                        if self.virtual_link_state is not None:
                            return True

                        if self.virtual_link_wait_interval is not None:
                            return True

                        if self.virual_link_transmission_delay is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                        return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.VirtualLink']['meta_info']


                class FloodListProcessTable(object):
                    """
                    OSPFv3 flood list information table for all
                    areas
                    
                    .. attribute:: flood
                    
                    	OSPFv3 flood list information
                    	**type**\: list of    :py:class:`Flood <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.FloodListProcessTable.Flood>`
                    
                    

                    """

                    _prefix = 'ipv6-ospfv3-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.flood = YList()
                        self.flood.parent = self
                        self.flood.name = 'flood'


                    class Flood(object):
                        """
                        OSPFv3 flood list information
                        
                        .. attribute:: interface_name  <key>
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: area_flood
                        
                        	Area scope floodlist
                        	**type**\: list of    :py:class:`AreaFlood <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.FloodListProcessTable.Flood.AreaFlood>`
                        
                        .. attribute:: as_flood
                        
                        	AS scope floodlist
                        	**type**\: list of    :py:class:`AsFlood <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.FloodListProcessTable.Flood.AsFlood>`
                        
                        .. attribute:: link_flood
                        
                        	Link floodlist
                        	**type**\: list of    :py:class:`LinkFlood <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.FloodListProcessTable.Flood.LinkFlood>`
                        
                        .. attribute:: ls_transmission_timer
                        
                        	Time until next LS transmission (ms) 
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: queue_length
                        
                        	Number of LSAs currently being flooded 
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.interface_name = None
                            self.area_flood = YList()
                            self.area_flood.parent = self
                            self.area_flood.name = 'area_flood'
                            self.as_flood = YList()
                            self.as_flood.parent = self
                            self.as_flood.name = 'as_flood'
                            self.link_flood = YList()
                            self.link_flood.parent = self
                            self.link_flood.name = 'link_flood'
                            self.ls_transmission_timer = None
                            self.queue_length = None


                        class LinkFlood(object):
                            """
                            Link floodlist
                            
                            .. attribute:: header_advertising_router
                            
                            	Router ID of the advertising router
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: header_lsa_age
                            
                            	Age of the LSA (seconds)
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: second
                            
                            .. attribute:: header_lsa_id
                            
                            	LSA ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: header_lsa_type
                            
                            	LSA type
                            	**type**\:   :py:class:`Ospfv3Lsa1Enum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Lsa1Enum>`
                            
                            .. attribute:: header_sequence_number
                            
                            	Current LSA sequence number
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.header_advertising_router = None
                                self.header_lsa_age = None
                                self.header_lsa_id = None
                                self.header_lsa_type = None
                                self.header_sequence_number = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:link-flood'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.header_advertising_router is not None:
                                    return True

                                if self.header_lsa_age is not None:
                                    return True

                                if self.header_lsa_id is not None:
                                    return True

                                if self.header_lsa_type is not None:
                                    return True

                                if self.header_sequence_number is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.FloodListProcessTable.Flood.LinkFlood']['meta_info']


                        class AreaFlood(object):
                            """
                            Area scope floodlist
                            
                            .. attribute:: header_advertising_router
                            
                            	Router ID of the advertising router
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: header_lsa_age
                            
                            	Age of the LSA (seconds)
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: second
                            
                            .. attribute:: header_lsa_id
                            
                            	LSA ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: header_lsa_type
                            
                            	LSA type
                            	**type**\:   :py:class:`Ospfv3Lsa1Enum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Lsa1Enum>`
                            
                            .. attribute:: header_sequence_number
                            
                            	Current LSA sequence number
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.header_advertising_router = None
                                self.header_lsa_age = None
                                self.header_lsa_id = None
                                self.header_lsa_type = None
                                self.header_sequence_number = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:area-flood'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.header_advertising_router is not None:
                                    return True

                                if self.header_lsa_age is not None:
                                    return True

                                if self.header_lsa_id is not None:
                                    return True

                                if self.header_lsa_type is not None:
                                    return True

                                if self.header_sequence_number is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.FloodListProcessTable.Flood.AreaFlood']['meta_info']


                        class AsFlood(object):
                            """
                            AS scope floodlist
                            
                            .. attribute:: header_advertising_router
                            
                            	Router ID of the advertising router
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: header_lsa_age
                            
                            	Age of the LSA (seconds)
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: second
                            
                            .. attribute:: header_lsa_id
                            
                            	LSA ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: header_lsa_type
                            
                            	LSA type
                            	**type**\:   :py:class:`Ospfv3Lsa1Enum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Lsa1Enum>`
                            
                            .. attribute:: header_sequence_number
                            
                            	Current LSA sequence number
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.header_advertising_router = None
                                self.header_lsa_age = None
                                self.header_lsa_id = None
                                self.header_lsa_type = None
                                self.header_sequence_number = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:as-flood'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.header_advertising_router is not None:
                                    return True

                                if self.header_lsa_age is not None:
                                    return True

                                if self.header_lsa_id is not None:
                                    return True

                                if self.header_lsa_type is not None:
                                    return True

                                if self.header_sequence_number is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.FloodListProcessTable.Flood.AsFlood']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')
                            if self.interface_name is None:
                                raise YPYModelError('Key property interface_name is None')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:flood[Cisco-IOS-XR-ipv6-ospfv3-oper:interface-name = ' + str(self.interface_name) + ']'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.interface_name is not None:
                                return True

                            if self.area_flood is not None:
                                for child_ref in self.area_flood:
                                    if child_ref._has_data():
                                        return True

                            if self.as_flood is not None:
                                for child_ref in self.as_flood:
                                    if child_ref._has_data():
                                        return True

                            if self.link_flood is not None:
                                for child_ref in self.link_flood:
                                    if child_ref._has_data():
                                        return True

                            if self.ls_transmission_timer is not None:
                                return True

                            if self.queue_length is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                            return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.FloodListProcessTable.Flood']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:flood-list-process-table'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.flood is not None:
                            for child_ref in self.flood:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                        return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.FloodListProcessTable']['meta_info']


                class RouteSummary(object):
                    """
                    Summarize OSPFv3 local RIB tables
                    
                    .. attribute:: extern_one_route
                    
                    	Extern 1 route summary 
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: extern_two_route
                    
                    	Extern 2 route summary 
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: inter_area_route
                    
                    	Inter route summary 
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: intra_area_route
                    
                    	Intra route summary 
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: nssa_one_route
                    
                    	NSSA 1 route summary 
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: nssa_two_route
                    
                    	NSSA 2 route summary 
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: redistribution_route
                    
                    	Redistribution route summary 
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: route_connected
                    
                    	Route connected 
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: route_id
                    
                    	Route summary of a route ID 
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: total_received_route
                    
                    	Total route received summary
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: total_sent_route
                    
                    	Total route summary 
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv6-ospfv3-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.extern_one_route = None
                        self.extern_two_route = None
                        self.inter_area_route = None
                        self.intra_area_route = None
                        self.nssa_one_route = None
                        self.nssa_two_route = None
                        self.redistribution_route = None
                        self.route_connected = None
                        self.route_id = None
                        self.total_received_route = None
                        self.total_sent_route = None

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:route-summary'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.extern_one_route is not None:
                            return True

                        if self.extern_two_route is not None:
                            return True

                        if self.inter_area_route is not None:
                            return True

                        if self.intra_area_route is not None:
                            return True

                        if self.nssa_one_route is not None:
                            return True

                        if self.nssa_two_route is not None:
                            return True

                        if self.redistribution_route is not None:
                            return True

                        if self.route_connected is not None:
                            return True

                        if self.route_id is not None:
                            return True

                        if self.total_received_route is not None:
                            return True

                        if self.total_sent_route is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                        return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.RouteSummary']['meta_info']


                class Areas(object):
                    """
                    OSPFv3 area table
                    
                    .. attribute:: area
                    
                    	Per\-area information
                    	**type**\: list of    :py:class:`Area <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area>`
                    
                    

                    """

                    _prefix = 'ipv6-ospfv3-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.area = YList()
                        self.area.parent = self
                        self.area.name = 'area'


                    class Area(object):
                        """
                        Per\-area information
                        
                        .. attribute:: area_id  <key>
                        
                        	Area ID
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: database_summary_table
                        
                        	Database summary table
                        	**type**\:   :py:class:`DatabaseSummaryTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseSummaryTable>`
                        
                        .. attribute:: database_table
                        
                        	OSPF Link State Database
                        	**type**\:   :py:class:`DatabaseTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable>`
                        
                        .. attribute:: flood_list_table
                        
                        	OSPFv3 flood list information table for an area
                        	**type**\:   :py:class:`FloodListTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.FloodListTable>`
                        
                        .. attribute:: interface_brief_table
                        
                        	OSPFv3 interface brief information table for an area
                        	**type**\:   :py:class:`InterfaceBriefTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.InterfaceBriefTable>`
                        
                        .. attribute:: interface_table
                        
                        	OSPFv3 interface information table for an area
                        	**type**\:   :py:class:`InterfaceTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.InterfaceTable>`
                        
                        .. attribute:: neighbor_detail_table
                        
                        	OSPFv3 area neighbor information table
                        	**type**\:   :py:class:`NeighborDetailTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.NeighborDetailTable>`
                        
                        .. attribute:: neighbor_table
                        
                        	OSPFv3 neighbor information table
                        	**type**\:   :py:class:`NeighborTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.NeighborTable>`
                        
                        .. attribute:: request_list_table
                        
                        	OSPFv3 request list information in an area
                        	**type**\:   :py:class:`RequestListTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.RequestListTable>`
                        
                        .. attribute:: retransmission_list_table
                        
                        	OSPFv3 retransmission list information table in an area
                        	**type**\:   :py:class:`RetransmissionListTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.RetransmissionListTable>`
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.area_id = None
                            self.database_summary_table = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseSummaryTable()
                            self.database_summary_table.parent = self
                            self.database_table = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable()
                            self.database_table.parent = self
                            self.flood_list_table = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.FloodListTable()
                            self.flood_list_table.parent = self
                            self.interface_brief_table = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.InterfaceBriefTable()
                            self.interface_brief_table.parent = self
                            self.interface_table = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.InterfaceTable()
                            self.interface_table.parent = self
                            self.neighbor_detail_table = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.NeighborDetailTable()
                            self.neighbor_detail_table.parent = self
                            self.neighbor_table = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.NeighborTable()
                            self.neighbor_table.parent = self
                            self.request_list_table = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.RequestListTable()
                            self.request_list_table.parent = self
                            self.retransmission_list_table = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.RetransmissionListTable()
                            self.retransmission_list_table.parent = self


                        class NeighborDetailTable(object):
                            """
                            OSPFv3 area neighbor information table
                            
                            .. attribute:: neighbor_detail
                            
                            	OSPFv3 neighbor detail information
                            	**type**\: list of    :py:class:`NeighborDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.NeighborDetailTable.NeighborDetail>`
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.neighbor_detail = YList()
                                self.neighbor_detail.parent = self
                                self.neighbor_detail.name = 'neighbor_detail'


                            class NeighborDetail(object):
                                """
                                OSPFv3 neighbor detail information
                                
                                .. attribute:: interface_name
                                
                                	Interface name
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: is_neighbor_sham_link
                                
                                	If true, neighbor is on a sham link 
                                	**type**\:  bool
                                
                                .. attribute:: is_neighbor_virtual_link
                                
                                	If true, neighbor is on a virtual link 
                                	**type**\:  bool
                                
                                .. attribute:: neighbor_address
                                
                                	Neighbor ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: neighbor_address_xr
                                
                                	Neighbor IP Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: neighbor_bfd_info
                                
                                	Neighbor BFD information
                                	**type**\:   :py:class:`NeighborBfdInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.NeighborDetailTable.NeighborDetail.NeighborBfdInfo>`
                                
                                .. attribute:: neighbor_dead_timer
                                
                                	Time until neighbor's dead timer expires (seconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: neighbor_designated_router
                                
                                	Designated router 
                                	**type**\:  str
                                
                                	**length:** 0..9
                                
                                .. attribute:: neighbor_detail
                                
                                	Detailed OSPFv3 neighbor information 
                                	**type**\:   :py:class:`NeighborDetail_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.NeighborDetailTable.NeighborDetail.NeighborDetail_>`
                                
                                .. attribute:: neighbor_dr_priority
                                
                                	Neighbor's DR priority
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: neighbor_interface_id
                                
                                	Neighbor interface ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: neighbor_sham_link_id
                                
                                	Neighbor sham link id 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: neighbor_state
                                
                                	Neighbor's state
                                	**type**\:   :py:class:`Ospfv3NeighborStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3NeighborStateEnum>`
                                
                                .. attribute:: neighbor_up_time
                                
                                	Amount of time since the adjacency is up (seconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: neighbor_virtual_link_id
                                
                                	Neighbor virtual link id 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.interface_name = None
                                    self.is_neighbor_sham_link = None
                                    self.is_neighbor_virtual_link = None
                                    self.neighbor_address = None
                                    self.neighbor_address_xr = None
                                    self.neighbor_bfd_info = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.NeighborDetailTable.NeighborDetail.NeighborBfdInfo()
                                    self.neighbor_bfd_info.parent = self
                                    self.neighbor_dead_timer = None
                                    self.neighbor_designated_router = None
                                    self.neighbor_detail = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.NeighborDetailTable.NeighborDetail.NeighborDetail_()
                                    self.neighbor_detail.parent = self
                                    self.neighbor_dr_priority = None
                                    self.neighbor_interface_id = None
                                    self.neighbor_sham_link_id = None
                                    self.neighbor_state = None
                                    self.neighbor_up_time = None
                                    self.neighbor_virtual_link_id = None


                                class NeighborDetail_(object):
                                    """
                                    Detailed OSPFv3 neighbor information 
                                    
                                    .. attribute:: interface_type
                                    
                                    	Interface type
                                    	**type**\:   :py:class:`Ospfv3InterfaceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3InterfaceEnum>`
                                    
                                    .. attribute:: is_neighbor_filtered
                                    
                                    	If true, filter outgoing LSAs 
                                    	**type**\:  bool
                                    
                                    .. attribute:: neighbor_backup_designated_router_address
                                    
                                    	Address of backup designated router
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: neighbor_cost
                                    
                                    	Cost of path to this neighbor 
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: neighbor_designated_router_address
                                    
                                    	Address of designated router
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: neighbor_ignore_timer
                                    
                                    	Remaining time when ignore timer is running 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: neighbor_option
                                    
                                    	 This is bitmask of neighbor's option field received 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: neighbor_retransmission
                                    
                                    	Retransmission information with this neighbor
                                    	**type**\:   :py:class:`NeighborRetransmission <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.NeighborDetailTable.NeighborDetail.NeighborDetail_.NeighborRetransmission>`
                                    
                                    .. attribute:: next_poll_interval
                                    
                                    	For NBMA networks, amount of time remaining in seconds before the next poll interval expires and Hello is sent (s)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: pending_events
                                    
                                    	Number of pending events 
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: poll_interval
                                    
                                    	Poll interval (s)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: state_changes
                                    
                                    	Number of state changes 
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.interface_type = None
                                        self.is_neighbor_filtered = None
                                        self.neighbor_backup_designated_router_address = None
                                        self.neighbor_cost = None
                                        self.neighbor_designated_router_address = None
                                        self.neighbor_ignore_timer = None
                                        self.neighbor_option = None
                                        self.neighbor_retransmission = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.NeighborDetailTable.NeighborDetail.NeighborDetail_.NeighborRetransmission()
                                        self.neighbor_retransmission.parent = self
                                        self.next_poll_interval = None
                                        self.pending_events = None
                                        self.poll_interval = None
                                        self.state_changes = None


                                    class NeighborRetransmission(object):
                                        """
                                        Retransmission information with this neighbor
                                        
                                        .. attribute:: area_first_flood
                                        
                                        	First flood item for area scope LSAs
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: area_first_flood_index
                                        
                                        	Index of the first flood item for area scope LSAs
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: area_flood_index
                                        
                                        	Area scope LSA's flood index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: area_next_flood
                                        
                                        	Next flood item for area scope LSAs
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: area_next_flood_index
                                        
                                        	Index of next flood item for Area scope LSAs
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: as_first_flood
                                        
                                        	First flood item for AS scope LSAs
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: as_first_flood_index
                                        
                                        	Index for first flood item for AS scope LSAs
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: as_flood_index
                                        
                                        	AS scope LSA's flood index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: as_next_flood
                                        
                                        	Next flood item for AS scope LSAs
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: as_next_flood_index
                                        
                                        	Index of next flood item for AS scope LSAs
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: database_descriptor_retransmissions
                                        
                                        	Number of database descriptor retransmissions during last exchange
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_retransmission_length
                                        
                                        	Number of LSAs sent in last retransmission
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_retransmission_time
                                        
                                        	Last retransmission scan time (ms)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: link_first_flood
                                        
                                        	Link first flood information 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: link_first_flood_index
                                        
                                        	Link first flood information index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: link_flood_index
                                        
                                        	Link flood index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: link_next_flood
                                        
                                        	Link next flood information 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: link_next_flood_index
                                        
                                        	Link next flood information index 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: lsa_retransmission_timer
                                        
                                        	Time until next LSA retransmission (ms)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: maximum_retransmission_length
                                        
                                        	Maximum number of LSAs sent in a retransmission
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: maximum_retransmission_time
                                        
                                        	Maximum retransmission scan time (ms)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: neighbor_retransmissions
                                        
                                        	Number of neighbor retransmissions 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: retransmissions
                                        
                                        	Number of retransmissions for this neighbor
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.area_first_flood = None
                                            self.area_first_flood_index = None
                                            self.area_flood_index = None
                                            self.area_next_flood = None
                                            self.area_next_flood_index = None
                                            self.as_first_flood = None
                                            self.as_first_flood_index = None
                                            self.as_flood_index = None
                                            self.as_next_flood = None
                                            self.as_next_flood_index = None
                                            self.database_descriptor_retransmissions = None
                                            self.last_retransmission_length = None
                                            self.last_retransmission_time = None
                                            self.link_first_flood = None
                                            self.link_first_flood_index = None
                                            self.link_flood_index = None
                                            self.link_next_flood = None
                                            self.link_next_flood_index = None
                                            self.lsa_retransmission_timer = None
                                            self.maximum_retransmission_length = None
                                            self.maximum_retransmission_time = None
                                            self.neighbor_retransmissions = None
                                            self.retransmissions = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:neighbor-retransmission'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.area_first_flood is not None:
                                                return True

                                            if self.area_first_flood_index is not None:
                                                return True

                                            if self.area_flood_index is not None:
                                                return True

                                            if self.area_next_flood is not None:
                                                return True

                                            if self.area_next_flood_index is not None:
                                                return True

                                            if self.as_first_flood is not None:
                                                return True

                                            if self.as_first_flood_index is not None:
                                                return True

                                            if self.as_flood_index is not None:
                                                return True

                                            if self.as_next_flood is not None:
                                                return True

                                            if self.as_next_flood_index is not None:
                                                return True

                                            if self.database_descriptor_retransmissions is not None:
                                                return True

                                            if self.last_retransmission_length is not None:
                                                return True

                                            if self.last_retransmission_time is not None:
                                                return True

                                            if self.link_first_flood is not None:
                                                return True

                                            if self.link_first_flood_index is not None:
                                                return True

                                            if self.link_flood_index is not None:
                                                return True

                                            if self.link_next_flood is not None:
                                                return True

                                            if self.link_next_flood_index is not None:
                                                return True

                                            if self.lsa_retransmission_timer is not None:
                                                return True

                                            if self.maximum_retransmission_length is not None:
                                                return True

                                            if self.maximum_retransmission_time is not None:
                                                return True

                                            if self.neighbor_retransmissions is not None:
                                                return True

                                            if self.retransmissions is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Areas.Area.NeighborDetailTable.NeighborDetail.NeighborDetail_.NeighborRetransmission']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:neighbor-detail'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.interface_type is not None:
                                            return True

                                        if self.is_neighbor_filtered is not None:
                                            return True

                                        if self.neighbor_backup_designated_router_address is not None:
                                            return True

                                        if self.neighbor_cost is not None:
                                            return True

                                        if self.neighbor_designated_router_address is not None:
                                            return True

                                        if self.neighbor_ignore_timer is not None:
                                            return True

                                        if self.neighbor_option is not None:
                                            return True

                                        if self.neighbor_retransmission is not None and self.neighbor_retransmission._has_data():
                                            return True

                                        if self.next_poll_interval is not None:
                                            return True

                                        if self.pending_events is not None:
                                            return True

                                        if self.poll_interval is not None:
                                            return True

                                        if self.state_changes is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                        return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Areas.Area.NeighborDetailTable.NeighborDetail.NeighborDetail_']['meta_info']


                                class NeighborBfdInfo(object):
                                    """
                                    Neighbor BFD information
                                    
                                    .. attribute:: bfd_intf_enable_mode
                                    
                                    	BFD enable mode \- Default/Strict
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bfd_status_flag
                                    
                                    	Status of the BFD Session
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.bfd_intf_enable_mode = None
                                        self.bfd_status_flag = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:neighbor-bfd-info'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bfd_intf_enable_mode is not None:
                                            return True

                                        if self.bfd_status_flag is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                        return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Areas.Area.NeighborDetailTable.NeighborDetail.NeighborBfdInfo']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:neighbor-detail'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.interface_name is not None:
                                        return True

                                    if self.is_neighbor_sham_link is not None:
                                        return True

                                    if self.is_neighbor_virtual_link is not None:
                                        return True

                                    if self.neighbor_address is not None:
                                        return True

                                    if self.neighbor_address_xr is not None:
                                        return True

                                    if self.neighbor_bfd_info is not None and self.neighbor_bfd_info._has_data():
                                        return True

                                    if self.neighbor_dead_timer is not None:
                                        return True

                                    if self.neighbor_designated_router is not None:
                                        return True

                                    if self.neighbor_detail is not None and self.neighbor_detail._has_data():
                                        return True

                                    if self.neighbor_dr_priority is not None:
                                        return True

                                    if self.neighbor_interface_id is not None:
                                        return True

                                    if self.neighbor_sham_link_id is not None:
                                        return True

                                    if self.neighbor_state is not None:
                                        return True

                                    if self.neighbor_up_time is not None:
                                        return True

                                    if self.neighbor_virtual_link_id is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                    return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Areas.Area.NeighborDetailTable.NeighborDetail']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:neighbor-detail-table'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.neighbor_detail is not None:
                                    for child_ref in self.neighbor_detail:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Areas.Area.NeighborDetailTable']['meta_info']


                        class InterfaceBriefTable(object):
                            """
                            OSPFv3 interface brief information table for
                            an area
                            
                            .. attribute:: interface_brief
                            
                            	Interface brief information
                            	**type**\: list of    :py:class:`InterfaceBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.InterfaceBriefTable.InterfaceBrief>`
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.interface_brief = YList()
                                self.interface_brief.parent = self
                                self.interface_brief.name = 'interface_brief'


                            class InterfaceBrief(object):
                                """
                                Interface brief information
                                
                                .. attribute:: interface_name  <key>
                                
                                	Interface name
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: interface_address
                                
                                	Interface IP address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: interface_adjacent_neighbors
                                
                                	Total number of adjacent neighbors
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: interface_link_cost
                                
                                	Interface link cost
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: interface_neighbors
                                
                                	Total number of neighbors 
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: network_type
                                
                                	Network type
                                	**type**\:   :py:class:`Ospfv3InterfaceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3InterfaceEnum>`
                                
                                .. attribute:: ospf_interface_state
                                
                                	Interface OSPF state
                                	**type**\:   :py:class:`Ospfv3InterfaceStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3InterfaceStateEnum>`
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.interface_name = None
                                    self.interface_address = None
                                    self.interface_adjacent_neighbors = None
                                    self.interface_link_cost = None
                                    self.interface_neighbors = None
                                    self.network_type = None
                                    self.ospf_interface_state = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')
                                    if self.interface_name is None:
                                        raise YPYModelError('Key property interface_name is None')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:interface-brief[Cisco-IOS-XR-ipv6-ospfv3-oper:interface-name = ' + str(self.interface_name) + ']'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.interface_name is not None:
                                        return True

                                    if self.interface_address is not None:
                                        return True

                                    if self.interface_adjacent_neighbors is not None:
                                        return True

                                    if self.interface_link_cost is not None:
                                        return True

                                    if self.interface_neighbors is not None:
                                        return True

                                    if self.network_type is not None:
                                        return True

                                    if self.ospf_interface_state is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                    return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Areas.Area.InterfaceBriefTable.InterfaceBrief']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:interface-brief-table'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.interface_brief is not None:
                                    for child_ref in self.interface_brief:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Areas.Area.InterfaceBriefTable']['meta_info']


                        class RequestListTable(object):
                            """
                            OSPFv3 request list information in an area
                            
                            .. attribute:: request
                            
                            	OSPFv3 request list information
                            	**type**\: list of    :py:class:`Request <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.RequestListTable.Request>`
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.request = YList()
                                self.request.parent = self
                                self.request.name = 'request'


                            class Request(object):
                                """
                                OSPFv3 request list information
                                
                                .. attribute:: interface_name
                                
                                	Interface name
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: is_request_sham_link
                                
                                	If true, sham link is requested 
                                	**type**\:  bool
                                
                                .. attribute:: is_request_virtual_link
                                
                                	If true, virtual link is requested 
                                	**type**\:  bool
                                
                                .. attribute:: neighbor_address
                                
                                	Neighbor address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: request
                                
                                	List of request list entries
                                	**type**\: list of    :py:class:`Request_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.RequestListTable.Request.Request_>`
                                
                                .. attribute:: request_neighbor_address
                                
                                	Neighbor IP address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: request_sham_link_id
                                
                                	Request sham link ID 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: request_virtual_link_id
                                
                                	Request virtual link ID 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.interface_name = None
                                    self.is_request_sham_link = None
                                    self.is_request_virtual_link = None
                                    self.neighbor_address = None
                                    self.request = YList()
                                    self.request.parent = self
                                    self.request.name = 'request'
                                    self.request_neighbor_address = None
                                    self.request_sham_link_id = None
                                    self.request_virtual_link_id = None


                                class Request_(object):
                                    """
                                    List of request list entries
                                    
                                    .. attribute:: header_advertising_router
                                    
                                    	Router ID of the advertising router
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: header_lsa_age
                                    
                                    	Age of the LSA (seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: header_lsa_id
                                    
                                    	LSA ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: header_lsa_type
                                    
                                    	LSA type
                                    	**type**\:   :py:class:`Ospfv3Lsa1Enum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Lsa1Enum>`
                                    
                                    .. attribute:: header_sequence_number
                                    
                                    	Current LSA sequence number
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.header_advertising_router = None
                                        self.header_lsa_age = None
                                        self.header_lsa_id = None
                                        self.header_lsa_type = None
                                        self.header_sequence_number = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:request'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.header_advertising_router is not None:
                                            return True

                                        if self.header_lsa_age is not None:
                                            return True

                                        if self.header_lsa_id is not None:
                                            return True

                                        if self.header_lsa_type is not None:
                                            return True

                                        if self.header_sequence_number is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                        return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Areas.Area.RequestListTable.Request.Request_']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:request'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.interface_name is not None:
                                        return True

                                    if self.is_request_sham_link is not None:
                                        return True

                                    if self.is_request_virtual_link is not None:
                                        return True

                                    if self.neighbor_address is not None:
                                        return True

                                    if self.request is not None:
                                        for child_ref in self.request:
                                            if child_ref._has_data():
                                                return True

                                    if self.request_neighbor_address is not None:
                                        return True

                                    if self.request_sham_link_id is not None:
                                        return True

                                    if self.request_virtual_link_id is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                    return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Areas.Area.RequestListTable.Request']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:request-list-table'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.request is not None:
                                    for child_ref in self.request:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Areas.Area.RequestListTable']['meta_info']


                        class NeighborTable(object):
                            """
                            OSPFv3 neighbor information table
                            
                            .. attribute:: neighbor
                            
                            	OSPFv3 neighbor detail information
                            	**type**\: list of    :py:class:`Neighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.NeighborTable.Neighbor>`
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.neighbor = YList()
                                self.neighbor.parent = self
                                self.neighbor.name = 'neighbor'


                            class Neighbor(object):
                                """
                                OSPFv3 neighbor detail information
                                
                                .. attribute:: interface_name
                                
                                	Interface name
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: is_neighbor_sham_link
                                
                                	If true, neighbor is on a sham link 
                                	**type**\:  bool
                                
                                .. attribute:: is_neighbor_virtual_link
                                
                                	If true, neighbor is on a virtual link 
                                	**type**\:  bool
                                
                                .. attribute:: neighbor_address
                                
                                	Neighbor ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: neighbor_address_xr
                                
                                	Neighbor IP Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: neighbor_bfd_info
                                
                                	Neighbor BFD information
                                	**type**\:   :py:class:`NeighborBfdInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.NeighborTable.Neighbor.NeighborBfdInfo>`
                                
                                .. attribute:: neighbor_dead_timer
                                
                                	Time until neighbor's dead timer expires (seconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: neighbor_designated_router
                                
                                	Designated router 
                                	**type**\:  str
                                
                                	**length:** 0..9
                                
                                .. attribute:: neighbor_detail
                                
                                	Detailed OSPFv3 neighbor information 
                                	**type**\:   :py:class:`NeighborDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.NeighborTable.Neighbor.NeighborDetail>`
                                
                                .. attribute:: neighbor_dr_priority
                                
                                	Neighbor's DR priority
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: neighbor_interface_id
                                
                                	Neighbor interface ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: neighbor_sham_link_id
                                
                                	Neighbor sham link id 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: neighbor_state
                                
                                	Neighbor's state
                                	**type**\:   :py:class:`Ospfv3NeighborStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3NeighborStateEnum>`
                                
                                .. attribute:: neighbor_up_time
                                
                                	Amount of time since the adjacency is up (seconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: neighbor_virtual_link_id
                                
                                	Neighbor virtual link id 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.interface_name = None
                                    self.is_neighbor_sham_link = None
                                    self.is_neighbor_virtual_link = None
                                    self.neighbor_address = None
                                    self.neighbor_address_xr = None
                                    self.neighbor_bfd_info = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.NeighborTable.Neighbor.NeighborBfdInfo()
                                    self.neighbor_bfd_info.parent = self
                                    self.neighbor_dead_timer = None
                                    self.neighbor_designated_router = None
                                    self.neighbor_detail = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.NeighborTable.Neighbor.NeighborDetail()
                                    self.neighbor_detail.parent = self
                                    self.neighbor_dr_priority = None
                                    self.neighbor_interface_id = None
                                    self.neighbor_sham_link_id = None
                                    self.neighbor_state = None
                                    self.neighbor_up_time = None
                                    self.neighbor_virtual_link_id = None


                                class NeighborDetail(object):
                                    """
                                    Detailed OSPFv3 neighbor information 
                                    
                                    .. attribute:: interface_type
                                    
                                    	Interface type
                                    	**type**\:   :py:class:`Ospfv3InterfaceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3InterfaceEnum>`
                                    
                                    .. attribute:: is_neighbor_filtered
                                    
                                    	If true, filter outgoing LSAs 
                                    	**type**\:  bool
                                    
                                    .. attribute:: neighbor_backup_designated_router_address
                                    
                                    	Address of backup designated router
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: neighbor_cost
                                    
                                    	Cost of path to this neighbor 
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: neighbor_designated_router_address
                                    
                                    	Address of designated router
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: neighbor_ignore_timer
                                    
                                    	Remaining time when ignore timer is running 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: neighbor_option
                                    
                                    	 This is bitmask of neighbor's option field received 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: neighbor_retransmission
                                    
                                    	Retransmission information with this neighbor
                                    	**type**\:   :py:class:`NeighborRetransmission <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.NeighborTable.Neighbor.NeighborDetail.NeighborRetransmission>`
                                    
                                    .. attribute:: next_poll_interval
                                    
                                    	For NBMA networks, amount of time remaining in seconds before the next poll interval expires and Hello is sent (s)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: pending_events
                                    
                                    	Number of pending events 
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: poll_interval
                                    
                                    	Poll interval (s)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: state_changes
                                    
                                    	Number of state changes 
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.interface_type = None
                                        self.is_neighbor_filtered = None
                                        self.neighbor_backup_designated_router_address = None
                                        self.neighbor_cost = None
                                        self.neighbor_designated_router_address = None
                                        self.neighbor_ignore_timer = None
                                        self.neighbor_option = None
                                        self.neighbor_retransmission = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.NeighborTable.Neighbor.NeighborDetail.NeighborRetransmission()
                                        self.neighbor_retransmission.parent = self
                                        self.next_poll_interval = None
                                        self.pending_events = None
                                        self.poll_interval = None
                                        self.state_changes = None


                                    class NeighborRetransmission(object):
                                        """
                                        Retransmission information with this neighbor
                                        
                                        .. attribute:: area_first_flood
                                        
                                        	First flood item for area scope LSAs
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: area_first_flood_index
                                        
                                        	Index of the first flood item for area scope LSAs
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: area_flood_index
                                        
                                        	Area scope LSA's flood index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: area_next_flood
                                        
                                        	Next flood item for area scope LSAs
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: area_next_flood_index
                                        
                                        	Index of next flood item for Area scope LSAs
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: as_first_flood
                                        
                                        	First flood item for AS scope LSAs
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: as_first_flood_index
                                        
                                        	Index for first flood item for AS scope LSAs
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: as_flood_index
                                        
                                        	AS scope LSA's flood index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: as_next_flood
                                        
                                        	Next flood item for AS scope LSAs
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: as_next_flood_index
                                        
                                        	Index of next flood item for AS scope LSAs
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: database_descriptor_retransmissions
                                        
                                        	Number of database descriptor retransmissions during last exchange
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_retransmission_length
                                        
                                        	Number of LSAs sent in last retransmission
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_retransmission_time
                                        
                                        	Last retransmission scan time (ms)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: link_first_flood
                                        
                                        	Link first flood information 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: link_first_flood_index
                                        
                                        	Link first flood information index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: link_flood_index
                                        
                                        	Link flood index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: link_next_flood
                                        
                                        	Link next flood information 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: link_next_flood_index
                                        
                                        	Link next flood information index 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: lsa_retransmission_timer
                                        
                                        	Time until next LSA retransmission (ms)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: maximum_retransmission_length
                                        
                                        	Maximum number of LSAs sent in a retransmission
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: maximum_retransmission_time
                                        
                                        	Maximum retransmission scan time (ms)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: neighbor_retransmissions
                                        
                                        	Number of neighbor retransmissions 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: retransmissions
                                        
                                        	Number of retransmissions for this neighbor
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.area_first_flood = None
                                            self.area_first_flood_index = None
                                            self.area_flood_index = None
                                            self.area_next_flood = None
                                            self.area_next_flood_index = None
                                            self.as_first_flood = None
                                            self.as_first_flood_index = None
                                            self.as_flood_index = None
                                            self.as_next_flood = None
                                            self.as_next_flood_index = None
                                            self.database_descriptor_retransmissions = None
                                            self.last_retransmission_length = None
                                            self.last_retransmission_time = None
                                            self.link_first_flood = None
                                            self.link_first_flood_index = None
                                            self.link_flood_index = None
                                            self.link_next_flood = None
                                            self.link_next_flood_index = None
                                            self.lsa_retransmission_timer = None
                                            self.maximum_retransmission_length = None
                                            self.maximum_retransmission_time = None
                                            self.neighbor_retransmissions = None
                                            self.retransmissions = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:neighbor-retransmission'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.area_first_flood is not None:
                                                return True

                                            if self.area_first_flood_index is not None:
                                                return True

                                            if self.area_flood_index is not None:
                                                return True

                                            if self.area_next_flood is not None:
                                                return True

                                            if self.area_next_flood_index is not None:
                                                return True

                                            if self.as_first_flood is not None:
                                                return True

                                            if self.as_first_flood_index is not None:
                                                return True

                                            if self.as_flood_index is not None:
                                                return True

                                            if self.as_next_flood is not None:
                                                return True

                                            if self.as_next_flood_index is not None:
                                                return True

                                            if self.database_descriptor_retransmissions is not None:
                                                return True

                                            if self.last_retransmission_length is not None:
                                                return True

                                            if self.last_retransmission_time is not None:
                                                return True

                                            if self.link_first_flood is not None:
                                                return True

                                            if self.link_first_flood_index is not None:
                                                return True

                                            if self.link_flood_index is not None:
                                                return True

                                            if self.link_next_flood is not None:
                                                return True

                                            if self.link_next_flood_index is not None:
                                                return True

                                            if self.lsa_retransmission_timer is not None:
                                                return True

                                            if self.maximum_retransmission_length is not None:
                                                return True

                                            if self.maximum_retransmission_time is not None:
                                                return True

                                            if self.neighbor_retransmissions is not None:
                                                return True

                                            if self.retransmissions is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Areas.Area.NeighborTable.Neighbor.NeighborDetail.NeighborRetransmission']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:neighbor-detail'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.interface_type is not None:
                                            return True

                                        if self.is_neighbor_filtered is not None:
                                            return True

                                        if self.neighbor_backup_designated_router_address is not None:
                                            return True

                                        if self.neighbor_cost is not None:
                                            return True

                                        if self.neighbor_designated_router_address is not None:
                                            return True

                                        if self.neighbor_ignore_timer is not None:
                                            return True

                                        if self.neighbor_option is not None:
                                            return True

                                        if self.neighbor_retransmission is not None and self.neighbor_retransmission._has_data():
                                            return True

                                        if self.next_poll_interval is not None:
                                            return True

                                        if self.pending_events is not None:
                                            return True

                                        if self.poll_interval is not None:
                                            return True

                                        if self.state_changes is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                        return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Areas.Area.NeighborTable.Neighbor.NeighborDetail']['meta_info']


                                class NeighborBfdInfo(object):
                                    """
                                    Neighbor BFD information
                                    
                                    .. attribute:: bfd_intf_enable_mode
                                    
                                    	BFD enable mode \- Default/Strict
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bfd_status_flag
                                    
                                    	Status of the BFD Session
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.bfd_intf_enable_mode = None
                                        self.bfd_status_flag = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:neighbor-bfd-info'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bfd_intf_enable_mode is not None:
                                            return True

                                        if self.bfd_status_flag is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                        return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Areas.Area.NeighborTable.Neighbor.NeighborBfdInfo']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:neighbor'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.interface_name is not None:
                                        return True

                                    if self.is_neighbor_sham_link is not None:
                                        return True

                                    if self.is_neighbor_virtual_link is not None:
                                        return True

                                    if self.neighbor_address is not None:
                                        return True

                                    if self.neighbor_address_xr is not None:
                                        return True

                                    if self.neighbor_bfd_info is not None and self.neighbor_bfd_info._has_data():
                                        return True

                                    if self.neighbor_dead_timer is not None:
                                        return True

                                    if self.neighbor_designated_router is not None:
                                        return True

                                    if self.neighbor_detail is not None and self.neighbor_detail._has_data():
                                        return True

                                    if self.neighbor_dr_priority is not None:
                                        return True

                                    if self.neighbor_interface_id is not None:
                                        return True

                                    if self.neighbor_sham_link_id is not None:
                                        return True

                                    if self.neighbor_state is not None:
                                        return True

                                    if self.neighbor_up_time is not None:
                                        return True

                                    if self.neighbor_virtual_link_id is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                    return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Areas.Area.NeighborTable.Neighbor']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:neighbor-table'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.neighbor is not None:
                                    for child_ref in self.neighbor:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Areas.Area.NeighborTable']['meta_info']


                        class InterfaceTable(object):
                            """
                            OSPFv3 interface information table for an area
                            
                            .. attribute:: interface
                            
                            	OSPFv3 interface information
                            	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.InterfaceTable.Interface>`
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.interface = YList()
                                self.interface.parent = self
                                self.interface.name = 'interface'


                            class Interface(object):
                                """
                                OSPFv3 interface information
                                
                                .. attribute:: interface_name  <key>
                                
                                	Interface name
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: active_interface
                                
                                	Active interface details 
                                	**type**\:   :py:class:`ActiveInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.InterfaceTable.Interface.ActiveInterface>`
                                
                                .. attribute:: adjacent_neighbor
                                
                                	Number of adjacent neighbors
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: backup_designated_router_address
                                
                                	Backup designated router interface address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: backup_designated_router_id
                                
                                	Backup designated router ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: configured_ldp_sync
                                
                                	If true, configured as LDP sync
                                	**type**\:  bool
                                
                                .. attribute:: dead_interval
                                
                                	Configured dead interval (s) 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: designated_router_address
                                
                                	Designated router interface address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: designated_router_id
                                
                                	Designated router ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: hello_interval
                                
                                	Configured hello interval (s)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interface_address
                                
                                	Interface IPv6 address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: interface_authentication_spi
                                
                                	Interface authentication spi 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interface_authentication_transmit
                                
                                	Interface authentication transmit 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interface_bfd
                                
                                	BFD information 
                                	**type**\:   :py:class:`InterfaceBfd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.InterfaceTable.Interface.InterfaceBfd>`
                                
                                .. attribute:: interface_dc_bitless_ls_as
                                
                                	Number of LSAs with demand circuit bit not set for the area in which the interface is running
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interface_encrypted_authentication_transmitted
                                
                                	Interface encrypted authentication transmitted 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interface_encryption_spi
                                
                                	Interface encryption spi
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interface_encryption_transmitted
                                
                                	Interface encryption transmitted 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interface_ldp_sync
                                
                                	If true, interface LDP sync is achieved
                                	**type**\:  bool
                                
                                .. attribute:: interface_link_cost
                                
                                	Interface link cost
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: interface_neighbor
                                
                                	Information for neighbors on the interface
                                	**type**\: list of    :py:class:`InterfaceNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.InterfaceTable.Interface.InterfaceNeighbor>`
                                
                                .. attribute:: interface_number
                                
                                	Interface number 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interface_priority
                                
                                	Interface priority
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: interface_references
                                
                                	Interface reference count 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interface_retransmission_interval
                                
                                	Configured retransmit interval (s) 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interface_router_id
                                
                                	Interface router ID 
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: interface_state
                                
                                	Interface state
                                	**type**\:   :py:class:`ImStateEnumEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.ImStateEnumEnum>`
                                
                                .. attribute:: is_demand_circuit_configured
                                
                                	If true, configured as demand circuit 
                                	**type**\:  bool
                                
                                .. attribute:: is_designated_router
                                
                                	If true, designated router
                                	**type**\:  bool
                                
                                .. attribute:: is_interface_demand_circuit
                                
                                	If true, interface running as demand circuit
                                	**type**\:  bool
                                
                                .. attribute:: is_interface_encryption_enabled
                                
                                	If true, interface encryption is enabled 
                                	**type**\:  bool
                                
                                .. attribute:: is_interface_flood_reduction
                                
                                	If true, interface flood reduction is active 
                                	**type**\:  bool
                                
                                .. attribute:: is_interface_ip_security_active
                                
                                	If true, interface IP security is active 
                                	**type**\:  bool
                                
                                .. attribute:: is_interface_ip_security_required
                                
                                	If true, interface IP security is required 
                                	**type**\:  bool
                                
                                .. attribute:: is_interface_line_up
                                
                                	If true, line protocol is up 
                                	**type**\:  bool
                                
                                .. attribute:: is_interface_lsa_filtered
                                
                                	Filter is configured for out going LSAs 
                                	**type**\:  bool
                                
                                .. attribute:: is_prefix_suppress
                                
                                	If true prefix suppression is enabled
                                	**type**\:  bool
                                
                                .. attribute:: network_lsa_flush_timer
                                
                                	The amount of time in seconds before flush timer for old network LSA expires 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: network_type
                                
                                	Network type
                                	**type**\:   :py:class:`Ospfv3InterfaceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3InterfaceEnum>`
                                
                                .. attribute:: next_hello_time
                                
                                	Time until next Hello (s) 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ospf_interface_state
                                
                                	Interface state
                                	**type**\:   :py:class:`Ospfv3InterfaceStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3InterfaceStateEnum>`
                                
                                .. attribute:: transmission_delay
                                
                                	Interface transmission delay (sec)
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: wait_interval
                                
                                	Configured wait interval (s) 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.interface_name = None
                                    self.active_interface = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.InterfaceTable.Interface.ActiveInterface()
                                    self.active_interface.parent = self
                                    self.adjacent_neighbor = None
                                    self.backup_designated_router_address = None
                                    self.backup_designated_router_id = None
                                    self.configured_ldp_sync = None
                                    self.dead_interval = None
                                    self.designated_router_address = None
                                    self.designated_router_id = None
                                    self.hello_interval = None
                                    self.interface_address = None
                                    self.interface_authentication_spi = None
                                    self.interface_authentication_transmit = None
                                    self.interface_bfd = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.InterfaceTable.Interface.InterfaceBfd()
                                    self.interface_bfd.parent = self
                                    self.interface_dc_bitless_ls_as = None
                                    self.interface_encrypted_authentication_transmitted = None
                                    self.interface_encryption_spi = None
                                    self.interface_encryption_transmitted = None
                                    self.interface_ldp_sync = None
                                    self.interface_link_cost = None
                                    self.interface_neighbor = YList()
                                    self.interface_neighbor.parent = self
                                    self.interface_neighbor.name = 'interface_neighbor'
                                    self.interface_number = None
                                    self.interface_priority = None
                                    self.interface_references = None
                                    self.interface_retransmission_interval = None
                                    self.interface_router_id = None
                                    self.interface_state = None
                                    self.is_demand_circuit_configured = None
                                    self.is_designated_router = None
                                    self.is_interface_demand_circuit = None
                                    self.is_interface_encryption_enabled = None
                                    self.is_interface_flood_reduction = None
                                    self.is_interface_ip_security_active = None
                                    self.is_interface_ip_security_required = None
                                    self.is_interface_line_up = None
                                    self.is_interface_lsa_filtered = None
                                    self.is_prefix_suppress = None
                                    self.network_lsa_flush_timer = None
                                    self.network_type = None
                                    self.next_hello_time = None
                                    self.ospf_interface_state = None
                                    self.transmission_delay = None
                                    self.wait_interval = None


                                class ActiveInterface(object):
                                    """
                                    Active interface details 
                                    
                                    .. attribute:: flood_queue_length
                                    
                                    	Flood queue length
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: flood_scan_length
                                    
                                    	Last flood scan length 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_area_flood_index
                                    
                                    	Area scope LSAs flood index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_area_next_flood
                                    
                                    	Next LSA to flood (Area scope)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_area_next_flood_index
                                    
                                    	Index of next LSA to flood (Area scope) 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_as_flood_index
                                    
                                    	AS scope LSAs flood index 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_as_next_flood
                                    
                                    	Next LSA to flood (AS scope)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_as_next_flood_index
                                    
                                    	Index of next LSA to flood (AS scope)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_flood_pacing_timer
                                    
                                    	Time until next flood pacing timer (ms) 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_link_flood_index
                                    
                                    	Interface flood link index 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_link_next_flood
                                    
                                    	Interface link next flood information 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_link_next_index
                                    
                                    	Interface link next information index 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_neighbors
                                    
                                    	Total number of neighbors 
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: last_flood_time
                                    
                                    	Last flood scan time (ms)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: maximum_flood_length
                                    
                                    	Maximum flood length 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: maximum_flood_time
                                    
                                    	Maximum flood time (ms) 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: suppressed_hellos
                                    
                                    	Number of neighbors for which hellos are suppressed 
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: wait_time
                                    
                                    	Wait time for DR/BDR selection (s)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.flood_queue_length = None
                                        self.flood_scan_length = None
                                        self.interface_area_flood_index = None
                                        self.interface_area_next_flood = None
                                        self.interface_area_next_flood_index = None
                                        self.interface_as_flood_index = None
                                        self.interface_as_next_flood = None
                                        self.interface_as_next_flood_index = None
                                        self.interface_flood_pacing_timer = None
                                        self.interface_link_flood_index = None
                                        self.interface_link_next_flood = None
                                        self.interface_link_next_index = None
                                        self.interface_neighbors = None
                                        self.last_flood_time = None
                                        self.maximum_flood_length = None
                                        self.maximum_flood_time = None
                                        self.suppressed_hellos = None
                                        self.wait_time = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:active-interface'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.flood_queue_length is not None:
                                            return True

                                        if self.flood_scan_length is not None:
                                            return True

                                        if self.interface_area_flood_index is not None:
                                            return True

                                        if self.interface_area_next_flood is not None:
                                            return True

                                        if self.interface_area_next_flood_index is not None:
                                            return True

                                        if self.interface_as_flood_index is not None:
                                            return True

                                        if self.interface_as_next_flood is not None:
                                            return True

                                        if self.interface_as_next_flood_index is not None:
                                            return True

                                        if self.interface_flood_pacing_timer is not None:
                                            return True

                                        if self.interface_link_flood_index is not None:
                                            return True

                                        if self.interface_link_next_flood is not None:
                                            return True

                                        if self.interface_link_next_index is not None:
                                            return True

                                        if self.interface_neighbors is not None:
                                            return True

                                        if self.last_flood_time is not None:
                                            return True

                                        if self.maximum_flood_length is not None:
                                            return True

                                        if self.maximum_flood_time is not None:
                                            return True

                                        if self.suppressed_hellos is not None:
                                            return True

                                        if self.wait_time is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                        return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Areas.Area.InterfaceTable.Interface.ActiveInterface']['meta_info']


                                class InterfaceBfd(object):
                                    """
                                    BFD information 
                                    
                                    .. attribute:: bfd_detection_multiplier
                                    
                                    	BFD detection multiplier 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bfd_interval
                                    
                                    	BFD interval (ms) 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bfd_intf_enable_mode
                                    
                                    	BFD Enable Mode on the interface \- Default/Strict
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.bfd_detection_multiplier = None
                                        self.bfd_interval = None
                                        self.bfd_intf_enable_mode = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:interface-bfd'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bfd_detection_multiplier is not None:
                                            return True

                                        if self.bfd_interval is not None:
                                            return True

                                        if self.bfd_intf_enable_mode is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                        return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Areas.Area.InterfaceTable.Interface.InterfaceBfd']['meta_info']


                                class InterfaceNeighbor(object):
                                    """
                                    Information for neighbors on the interface
                                    
                                    .. attribute:: interface_neighbor_cost
                                    
                                    	Cost of link to neighbor
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_neighbor_id
                                    
                                    	Neighbor router ID 
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: is_hello_suppressed
                                    
                                    	If true, hello is suppressed 
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_neighbor_bdr
                                    
                                    	If true, backup designated router is found 
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_neighbor_dr
                                    
                                    	If true, designated router is found 
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.interface_neighbor_cost = None
                                        self.interface_neighbor_id = None
                                        self.is_hello_suppressed = None
                                        self.is_neighbor_bdr = None
                                        self.is_neighbor_dr = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:interface-neighbor'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.interface_neighbor_cost is not None:
                                            return True

                                        if self.interface_neighbor_id is not None:
                                            return True

                                        if self.is_hello_suppressed is not None:
                                            return True

                                        if self.is_neighbor_bdr is not None:
                                            return True

                                        if self.is_neighbor_dr is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                        return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Areas.Area.InterfaceTable.Interface.InterfaceNeighbor']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')
                                    if self.interface_name is None:
                                        raise YPYModelError('Key property interface_name is None')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:interface[Cisco-IOS-XR-ipv6-ospfv3-oper:interface-name = ' + str(self.interface_name) + ']'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.interface_name is not None:
                                        return True

                                    if self.active_interface is not None and self.active_interface._has_data():
                                        return True

                                    if self.adjacent_neighbor is not None:
                                        return True

                                    if self.backup_designated_router_address is not None:
                                        return True

                                    if self.backup_designated_router_id is not None:
                                        return True

                                    if self.configured_ldp_sync is not None:
                                        return True

                                    if self.dead_interval is not None:
                                        return True

                                    if self.designated_router_address is not None:
                                        return True

                                    if self.designated_router_id is not None:
                                        return True

                                    if self.hello_interval is not None:
                                        return True

                                    if self.interface_address is not None:
                                        return True

                                    if self.interface_authentication_spi is not None:
                                        return True

                                    if self.interface_authentication_transmit is not None:
                                        return True

                                    if self.interface_bfd is not None and self.interface_bfd._has_data():
                                        return True

                                    if self.interface_dc_bitless_ls_as is not None:
                                        return True

                                    if self.interface_encrypted_authentication_transmitted is not None:
                                        return True

                                    if self.interface_encryption_spi is not None:
                                        return True

                                    if self.interface_encryption_transmitted is not None:
                                        return True

                                    if self.interface_ldp_sync is not None:
                                        return True

                                    if self.interface_link_cost is not None:
                                        return True

                                    if self.interface_neighbor is not None:
                                        for child_ref in self.interface_neighbor:
                                            if child_ref._has_data():
                                                return True

                                    if self.interface_number is not None:
                                        return True

                                    if self.interface_priority is not None:
                                        return True

                                    if self.interface_references is not None:
                                        return True

                                    if self.interface_retransmission_interval is not None:
                                        return True

                                    if self.interface_router_id is not None:
                                        return True

                                    if self.interface_state is not None:
                                        return True

                                    if self.is_demand_circuit_configured is not None:
                                        return True

                                    if self.is_designated_router is not None:
                                        return True

                                    if self.is_interface_demand_circuit is not None:
                                        return True

                                    if self.is_interface_encryption_enabled is not None:
                                        return True

                                    if self.is_interface_flood_reduction is not None:
                                        return True

                                    if self.is_interface_ip_security_active is not None:
                                        return True

                                    if self.is_interface_ip_security_required is not None:
                                        return True

                                    if self.is_interface_line_up is not None:
                                        return True

                                    if self.is_interface_lsa_filtered is not None:
                                        return True

                                    if self.is_prefix_suppress is not None:
                                        return True

                                    if self.network_lsa_flush_timer is not None:
                                        return True

                                    if self.network_type is not None:
                                        return True

                                    if self.next_hello_time is not None:
                                        return True

                                    if self.ospf_interface_state is not None:
                                        return True

                                    if self.transmission_delay is not None:
                                        return True

                                    if self.wait_interval is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                    return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Areas.Area.InterfaceTable.Interface']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:interface-table'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.interface is not None:
                                    for child_ref in self.interface:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Areas.Area.InterfaceTable']['meta_info']


                        class FloodListTable(object):
                            """
                            OSPFv3 flood list information table for an
                            area
                            
                            .. attribute:: flood
                            
                            	OSPFv3 flood list information
                            	**type**\: list of    :py:class:`Flood <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.FloodListTable.Flood>`
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.flood = YList()
                                self.flood.parent = self
                                self.flood.name = 'flood'


                            class Flood(object):
                                """
                                OSPFv3 flood list information
                                
                                .. attribute:: interface_name  <key>
                                
                                	Interface name
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: area_flood
                                
                                	Area scope floodlist
                                	**type**\: list of    :py:class:`AreaFlood <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.FloodListTable.Flood.AreaFlood>`
                                
                                .. attribute:: as_flood
                                
                                	AS scope floodlist
                                	**type**\: list of    :py:class:`AsFlood <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.FloodListTable.Flood.AsFlood>`
                                
                                .. attribute:: link_flood
                                
                                	Link floodlist
                                	**type**\: list of    :py:class:`LinkFlood <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.FloodListTable.Flood.LinkFlood>`
                                
                                .. attribute:: ls_transmission_timer
                                
                                	Time until next LS transmission (ms) 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: queue_length
                                
                                	Number of LSAs currently being flooded 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.interface_name = None
                                    self.area_flood = YList()
                                    self.area_flood.parent = self
                                    self.area_flood.name = 'area_flood'
                                    self.as_flood = YList()
                                    self.as_flood.parent = self
                                    self.as_flood.name = 'as_flood'
                                    self.link_flood = YList()
                                    self.link_flood.parent = self
                                    self.link_flood.name = 'link_flood'
                                    self.ls_transmission_timer = None
                                    self.queue_length = None


                                class LinkFlood(object):
                                    """
                                    Link floodlist
                                    
                                    .. attribute:: header_advertising_router
                                    
                                    	Router ID of the advertising router
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: header_lsa_age
                                    
                                    	Age of the LSA (seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: header_lsa_id
                                    
                                    	LSA ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: header_lsa_type
                                    
                                    	LSA type
                                    	**type**\:   :py:class:`Ospfv3Lsa1Enum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Lsa1Enum>`
                                    
                                    .. attribute:: header_sequence_number
                                    
                                    	Current LSA sequence number
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.header_advertising_router = None
                                        self.header_lsa_age = None
                                        self.header_lsa_id = None
                                        self.header_lsa_type = None
                                        self.header_sequence_number = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:link-flood'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.header_advertising_router is not None:
                                            return True

                                        if self.header_lsa_age is not None:
                                            return True

                                        if self.header_lsa_id is not None:
                                            return True

                                        if self.header_lsa_type is not None:
                                            return True

                                        if self.header_sequence_number is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                        return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Areas.Area.FloodListTable.Flood.LinkFlood']['meta_info']


                                class AreaFlood(object):
                                    """
                                    Area scope floodlist
                                    
                                    .. attribute:: header_advertising_router
                                    
                                    	Router ID of the advertising router
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: header_lsa_age
                                    
                                    	Age of the LSA (seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: header_lsa_id
                                    
                                    	LSA ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: header_lsa_type
                                    
                                    	LSA type
                                    	**type**\:   :py:class:`Ospfv3Lsa1Enum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Lsa1Enum>`
                                    
                                    .. attribute:: header_sequence_number
                                    
                                    	Current LSA sequence number
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.header_advertising_router = None
                                        self.header_lsa_age = None
                                        self.header_lsa_id = None
                                        self.header_lsa_type = None
                                        self.header_sequence_number = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:area-flood'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.header_advertising_router is not None:
                                            return True

                                        if self.header_lsa_age is not None:
                                            return True

                                        if self.header_lsa_id is not None:
                                            return True

                                        if self.header_lsa_type is not None:
                                            return True

                                        if self.header_sequence_number is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                        return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Areas.Area.FloodListTable.Flood.AreaFlood']['meta_info']


                                class AsFlood(object):
                                    """
                                    AS scope floodlist
                                    
                                    .. attribute:: header_advertising_router
                                    
                                    	Router ID of the advertising router
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: header_lsa_age
                                    
                                    	Age of the LSA (seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: header_lsa_id
                                    
                                    	LSA ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: header_lsa_type
                                    
                                    	LSA type
                                    	**type**\:   :py:class:`Ospfv3Lsa1Enum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Lsa1Enum>`
                                    
                                    .. attribute:: header_sequence_number
                                    
                                    	Current LSA sequence number
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.header_advertising_router = None
                                        self.header_lsa_age = None
                                        self.header_lsa_id = None
                                        self.header_lsa_type = None
                                        self.header_sequence_number = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:as-flood'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.header_advertising_router is not None:
                                            return True

                                        if self.header_lsa_age is not None:
                                            return True

                                        if self.header_lsa_id is not None:
                                            return True

                                        if self.header_lsa_type is not None:
                                            return True

                                        if self.header_sequence_number is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                        return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Areas.Area.FloodListTable.Flood.AsFlood']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')
                                    if self.interface_name is None:
                                        raise YPYModelError('Key property interface_name is None')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:flood[Cisco-IOS-XR-ipv6-ospfv3-oper:interface-name = ' + str(self.interface_name) + ']'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.interface_name is not None:
                                        return True

                                    if self.area_flood is not None:
                                        for child_ref in self.area_flood:
                                            if child_ref._has_data():
                                                return True

                                    if self.as_flood is not None:
                                        for child_ref in self.as_flood:
                                            if child_ref._has_data():
                                                return True

                                    if self.link_flood is not None:
                                        for child_ref in self.link_flood:
                                            if child_ref._has_data():
                                                return True

                                    if self.ls_transmission_timer is not None:
                                        return True

                                    if self.queue_length is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                    return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Areas.Area.FloodListTable.Flood']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:flood-list-table'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.flood is not None:
                                    for child_ref in self.flood:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Areas.Area.FloodListTable']['meta_info']


                        class RetransmissionListTable(object):
                            """
                            OSPFv3 retransmission list information table
                            in an area
                            
                            .. attribute:: retransmission
                            
                            	OSPFv3 retransmission list information
                            	**type**\: list of    :py:class:`Retransmission <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.RetransmissionListTable.Retransmission>`
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.retransmission = YList()
                                self.retransmission.parent = self
                                self.retransmission.name = 'retransmission'


                            class Retransmission(object):
                                """
                                OSPFv3 retransmission list information
                                
                                .. attribute:: interface_name
                                
                                	Interface name
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: is_retransmission_sham_link
                                
                                	If true, sham link is retransmitted 
                                	**type**\:  bool
                                
                                .. attribute:: is_retransmissionvirtual_link
                                
                                	If true, virtual link is retransmitted 
                                	**type**\:  bool
                                
                                .. attribute:: neighbor_address
                                
                                	Neighbor address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: retransmission_area_db
                                
                                	List of area scope entries
                                	**type**\: list of    :py:class:`RetransmissionAreaDb <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.RetransmissionListTable.Retransmission.RetransmissionAreaDb>`
                                
                                .. attribute:: retransmission_asdb
                                
                                	List of AS scope entries
                                	**type**\: list of    :py:class:`RetransmissionAsdb <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.RetransmissionListTable.Retransmission.RetransmissionAsdb>`
                                
                                .. attribute:: retransmission_length
                                
                                	Retransmission queue length
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: retransmission_neighbor_address
                                
                                	Neighbor IP address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: retransmission_sham_link_id
                                
                                	Retransmission sham link ID 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: retransmission_timer
                                
                                	Amount of time remaining on retransmission timer (ms)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: retransmissionvirtual_link_db
                                
                                	List of virtual link scope entries 
                                	**type**\: list of    :py:class:`RetransmissionvirtualLinkDb <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.RetransmissionListTable.Retransmission.RetransmissionvirtualLinkDb>`
                                
                                .. attribute:: retransmissionvirtual_link_id
                                
                                	Retransmission virtual link ID 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.interface_name = None
                                    self.is_retransmission_sham_link = None
                                    self.is_retransmissionvirtual_link = None
                                    self.neighbor_address = None
                                    self.retransmission_area_db = YList()
                                    self.retransmission_area_db.parent = self
                                    self.retransmission_area_db.name = 'retransmission_area_db'
                                    self.retransmission_asdb = YList()
                                    self.retransmission_asdb.parent = self
                                    self.retransmission_asdb.name = 'retransmission_asdb'
                                    self.retransmission_length = None
                                    self.retransmission_neighbor_address = None
                                    self.retransmission_sham_link_id = None
                                    self.retransmission_timer = None
                                    self.retransmissionvirtual_link_db = YList()
                                    self.retransmissionvirtual_link_db.parent = self
                                    self.retransmissionvirtual_link_db.name = 'retransmissionvirtual_link_db'
                                    self.retransmissionvirtual_link_id = None


                                class RetransmissionvirtualLinkDb(object):
                                    """
                                    List of virtual link scope entries 
                                    
                                    .. attribute:: header_advertising_router
                                    
                                    	Router ID of the advertising router
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: header_lsa_age
                                    
                                    	Age of the LSA (seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: header_lsa_id
                                    
                                    	LSA ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: header_lsa_type
                                    
                                    	LSA type
                                    	**type**\:   :py:class:`Ospfv3Lsa1Enum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Lsa1Enum>`
                                    
                                    .. attribute:: header_sequence_number
                                    
                                    	Current LSA sequence number
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.header_advertising_router = None
                                        self.header_lsa_age = None
                                        self.header_lsa_id = None
                                        self.header_lsa_type = None
                                        self.header_sequence_number = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:retransmissionvirtual-link-db'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.header_advertising_router is not None:
                                            return True

                                        if self.header_lsa_age is not None:
                                            return True

                                        if self.header_lsa_id is not None:
                                            return True

                                        if self.header_lsa_type is not None:
                                            return True

                                        if self.header_sequence_number is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                        return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Areas.Area.RetransmissionListTable.Retransmission.RetransmissionvirtualLinkDb']['meta_info']


                                class RetransmissionAreaDb(object):
                                    """
                                    List of area scope entries
                                    
                                    .. attribute:: header_advertising_router
                                    
                                    	Router ID of the advertising router
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: header_lsa_age
                                    
                                    	Age of the LSA (seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: header_lsa_id
                                    
                                    	LSA ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: header_lsa_type
                                    
                                    	LSA type
                                    	**type**\:   :py:class:`Ospfv3Lsa1Enum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Lsa1Enum>`
                                    
                                    .. attribute:: header_sequence_number
                                    
                                    	Current LSA sequence number
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.header_advertising_router = None
                                        self.header_lsa_age = None
                                        self.header_lsa_id = None
                                        self.header_lsa_type = None
                                        self.header_sequence_number = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:retransmission-area-db'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.header_advertising_router is not None:
                                            return True

                                        if self.header_lsa_age is not None:
                                            return True

                                        if self.header_lsa_id is not None:
                                            return True

                                        if self.header_lsa_type is not None:
                                            return True

                                        if self.header_sequence_number is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                        return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Areas.Area.RetransmissionListTable.Retransmission.RetransmissionAreaDb']['meta_info']


                                class RetransmissionAsdb(object):
                                    """
                                    List of AS scope entries
                                    
                                    .. attribute:: header_advertising_router
                                    
                                    	Router ID of the advertising router
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: header_lsa_age
                                    
                                    	Age of the LSA (seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: header_lsa_id
                                    
                                    	LSA ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: header_lsa_type
                                    
                                    	LSA type
                                    	**type**\:   :py:class:`Ospfv3Lsa1Enum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Lsa1Enum>`
                                    
                                    .. attribute:: header_sequence_number
                                    
                                    	Current LSA sequence number
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.header_advertising_router = None
                                        self.header_lsa_age = None
                                        self.header_lsa_id = None
                                        self.header_lsa_type = None
                                        self.header_sequence_number = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:retransmission-asdb'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.header_advertising_router is not None:
                                            return True

                                        if self.header_lsa_age is not None:
                                            return True

                                        if self.header_lsa_id is not None:
                                            return True

                                        if self.header_lsa_type is not None:
                                            return True

                                        if self.header_sequence_number is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                        return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Areas.Area.RetransmissionListTable.Retransmission.RetransmissionAsdb']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:retransmission'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.interface_name is not None:
                                        return True

                                    if self.is_retransmission_sham_link is not None:
                                        return True

                                    if self.is_retransmissionvirtual_link is not None:
                                        return True

                                    if self.neighbor_address is not None:
                                        return True

                                    if self.retransmission_area_db is not None:
                                        for child_ref in self.retransmission_area_db:
                                            if child_ref._has_data():
                                                return True

                                    if self.retransmission_asdb is not None:
                                        for child_ref in self.retransmission_asdb:
                                            if child_ref._has_data():
                                                return True

                                    if self.retransmission_length is not None:
                                        return True

                                    if self.retransmission_neighbor_address is not None:
                                        return True

                                    if self.retransmission_sham_link_id is not None:
                                        return True

                                    if self.retransmission_timer is not None:
                                        return True

                                    if self.retransmissionvirtual_link_db is not None:
                                        for child_ref in self.retransmissionvirtual_link_db:
                                            if child_ref._has_data():
                                                return True

                                    if self.retransmissionvirtual_link_id is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                    return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Areas.Area.RetransmissionListTable.Retransmission']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:retransmission-list-table'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.retransmission is not None:
                                    for child_ref in self.retransmission:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Areas.Area.RetransmissionListTable']['meta_info']


                        class DatabaseTable(object):
                            """
                            OSPF Link State Database
                            
                            .. attribute:: lsa_internal_table
                            
                            	Database LSA information
                            	**type**\:   :py:class:`LsaInternalTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable>`
                            
                            .. attribute:: lsa_table
                            
                            	Database LSA information
                            	**type**\:   :py:class:`LsaTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable>`
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.lsa_internal_table = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable()
                                self.lsa_internal_table.parent = self
                                self.lsa_table = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable()
                                self.lsa_table.parent = self


                            class LsaTable(object):
                                """
                                Database LSA information
                                
                                .. attribute:: lsa
                                
                                	Database LSA information
                                	**type**\: list of    :py:class:`Lsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa>`
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.lsa = YList()
                                    self.lsa.parent = self
                                    self.lsa.name = 'lsa'


                                class Lsa(object):
                                    """
                                    Database LSA information
                                    
                                    .. attribute:: advertising_router
                                    
                                    	Advertising Router ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: area_id
                                    
                                    	Area ID
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: interface_name
                                    
                                    	InterfaceName
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                    
                                    .. attribute:: ls_id
                                    
                                    	Link state ID
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: ls_type
                                    
                                    	LSA type
                                    	**type**\:   :py:class:`Ospfv3LsaEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3LsaEnum>`
                                    
                                    .. attribute:: lsa_info
                                    
                                    	Summary of all LSAs or LSA specific information 
                                    	**type**\:   :py:class:`LsaInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo>`
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.advertising_router = None
                                        self.area_id = None
                                        self.interface_name = None
                                        self.ls_id = None
                                        self.ls_type = None
                                        self.lsa_info = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo()
                                        self.lsa_info.parent = self


                                    class LsaInfo(object):
                                        """
                                        Summary of all LSAs or LSA specific information 
                                        
                                        .. attribute:: external_lsa_type
                                        
                                        	External LSA
                                        	**type**\:   :py:class:`ExternalLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType>`
                                        
                                        .. attribute:: grace_lsa
                                        
                                        	Grace LSA
                                        	**type**\:   :py:class:`GraceLsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa>`
                                        
                                        .. attribute:: inter_area_prefix_lsa_type
                                        
                                        	Inter Area Prefix LSA
                                        	**type**\:   :py:class:`InterAreaPrefixLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType>`
                                        
                                        .. attribute:: inter_area_router_lsa_type
                                        
                                        	Inter Area Router LSA
                                        	**type**\:   :py:class:`InterAreaRouterLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType>`
                                        
                                        .. attribute:: intra_area_prefix_lsa_type
                                        
                                        	Intra Area Prefix LSA
                                        	**type**\:   :py:class:`IntraAreaPrefixLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType>`
                                        
                                        .. attribute:: link_lsa_type
                                        
                                        	Link LSA
                                        	**type**\:   :py:class:`LinkLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType>`
                                        
                                        .. attribute:: lsa_info_type
                                        
                                        	LSAInfoType
                                        	**type**\:   :py:class:`Ospfv3LsaInfoTypesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3LsaInfoTypesEnum>`
                                        
                                        .. attribute:: lsa_summary_info
                                        
                                        	Summary information of LSAs
                                        	**type**\:   :py:class:`LsaSummaryInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo>`
                                        
                                        .. attribute:: network_lsa_type
                                        
                                        	Network LSA
                                        	**type**\:   :py:class:`NetworkLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType>`
                                        
                                        .. attribute:: nssalsa_type
                                        
                                        	NSSA External LSA
                                        	**type**\:   :py:class:`NssalsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType>`
                                        
                                        .. attribute:: router_lsa_type
                                        
                                        	Router LSA
                                        	**type**\:   :py:class:`RouterLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType>`
                                        
                                        .. attribute:: unknown_area_lsa_type
                                        
                                        	Unknown\-Area scope LSA
                                        	**type**\:   :py:class:`UnknownAreaLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType>`
                                        
                                        .. attribute:: unknown_aslsa_type
                                        
                                        	Unknown\-AS scope LSA
                                        	**type**\:   :py:class:`UnknownAslsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType>`
                                        
                                        .. attribute:: unknown_link_lsa_type
                                        
                                        	Unknown Link Scope LSA
                                        	**type**\:   :py:class:`UnknownLinkLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType>`
                                        
                                        .. attribute:: unknown_lsa_type
                                        
                                        	Unknown LSA
                                        	**type**\:   :py:class:`UnknownLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType>`
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.external_lsa_type = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType()
                                            self.external_lsa_type.parent = self
                                            self.grace_lsa = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa()
                                            self.grace_lsa.parent = self
                                            self.inter_area_prefix_lsa_type = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType()
                                            self.inter_area_prefix_lsa_type.parent = self
                                            self.inter_area_router_lsa_type = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType()
                                            self.inter_area_router_lsa_type.parent = self
                                            self.intra_area_prefix_lsa_type = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType()
                                            self.intra_area_prefix_lsa_type.parent = self
                                            self.link_lsa_type = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType()
                                            self.link_lsa_type.parent = self
                                            self.lsa_info_type = None
                                            self.lsa_summary_info = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo()
                                            self.lsa_summary_info.parent = self
                                            self.network_lsa_type = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType()
                                            self.network_lsa_type.parent = self
                                            self.nssalsa_type = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType()
                                            self.nssalsa_type.parent = self
                                            self.router_lsa_type = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType()
                                            self.router_lsa_type.parent = self
                                            self.unknown_area_lsa_type = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType()
                                            self.unknown_area_lsa_type.parent = self
                                            self.unknown_aslsa_type = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType()
                                            self.unknown_aslsa_type.parent = self
                                            self.unknown_link_lsa_type = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType()
                                            self.unknown_link_lsa_type.parent = self
                                            self.unknown_lsa_type = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType()
                                            self.unknown_lsa_type.parent = self


                                        class LsaSummaryInfo(object):
                                            """
                                            Summary information of LSAs
                                            
                                            .. attribute:: interface_name
                                            
                                            	LSA interface name 
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                            
                                            .. attribute:: is_sham_link
                                            
                                            	If true, it is a sham link 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_virtual_link
                                            
                                            	If true, it is a virtual link 
                                            	**type**\:  bool
                                            
                                            .. attribute:: links
                                            
                                            	Number of links
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_detail
                                            
                                            	Detailed LSA information
                                            	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo.LsaDetail>`
                                            
                                            .. attribute:: lsa_header
                                            
                                            	Header information 
                                            	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo.LsaHeader>`
                                            
                                            .. attribute:: lsa_router_id
                                            
                                            	LSA router ID 
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: prefix
                                            
                                            	OSPFv3 address Prefix 
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: prefix_length
                                            
                                            	Prefix length 
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: reference_lsa_id
                                            
                                            	Reference LSA ID 
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: reference_type
                                            
                                            	Reference type 
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: router_la_bits
                                            
                                            	Router LA bits 
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: sham_link_id
                                            
                                            	Sham link ID 
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: virtual_link_id
                                            
                                            	Virtual link ID 
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface_name = None
                                                self.is_sham_link = None
                                                self.is_virtual_link = None
                                                self.links = None
                                                self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo.LsaDetail()
                                                self.lsa_detail.parent = self
                                                self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo.LsaHeader()
                                                self.lsa_header.parent = self
                                                self.lsa_router_id = None
                                                self.prefix = None
                                                self.prefix_length = None
                                                self.reference_lsa_id = None
                                                self.reference_type = None
                                                self.router_la_bits = None
                                                self.sham_link_id = None
                                                self.virtual_link_id = None


                                            class LsaHeader(object):
                                                """
                                                Header information 
                                                
                                                .. attribute:: advertising_router
                                                
                                                	Router ID of Advertising Router
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: checksum
                                                
                                                	Checksum value
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: is_do_not_age_lsa
                                                
                                                	If true, Do Not Age this LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_graceful_restart_active
                                                
                                                	If true, if grace restart is active 
                                                	**type**\:  bool
                                                
                                                .. attribute:: ls_id
                                                
                                                	LS ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: lsa_age
                                                
                                                	LSA's Age (s)
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_area_id
                                                
                                                	Area ID in decimal or dotted\-decimal format
                                                	**type**\:  str
                                                
                                                	**length:** 0..16
                                                
                                                .. attribute:: lsa_type
                                                
                                                	LSA type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: sequence_number
                                                
                                                	Current Sequence number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.advertising_router = None
                                                    self.checksum = None
                                                    self.is_do_not_age_lsa = None
                                                    self.is_graceful_restart_active = None
                                                    self.ls_id = None
                                                    self.lsa_age = None
                                                    self.lsa_area_id = None
                                                    self.lsa_type = None
                                                    self.sequence_number = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-header'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.advertising_router is not None:
                                                        return True

                                                    if self.checksum is not None:
                                                        return True

                                                    if self.is_do_not_age_lsa is not None:
                                                        return True

                                                    if self.is_graceful_restart_active is not None:
                                                        return True

                                                    if self.ls_id is not None:
                                                        return True

                                                    if self.lsa_age is not None:
                                                        return True

                                                    if self.lsa_area_id is not None:
                                                        return True

                                                    if self.lsa_type is not None:
                                                        return True

                                                    if self.sequence_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                    return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo.LsaHeader']['meta_info']


                                            class LsaDetail(object):
                                                """
                                                Detailed LSA information
                                                
                                                .. attribute:: free_time
                                                
                                                	The amount of time since the last check was made to free this LSA (s)
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_acknowledged
                                                
                                                	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_advertising_router_reachable
                                                
                                                	If true, Advertising Router is reachable
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_deleted
                                                
                                                	If true, flag is set to delete this LSA 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_flood_pending
                                                
                                                	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_maximum_aged
                                                
                                                	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_neighbor_exchange
                                                
                                                	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_no_delete
                                                
                                                	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_nsr_ack_pending
                                                
                                                	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_partial_spf
                                                
                                                	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_routing_bit
                                                
                                                	If true, Routing Bit set on the LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_routing_table
                                                
                                                	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                	**type**\:  bool
                                                
                                                .. attribute:: lsa_flood_required_post_fail_over
                                                
                                                	LSA flood required after FO
                                                	**type**\:  bool
                                                
                                                .. attribute:: lsa_length
                                                
                                                	Length of the LSA
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_sync_state
                                                
                                                	State of LSA sync with active
                                                	**type**\:   :py:class:`OspfLsaSyncStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncStateEnum>`
                                                
                                                .. attribute:: minute_table_index
                                                
                                                	Minute table index
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: nsr_flood_required
                                                
                                                	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                	**type**\:  bool
                                                
                                                .. attribute:: rate_limit
                                                
                                                	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                	**type**\:  bool
                                                
                                                .. attribute:: second_table_index
                                                
                                                	Second table index
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.free_time = None
                                                    self.is_acknowledged = None
                                                    self.is_advertising_router_reachable = None
                                                    self.is_deleted = None
                                                    self.is_flood_pending = None
                                                    self.is_maximum_aged = None
                                                    self.is_neighbor_exchange = None
                                                    self.is_no_delete = None
                                                    self.is_nsr_ack_pending = None
                                                    self.is_partial_spf = None
                                                    self.is_routing_bit = None
                                                    self.is_routing_table = None
                                                    self.lsa_flood_required_post_fail_over = None
                                                    self.lsa_length = None
                                                    self.lsa_sync_state = None
                                                    self.minute_table_index = None
                                                    self.nsr_flood_required = None
                                                    self.rate_limit = None
                                                    self.second_table_index = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-detail'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.free_time is not None:
                                                        return True

                                                    if self.is_acknowledged is not None:
                                                        return True

                                                    if self.is_advertising_router_reachable is not None:
                                                        return True

                                                    if self.is_deleted is not None:
                                                        return True

                                                    if self.is_flood_pending is not None:
                                                        return True

                                                    if self.is_maximum_aged is not None:
                                                        return True

                                                    if self.is_neighbor_exchange is not None:
                                                        return True

                                                    if self.is_no_delete is not None:
                                                        return True

                                                    if self.is_nsr_ack_pending is not None:
                                                        return True

                                                    if self.is_partial_spf is not None:
                                                        return True

                                                    if self.is_routing_bit is not None:
                                                        return True

                                                    if self.is_routing_table is not None:
                                                        return True

                                                    if self.lsa_flood_required_post_fail_over is not None:
                                                        return True

                                                    if self.lsa_length is not None:
                                                        return True

                                                    if self.lsa_sync_state is not None:
                                                        return True

                                                    if self.minute_table_index is not None:
                                                        return True

                                                    if self.nsr_flood_required is not None:
                                                        return True

                                                    if self.rate_limit is not None:
                                                        return True

                                                    if self.second_table_index is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                    return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo.LsaDetail']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-summary-info'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface_name is not None:
                                                    return True

                                                if self.is_sham_link is not None:
                                                    return True

                                                if self.is_virtual_link is not None:
                                                    return True

                                                if self.links is not None:
                                                    return True

                                                if self.lsa_detail is not None and self.lsa_detail._has_data():
                                                    return True

                                                if self.lsa_header is not None and self.lsa_header._has_data():
                                                    return True

                                                if self.lsa_router_id is not None:
                                                    return True

                                                if self.prefix is not None:
                                                    return True

                                                if self.prefix_length is not None:
                                                    return True

                                                if self.reference_lsa_id is not None:
                                                    return True

                                                if self.reference_type is not None:
                                                    return True

                                                if self.router_la_bits is not None:
                                                    return True

                                                if self.sham_link_id is not None:
                                                    return True

                                                if self.virtual_link_id is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo']['meta_info']


                                        class RouterLsaType(object):
                                            """
                                            Router LSA
                                            
                                            .. attribute:: link
                                            
                                            	List of links in this LSA
                                            	**type**\: list of    :py:class:`Link <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.Link>`
                                            
                                            .. attribute:: lsa_detail
                                            
                                            	Detailed LSA information
                                            	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.LsaDetail>`
                                            
                                            .. attribute:: lsa_header
                                            
                                            	Header information 
                                            	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.LsaHeader>`
                                            
                                            .. attribute:: router_la_bits
                                            
                                            	Router LA bits 
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: rpf_path
                                            
                                            	Router LSA Reverse\-Path Forwarding information 
                                            	**type**\:   :py:class:`RpfPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.RpfPath>`
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.link = YList()
                                                self.link.parent = self
                                                self.link.name = 'link'
                                                self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.LsaDetail()
                                                self.lsa_detail.parent = self
                                                self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.LsaHeader()
                                                self.lsa_header.parent = self
                                                self.router_la_bits = None
                                                self.rpf_path = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.RpfPath()
                                                self.rpf_path.parent = self


                                            class LsaHeader(object):
                                                """
                                                Header information 
                                                
                                                .. attribute:: advertising_router
                                                
                                                	Router ID of Advertising Router
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: checksum
                                                
                                                	Checksum value
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: is_do_not_age_lsa
                                                
                                                	If true, Do Not Age this LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_graceful_restart_active
                                                
                                                	If true, if grace restart is active 
                                                	**type**\:  bool
                                                
                                                .. attribute:: ls_id
                                                
                                                	LS ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: lsa_age
                                                
                                                	LSA's Age (s)
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_area_id
                                                
                                                	Area ID in decimal or dotted\-decimal format
                                                	**type**\:  str
                                                
                                                	**length:** 0..16
                                                
                                                .. attribute:: lsa_type
                                                
                                                	LSA type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: sequence_number
                                                
                                                	Current Sequence number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.advertising_router = None
                                                    self.checksum = None
                                                    self.is_do_not_age_lsa = None
                                                    self.is_graceful_restart_active = None
                                                    self.ls_id = None
                                                    self.lsa_age = None
                                                    self.lsa_area_id = None
                                                    self.lsa_type = None
                                                    self.sequence_number = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-header'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.advertising_router is not None:
                                                        return True

                                                    if self.checksum is not None:
                                                        return True

                                                    if self.is_do_not_age_lsa is not None:
                                                        return True

                                                    if self.is_graceful_restart_active is not None:
                                                        return True

                                                    if self.ls_id is not None:
                                                        return True

                                                    if self.lsa_age is not None:
                                                        return True

                                                    if self.lsa_area_id is not None:
                                                        return True

                                                    if self.lsa_type is not None:
                                                        return True

                                                    if self.sequence_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                    return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.LsaHeader']['meta_info']


                                            class LsaDetail(object):
                                                """
                                                Detailed LSA information
                                                
                                                .. attribute:: free_time
                                                
                                                	The amount of time since the last check was made to free this LSA (s)
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_acknowledged
                                                
                                                	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_advertising_router_reachable
                                                
                                                	If true, Advertising Router is reachable
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_deleted
                                                
                                                	If true, flag is set to delete this LSA 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_flood_pending
                                                
                                                	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_maximum_aged
                                                
                                                	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_neighbor_exchange
                                                
                                                	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_no_delete
                                                
                                                	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_nsr_ack_pending
                                                
                                                	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_partial_spf
                                                
                                                	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_routing_bit
                                                
                                                	If true, Routing Bit set on the LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_routing_table
                                                
                                                	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                	**type**\:  bool
                                                
                                                .. attribute:: lsa_flood_required_post_fail_over
                                                
                                                	LSA flood required after FO
                                                	**type**\:  bool
                                                
                                                .. attribute:: lsa_length
                                                
                                                	Length of the LSA
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_sync_state
                                                
                                                	State of LSA sync with active
                                                	**type**\:   :py:class:`OspfLsaSyncStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncStateEnum>`
                                                
                                                .. attribute:: minute_table_index
                                                
                                                	Minute table index
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: nsr_flood_required
                                                
                                                	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                	**type**\:  bool
                                                
                                                .. attribute:: rate_limit
                                                
                                                	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                	**type**\:  bool
                                                
                                                .. attribute:: second_table_index
                                                
                                                	Second table index
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.free_time = None
                                                    self.is_acknowledged = None
                                                    self.is_advertising_router_reachable = None
                                                    self.is_deleted = None
                                                    self.is_flood_pending = None
                                                    self.is_maximum_aged = None
                                                    self.is_neighbor_exchange = None
                                                    self.is_no_delete = None
                                                    self.is_nsr_ack_pending = None
                                                    self.is_partial_spf = None
                                                    self.is_routing_bit = None
                                                    self.is_routing_table = None
                                                    self.lsa_flood_required_post_fail_over = None
                                                    self.lsa_length = None
                                                    self.lsa_sync_state = None
                                                    self.minute_table_index = None
                                                    self.nsr_flood_required = None
                                                    self.rate_limit = None
                                                    self.second_table_index = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-detail'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.free_time is not None:
                                                        return True

                                                    if self.is_acknowledged is not None:
                                                        return True

                                                    if self.is_advertising_router_reachable is not None:
                                                        return True

                                                    if self.is_deleted is not None:
                                                        return True

                                                    if self.is_flood_pending is not None:
                                                        return True

                                                    if self.is_maximum_aged is not None:
                                                        return True

                                                    if self.is_neighbor_exchange is not None:
                                                        return True

                                                    if self.is_no_delete is not None:
                                                        return True

                                                    if self.is_nsr_ack_pending is not None:
                                                        return True

                                                    if self.is_partial_spf is not None:
                                                        return True

                                                    if self.is_routing_bit is not None:
                                                        return True

                                                    if self.is_routing_table is not None:
                                                        return True

                                                    if self.lsa_flood_required_post_fail_over is not None:
                                                        return True

                                                    if self.lsa_length is not None:
                                                        return True

                                                    if self.lsa_sync_state is not None:
                                                        return True

                                                    if self.minute_table_index is not None:
                                                        return True

                                                    if self.nsr_flood_required is not None:
                                                        return True

                                                    if self.rate_limit is not None:
                                                        return True

                                                    if self.second_table_index is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                    return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.LsaDetail']['meta_info']


                                            class RpfPath(object):
                                                """
                                                Router LSA Reverse\-Path Forwarding information 
                                                
                                                .. attribute:: interface_name
                                                
                                                	RPF multicast IDB 
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                
                                                .. attribute:: rpf_multicast_next_hop
                                                
                                                	RPF multicast next hop 
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.interface_name = None
                                                    self.rpf_multicast_next_hop = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:rpf-path'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.interface_name is not None:
                                                        return True

                                                    if self.rpf_multicast_next_hop is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                    return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.RpfPath']['meta_info']


                                            class Link(object):
                                                """
                                                List of links in this LSA
                                                
                                                .. attribute:: link_interface_id
                                                
                                                	LSA link interface ID 
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: link_metric
                                                
                                                	LSA link metric 
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: link_neighbor_interface_id
                                                
                                                	LSA link neighbor interface ID 
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: link_neighbor_router_id
                                                
                                                	LSA link neigbhor router id 
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: link_type
                                                
                                                	Type of link
                                                	**type**\:   :py:class:`Ospfv3LinkEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3LinkEnum>`
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.link_interface_id = None
                                                    self.link_metric = None
                                                    self.link_neighbor_interface_id = None
                                                    self.link_neighbor_router_id = None
                                                    self.link_type = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:link'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.link_interface_id is not None:
                                                        return True

                                                    if self.link_metric is not None:
                                                        return True

                                                    if self.link_neighbor_interface_id is not None:
                                                        return True

                                                    if self.link_neighbor_router_id is not None:
                                                        return True

                                                    if self.link_type is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                    return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.Link']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:router-lsa-type'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.link is not None:
                                                    for child_ref in self.link:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.lsa_detail is not None and self.lsa_detail._has_data():
                                                    return True

                                                if self.lsa_header is not None and self.lsa_header._has_data():
                                                    return True

                                                if self.router_la_bits is not None:
                                                    return True

                                                if self.rpf_path is not None and self.rpf_path._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType']['meta_info']


                                        class NetworkLsaType(object):
                                            """
                                            Network LSA
                                            
                                            .. attribute:: lsa_detail
                                            
                                            	Detailed LSA information
                                            	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType.LsaDetail>`
                                            
                                            .. attribute:: lsa_header
                                            
                                            	Header information 
                                            	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType.LsaHeader>`
                                            
                                            .. attribute:: neighbor_router
                                            
                                            	Neighbor router list
                                            	**type**\:  list of str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType.LsaDetail()
                                                self.lsa_detail.parent = self
                                                self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType.LsaHeader()
                                                self.lsa_header.parent = self
                                                self.neighbor_router = YLeafList()
                                                self.neighbor_router.parent = self
                                                self.neighbor_router.name = 'neighbor_router'


                                            class LsaHeader(object):
                                                """
                                                Header information 
                                                
                                                .. attribute:: advertising_router
                                                
                                                	Router ID of Advertising Router
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: checksum
                                                
                                                	Checksum value
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: is_do_not_age_lsa
                                                
                                                	If true, Do Not Age this LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_graceful_restart_active
                                                
                                                	If true, if grace restart is active 
                                                	**type**\:  bool
                                                
                                                .. attribute:: ls_id
                                                
                                                	LS ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: lsa_age
                                                
                                                	LSA's Age (s)
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_area_id
                                                
                                                	Area ID in decimal or dotted\-decimal format
                                                	**type**\:  str
                                                
                                                	**length:** 0..16
                                                
                                                .. attribute:: lsa_type
                                                
                                                	LSA type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: sequence_number
                                                
                                                	Current Sequence number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.advertising_router = None
                                                    self.checksum = None
                                                    self.is_do_not_age_lsa = None
                                                    self.is_graceful_restart_active = None
                                                    self.ls_id = None
                                                    self.lsa_age = None
                                                    self.lsa_area_id = None
                                                    self.lsa_type = None
                                                    self.sequence_number = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-header'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.advertising_router is not None:
                                                        return True

                                                    if self.checksum is not None:
                                                        return True

                                                    if self.is_do_not_age_lsa is not None:
                                                        return True

                                                    if self.is_graceful_restart_active is not None:
                                                        return True

                                                    if self.ls_id is not None:
                                                        return True

                                                    if self.lsa_age is not None:
                                                        return True

                                                    if self.lsa_area_id is not None:
                                                        return True

                                                    if self.lsa_type is not None:
                                                        return True

                                                    if self.sequence_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                    return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType.LsaHeader']['meta_info']


                                            class LsaDetail(object):
                                                """
                                                Detailed LSA information
                                                
                                                .. attribute:: free_time
                                                
                                                	The amount of time since the last check was made to free this LSA (s)
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_acknowledged
                                                
                                                	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_advertising_router_reachable
                                                
                                                	If true, Advertising Router is reachable
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_deleted
                                                
                                                	If true, flag is set to delete this LSA 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_flood_pending
                                                
                                                	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_maximum_aged
                                                
                                                	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_neighbor_exchange
                                                
                                                	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_no_delete
                                                
                                                	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_nsr_ack_pending
                                                
                                                	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_partial_spf
                                                
                                                	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_routing_bit
                                                
                                                	If true, Routing Bit set on the LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_routing_table
                                                
                                                	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                	**type**\:  bool
                                                
                                                .. attribute:: lsa_flood_required_post_fail_over
                                                
                                                	LSA flood required after FO
                                                	**type**\:  bool
                                                
                                                .. attribute:: lsa_length
                                                
                                                	Length of the LSA
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_sync_state
                                                
                                                	State of LSA sync with active
                                                	**type**\:   :py:class:`OspfLsaSyncStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncStateEnum>`
                                                
                                                .. attribute:: minute_table_index
                                                
                                                	Minute table index
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: nsr_flood_required
                                                
                                                	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                	**type**\:  bool
                                                
                                                .. attribute:: rate_limit
                                                
                                                	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                	**type**\:  bool
                                                
                                                .. attribute:: second_table_index
                                                
                                                	Second table index
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.free_time = None
                                                    self.is_acknowledged = None
                                                    self.is_advertising_router_reachable = None
                                                    self.is_deleted = None
                                                    self.is_flood_pending = None
                                                    self.is_maximum_aged = None
                                                    self.is_neighbor_exchange = None
                                                    self.is_no_delete = None
                                                    self.is_nsr_ack_pending = None
                                                    self.is_partial_spf = None
                                                    self.is_routing_bit = None
                                                    self.is_routing_table = None
                                                    self.lsa_flood_required_post_fail_over = None
                                                    self.lsa_length = None
                                                    self.lsa_sync_state = None
                                                    self.minute_table_index = None
                                                    self.nsr_flood_required = None
                                                    self.rate_limit = None
                                                    self.second_table_index = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-detail'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.free_time is not None:
                                                        return True

                                                    if self.is_acknowledged is not None:
                                                        return True

                                                    if self.is_advertising_router_reachable is not None:
                                                        return True

                                                    if self.is_deleted is not None:
                                                        return True

                                                    if self.is_flood_pending is not None:
                                                        return True

                                                    if self.is_maximum_aged is not None:
                                                        return True

                                                    if self.is_neighbor_exchange is not None:
                                                        return True

                                                    if self.is_no_delete is not None:
                                                        return True

                                                    if self.is_nsr_ack_pending is not None:
                                                        return True

                                                    if self.is_partial_spf is not None:
                                                        return True

                                                    if self.is_routing_bit is not None:
                                                        return True

                                                    if self.is_routing_table is not None:
                                                        return True

                                                    if self.lsa_flood_required_post_fail_over is not None:
                                                        return True

                                                    if self.lsa_length is not None:
                                                        return True

                                                    if self.lsa_sync_state is not None:
                                                        return True

                                                    if self.minute_table_index is not None:
                                                        return True

                                                    if self.nsr_flood_required is not None:
                                                        return True

                                                    if self.rate_limit is not None:
                                                        return True

                                                    if self.second_table_index is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                    return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType.LsaDetail']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:network-lsa-type'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.lsa_detail is not None and self.lsa_detail._has_data():
                                                    return True

                                                if self.lsa_header is not None and self.lsa_header._has_data():
                                                    return True

                                                if self.neighbor_router is not None:
                                                    for child in self.neighbor_router:
                                                        if child is not None:
                                                            return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType']['meta_info']


                                        class InterAreaPrefixLsaType(object):
                                            """
                                            Inter Area Prefix LSA
                                            
                                            .. attribute:: lsa_detail
                                            
                                            	Detailed LSA Information
                                            	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaDetail>`
                                            
                                            .. attribute:: lsa_header
                                            
                                            	Header information 
                                            	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaHeader>`
                                            
                                            .. attribute:: prefix
                                            
                                            	LSA address prefix 
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: prefix_length
                                            
                                            	Prefix length 
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: priority
                                            
                                            	Prefix priority
                                            	**type**\:   :py:class:`PrefixPriorityEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.PrefixPriorityEnum>`
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaDetail()
                                                self.lsa_detail.parent = self
                                                self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaHeader()
                                                self.lsa_header.parent = self
                                                self.prefix = None
                                                self.prefix_length = None
                                                self.priority = None


                                            class LsaHeader(object):
                                                """
                                                Header information 
                                                
                                                .. attribute:: advertising_router
                                                
                                                	Router ID of Advertising Router
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: checksum
                                                
                                                	Checksum value
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: is_do_not_age_lsa
                                                
                                                	If true, Do Not Age this LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_graceful_restart_active
                                                
                                                	If true, if grace restart is active 
                                                	**type**\:  bool
                                                
                                                .. attribute:: ls_id
                                                
                                                	LS ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: lsa_age
                                                
                                                	LSA's Age (s)
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_area_id
                                                
                                                	Area ID in decimal or dotted\-decimal format
                                                	**type**\:  str
                                                
                                                	**length:** 0..16
                                                
                                                .. attribute:: lsa_type
                                                
                                                	LSA type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: sequence_number
                                                
                                                	Current Sequence number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.advertising_router = None
                                                    self.checksum = None
                                                    self.is_do_not_age_lsa = None
                                                    self.is_graceful_restart_active = None
                                                    self.ls_id = None
                                                    self.lsa_age = None
                                                    self.lsa_area_id = None
                                                    self.lsa_type = None
                                                    self.sequence_number = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-header'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.advertising_router is not None:
                                                        return True

                                                    if self.checksum is not None:
                                                        return True

                                                    if self.is_do_not_age_lsa is not None:
                                                        return True

                                                    if self.is_graceful_restart_active is not None:
                                                        return True

                                                    if self.ls_id is not None:
                                                        return True

                                                    if self.lsa_age is not None:
                                                        return True

                                                    if self.lsa_area_id is not None:
                                                        return True

                                                    if self.lsa_type is not None:
                                                        return True

                                                    if self.sequence_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                    return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaHeader']['meta_info']


                                            class LsaDetail(object):
                                                """
                                                Detailed LSA Information
                                                
                                                .. attribute:: free_time
                                                
                                                	The amount of time since the last check was made to free this LSA (s)
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_acknowledged
                                                
                                                	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_advertising_router_reachable
                                                
                                                	If true, Advertising Router is reachable
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_deleted
                                                
                                                	If true, flag is set to delete this LSA 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_flood_pending
                                                
                                                	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_maximum_aged
                                                
                                                	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_neighbor_exchange
                                                
                                                	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_no_delete
                                                
                                                	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_nsr_ack_pending
                                                
                                                	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_partial_spf
                                                
                                                	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_routing_bit
                                                
                                                	If true, Routing Bit set on the LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_routing_table
                                                
                                                	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                	**type**\:  bool
                                                
                                                .. attribute:: lsa_flood_required_post_fail_over
                                                
                                                	LSA flood required after FO
                                                	**type**\:  bool
                                                
                                                .. attribute:: lsa_length
                                                
                                                	Length of the LSA
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_sync_state
                                                
                                                	State of LSA sync with active
                                                	**type**\:   :py:class:`OspfLsaSyncStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncStateEnum>`
                                                
                                                .. attribute:: minute_table_index
                                                
                                                	Minute table index
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: nsr_flood_required
                                                
                                                	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                	**type**\:  bool
                                                
                                                .. attribute:: rate_limit
                                                
                                                	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                	**type**\:  bool
                                                
                                                .. attribute:: second_table_index
                                                
                                                	Second table index
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.free_time = None
                                                    self.is_acknowledged = None
                                                    self.is_advertising_router_reachable = None
                                                    self.is_deleted = None
                                                    self.is_flood_pending = None
                                                    self.is_maximum_aged = None
                                                    self.is_neighbor_exchange = None
                                                    self.is_no_delete = None
                                                    self.is_nsr_ack_pending = None
                                                    self.is_partial_spf = None
                                                    self.is_routing_bit = None
                                                    self.is_routing_table = None
                                                    self.lsa_flood_required_post_fail_over = None
                                                    self.lsa_length = None
                                                    self.lsa_sync_state = None
                                                    self.minute_table_index = None
                                                    self.nsr_flood_required = None
                                                    self.rate_limit = None
                                                    self.second_table_index = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-detail'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.free_time is not None:
                                                        return True

                                                    if self.is_acknowledged is not None:
                                                        return True

                                                    if self.is_advertising_router_reachable is not None:
                                                        return True

                                                    if self.is_deleted is not None:
                                                        return True

                                                    if self.is_flood_pending is not None:
                                                        return True

                                                    if self.is_maximum_aged is not None:
                                                        return True

                                                    if self.is_neighbor_exchange is not None:
                                                        return True

                                                    if self.is_no_delete is not None:
                                                        return True

                                                    if self.is_nsr_ack_pending is not None:
                                                        return True

                                                    if self.is_partial_spf is not None:
                                                        return True

                                                    if self.is_routing_bit is not None:
                                                        return True

                                                    if self.is_routing_table is not None:
                                                        return True

                                                    if self.lsa_flood_required_post_fail_over is not None:
                                                        return True

                                                    if self.lsa_length is not None:
                                                        return True

                                                    if self.lsa_sync_state is not None:
                                                        return True

                                                    if self.minute_table_index is not None:
                                                        return True

                                                    if self.nsr_flood_required is not None:
                                                        return True

                                                    if self.rate_limit is not None:
                                                        return True

                                                    if self.second_table_index is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                    return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaDetail']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:inter-area-prefix-lsa-type'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.lsa_detail is not None and self.lsa_detail._has_data():
                                                    return True

                                                if self.lsa_header is not None and self.lsa_header._has_data():
                                                    return True

                                                if self.prefix is not None:
                                                    return True

                                                if self.prefix_length is not None:
                                                    return True

                                                if self.priority is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType']['meta_info']


                                        class InterAreaRouterLsaType(object):
                                            """
                                            Inter Area Router LSA
                                            
                                            .. attribute:: lsa_detail
                                            
                                            	Detailed LSA information
                                            	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaDetail>`
                                            
                                            .. attribute:: lsa_header
                                            
                                            	Header information 
                                            	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaHeader>`
                                            
                                            .. attribute:: lsa_router_id
                                            
                                            	LSA router ID 
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaDetail()
                                                self.lsa_detail.parent = self
                                                self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaHeader()
                                                self.lsa_header.parent = self
                                                self.lsa_router_id = None


                                            class LsaHeader(object):
                                                """
                                                Header information 
                                                
                                                .. attribute:: advertising_router
                                                
                                                	Router ID of Advertising Router
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: checksum
                                                
                                                	Checksum value
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: is_do_not_age_lsa
                                                
                                                	If true, Do Not Age this LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_graceful_restart_active
                                                
                                                	If true, if grace restart is active 
                                                	**type**\:  bool
                                                
                                                .. attribute:: ls_id
                                                
                                                	LS ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: lsa_age
                                                
                                                	LSA's Age (s)
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_area_id
                                                
                                                	Area ID in decimal or dotted\-decimal format
                                                	**type**\:  str
                                                
                                                	**length:** 0..16
                                                
                                                .. attribute:: lsa_type
                                                
                                                	LSA type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: sequence_number
                                                
                                                	Current Sequence number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.advertising_router = None
                                                    self.checksum = None
                                                    self.is_do_not_age_lsa = None
                                                    self.is_graceful_restart_active = None
                                                    self.ls_id = None
                                                    self.lsa_age = None
                                                    self.lsa_area_id = None
                                                    self.lsa_type = None
                                                    self.sequence_number = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-header'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.advertising_router is not None:
                                                        return True

                                                    if self.checksum is not None:
                                                        return True

                                                    if self.is_do_not_age_lsa is not None:
                                                        return True

                                                    if self.is_graceful_restart_active is not None:
                                                        return True

                                                    if self.ls_id is not None:
                                                        return True

                                                    if self.lsa_age is not None:
                                                        return True

                                                    if self.lsa_area_id is not None:
                                                        return True

                                                    if self.lsa_type is not None:
                                                        return True

                                                    if self.sequence_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                    return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaHeader']['meta_info']


                                            class LsaDetail(object):
                                                """
                                                Detailed LSA information
                                                
                                                .. attribute:: free_time
                                                
                                                	The amount of time since the last check was made to free this LSA (s)
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_acknowledged
                                                
                                                	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_advertising_router_reachable
                                                
                                                	If true, Advertising Router is reachable
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_deleted
                                                
                                                	If true, flag is set to delete this LSA 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_flood_pending
                                                
                                                	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_maximum_aged
                                                
                                                	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_neighbor_exchange
                                                
                                                	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_no_delete
                                                
                                                	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_nsr_ack_pending
                                                
                                                	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_partial_spf
                                                
                                                	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_routing_bit
                                                
                                                	If true, Routing Bit set on the LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_routing_table
                                                
                                                	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                	**type**\:  bool
                                                
                                                .. attribute:: lsa_flood_required_post_fail_over
                                                
                                                	LSA flood required after FO
                                                	**type**\:  bool
                                                
                                                .. attribute:: lsa_length
                                                
                                                	Length of the LSA
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_sync_state
                                                
                                                	State of LSA sync with active
                                                	**type**\:   :py:class:`OspfLsaSyncStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncStateEnum>`
                                                
                                                .. attribute:: minute_table_index
                                                
                                                	Minute table index
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: nsr_flood_required
                                                
                                                	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                	**type**\:  bool
                                                
                                                .. attribute:: rate_limit
                                                
                                                	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                	**type**\:  bool
                                                
                                                .. attribute:: second_table_index
                                                
                                                	Second table index
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.free_time = None
                                                    self.is_acknowledged = None
                                                    self.is_advertising_router_reachable = None
                                                    self.is_deleted = None
                                                    self.is_flood_pending = None
                                                    self.is_maximum_aged = None
                                                    self.is_neighbor_exchange = None
                                                    self.is_no_delete = None
                                                    self.is_nsr_ack_pending = None
                                                    self.is_partial_spf = None
                                                    self.is_routing_bit = None
                                                    self.is_routing_table = None
                                                    self.lsa_flood_required_post_fail_over = None
                                                    self.lsa_length = None
                                                    self.lsa_sync_state = None
                                                    self.minute_table_index = None
                                                    self.nsr_flood_required = None
                                                    self.rate_limit = None
                                                    self.second_table_index = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-detail'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.free_time is not None:
                                                        return True

                                                    if self.is_acknowledged is not None:
                                                        return True

                                                    if self.is_advertising_router_reachable is not None:
                                                        return True

                                                    if self.is_deleted is not None:
                                                        return True

                                                    if self.is_flood_pending is not None:
                                                        return True

                                                    if self.is_maximum_aged is not None:
                                                        return True

                                                    if self.is_neighbor_exchange is not None:
                                                        return True

                                                    if self.is_no_delete is not None:
                                                        return True

                                                    if self.is_nsr_ack_pending is not None:
                                                        return True

                                                    if self.is_partial_spf is not None:
                                                        return True

                                                    if self.is_routing_bit is not None:
                                                        return True

                                                    if self.is_routing_table is not None:
                                                        return True

                                                    if self.lsa_flood_required_post_fail_over is not None:
                                                        return True

                                                    if self.lsa_length is not None:
                                                        return True

                                                    if self.lsa_sync_state is not None:
                                                        return True

                                                    if self.minute_table_index is not None:
                                                        return True

                                                    if self.nsr_flood_required is not None:
                                                        return True

                                                    if self.rate_limit is not None:
                                                        return True

                                                    if self.second_table_index is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                    return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaDetail']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:inter-area-router-lsa-type'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.lsa_detail is not None and self.lsa_detail._has_data():
                                                    return True

                                                if self.lsa_header is not None and self.lsa_header._has_data():
                                                    return True

                                                if self.lsa_router_id is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType']['meta_info']


                                        class ExternalLsaType(object):
                                            """
                                            External LSA
                                            
                                            .. attribute:: external_tag
                                            
                                            	Route Tag
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: forwarding_address
                                            
                                            	Forwarding Address
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: is_forwarding_address_set
                                            
                                            	If true, forwarding address is set 
                                            	**type**\:  bool
                                            
                                            .. attribute:: lsa_detail
                                            
                                            	Detailed LSA Information
                                            	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType.LsaDetail>`
                                            
                                            .. attribute:: lsa_header
                                            
                                            	Header information 
                                            	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType.LsaHeader>`
                                            
                                            .. attribute:: metric_type
                                            
                                            	Metric type 
                                            	**type**\:   :py:class:`Ospfv3DefaultMetricEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3DefaultMetricEnum>`
                                            
                                            .. attribute:: prefix
                                            
                                            	IPV6 address prefix 
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: prefix_length
                                            
                                            	Prefix length 
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: priority
                                            
                                            	Prefix priority
                                            	**type**\:   :py:class:`PrefixPriorityEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.PrefixPriorityEnum>`
                                            
                                            .. attribute:: tos_cost
                                            
                                            	Type of service cost metric 
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.external_tag = None
                                                self.forwarding_address = None
                                                self.is_forwarding_address_set = None
                                                self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType.LsaDetail()
                                                self.lsa_detail.parent = self
                                                self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType.LsaHeader()
                                                self.lsa_header.parent = self
                                                self.metric_type = None
                                                self.prefix = None
                                                self.prefix_length = None
                                                self.priority = None
                                                self.tos_cost = None


                                            class LsaHeader(object):
                                                """
                                                Header information 
                                                
                                                .. attribute:: advertising_router
                                                
                                                	Router ID of Advertising Router
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: checksum
                                                
                                                	Checksum value
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: is_do_not_age_lsa
                                                
                                                	If true, Do Not Age this LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_graceful_restart_active
                                                
                                                	If true, if grace restart is active 
                                                	**type**\:  bool
                                                
                                                .. attribute:: ls_id
                                                
                                                	LS ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: lsa_age
                                                
                                                	LSA's Age (s)
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_area_id
                                                
                                                	Area ID in decimal or dotted\-decimal format
                                                	**type**\:  str
                                                
                                                	**length:** 0..16
                                                
                                                .. attribute:: lsa_type
                                                
                                                	LSA type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: sequence_number
                                                
                                                	Current Sequence number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.advertising_router = None
                                                    self.checksum = None
                                                    self.is_do_not_age_lsa = None
                                                    self.is_graceful_restart_active = None
                                                    self.ls_id = None
                                                    self.lsa_age = None
                                                    self.lsa_area_id = None
                                                    self.lsa_type = None
                                                    self.sequence_number = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-header'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.advertising_router is not None:
                                                        return True

                                                    if self.checksum is not None:
                                                        return True

                                                    if self.is_do_not_age_lsa is not None:
                                                        return True

                                                    if self.is_graceful_restart_active is not None:
                                                        return True

                                                    if self.ls_id is not None:
                                                        return True

                                                    if self.lsa_age is not None:
                                                        return True

                                                    if self.lsa_area_id is not None:
                                                        return True

                                                    if self.lsa_type is not None:
                                                        return True

                                                    if self.sequence_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                    return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType.LsaHeader']['meta_info']


                                            class LsaDetail(object):
                                                """
                                                Detailed LSA Information
                                                
                                                .. attribute:: free_time
                                                
                                                	The amount of time since the last check was made to free this LSA (s)
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_acknowledged
                                                
                                                	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_advertising_router_reachable
                                                
                                                	If true, Advertising Router is reachable
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_deleted
                                                
                                                	If true, flag is set to delete this LSA 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_flood_pending
                                                
                                                	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_maximum_aged
                                                
                                                	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_neighbor_exchange
                                                
                                                	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_no_delete
                                                
                                                	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_nsr_ack_pending
                                                
                                                	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_partial_spf
                                                
                                                	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_routing_bit
                                                
                                                	If true, Routing Bit set on the LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_routing_table
                                                
                                                	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                	**type**\:  bool
                                                
                                                .. attribute:: lsa_flood_required_post_fail_over
                                                
                                                	LSA flood required after FO
                                                	**type**\:  bool
                                                
                                                .. attribute:: lsa_length
                                                
                                                	Length of the LSA
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_sync_state
                                                
                                                	State of LSA sync with active
                                                	**type**\:   :py:class:`OspfLsaSyncStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncStateEnum>`
                                                
                                                .. attribute:: minute_table_index
                                                
                                                	Minute table index
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: nsr_flood_required
                                                
                                                	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                	**type**\:  bool
                                                
                                                .. attribute:: rate_limit
                                                
                                                	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                	**type**\:  bool
                                                
                                                .. attribute:: second_table_index
                                                
                                                	Second table index
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.free_time = None
                                                    self.is_acknowledged = None
                                                    self.is_advertising_router_reachable = None
                                                    self.is_deleted = None
                                                    self.is_flood_pending = None
                                                    self.is_maximum_aged = None
                                                    self.is_neighbor_exchange = None
                                                    self.is_no_delete = None
                                                    self.is_nsr_ack_pending = None
                                                    self.is_partial_spf = None
                                                    self.is_routing_bit = None
                                                    self.is_routing_table = None
                                                    self.lsa_flood_required_post_fail_over = None
                                                    self.lsa_length = None
                                                    self.lsa_sync_state = None
                                                    self.minute_table_index = None
                                                    self.nsr_flood_required = None
                                                    self.rate_limit = None
                                                    self.second_table_index = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-detail'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.free_time is not None:
                                                        return True

                                                    if self.is_acknowledged is not None:
                                                        return True

                                                    if self.is_advertising_router_reachable is not None:
                                                        return True

                                                    if self.is_deleted is not None:
                                                        return True

                                                    if self.is_flood_pending is not None:
                                                        return True

                                                    if self.is_maximum_aged is not None:
                                                        return True

                                                    if self.is_neighbor_exchange is not None:
                                                        return True

                                                    if self.is_no_delete is not None:
                                                        return True

                                                    if self.is_nsr_ack_pending is not None:
                                                        return True

                                                    if self.is_partial_spf is not None:
                                                        return True

                                                    if self.is_routing_bit is not None:
                                                        return True

                                                    if self.is_routing_table is not None:
                                                        return True

                                                    if self.lsa_flood_required_post_fail_over is not None:
                                                        return True

                                                    if self.lsa_length is not None:
                                                        return True

                                                    if self.lsa_sync_state is not None:
                                                        return True

                                                    if self.minute_table_index is not None:
                                                        return True

                                                    if self.nsr_flood_required is not None:
                                                        return True

                                                    if self.rate_limit is not None:
                                                        return True

                                                    if self.second_table_index is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                    return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType.LsaDetail']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:external-lsa-type'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.external_tag is not None:
                                                    return True

                                                if self.forwarding_address is not None:
                                                    return True

                                                if self.is_forwarding_address_set is not None:
                                                    return True

                                                if self.lsa_detail is not None and self.lsa_detail._has_data():
                                                    return True

                                                if self.lsa_header is not None and self.lsa_header._has_data():
                                                    return True

                                                if self.metric_type is not None:
                                                    return True

                                                if self.prefix is not None:
                                                    return True

                                                if self.prefix_length is not None:
                                                    return True

                                                if self.priority is not None:
                                                    return True

                                                if self.tos_cost is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType']['meta_info']


                                        class NssalsaType(object):
                                            """
                                            NSSA External LSA
                                            
                                            .. attribute:: external_tag
                                            
                                            	Route Tag
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: forwarding_address
                                            
                                            	Forwarding Address
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: is_forwarding_address_set
                                            
                                            	If true, forwarding address is set 
                                            	**type**\:  bool
                                            
                                            .. attribute:: lsa_detail
                                            
                                            	Detailed LSA Information
                                            	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType.LsaDetail>`
                                            
                                            .. attribute:: lsa_header
                                            
                                            	Header information 
                                            	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType.LsaHeader>`
                                            
                                            .. attribute:: metric_type
                                            
                                            	Metric type 
                                            	**type**\:   :py:class:`Ospfv3DefaultMetricEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3DefaultMetricEnum>`
                                            
                                            .. attribute:: prefix
                                            
                                            	IPV6 address prefix 
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: prefix_length
                                            
                                            	Prefix length 
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: priority
                                            
                                            	Prefix priority
                                            	**type**\:   :py:class:`PrefixPriorityEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.PrefixPriorityEnum>`
                                            
                                            .. attribute:: tos_cost
                                            
                                            	Type of service cost metric 
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.external_tag = None
                                                self.forwarding_address = None
                                                self.is_forwarding_address_set = None
                                                self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType.LsaDetail()
                                                self.lsa_detail.parent = self
                                                self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType.LsaHeader()
                                                self.lsa_header.parent = self
                                                self.metric_type = None
                                                self.prefix = None
                                                self.prefix_length = None
                                                self.priority = None
                                                self.tos_cost = None


                                            class LsaHeader(object):
                                                """
                                                Header information 
                                                
                                                .. attribute:: advertising_router
                                                
                                                	Router ID of Advertising Router
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: checksum
                                                
                                                	Checksum value
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: is_do_not_age_lsa
                                                
                                                	If true, Do Not Age this LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_graceful_restart_active
                                                
                                                	If true, if grace restart is active 
                                                	**type**\:  bool
                                                
                                                .. attribute:: ls_id
                                                
                                                	LS ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: lsa_age
                                                
                                                	LSA's Age (s)
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_area_id
                                                
                                                	Area ID in decimal or dotted\-decimal format
                                                	**type**\:  str
                                                
                                                	**length:** 0..16
                                                
                                                .. attribute:: lsa_type
                                                
                                                	LSA type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: sequence_number
                                                
                                                	Current Sequence number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.advertising_router = None
                                                    self.checksum = None
                                                    self.is_do_not_age_lsa = None
                                                    self.is_graceful_restart_active = None
                                                    self.ls_id = None
                                                    self.lsa_age = None
                                                    self.lsa_area_id = None
                                                    self.lsa_type = None
                                                    self.sequence_number = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-header'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.advertising_router is not None:
                                                        return True

                                                    if self.checksum is not None:
                                                        return True

                                                    if self.is_do_not_age_lsa is not None:
                                                        return True

                                                    if self.is_graceful_restart_active is not None:
                                                        return True

                                                    if self.ls_id is not None:
                                                        return True

                                                    if self.lsa_age is not None:
                                                        return True

                                                    if self.lsa_area_id is not None:
                                                        return True

                                                    if self.lsa_type is not None:
                                                        return True

                                                    if self.sequence_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                    return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType.LsaHeader']['meta_info']


                                            class LsaDetail(object):
                                                """
                                                Detailed LSA Information
                                                
                                                .. attribute:: free_time
                                                
                                                	The amount of time since the last check was made to free this LSA (s)
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_acknowledged
                                                
                                                	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_advertising_router_reachable
                                                
                                                	If true, Advertising Router is reachable
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_deleted
                                                
                                                	If true, flag is set to delete this LSA 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_flood_pending
                                                
                                                	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_maximum_aged
                                                
                                                	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_neighbor_exchange
                                                
                                                	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_no_delete
                                                
                                                	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_nsr_ack_pending
                                                
                                                	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_partial_spf
                                                
                                                	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_routing_bit
                                                
                                                	If true, Routing Bit set on the LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_routing_table
                                                
                                                	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                	**type**\:  bool
                                                
                                                .. attribute:: lsa_flood_required_post_fail_over
                                                
                                                	LSA flood required after FO
                                                	**type**\:  bool
                                                
                                                .. attribute:: lsa_length
                                                
                                                	Length of the LSA
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_sync_state
                                                
                                                	State of LSA sync with active
                                                	**type**\:   :py:class:`OspfLsaSyncStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncStateEnum>`
                                                
                                                .. attribute:: minute_table_index
                                                
                                                	Minute table index
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: nsr_flood_required
                                                
                                                	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                	**type**\:  bool
                                                
                                                .. attribute:: rate_limit
                                                
                                                	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                	**type**\:  bool
                                                
                                                .. attribute:: second_table_index
                                                
                                                	Second table index
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.free_time = None
                                                    self.is_acknowledged = None
                                                    self.is_advertising_router_reachable = None
                                                    self.is_deleted = None
                                                    self.is_flood_pending = None
                                                    self.is_maximum_aged = None
                                                    self.is_neighbor_exchange = None
                                                    self.is_no_delete = None
                                                    self.is_nsr_ack_pending = None
                                                    self.is_partial_spf = None
                                                    self.is_routing_bit = None
                                                    self.is_routing_table = None
                                                    self.lsa_flood_required_post_fail_over = None
                                                    self.lsa_length = None
                                                    self.lsa_sync_state = None
                                                    self.minute_table_index = None
                                                    self.nsr_flood_required = None
                                                    self.rate_limit = None
                                                    self.second_table_index = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-detail'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.free_time is not None:
                                                        return True

                                                    if self.is_acknowledged is not None:
                                                        return True

                                                    if self.is_advertising_router_reachable is not None:
                                                        return True

                                                    if self.is_deleted is not None:
                                                        return True

                                                    if self.is_flood_pending is not None:
                                                        return True

                                                    if self.is_maximum_aged is not None:
                                                        return True

                                                    if self.is_neighbor_exchange is not None:
                                                        return True

                                                    if self.is_no_delete is not None:
                                                        return True

                                                    if self.is_nsr_ack_pending is not None:
                                                        return True

                                                    if self.is_partial_spf is not None:
                                                        return True

                                                    if self.is_routing_bit is not None:
                                                        return True

                                                    if self.is_routing_table is not None:
                                                        return True

                                                    if self.lsa_flood_required_post_fail_over is not None:
                                                        return True

                                                    if self.lsa_length is not None:
                                                        return True

                                                    if self.lsa_sync_state is not None:
                                                        return True

                                                    if self.minute_table_index is not None:
                                                        return True

                                                    if self.nsr_flood_required is not None:
                                                        return True

                                                    if self.rate_limit is not None:
                                                        return True

                                                    if self.second_table_index is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                    return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType.LsaDetail']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:nssalsa-type'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.external_tag is not None:
                                                    return True

                                                if self.forwarding_address is not None:
                                                    return True

                                                if self.is_forwarding_address_set is not None:
                                                    return True

                                                if self.lsa_detail is not None and self.lsa_detail._has_data():
                                                    return True

                                                if self.lsa_header is not None and self.lsa_header._has_data():
                                                    return True

                                                if self.metric_type is not None:
                                                    return True

                                                if self.prefix is not None:
                                                    return True

                                                if self.prefix_length is not None:
                                                    return True

                                                if self.priority is not None:
                                                    return True

                                                if self.tos_cost is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType']['meta_info']


                                        class LinkLsaType(object):
                                            """
                                            Link LSA
                                            
                                            .. attribute:: interface_name
                                            
                                            	LSA interface handle
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                            
                                            .. attribute:: is_sham_link
                                            
                                            	If true, it is a sham link
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_virtual_link
                                            
                                            	If true, it is a virtual link
                                            	**type**\:  bool
                                            
                                            .. attribute:: lsa_detail
                                            
                                            	Detailed LSA information
                                            	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType.LsaDetail>`
                                            
                                            .. attribute:: lsa_header
                                            
                                            	Header information 
                                            	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType.LsaHeader>`
                                            
                                            .. attribute:: lsa_link_local
                                            
                                            	LSA link local 
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: prefix
                                            
                                            	OSPFv3 prefix 
                                            	**type**\: list of    :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType.Prefix>`
                                            
                                            .. attribute:: router_priority
                                            
                                            	Router priority 
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: sham_link_id
                                            
                                            	Sham link ID 
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: virtual_link_id
                                            
                                            	Virtual link ID 
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface_name = None
                                                self.is_sham_link = None
                                                self.is_virtual_link = None
                                                self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType.LsaDetail()
                                                self.lsa_detail.parent = self
                                                self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType.LsaHeader()
                                                self.lsa_header.parent = self
                                                self.lsa_link_local = None
                                                self.prefix = YList()
                                                self.prefix.parent = self
                                                self.prefix.name = 'prefix'
                                                self.router_priority = None
                                                self.sham_link_id = None
                                                self.virtual_link_id = None


                                            class LsaHeader(object):
                                                """
                                                Header information 
                                                
                                                .. attribute:: advertising_router
                                                
                                                	Router ID of Advertising Router
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: checksum
                                                
                                                	Checksum value
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: is_do_not_age_lsa
                                                
                                                	If true, Do Not Age this LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_graceful_restart_active
                                                
                                                	If true, if grace restart is active 
                                                	**type**\:  bool
                                                
                                                .. attribute:: ls_id
                                                
                                                	LS ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: lsa_age
                                                
                                                	LSA's Age (s)
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_area_id
                                                
                                                	Area ID in decimal or dotted\-decimal format
                                                	**type**\:  str
                                                
                                                	**length:** 0..16
                                                
                                                .. attribute:: lsa_type
                                                
                                                	LSA type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: sequence_number
                                                
                                                	Current Sequence number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.advertising_router = None
                                                    self.checksum = None
                                                    self.is_do_not_age_lsa = None
                                                    self.is_graceful_restart_active = None
                                                    self.ls_id = None
                                                    self.lsa_age = None
                                                    self.lsa_area_id = None
                                                    self.lsa_type = None
                                                    self.sequence_number = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-header'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.advertising_router is not None:
                                                        return True

                                                    if self.checksum is not None:
                                                        return True

                                                    if self.is_do_not_age_lsa is not None:
                                                        return True

                                                    if self.is_graceful_restart_active is not None:
                                                        return True

                                                    if self.ls_id is not None:
                                                        return True

                                                    if self.lsa_age is not None:
                                                        return True

                                                    if self.lsa_area_id is not None:
                                                        return True

                                                    if self.lsa_type is not None:
                                                        return True

                                                    if self.sequence_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                    return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType.LsaHeader']['meta_info']


                                            class LsaDetail(object):
                                                """
                                                Detailed LSA information
                                                
                                                .. attribute:: free_time
                                                
                                                	The amount of time since the last check was made to free this LSA (s)
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_acknowledged
                                                
                                                	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_advertising_router_reachable
                                                
                                                	If true, Advertising Router is reachable
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_deleted
                                                
                                                	If true, flag is set to delete this LSA 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_flood_pending
                                                
                                                	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_maximum_aged
                                                
                                                	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_neighbor_exchange
                                                
                                                	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_no_delete
                                                
                                                	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_nsr_ack_pending
                                                
                                                	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_partial_spf
                                                
                                                	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_routing_bit
                                                
                                                	If true, Routing Bit set on the LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_routing_table
                                                
                                                	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                	**type**\:  bool
                                                
                                                .. attribute:: lsa_flood_required_post_fail_over
                                                
                                                	LSA flood required after FO
                                                	**type**\:  bool
                                                
                                                .. attribute:: lsa_length
                                                
                                                	Length of the LSA
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_sync_state
                                                
                                                	State of LSA sync with active
                                                	**type**\:   :py:class:`OspfLsaSyncStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncStateEnum>`
                                                
                                                .. attribute:: minute_table_index
                                                
                                                	Minute table index
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: nsr_flood_required
                                                
                                                	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                	**type**\:  bool
                                                
                                                .. attribute:: rate_limit
                                                
                                                	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                	**type**\:  bool
                                                
                                                .. attribute:: second_table_index
                                                
                                                	Second table index
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.free_time = None
                                                    self.is_acknowledged = None
                                                    self.is_advertising_router_reachable = None
                                                    self.is_deleted = None
                                                    self.is_flood_pending = None
                                                    self.is_maximum_aged = None
                                                    self.is_neighbor_exchange = None
                                                    self.is_no_delete = None
                                                    self.is_nsr_ack_pending = None
                                                    self.is_partial_spf = None
                                                    self.is_routing_bit = None
                                                    self.is_routing_table = None
                                                    self.lsa_flood_required_post_fail_over = None
                                                    self.lsa_length = None
                                                    self.lsa_sync_state = None
                                                    self.minute_table_index = None
                                                    self.nsr_flood_required = None
                                                    self.rate_limit = None
                                                    self.second_table_index = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-detail'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.free_time is not None:
                                                        return True

                                                    if self.is_acknowledged is not None:
                                                        return True

                                                    if self.is_advertising_router_reachable is not None:
                                                        return True

                                                    if self.is_deleted is not None:
                                                        return True

                                                    if self.is_flood_pending is not None:
                                                        return True

                                                    if self.is_maximum_aged is not None:
                                                        return True

                                                    if self.is_neighbor_exchange is not None:
                                                        return True

                                                    if self.is_no_delete is not None:
                                                        return True

                                                    if self.is_nsr_ack_pending is not None:
                                                        return True

                                                    if self.is_partial_spf is not None:
                                                        return True

                                                    if self.is_routing_bit is not None:
                                                        return True

                                                    if self.is_routing_table is not None:
                                                        return True

                                                    if self.lsa_flood_required_post_fail_over is not None:
                                                        return True

                                                    if self.lsa_length is not None:
                                                        return True

                                                    if self.lsa_sync_state is not None:
                                                        return True

                                                    if self.minute_table_index is not None:
                                                        return True

                                                    if self.nsr_flood_required is not None:
                                                        return True

                                                    if self.rate_limit is not None:
                                                        return True

                                                    if self.second_table_index is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                    return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType.LsaDetail']['meta_info']


                                            class Prefix(object):
                                                """
                                                OSPFv3 prefix 
                                                
                                                .. attribute:: ospfv3_prefix_length
                                                
                                                	OSPFv3 prefix length 
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: ospfv3_prefix_metric
                                                
                                                	OSPFv3 prefix metric 
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: ospfv3_prefix_options
                                                
                                                	OSPFv3 prefix options 
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: prefix
                                                
                                                	OSPFv3 prefix 
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: priority
                                                
                                                	Prefix priority
                                                	**type**\:   :py:class:`PrefixPriorityEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.PrefixPriorityEnum>`
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ospfv3_prefix_length = None
                                                    self.ospfv3_prefix_metric = None
                                                    self.ospfv3_prefix_options = None
                                                    self.prefix = None
                                                    self.priority = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:prefix'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ospfv3_prefix_length is not None:
                                                        return True

                                                    if self.ospfv3_prefix_metric is not None:
                                                        return True

                                                    if self.ospfv3_prefix_options is not None:
                                                        return True

                                                    if self.prefix is not None:
                                                        return True

                                                    if self.priority is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                    return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType.Prefix']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:link-lsa-type'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface_name is not None:
                                                    return True

                                                if self.is_sham_link is not None:
                                                    return True

                                                if self.is_virtual_link is not None:
                                                    return True

                                                if self.lsa_detail is not None and self.lsa_detail._has_data():
                                                    return True

                                                if self.lsa_header is not None and self.lsa_header._has_data():
                                                    return True

                                                if self.lsa_link_local is not None:
                                                    return True

                                                if self.prefix is not None:
                                                    for child_ref in self.prefix:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.router_priority is not None:
                                                    return True

                                                if self.sham_link_id is not None:
                                                    return True

                                                if self.virtual_link_id is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType']['meta_info']


                                        class IntraAreaPrefixLsaType(object):
                                            """
                                            Intra Area Prefix LSA
                                            
                                            .. attribute:: lsa_detail
                                            
                                            	Detailed LSA information
                                            	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaDetail>`
                                            
                                            .. attribute:: lsa_header
                                            
                                            	Header information 
                                            	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaHeader>`
                                            
                                            .. attribute:: prefix
                                            
                                            	OSPFv3 prefix 
                                            	**type**\: list of    :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.Prefix>`
                                            
                                            .. attribute:: reference_advertised_router
                                            
                                            	Reference advertised router 
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: reference_lsa_id
                                            
                                            	Reference LSA ID 
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: reference_type
                                            
                                            	Reference type 
                                            	**type**\:   :py:class:`Ospfv3Lsa1Enum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Lsa1Enum>`
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaDetail()
                                                self.lsa_detail.parent = self
                                                self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaHeader()
                                                self.lsa_header.parent = self
                                                self.prefix = YList()
                                                self.prefix.parent = self
                                                self.prefix.name = 'prefix'
                                                self.reference_advertised_router = None
                                                self.reference_lsa_id = None
                                                self.reference_type = None


                                            class LsaHeader(object):
                                                """
                                                Header information 
                                                
                                                .. attribute:: advertising_router
                                                
                                                	Router ID of Advertising Router
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: checksum
                                                
                                                	Checksum value
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: is_do_not_age_lsa
                                                
                                                	If true, Do Not Age this LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_graceful_restart_active
                                                
                                                	If true, if grace restart is active 
                                                	**type**\:  bool
                                                
                                                .. attribute:: ls_id
                                                
                                                	LS ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: lsa_age
                                                
                                                	LSA's Age (s)
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_area_id
                                                
                                                	Area ID in decimal or dotted\-decimal format
                                                	**type**\:  str
                                                
                                                	**length:** 0..16
                                                
                                                .. attribute:: lsa_type
                                                
                                                	LSA type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: sequence_number
                                                
                                                	Current Sequence number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.advertising_router = None
                                                    self.checksum = None
                                                    self.is_do_not_age_lsa = None
                                                    self.is_graceful_restart_active = None
                                                    self.ls_id = None
                                                    self.lsa_age = None
                                                    self.lsa_area_id = None
                                                    self.lsa_type = None
                                                    self.sequence_number = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-header'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.advertising_router is not None:
                                                        return True

                                                    if self.checksum is not None:
                                                        return True

                                                    if self.is_do_not_age_lsa is not None:
                                                        return True

                                                    if self.is_graceful_restart_active is not None:
                                                        return True

                                                    if self.ls_id is not None:
                                                        return True

                                                    if self.lsa_age is not None:
                                                        return True

                                                    if self.lsa_area_id is not None:
                                                        return True

                                                    if self.lsa_type is not None:
                                                        return True

                                                    if self.sequence_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                    return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaHeader']['meta_info']


                                            class LsaDetail(object):
                                                """
                                                Detailed LSA information
                                                
                                                .. attribute:: free_time
                                                
                                                	The amount of time since the last check was made to free this LSA (s)
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_acknowledged
                                                
                                                	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_advertising_router_reachable
                                                
                                                	If true, Advertising Router is reachable
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_deleted
                                                
                                                	If true, flag is set to delete this LSA 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_flood_pending
                                                
                                                	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_maximum_aged
                                                
                                                	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_neighbor_exchange
                                                
                                                	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_no_delete
                                                
                                                	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_nsr_ack_pending
                                                
                                                	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_partial_spf
                                                
                                                	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_routing_bit
                                                
                                                	If true, Routing Bit set on the LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_routing_table
                                                
                                                	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                	**type**\:  bool
                                                
                                                .. attribute:: lsa_flood_required_post_fail_over
                                                
                                                	LSA flood required after FO
                                                	**type**\:  bool
                                                
                                                .. attribute:: lsa_length
                                                
                                                	Length of the LSA
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_sync_state
                                                
                                                	State of LSA sync with active
                                                	**type**\:   :py:class:`OspfLsaSyncStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncStateEnum>`
                                                
                                                .. attribute:: minute_table_index
                                                
                                                	Minute table index
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: nsr_flood_required
                                                
                                                	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                	**type**\:  bool
                                                
                                                .. attribute:: rate_limit
                                                
                                                	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                	**type**\:  bool
                                                
                                                .. attribute:: second_table_index
                                                
                                                	Second table index
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.free_time = None
                                                    self.is_acknowledged = None
                                                    self.is_advertising_router_reachable = None
                                                    self.is_deleted = None
                                                    self.is_flood_pending = None
                                                    self.is_maximum_aged = None
                                                    self.is_neighbor_exchange = None
                                                    self.is_no_delete = None
                                                    self.is_nsr_ack_pending = None
                                                    self.is_partial_spf = None
                                                    self.is_routing_bit = None
                                                    self.is_routing_table = None
                                                    self.lsa_flood_required_post_fail_over = None
                                                    self.lsa_length = None
                                                    self.lsa_sync_state = None
                                                    self.minute_table_index = None
                                                    self.nsr_flood_required = None
                                                    self.rate_limit = None
                                                    self.second_table_index = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-detail'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.free_time is not None:
                                                        return True

                                                    if self.is_acknowledged is not None:
                                                        return True

                                                    if self.is_advertising_router_reachable is not None:
                                                        return True

                                                    if self.is_deleted is not None:
                                                        return True

                                                    if self.is_flood_pending is not None:
                                                        return True

                                                    if self.is_maximum_aged is not None:
                                                        return True

                                                    if self.is_neighbor_exchange is not None:
                                                        return True

                                                    if self.is_no_delete is not None:
                                                        return True

                                                    if self.is_nsr_ack_pending is not None:
                                                        return True

                                                    if self.is_partial_spf is not None:
                                                        return True

                                                    if self.is_routing_bit is not None:
                                                        return True

                                                    if self.is_routing_table is not None:
                                                        return True

                                                    if self.lsa_flood_required_post_fail_over is not None:
                                                        return True

                                                    if self.lsa_length is not None:
                                                        return True

                                                    if self.lsa_sync_state is not None:
                                                        return True

                                                    if self.minute_table_index is not None:
                                                        return True

                                                    if self.nsr_flood_required is not None:
                                                        return True

                                                    if self.rate_limit is not None:
                                                        return True

                                                    if self.second_table_index is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                    return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaDetail']['meta_info']


                                            class Prefix(object):
                                                """
                                                OSPFv3 prefix 
                                                
                                                .. attribute:: ospfv3_prefix_length
                                                
                                                	OSPFv3 prefix length 
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: ospfv3_prefix_metric
                                                
                                                	OSPFv3 prefix metric 
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: ospfv3_prefix_options
                                                
                                                	OSPFv3 prefix options 
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: prefix
                                                
                                                	OSPFv3 prefix 
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: priority
                                                
                                                	Prefix priority
                                                	**type**\:   :py:class:`PrefixPriorityEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.PrefixPriorityEnum>`
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ospfv3_prefix_length = None
                                                    self.ospfv3_prefix_metric = None
                                                    self.ospfv3_prefix_options = None
                                                    self.prefix = None
                                                    self.priority = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:prefix'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ospfv3_prefix_length is not None:
                                                        return True

                                                    if self.ospfv3_prefix_metric is not None:
                                                        return True

                                                    if self.ospfv3_prefix_options is not None:
                                                        return True

                                                    if self.prefix is not None:
                                                        return True

                                                    if self.priority is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                    return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.Prefix']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:intra-area-prefix-lsa-type'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.lsa_detail is not None and self.lsa_detail._has_data():
                                                    return True

                                                if self.lsa_header is not None and self.lsa_header._has_data():
                                                    return True

                                                if self.prefix is not None:
                                                    for child_ref in self.prefix:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.reference_advertised_router is not None:
                                                    return True

                                                if self.reference_lsa_id is not None:
                                                    return True

                                                if self.reference_type is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType']['meta_info']


                                        class GraceLsa(object):
                                            """
                                            Grace LSA
                                            
                                            .. attribute:: grace_period
                                            
                                            	The grace periord where helper routers should wait before advertising it fully adjacent(s) 
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: grace_reason
                                            
                                            	Reason for router restart
                                            	**type**\:   :py:class:`Ospfv3GracefulRestartReasonEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3GracefulRestartReasonEnum>`
                                            
                                            .. attribute:: lsa_detail
                                            
                                            	Detailed LSA information
                                            	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa.LsaDetail>`
                                            
                                            .. attribute:: lsa_header
                                            
                                            	Header information 
                                            	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa.LsaHeader>`
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.grace_period = None
                                                self.grace_reason = None
                                                self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa.LsaDetail()
                                                self.lsa_detail.parent = self
                                                self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa.LsaHeader()
                                                self.lsa_header.parent = self


                                            class LsaHeader(object):
                                                """
                                                Header information 
                                                
                                                .. attribute:: advertising_router
                                                
                                                	Router ID of Advertising Router
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: checksum
                                                
                                                	Checksum value
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: is_do_not_age_lsa
                                                
                                                	If true, Do Not Age this LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_graceful_restart_active
                                                
                                                	If true, if grace restart is active 
                                                	**type**\:  bool
                                                
                                                .. attribute:: ls_id
                                                
                                                	LS ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: lsa_age
                                                
                                                	LSA's Age (s)
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_area_id
                                                
                                                	Area ID in decimal or dotted\-decimal format
                                                	**type**\:  str
                                                
                                                	**length:** 0..16
                                                
                                                .. attribute:: lsa_type
                                                
                                                	LSA type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: sequence_number
                                                
                                                	Current Sequence number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.advertising_router = None
                                                    self.checksum = None
                                                    self.is_do_not_age_lsa = None
                                                    self.is_graceful_restart_active = None
                                                    self.ls_id = None
                                                    self.lsa_age = None
                                                    self.lsa_area_id = None
                                                    self.lsa_type = None
                                                    self.sequence_number = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-header'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.advertising_router is not None:
                                                        return True

                                                    if self.checksum is not None:
                                                        return True

                                                    if self.is_do_not_age_lsa is not None:
                                                        return True

                                                    if self.is_graceful_restart_active is not None:
                                                        return True

                                                    if self.ls_id is not None:
                                                        return True

                                                    if self.lsa_age is not None:
                                                        return True

                                                    if self.lsa_area_id is not None:
                                                        return True

                                                    if self.lsa_type is not None:
                                                        return True

                                                    if self.sequence_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                    return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa.LsaHeader']['meta_info']


                                            class LsaDetail(object):
                                                """
                                                Detailed LSA information
                                                
                                                .. attribute:: free_time
                                                
                                                	The amount of time since the last check was made to free this LSA (s)
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_acknowledged
                                                
                                                	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_advertising_router_reachable
                                                
                                                	If true, Advertising Router is reachable
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_deleted
                                                
                                                	If true, flag is set to delete this LSA 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_flood_pending
                                                
                                                	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_maximum_aged
                                                
                                                	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_neighbor_exchange
                                                
                                                	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_no_delete
                                                
                                                	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_nsr_ack_pending
                                                
                                                	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_partial_spf
                                                
                                                	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_routing_bit
                                                
                                                	If true, Routing Bit set on the LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_routing_table
                                                
                                                	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                	**type**\:  bool
                                                
                                                .. attribute:: lsa_flood_required_post_fail_over
                                                
                                                	LSA flood required after FO
                                                	**type**\:  bool
                                                
                                                .. attribute:: lsa_length
                                                
                                                	Length of the LSA
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_sync_state
                                                
                                                	State of LSA sync with active
                                                	**type**\:   :py:class:`OspfLsaSyncStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncStateEnum>`
                                                
                                                .. attribute:: minute_table_index
                                                
                                                	Minute table index
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: nsr_flood_required
                                                
                                                	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                	**type**\:  bool
                                                
                                                .. attribute:: rate_limit
                                                
                                                	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                	**type**\:  bool
                                                
                                                .. attribute:: second_table_index
                                                
                                                	Second table index
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.free_time = None
                                                    self.is_acknowledged = None
                                                    self.is_advertising_router_reachable = None
                                                    self.is_deleted = None
                                                    self.is_flood_pending = None
                                                    self.is_maximum_aged = None
                                                    self.is_neighbor_exchange = None
                                                    self.is_no_delete = None
                                                    self.is_nsr_ack_pending = None
                                                    self.is_partial_spf = None
                                                    self.is_routing_bit = None
                                                    self.is_routing_table = None
                                                    self.lsa_flood_required_post_fail_over = None
                                                    self.lsa_length = None
                                                    self.lsa_sync_state = None
                                                    self.minute_table_index = None
                                                    self.nsr_flood_required = None
                                                    self.rate_limit = None
                                                    self.second_table_index = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-detail'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.free_time is not None:
                                                        return True

                                                    if self.is_acknowledged is not None:
                                                        return True

                                                    if self.is_advertising_router_reachable is not None:
                                                        return True

                                                    if self.is_deleted is not None:
                                                        return True

                                                    if self.is_flood_pending is not None:
                                                        return True

                                                    if self.is_maximum_aged is not None:
                                                        return True

                                                    if self.is_neighbor_exchange is not None:
                                                        return True

                                                    if self.is_no_delete is not None:
                                                        return True

                                                    if self.is_nsr_ack_pending is not None:
                                                        return True

                                                    if self.is_partial_spf is not None:
                                                        return True

                                                    if self.is_routing_bit is not None:
                                                        return True

                                                    if self.is_routing_table is not None:
                                                        return True

                                                    if self.lsa_flood_required_post_fail_over is not None:
                                                        return True

                                                    if self.lsa_length is not None:
                                                        return True

                                                    if self.lsa_sync_state is not None:
                                                        return True

                                                    if self.minute_table_index is not None:
                                                        return True

                                                    if self.nsr_flood_required is not None:
                                                        return True

                                                    if self.rate_limit is not None:
                                                        return True

                                                    if self.second_table_index is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                    return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa.LsaDetail']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:grace-lsa'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.grace_period is not None:
                                                    return True

                                                if self.grace_reason is not None:
                                                    return True

                                                if self.lsa_detail is not None and self.lsa_detail._has_data():
                                                    return True

                                                if self.lsa_header is not None and self.lsa_header._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa']['meta_info']


                                        class UnknownLinkLsaType(object):
                                            """
                                            Unknown Link Scope LSA
                                            
                                            .. attribute:: interface_name
                                            
                                            	LSA interface name 
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                            
                                            .. attribute:: is_sham_link
                                            
                                            	If true, it is a sham link 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_virtual_link
                                            
                                            	If true, it is a virtual link 
                                            	**type**\:  bool
                                            
                                            .. attribute:: lsa_detail
                                            
                                            	Detailed LSA information
                                            	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaDetail>`
                                            
                                            .. attribute:: lsa_header
                                            
                                            	Header information 
                                            	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaHeader>`
                                            
                                            .. attribute:: sham_link_id
                                            
                                            	Shamlink ID 
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: virtual_link_id
                                            
                                            	Virtual link ID 
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface_name = None
                                                self.is_sham_link = None
                                                self.is_virtual_link = None
                                                self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaDetail()
                                                self.lsa_detail.parent = self
                                                self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaHeader()
                                                self.lsa_header.parent = self
                                                self.sham_link_id = None
                                                self.virtual_link_id = None


                                            class LsaHeader(object):
                                                """
                                                Header information 
                                                
                                                .. attribute:: advertising_router
                                                
                                                	Router ID of Advertising Router
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: checksum
                                                
                                                	Checksum value
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: is_do_not_age_lsa
                                                
                                                	If true, Do Not Age this LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_graceful_restart_active
                                                
                                                	If true, if grace restart is active 
                                                	**type**\:  bool
                                                
                                                .. attribute:: ls_id
                                                
                                                	LS ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: lsa_age
                                                
                                                	LSA's Age (s)
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_area_id
                                                
                                                	Area ID in decimal or dotted\-decimal format
                                                	**type**\:  str
                                                
                                                	**length:** 0..16
                                                
                                                .. attribute:: lsa_type
                                                
                                                	LSA type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: sequence_number
                                                
                                                	Current Sequence number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.advertising_router = None
                                                    self.checksum = None
                                                    self.is_do_not_age_lsa = None
                                                    self.is_graceful_restart_active = None
                                                    self.ls_id = None
                                                    self.lsa_age = None
                                                    self.lsa_area_id = None
                                                    self.lsa_type = None
                                                    self.sequence_number = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-header'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.advertising_router is not None:
                                                        return True

                                                    if self.checksum is not None:
                                                        return True

                                                    if self.is_do_not_age_lsa is not None:
                                                        return True

                                                    if self.is_graceful_restart_active is not None:
                                                        return True

                                                    if self.ls_id is not None:
                                                        return True

                                                    if self.lsa_age is not None:
                                                        return True

                                                    if self.lsa_area_id is not None:
                                                        return True

                                                    if self.lsa_type is not None:
                                                        return True

                                                    if self.sequence_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                    return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaHeader']['meta_info']


                                            class LsaDetail(object):
                                                """
                                                Detailed LSA information
                                                
                                                .. attribute:: free_time
                                                
                                                	The amount of time since the last check was made to free this LSA (s)
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_acknowledged
                                                
                                                	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_advertising_router_reachable
                                                
                                                	If true, Advertising Router is reachable
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_deleted
                                                
                                                	If true, flag is set to delete this LSA 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_flood_pending
                                                
                                                	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_maximum_aged
                                                
                                                	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_neighbor_exchange
                                                
                                                	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_no_delete
                                                
                                                	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_nsr_ack_pending
                                                
                                                	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_partial_spf
                                                
                                                	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_routing_bit
                                                
                                                	If true, Routing Bit set on the LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_routing_table
                                                
                                                	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                	**type**\:  bool
                                                
                                                .. attribute:: lsa_flood_required_post_fail_over
                                                
                                                	LSA flood required after FO
                                                	**type**\:  bool
                                                
                                                .. attribute:: lsa_length
                                                
                                                	Length of the LSA
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_sync_state
                                                
                                                	State of LSA sync with active
                                                	**type**\:   :py:class:`OspfLsaSyncStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncStateEnum>`
                                                
                                                .. attribute:: minute_table_index
                                                
                                                	Minute table index
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: nsr_flood_required
                                                
                                                	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                	**type**\:  bool
                                                
                                                .. attribute:: rate_limit
                                                
                                                	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                	**type**\:  bool
                                                
                                                .. attribute:: second_table_index
                                                
                                                	Second table index
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.free_time = None
                                                    self.is_acknowledged = None
                                                    self.is_advertising_router_reachable = None
                                                    self.is_deleted = None
                                                    self.is_flood_pending = None
                                                    self.is_maximum_aged = None
                                                    self.is_neighbor_exchange = None
                                                    self.is_no_delete = None
                                                    self.is_nsr_ack_pending = None
                                                    self.is_partial_spf = None
                                                    self.is_routing_bit = None
                                                    self.is_routing_table = None
                                                    self.lsa_flood_required_post_fail_over = None
                                                    self.lsa_length = None
                                                    self.lsa_sync_state = None
                                                    self.minute_table_index = None
                                                    self.nsr_flood_required = None
                                                    self.rate_limit = None
                                                    self.second_table_index = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-detail'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.free_time is not None:
                                                        return True

                                                    if self.is_acknowledged is not None:
                                                        return True

                                                    if self.is_advertising_router_reachable is not None:
                                                        return True

                                                    if self.is_deleted is not None:
                                                        return True

                                                    if self.is_flood_pending is not None:
                                                        return True

                                                    if self.is_maximum_aged is not None:
                                                        return True

                                                    if self.is_neighbor_exchange is not None:
                                                        return True

                                                    if self.is_no_delete is not None:
                                                        return True

                                                    if self.is_nsr_ack_pending is not None:
                                                        return True

                                                    if self.is_partial_spf is not None:
                                                        return True

                                                    if self.is_routing_bit is not None:
                                                        return True

                                                    if self.is_routing_table is not None:
                                                        return True

                                                    if self.lsa_flood_required_post_fail_over is not None:
                                                        return True

                                                    if self.lsa_length is not None:
                                                        return True

                                                    if self.lsa_sync_state is not None:
                                                        return True

                                                    if self.minute_table_index is not None:
                                                        return True

                                                    if self.nsr_flood_required is not None:
                                                        return True

                                                    if self.rate_limit is not None:
                                                        return True

                                                    if self.second_table_index is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                    return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaDetail']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:unknown-link-lsa-type'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface_name is not None:
                                                    return True

                                                if self.is_sham_link is not None:
                                                    return True

                                                if self.is_virtual_link is not None:
                                                    return True

                                                if self.lsa_detail is not None and self.lsa_detail._has_data():
                                                    return True

                                                if self.lsa_header is not None and self.lsa_header._has_data():
                                                    return True

                                                if self.sham_link_id is not None:
                                                    return True

                                                if self.virtual_link_id is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType']['meta_info']


                                        class UnknownAreaLsaType(object):
                                            """
                                            Unknown\-Area scope LSA
                                            
                                            .. attribute:: interface_name
                                            
                                            	LSA interface name 
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                            
                                            .. attribute:: is_sham_link
                                            
                                            	If true, it is a sham link 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_virtual_link
                                            
                                            	If true, it is a virtual link 
                                            	**type**\:  bool
                                            
                                            .. attribute:: lsa_detail
                                            
                                            	Detailed LSA information
                                            	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaDetail>`
                                            
                                            .. attribute:: lsa_header
                                            
                                            	Header information 
                                            	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaHeader>`
                                            
                                            .. attribute:: sham_link_id
                                            
                                            	Shamlink ID 
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: virtual_link_id
                                            
                                            	Virtual link ID 
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface_name = None
                                                self.is_sham_link = None
                                                self.is_virtual_link = None
                                                self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaDetail()
                                                self.lsa_detail.parent = self
                                                self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaHeader()
                                                self.lsa_header.parent = self
                                                self.sham_link_id = None
                                                self.virtual_link_id = None


                                            class LsaHeader(object):
                                                """
                                                Header information 
                                                
                                                .. attribute:: advertising_router
                                                
                                                	Router ID of Advertising Router
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: checksum
                                                
                                                	Checksum value
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: is_do_not_age_lsa
                                                
                                                	If true, Do Not Age this LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_graceful_restart_active
                                                
                                                	If true, if grace restart is active 
                                                	**type**\:  bool
                                                
                                                .. attribute:: ls_id
                                                
                                                	LS ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: lsa_age
                                                
                                                	LSA's Age (s)
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_area_id
                                                
                                                	Area ID in decimal or dotted\-decimal format
                                                	**type**\:  str
                                                
                                                	**length:** 0..16
                                                
                                                .. attribute:: lsa_type
                                                
                                                	LSA type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: sequence_number
                                                
                                                	Current Sequence number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.advertising_router = None
                                                    self.checksum = None
                                                    self.is_do_not_age_lsa = None
                                                    self.is_graceful_restart_active = None
                                                    self.ls_id = None
                                                    self.lsa_age = None
                                                    self.lsa_area_id = None
                                                    self.lsa_type = None
                                                    self.sequence_number = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-header'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.advertising_router is not None:
                                                        return True

                                                    if self.checksum is not None:
                                                        return True

                                                    if self.is_do_not_age_lsa is not None:
                                                        return True

                                                    if self.is_graceful_restart_active is not None:
                                                        return True

                                                    if self.ls_id is not None:
                                                        return True

                                                    if self.lsa_age is not None:
                                                        return True

                                                    if self.lsa_area_id is not None:
                                                        return True

                                                    if self.lsa_type is not None:
                                                        return True

                                                    if self.sequence_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                    return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaHeader']['meta_info']


                                            class LsaDetail(object):
                                                """
                                                Detailed LSA information
                                                
                                                .. attribute:: free_time
                                                
                                                	The amount of time since the last check was made to free this LSA (s)
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_acknowledged
                                                
                                                	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_advertising_router_reachable
                                                
                                                	If true, Advertising Router is reachable
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_deleted
                                                
                                                	If true, flag is set to delete this LSA 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_flood_pending
                                                
                                                	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_maximum_aged
                                                
                                                	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_neighbor_exchange
                                                
                                                	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_no_delete
                                                
                                                	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_nsr_ack_pending
                                                
                                                	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_partial_spf
                                                
                                                	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_routing_bit
                                                
                                                	If true, Routing Bit set on the LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_routing_table
                                                
                                                	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                	**type**\:  bool
                                                
                                                .. attribute:: lsa_flood_required_post_fail_over
                                                
                                                	LSA flood required after FO
                                                	**type**\:  bool
                                                
                                                .. attribute:: lsa_length
                                                
                                                	Length of the LSA
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_sync_state
                                                
                                                	State of LSA sync with active
                                                	**type**\:   :py:class:`OspfLsaSyncStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncStateEnum>`
                                                
                                                .. attribute:: minute_table_index
                                                
                                                	Minute table index
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: nsr_flood_required
                                                
                                                	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                	**type**\:  bool
                                                
                                                .. attribute:: rate_limit
                                                
                                                	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                	**type**\:  bool
                                                
                                                .. attribute:: second_table_index
                                                
                                                	Second table index
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.free_time = None
                                                    self.is_acknowledged = None
                                                    self.is_advertising_router_reachable = None
                                                    self.is_deleted = None
                                                    self.is_flood_pending = None
                                                    self.is_maximum_aged = None
                                                    self.is_neighbor_exchange = None
                                                    self.is_no_delete = None
                                                    self.is_nsr_ack_pending = None
                                                    self.is_partial_spf = None
                                                    self.is_routing_bit = None
                                                    self.is_routing_table = None
                                                    self.lsa_flood_required_post_fail_over = None
                                                    self.lsa_length = None
                                                    self.lsa_sync_state = None
                                                    self.minute_table_index = None
                                                    self.nsr_flood_required = None
                                                    self.rate_limit = None
                                                    self.second_table_index = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-detail'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.free_time is not None:
                                                        return True

                                                    if self.is_acknowledged is not None:
                                                        return True

                                                    if self.is_advertising_router_reachable is not None:
                                                        return True

                                                    if self.is_deleted is not None:
                                                        return True

                                                    if self.is_flood_pending is not None:
                                                        return True

                                                    if self.is_maximum_aged is not None:
                                                        return True

                                                    if self.is_neighbor_exchange is not None:
                                                        return True

                                                    if self.is_no_delete is not None:
                                                        return True

                                                    if self.is_nsr_ack_pending is not None:
                                                        return True

                                                    if self.is_partial_spf is not None:
                                                        return True

                                                    if self.is_routing_bit is not None:
                                                        return True

                                                    if self.is_routing_table is not None:
                                                        return True

                                                    if self.lsa_flood_required_post_fail_over is not None:
                                                        return True

                                                    if self.lsa_length is not None:
                                                        return True

                                                    if self.lsa_sync_state is not None:
                                                        return True

                                                    if self.minute_table_index is not None:
                                                        return True

                                                    if self.nsr_flood_required is not None:
                                                        return True

                                                    if self.rate_limit is not None:
                                                        return True

                                                    if self.second_table_index is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                    return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaDetail']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:unknown-area-lsa-type'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface_name is not None:
                                                    return True

                                                if self.is_sham_link is not None:
                                                    return True

                                                if self.is_virtual_link is not None:
                                                    return True

                                                if self.lsa_detail is not None and self.lsa_detail._has_data():
                                                    return True

                                                if self.lsa_header is not None and self.lsa_header._has_data():
                                                    return True

                                                if self.sham_link_id is not None:
                                                    return True

                                                if self.virtual_link_id is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType']['meta_info']


                                        class UnknownAslsaType(object):
                                            """
                                            Unknown\-AS scope LSA
                                            
                                            .. attribute:: interface_name
                                            
                                            	LSA interface name 
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                            
                                            .. attribute:: is_sham_link
                                            
                                            	If true, it is a sham link 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_virtual_link
                                            
                                            	If true, it is a virtual link 
                                            	**type**\:  bool
                                            
                                            .. attribute:: lsa_detail
                                            
                                            	Detailed LSA information
                                            	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType.LsaDetail>`
                                            
                                            .. attribute:: lsa_header
                                            
                                            	Header information 
                                            	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType.LsaHeader>`
                                            
                                            .. attribute:: sham_link_id
                                            
                                            	Shamlink ID 
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: virtual_link_id
                                            
                                            	Virtual link ID 
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface_name = None
                                                self.is_sham_link = None
                                                self.is_virtual_link = None
                                                self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType.LsaDetail()
                                                self.lsa_detail.parent = self
                                                self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType.LsaHeader()
                                                self.lsa_header.parent = self
                                                self.sham_link_id = None
                                                self.virtual_link_id = None


                                            class LsaHeader(object):
                                                """
                                                Header information 
                                                
                                                .. attribute:: advertising_router
                                                
                                                	Router ID of Advertising Router
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: checksum
                                                
                                                	Checksum value
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: is_do_not_age_lsa
                                                
                                                	If true, Do Not Age this LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_graceful_restart_active
                                                
                                                	If true, if grace restart is active 
                                                	**type**\:  bool
                                                
                                                .. attribute:: ls_id
                                                
                                                	LS ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: lsa_age
                                                
                                                	LSA's Age (s)
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_area_id
                                                
                                                	Area ID in decimal or dotted\-decimal format
                                                	**type**\:  str
                                                
                                                	**length:** 0..16
                                                
                                                .. attribute:: lsa_type
                                                
                                                	LSA type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: sequence_number
                                                
                                                	Current Sequence number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.advertising_router = None
                                                    self.checksum = None
                                                    self.is_do_not_age_lsa = None
                                                    self.is_graceful_restart_active = None
                                                    self.ls_id = None
                                                    self.lsa_age = None
                                                    self.lsa_area_id = None
                                                    self.lsa_type = None
                                                    self.sequence_number = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-header'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.advertising_router is not None:
                                                        return True

                                                    if self.checksum is not None:
                                                        return True

                                                    if self.is_do_not_age_lsa is not None:
                                                        return True

                                                    if self.is_graceful_restart_active is not None:
                                                        return True

                                                    if self.ls_id is not None:
                                                        return True

                                                    if self.lsa_age is not None:
                                                        return True

                                                    if self.lsa_area_id is not None:
                                                        return True

                                                    if self.lsa_type is not None:
                                                        return True

                                                    if self.sequence_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                    return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType.LsaHeader']['meta_info']


                                            class LsaDetail(object):
                                                """
                                                Detailed LSA information
                                                
                                                .. attribute:: free_time
                                                
                                                	The amount of time since the last check was made to free this LSA (s)
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_acknowledged
                                                
                                                	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_advertising_router_reachable
                                                
                                                	If true, Advertising Router is reachable
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_deleted
                                                
                                                	If true, flag is set to delete this LSA 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_flood_pending
                                                
                                                	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_maximum_aged
                                                
                                                	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_neighbor_exchange
                                                
                                                	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_no_delete
                                                
                                                	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_nsr_ack_pending
                                                
                                                	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_partial_spf
                                                
                                                	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_routing_bit
                                                
                                                	If true, Routing Bit set on the LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_routing_table
                                                
                                                	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                	**type**\:  bool
                                                
                                                .. attribute:: lsa_flood_required_post_fail_over
                                                
                                                	LSA flood required after FO
                                                	**type**\:  bool
                                                
                                                .. attribute:: lsa_length
                                                
                                                	Length of the LSA
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_sync_state
                                                
                                                	State of LSA sync with active
                                                	**type**\:   :py:class:`OspfLsaSyncStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncStateEnum>`
                                                
                                                .. attribute:: minute_table_index
                                                
                                                	Minute table index
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: nsr_flood_required
                                                
                                                	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                	**type**\:  bool
                                                
                                                .. attribute:: rate_limit
                                                
                                                	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                	**type**\:  bool
                                                
                                                .. attribute:: second_table_index
                                                
                                                	Second table index
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.free_time = None
                                                    self.is_acknowledged = None
                                                    self.is_advertising_router_reachable = None
                                                    self.is_deleted = None
                                                    self.is_flood_pending = None
                                                    self.is_maximum_aged = None
                                                    self.is_neighbor_exchange = None
                                                    self.is_no_delete = None
                                                    self.is_nsr_ack_pending = None
                                                    self.is_partial_spf = None
                                                    self.is_routing_bit = None
                                                    self.is_routing_table = None
                                                    self.lsa_flood_required_post_fail_over = None
                                                    self.lsa_length = None
                                                    self.lsa_sync_state = None
                                                    self.minute_table_index = None
                                                    self.nsr_flood_required = None
                                                    self.rate_limit = None
                                                    self.second_table_index = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-detail'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.free_time is not None:
                                                        return True

                                                    if self.is_acknowledged is not None:
                                                        return True

                                                    if self.is_advertising_router_reachable is not None:
                                                        return True

                                                    if self.is_deleted is not None:
                                                        return True

                                                    if self.is_flood_pending is not None:
                                                        return True

                                                    if self.is_maximum_aged is not None:
                                                        return True

                                                    if self.is_neighbor_exchange is not None:
                                                        return True

                                                    if self.is_no_delete is not None:
                                                        return True

                                                    if self.is_nsr_ack_pending is not None:
                                                        return True

                                                    if self.is_partial_spf is not None:
                                                        return True

                                                    if self.is_routing_bit is not None:
                                                        return True

                                                    if self.is_routing_table is not None:
                                                        return True

                                                    if self.lsa_flood_required_post_fail_over is not None:
                                                        return True

                                                    if self.lsa_length is not None:
                                                        return True

                                                    if self.lsa_sync_state is not None:
                                                        return True

                                                    if self.minute_table_index is not None:
                                                        return True

                                                    if self.nsr_flood_required is not None:
                                                        return True

                                                    if self.rate_limit is not None:
                                                        return True

                                                    if self.second_table_index is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                    return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType.LsaDetail']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:unknown-aslsa-type'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface_name is not None:
                                                    return True

                                                if self.is_sham_link is not None:
                                                    return True

                                                if self.is_virtual_link is not None:
                                                    return True

                                                if self.lsa_detail is not None and self.lsa_detail._has_data():
                                                    return True

                                                if self.lsa_header is not None and self.lsa_header._has_data():
                                                    return True

                                                if self.sham_link_id is not None:
                                                    return True

                                                if self.virtual_link_id is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType']['meta_info']


                                        class UnknownLsaType(object):
                                            """
                                            Unknown LSA
                                            
                                            .. attribute:: interface_name
                                            
                                            	LSA interface name 
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                            
                                            .. attribute:: is_sham_link
                                            
                                            	If true, it is a sham link 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_virtual_link
                                            
                                            	If true, it is a virtual link 
                                            	**type**\:  bool
                                            
                                            .. attribute:: lsa_detail
                                            
                                            	Detailed LSA information
                                            	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType.LsaDetail>`
                                            
                                            .. attribute:: lsa_header
                                            
                                            	Header information 
                                            	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType.LsaHeader>`
                                            
                                            .. attribute:: sham_link_id
                                            
                                            	Shamlink ID 
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: virtual_link_id
                                            
                                            	Virtual link ID 
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface_name = None
                                                self.is_sham_link = None
                                                self.is_virtual_link = None
                                                self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType.LsaDetail()
                                                self.lsa_detail.parent = self
                                                self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType.LsaHeader()
                                                self.lsa_header.parent = self
                                                self.sham_link_id = None
                                                self.virtual_link_id = None


                                            class LsaHeader(object):
                                                """
                                                Header information 
                                                
                                                .. attribute:: advertising_router
                                                
                                                	Router ID of Advertising Router
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: checksum
                                                
                                                	Checksum value
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: is_do_not_age_lsa
                                                
                                                	If true, Do Not Age this LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_graceful_restart_active
                                                
                                                	If true, if grace restart is active 
                                                	**type**\:  bool
                                                
                                                .. attribute:: ls_id
                                                
                                                	LS ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: lsa_age
                                                
                                                	LSA's Age (s)
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_area_id
                                                
                                                	Area ID in decimal or dotted\-decimal format
                                                	**type**\:  str
                                                
                                                	**length:** 0..16
                                                
                                                .. attribute:: lsa_type
                                                
                                                	LSA type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: sequence_number
                                                
                                                	Current Sequence number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.advertising_router = None
                                                    self.checksum = None
                                                    self.is_do_not_age_lsa = None
                                                    self.is_graceful_restart_active = None
                                                    self.ls_id = None
                                                    self.lsa_age = None
                                                    self.lsa_area_id = None
                                                    self.lsa_type = None
                                                    self.sequence_number = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-header'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.advertising_router is not None:
                                                        return True

                                                    if self.checksum is not None:
                                                        return True

                                                    if self.is_do_not_age_lsa is not None:
                                                        return True

                                                    if self.is_graceful_restart_active is not None:
                                                        return True

                                                    if self.ls_id is not None:
                                                        return True

                                                    if self.lsa_age is not None:
                                                        return True

                                                    if self.lsa_area_id is not None:
                                                        return True

                                                    if self.lsa_type is not None:
                                                        return True

                                                    if self.sequence_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                    return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType.LsaHeader']['meta_info']


                                            class LsaDetail(object):
                                                """
                                                Detailed LSA information
                                                
                                                .. attribute:: free_time
                                                
                                                	The amount of time since the last check was made to free this LSA (s)
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_acknowledged
                                                
                                                	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_advertising_router_reachable
                                                
                                                	If true, Advertising Router is reachable
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_deleted
                                                
                                                	If true, flag is set to delete this LSA 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_flood_pending
                                                
                                                	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_maximum_aged
                                                
                                                	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_neighbor_exchange
                                                
                                                	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_no_delete
                                                
                                                	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_nsr_ack_pending
                                                
                                                	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_partial_spf
                                                
                                                	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_routing_bit
                                                
                                                	If true, Routing Bit set on the LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_routing_table
                                                
                                                	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                	**type**\:  bool
                                                
                                                .. attribute:: lsa_flood_required_post_fail_over
                                                
                                                	LSA flood required after FO
                                                	**type**\:  bool
                                                
                                                .. attribute:: lsa_length
                                                
                                                	Length of the LSA
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_sync_state
                                                
                                                	State of LSA sync with active
                                                	**type**\:   :py:class:`OspfLsaSyncStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncStateEnum>`
                                                
                                                .. attribute:: minute_table_index
                                                
                                                	Minute table index
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: nsr_flood_required
                                                
                                                	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                	**type**\:  bool
                                                
                                                .. attribute:: rate_limit
                                                
                                                	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                	**type**\:  bool
                                                
                                                .. attribute:: second_table_index
                                                
                                                	Second table index
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.free_time = None
                                                    self.is_acknowledged = None
                                                    self.is_advertising_router_reachable = None
                                                    self.is_deleted = None
                                                    self.is_flood_pending = None
                                                    self.is_maximum_aged = None
                                                    self.is_neighbor_exchange = None
                                                    self.is_no_delete = None
                                                    self.is_nsr_ack_pending = None
                                                    self.is_partial_spf = None
                                                    self.is_routing_bit = None
                                                    self.is_routing_table = None
                                                    self.lsa_flood_required_post_fail_over = None
                                                    self.lsa_length = None
                                                    self.lsa_sync_state = None
                                                    self.minute_table_index = None
                                                    self.nsr_flood_required = None
                                                    self.rate_limit = None
                                                    self.second_table_index = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-detail'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.free_time is not None:
                                                        return True

                                                    if self.is_acknowledged is not None:
                                                        return True

                                                    if self.is_advertising_router_reachable is not None:
                                                        return True

                                                    if self.is_deleted is not None:
                                                        return True

                                                    if self.is_flood_pending is not None:
                                                        return True

                                                    if self.is_maximum_aged is not None:
                                                        return True

                                                    if self.is_neighbor_exchange is not None:
                                                        return True

                                                    if self.is_no_delete is not None:
                                                        return True

                                                    if self.is_nsr_ack_pending is not None:
                                                        return True

                                                    if self.is_partial_spf is not None:
                                                        return True

                                                    if self.is_routing_bit is not None:
                                                        return True

                                                    if self.is_routing_table is not None:
                                                        return True

                                                    if self.lsa_flood_required_post_fail_over is not None:
                                                        return True

                                                    if self.lsa_length is not None:
                                                        return True

                                                    if self.lsa_sync_state is not None:
                                                        return True

                                                    if self.minute_table_index is not None:
                                                        return True

                                                    if self.nsr_flood_required is not None:
                                                        return True

                                                    if self.rate_limit is not None:
                                                        return True

                                                    if self.second_table_index is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                    return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType.LsaDetail']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:unknown-lsa-type'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface_name is not None:
                                                    return True

                                                if self.is_sham_link is not None:
                                                    return True

                                                if self.is_virtual_link is not None:
                                                    return True

                                                if self.lsa_detail is not None and self.lsa_detail._has_data():
                                                    return True

                                                if self.lsa_header is not None and self.lsa_header._has_data():
                                                    return True

                                                if self.sham_link_id is not None:
                                                    return True

                                                if self.virtual_link_id is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-info'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.external_lsa_type is not None and self.external_lsa_type._has_data():
                                                return True

                                            if self.grace_lsa is not None and self.grace_lsa._has_data():
                                                return True

                                            if self.inter_area_prefix_lsa_type is not None and self.inter_area_prefix_lsa_type._has_data():
                                                return True

                                            if self.inter_area_router_lsa_type is not None and self.inter_area_router_lsa_type._has_data():
                                                return True

                                            if self.intra_area_prefix_lsa_type is not None and self.intra_area_prefix_lsa_type._has_data():
                                                return True

                                            if self.link_lsa_type is not None and self.link_lsa_type._has_data():
                                                return True

                                            if self.lsa_info_type is not None:
                                                return True

                                            if self.lsa_summary_info is not None and self.lsa_summary_info._has_data():
                                                return True

                                            if self.network_lsa_type is not None and self.network_lsa_type._has_data():
                                                return True

                                            if self.nssalsa_type is not None and self.nssalsa_type._has_data():
                                                return True

                                            if self.router_lsa_type is not None and self.router_lsa_type._has_data():
                                                return True

                                            if self.unknown_area_lsa_type is not None and self.unknown_area_lsa_type._has_data():
                                                return True

                                            if self.unknown_aslsa_type is not None and self.unknown_aslsa_type._has_data():
                                                return True

                                            if self.unknown_link_lsa_type is not None and self.unknown_link_lsa_type._has_data():
                                                return True

                                            if self.unknown_lsa_type is not None and self.unknown_lsa_type._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.advertising_router is not None:
                                            return True

                                        if self.area_id is not None:
                                            return True

                                        if self.interface_name is not None:
                                            return True

                                        if self.ls_id is not None:
                                            return True

                                        if self.ls_type is not None:
                                            return True

                                        if self.lsa_info is not None and self.lsa_info._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                        return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-table'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.lsa is not None:
                                        for child_ref in self.lsa:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                    return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable']['meta_info']


                            class LsaInternalTable(object):
                                """
                                Database LSA information
                                
                                .. attribute:: lsa
                                
                                	Database LSA information
                                	**type**\: list of    :py:class:`Lsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa>`
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.lsa = YList()
                                    self.lsa.parent = self
                                    self.lsa.name = 'lsa'


                                class Lsa(object):
                                    """
                                    Database LSA information
                                    
                                    .. attribute:: advertising_router
                                    
                                    	Advertising Router ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: area_id
                                    
                                    	Area ID
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: interface_name
                                    
                                    	InterfaceName
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                    
                                    .. attribute:: ls_id
                                    
                                    	Link state ID
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: ls_type
                                    
                                    	LSA type
                                    	**type**\:   :py:class:`Ospfv3LsaEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3LsaEnum>`
                                    
                                    .. attribute:: lsa_info
                                    
                                    	Summary of all LSAs or LSA specific information 
                                    	**type**\:   :py:class:`LsaInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo>`
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.advertising_router = None
                                        self.area_id = None
                                        self.interface_name = None
                                        self.ls_id = None
                                        self.ls_type = None
                                        self.lsa_info = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo()
                                        self.lsa_info.parent = self


                                    class LsaInfo(object):
                                        """
                                        Summary of all LSAs or LSA specific information 
                                        
                                        .. attribute:: external_lsa_type
                                        
                                        	External LSA
                                        	**type**\:   :py:class:`ExternalLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType>`
                                        
                                        .. attribute:: grace_lsa
                                        
                                        	Grace LSA
                                        	**type**\:   :py:class:`GraceLsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa>`
                                        
                                        .. attribute:: inter_area_prefix_lsa_type
                                        
                                        	Inter Area Prefix LSA
                                        	**type**\:   :py:class:`InterAreaPrefixLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType>`
                                        
                                        .. attribute:: inter_area_router_lsa_type
                                        
                                        	Inter Area Router LSA
                                        	**type**\:   :py:class:`InterAreaRouterLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType>`
                                        
                                        .. attribute:: intra_area_prefix_lsa_type
                                        
                                        	Intra Area Prefix LSA
                                        	**type**\:   :py:class:`IntraAreaPrefixLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType>`
                                        
                                        .. attribute:: link_lsa_type
                                        
                                        	Link LSA
                                        	**type**\:   :py:class:`LinkLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType>`
                                        
                                        .. attribute:: lsa_info_type
                                        
                                        	LSAInfoType
                                        	**type**\:   :py:class:`Ospfv3LsaInfoTypesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3LsaInfoTypesEnum>`
                                        
                                        .. attribute:: lsa_summary_info
                                        
                                        	Summary information of LSAs
                                        	**type**\:   :py:class:`LsaSummaryInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo>`
                                        
                                        .. attribute:: network_lsa_type
                                        
                                        	Network LSA
                                        	**type**\:   :py:class:`NetworkLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType>`
                                        
                                        .. attribute:: nssalsa_type
                                        
                                        	NSSA External LSA
                                        	**type**\:   :py:class:`NssalsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType>`
                                        
                                        .. attribute:: router_lsa_type
                                        
                                        	Router LSA
                                        	**type**\:   :py:class:`RouterLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType>`
                                        
                                        .. attribute:: unknown_area_lsa_type
                                        
                                        	Unknown\-Area scope LSA
                                        	**type**\:   :py:class:`UnknownAreaLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType>`
                                        
                                        .. attribute:: unknown_aslsa_type
                                        
                                        	Unknown\-AS scope LSA
                                        	**type**\:   :py:class:`UnknownAslsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType>`
                                        
                                        .. attribute:: unknown_link_lsa_type
                                        
                                        	Unknown Link Scope LSA
                                        	**type**\:   :py:class:`UnknownLinkLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType>`
                                        
                                        .. attribute:: unknown_lsa_type
                                        
                                        	Unknown LSA
                                        	**type**\:   :py:class:`UnknownLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType>`
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.external_lsa_type = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType()
                                            self.external_lsa_type.parent = self
                                            self.grace_lsa = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa()
                                            self.grace_lsa.parent = self
                                            self.inter_area_prefix_lsa_type = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType()
                                            self.inter_area_prefix_lsa_type.parent = self
                                            self.inter_area_router_lsa_type = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType()
                                            self.inter_area_router_lsa_type.parent = self
                                            self.intra_area_prefix_lsa_type = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType()
                                            self.intra_area_prefix_lsa_type.parent = self
                                            self.link_lsa_type = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType()
                                            self.link_lsa_type.parent = self
                                            self.lsa_info_type = None
                                            self.lsa_summary_info = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo()
                                            self.lsa_summary_info.parent = self
                                            self.network_lsa_type = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType()
                                            self.network_lsa_type.parent = self
                                            self.nssalsa_type = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType()
                                            self.nssalsa_type.parent = self
                                            self.router_lsa_type = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType()
                                            self.router_lsa_type.parent = self
                                            self.unknown_area_lsa_type = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType()
                                            self.unknown_area_lsa_type.parent = self
                                            self.unknown_aslsa_type = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType()
                                            self.unknown_aslsa_type.parent = self
                                            self.unknown_link_lsa_type = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType()
                                            self.unknown_link_lsa_type.parent = self
                                            self.unknown_lsa_type = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType()
                                            self.unknown_lsa_type.parent = self


                                        class LsaSummaryInfo(object):
                                            """
                                            Summary information of LSAs
                                            
                                            .. attribute:: interface_name
                                            
                                            	LSA interface name 
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                            
                                            .. attribute:: is_sham_link
                                            
                                            	If true, it is a sham link 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_virtual_link
                                            
                                            	If true, it is a virtual link 
                                            	**type**\:  bool
                                            
                                            .. attribute:: links
                                            
                                            	Number of links
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_detail
                                            
                                            	Detailed LSA information
                                            	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo.LsaDetail>`
                                            
                                            .. attribute:: lsa_header
                                            
                                            	Header information 
                                            	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo.LsaHeader>`
                                            
                                            .. attribute:: lsa_router_id
                                            
                                            	LSA router ID 
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: prefix
                                            
                                            	OSPFv3 address Prefix 
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: prefix_length
                                            
                                            	Prefix length 
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: reference_lsa_id
                                            
                                            	Reference LSA ID 
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: reference_type
                                            
                                            	Reference type 
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: router_la_bits
                                            
                                            	Router LA bits 
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: sham_link_id
                                            
                                            	Sham link ID 
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: virtual_link_id
                                            
                                            	Virtual link ID 
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface_name = None
                                                self.is_sham_link = None
                                                self.is_virtual_link = None
                                                self.links = None
                                                self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo.LsaDetail()
                                                self.lsa_detail.parent = self
                                                self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo.LsaHeader()
                                                self.lsa_header.parent = self
                                                self.lsa_router_id = None
                                                self.prefix = None
                                                self.prefix_length = None
                                                self.reference_lsa_id = None
                                                self.reference_type = None
                                                self.router_la_bits = None
                                                self.sham_link_id = None
                                                self.virtual_link_id = None


                                            class LsaHeader(object):
                                                """
                                                Header information 
                                                
                                                .. attribute:: advertising_router
                                                
                                                	Router ID of Advertising Router
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: checksum
                                                
                                                	Checksum value
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: is_do_not_age_lsa
                                                
                                                	If true, Do Not Age this LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_graceful_restart_active
                                                
                                                	If true, if grace restart is active 
                                                	**type**\:  bool
                                                
                                                .. attribute:: ls_id
                                                
                                                	LS ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: lsa_age
                                                
                                                	LSA's Age (s)
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_area_id
                                                
                                                	Area ID in decimal or dotted\-decimal format
                                                	**type**\:  str
                                                
                                                	**length:** 0..16
                                                
                                                .. attribute:: lsa_type
                                                
                                                	LSA type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: sequence_number
                                                
                                                	Current Sequence number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.advertising_router = None
                                                    self.checksum = None
                                                    self.is_do_not_age_lsa = None
                                                    self.is_graceful_restart_active = None
                                                    self.ls_id = None
                                                    self.lsa_age = None
                                                    self.lsa_area_id = None
                                                    self.lsa_type = None
                                                    self.sequence_number = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-header'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.advertising_router is not None:
                                                        return True

                                                    if self.checksum is not None:
                                                        return True

                                                    if self.is_do_not_age_lsa is not None:
                                                        return True

                                                    if self.is_graceful_restart_active is not None:
                                                        return True

                                                    if self.ls_id is not None:
                                                        return True

                                                    if self.lsa_age is not None:
                                                        return True

                                                    if self.lsa_area_id is not None:
                                                        return True

                                                    if self.lsa_type is not None:
                                                        return True

                                                    if self.sequence_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                    return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo.LsaHeader']['meta_info']


                                            class LsaDetail(object):
                                                """
                                                Detailed LSA information
                                                
                                                .. attribute:: free_time
                                                
                                                	The amount of time since the last check was made to free this LSA (s)
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_acknowledged
                                                
                                                	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_advertising_router_reachable
                                                
                                                	If true, Advertising Router is reachable
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_deleted
                                                
                                                	If true, flag is set to delete this LSA 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_flood_pending
                                                
                                                	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_maximum_aged
                                                
                                                	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_neighbor_exchange
                                                
                                                	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_no_delete
                                                
                                                	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_nsr_ack_pending
                                                
                                                	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_partial_spf
                                                
                                                	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_routing_bit
                                                
                                                	If true, Routing Bit set on the LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_routing_table
                                                
                                                	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                	**type**\:  bool
                                                
                                                .. attribute:: lsa_flood_required_post_fail_over
                                                
                                                	LSA flood required after FO
                                                	**type**\:  bool
                                                
                                                .. attribute:: lsa_length
                                                
                                                	Length of the LSA
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_sync_state
                                                
                                                	State of LSA sync with active
                                                	**type**\:   :py:class:`OspfLsaSyncStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncStateEnum>`
                                                
                                                .. attribute:: minute_table_index
                                                
                                                	Minute table index
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: nsr_flood_required
                                                
                                                	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                	**type**\:  bool
                                                
                                                .. attribute:: rate_limit
                                                
                                                	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                	**type**\:  bool
                                                
                                                .. attribute:: second_table_index
                                                
                                                	Second table index
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.free_time = None
                                                    self.is_acknowledged = None
                                                    self.is_advertising_router_reachable = None
                                                    self.is_deleted = None
                                                    self.is_flood_pending = None
                                                    self.is_maximum_aged = None
                                                    self.is_neighbor_exchange = None
                                                    self.is_no_delete = None
                                                    self.is_nsr_ack_pending = None
                                                    self.is_partial_spf = None
                                                    self.is_routing_bit = None
                                                    self.is_routing_table = None
                                                    self.lsa_flood_required_post_fail_over = None
                                                    self.lsa_length = None
                                                    self.lsa_sync_state = None
                                                    self.minute_table_index = None
                                                    self.nsr_flood_required = None
                                                    self.rate_limit = None
                                                    self.second_table_index = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-detail'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.free_time is not None:
                                                        return True

                                                    if self.is_acknowledged is not None:
                                                        return True

                                                    if self.is_advertising_router_reachable is not None:
                                                        return True

                                                    if self.is_deleted is not None:
                                                        return True

                                                    if self.is_flood_pending is not None:
                                                        return True

                                                    if self.is_maximum_aged is not None:
                                                        return True

                                                    if self.is_neighbor_exchange is not None:
                                                        return True

                                                    if self.is_no_delete is not None:
                                                        return True

                                                    if self.is_nsr_ack_pending is not None:
                                                        return True

                                                    if self.is_partial_spf is not None:
                                                        return True

                                                    if self.is_routing_bit is not None:
                                                        return True

                                                    if self.is_routing_table is not None:
                                                        return True

                                                    if self.lsa_flood_required_post_fail_over is not None:
                                                        return True

                                                    if self.lsa_length is not None:
                                                        return True

                                                    if self.lsa_sync_state is not None:
                                                        return True

                                                    if self.minute_table_index is not None:
                                                        return True

                                                    if self.nsr_flood_required is not None:
                                                        return True

                                                    if self.rate_limit is not None:
                                                        return True

                                                    if self.second_table_index is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                    return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo.LsaDetail']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-summary-info'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface_name is not None:
                                                    return True

                                                if self.is_sham_link is not None:
                                                    return True

                                                if self.is_virtual_link is not None:
                                                    return True

                                                if self.links is not None:
                                                    return True

                                                if self.lsa_detail is not None and self.lsa_detail._has_data():
                                                    return True

                                                if self.lsa_header is not None and self.lsa_header._has_data():
                                                    return True

                                                if self.lsa_router_id is not None:
                                                    return True

                                                if self.prefix is not None:
                                                    return True

                                                if self.prefix_length is not None:
                                                    return True

                                                if self.reference_lsa_id is not None:
                                                    return True

                                                if self.reference_type is not None:
                                                    return True

                                                if self.router_la_bits is not None:
                                                    return True

                                                if self.sham_link_id is not None:
                                                    return True

                                                if self.virtual_link_id is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo']['meta_info']


                                        class RouterLsaType(object):
                                            """
                                            Router LSA
                                            
                                            .. attribute:: link
                                            
                                            	List of links in this LSA
                                            	**type**\: list of    :py:class:`Link <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.Link>`
                                            
                                            .. attribute:: lsa_detail
                                            
                                            	Detailed LSA information
                                            	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.LsaDetail>`
                                            
                                            .. attribute:: lsa_header
                                            
                                            	Header information 
                                            	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.LsaHeader>`
                                            
                                            .. attribute:: router_la_bits
                                            
                                            	Router LA bits 
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: rpf_path
                                            
                                            	Router LSA Reverse\-Path Forwarding information 
                                            	**type**\:   :py:class:`RpfPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.RpfPath>`
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.link = YList()
                                                self.link.parent = self
                                                self.link.name = 'link'
                                                self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.LsaDetail()
                                                self.lsa_detail.parent = self
                                                self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.LsaHeader()
                                                self.lsa_header.parent = self
                                                self.router_la_bits = None
                                                self.rpf_path = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.RpfPath()
                                                self.rpf_path.parent = self


                                            class LsaHeader(object):
                                                """
                                                Header information 
                                                
                                                .. attribute:: advertising_router
                                                
                                                	Router ID of Advertising Router
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: checksum
                                                
                                                	Checksum value
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: is_do_not_age_lsa
                                                
                                                	If true, Do Not Age this LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_graceful_restart_active
                                                
                                                	If true, if grace restart is active 
                                                	**type**\:  bool
                                                
                                                .. attribute:: ls_id
                                                
                                                	LS ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: lsa_age
                                                
                                                	LSA's Age (s)
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_area_id
                                                
                                                	Area ID in decimal or dotted\-decimal format
                                                	**type**\:  str
                                                
                                                	**length:** 0..16
                                                
                                                .. attribute:: lsa_type
                                                
                                                	LSA type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: sequence_number
                                                
                                                	Current Sequence number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.advertising_router = None
                                                    self.checksum = None
                                                    self.is_do_not_age_lsa = None
                                                    self.is_graceful_restart_active = None
                                                    self.ls_id = None
                                                    self.lsa_age = None
                                                    self.lsa_area_id = None
                                                    self.lsa_type = None
                                                    self.sequence_number = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-header'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.advertising_router is not None:
                                                        return True

                                                    if self.checksum is not None:
                                                        return True

                                                    if self.is_do_not_age_lsa is not None:
                                                        return True

                                                    if self.is_graceful_restart_active is not None:
                                                        return True

                                                    if self.ls_id is not None:
                                                        return True

                                                    if self.lsa_age is not None:
                                                        return True

                                                    if self.lsa_area_id is not None:
                                                        return True

                                                    if self.lsa_type is not None:
                                                        return True

                                                    if self.sequence_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                    return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.LsaHeader']['meta_info']


                                            class LsaDetail(object):
                                                """
                                                Detailed LSA information
                                                
                                                .. attribute:: free_time
                                                
                                                	The amount of time since the last check was made to free this LSA (s)
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_acknowledged
                                                
                                                	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_advertising_router_reachable
                                                
                                                	If true, Advertising Router is reachable
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_deleted
                                                
                                                	If true, flag is set to delete this LSA 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_flood_pending
                                                
                                                	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_maximum_aged
                                                
                                                	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_neighbor_exchange
                                                
                                                	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_no_delete
                                                
                                                	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_nsr_ack_pending
                                                
                                                	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_partial_spf
                                                
                                                	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_routing_bit
                                                
                                                	If true, Routing Bit set on the LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_routing_table
                                                
                                                	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                	**type**\:  bool
                                                
                                                .. attribute:: lsa_flood_required_post_fail_over
                                                
                                                	LSA flood required after FO
                                                	**type**\:  bool
                                                
                                                .. attribute:: lsa_length
                                                
                                                	Length of the LSA
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_sync_state
                                                
                                                	State of LSA sync with active
                                                	**type**\:   :py:class:`OspfLsaSyncStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncStateEnum>`
                                                
                                                .. attribute:: minute_table_index
                                                
                                                	Minute table index
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: nsr_flood_required
                                                
                                                	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                	**type**\:  bool
                                                
                                                .. attribute:: rate_limit
                                                
                                                	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                	**type**\:  bool
                                                
                                                .. attribute:: second_table_index
                                                
                                                	Second table index
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.free_time = None
                                                    self.is_acknowledged = None
                                                    self.is_advertising_router_reachable = None
                                                    self.is_deleted = None
                                                    self.is_flood_pending = None
                                                    self.is_maximum_aged = None
                                                    self.is_neighbor_exchange = None
                                                    self.is_no_delete = None
                                                    self.is_nsr_ack_pending = None
                                                    self.is_partial_spf = None
                                                    self.is_routing_bit = None
                                                    self.is_routing_table = None
                                                    self.lsa_flood_required_post_fail_over = None
                                                    self.lsa_length = None
                                                    self.lsa_sync_state = None
                                                    self.minute_table_index = None
                                                    self.nsr_flood_required = None
                                                    self.rate_limit = None
                                                    self.second_table_index = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-detail'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.free_time is not None:
                                                        return True

                                                    if self.is_acknowledged is not None:
                                                        return True

                                                    if self.is_advertising_router_reachable is not None:
                                                        return True

                                                    if self.is_deleted is not None:
                                                        return True

                                                    if self.is_flood_pending is not None:
                                                        return True

                                                    if self.is_maximum_aged is not None:
                                                        return True

                                                    if self.is_neighbor_exchange is not None:
                                                        return True

                                                    if self.is_no_delete is not None:
                                                        return True

                                                    if self.is_nsr_ack_pending is not None:
                                                        return True

                                                    if self.is_partial_spf is not None:
                                                        return True

                                                    if self.is_routing_bit is not None:
                                                        return True

                                                    if self.is_routing_table is not None:
                                                        return True

                                                    if self.lsa_flood_required_post_fail_over is not None:
                                                        return True

                                                    if self.lsa_length is not None:
                                                        return True

                                                    if self.lsa_sync_state is not None:
                                                        return True

                                                    if self.minute_table_index is not None:
                                                        return True

                                                    if self.nsr_flood_required is not None:
                                                        return True

                                                    if self.rate_limit is not None:
                                                        return True

                                                    if self.second_table_index is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                    return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.LsaDetail']['meta_info']


                                            class RpfPath(object):
                                                """
                                                Router LSA Reverse\-Path Forwarding information 
                                                
                                                .. attribute:: interface_name
                                                
                                                	RPF multicast IDB 
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                
                                                .. attribute:: rpf_multicast_next_hop
                                                
                                                	RPF multicast next hop 
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.interface_name = None
                                                    self.rpf_multicast_next_hop = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:rpf-path'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.interface_name is not None:
                                                        return True

                                                    if self.rpf_multicast_next_hop is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                    return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.RpfPath']['meta_info']


                                            class Link(object):
                                                """
                                                List of links in this LSA
                                                
                                                .. attribute:: link_interface_id
                                                
                                                	LSA link interface ID 
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: link_metric
                                                
                                                	LSA link metric 
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: link_neighbor_interface_id
                                                
                                                	LSA link neighbor interface ID 
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: link_neighbor_router_id
                                                
                                                	LSA link neigbhor router id 
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: link_type
                                                
                                                	Type of link
                                                	**type**\:   :py:class:`Ospfv3LinkEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3LinkEnum>`
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.link_interface_id = None
                                                    self.link_metric = None
                                                    self.link_neighbor_interface_id = None
                                                    self.link_neighbor_router_id = None
                                                    self.link_type = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:link'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.link_interface_id is not None:
                                                        return True

                                                    if self.link_metric is not None:
                                                        return True

                                                    if self.link_neighbor_interface_id is not None:
                                                        return True

                                                    if self.link_neighbor_router_id is not None:
                                                        return True

                                                    if self.link_type is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                    return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.Link']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:router-lsa-type'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.link is not None:
                                                    for child_ref in self.link:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.lsa_detail is not None and self.lsa_detail._has_data():
                                                    return True

                                                if self.lsa_header is not None and self.lsa_header._has_data():
                                                    return True

                                                if self.router_la_bits is not None:
                                                    return True

                                                if self.rpf_path is not None and self.rpf_path._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType']['meta_info']


                                        class NetworkLsaType(object):
                                            """
                                            Network LSA
                                            
                                            .. attribute:: lsa_detail
                                            
                                            	Detailed LSA information
                                            	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType.LsaDetail>`
                                            
                                            .. attribute:: lsa_header
                                            
                                            	Header information 
                                            	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType.LsaHeader>`
                                            
                                            .. attribute:: neighbor_router
                                            
                                            	Neighbor router list
                                            	**type**\:  list of str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType.LsaDetail()
                                                self.lsa_detail.parent = self
                                                self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType.LsaHeader()
                                                self.lsa_header.parent = self
                                                self.neighbor_router = YLeafList()
                                                self.neighbor_router.parent = self
                                                self.neighbor_router.name = 'neighbor_router'


                                            class LsaHeader(object):
                                                """
                                                Header information 
                                                
                                                .. attribute:: advertising_router
                                                
                                                	Router ID of Advertising Router
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: checksum
                                                
                                                	Checksum value
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: is_do_not_age_lsa
                                                
                                                	If true, Do Not Age this LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_graceful_restart_active
                                                
                                                	If true, if grace restart is active 
                                                	**type**\:  bool
                                                
                                                .. attribute:: ls_id
                                                
                                                	LS ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: lsa_age
                                                
                                                	LSA's Age (s)
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_area_id
                                                
                                                	Area ID in decimal or dotted\-decimal format
                                                	**type**\:  str
                                                
                                                	**length:** 0..16
                                                
                                                .. attribute:: lsa_type
                                                
                                                	LSA type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: sequence_number
                                                
                                                	Current Sequence number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.advertising_router = None
                                                    self.checksum = None
                                                    self.is_do_not_age_lsa = None
                                                    self.is_graceful_restart_active = None
                                                    self.ls_id = None
                                                    self.lsa_age = None
                                                    self.lsa_area_id = None
                                                    self.lsa_type = None
                                                    self.sequence_number = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-header'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.advertising_router is not None:
                                                        return True

                                                    if self.checksum is not None:
                                                        return True

                                                    if self.is_do_not_age_lsa is not None:
                                                        return True

                                                    if self.is_graceful_restart_active is not None:
                                                        return True

                                                    if self.ls_id is not None:
                                                        return True

                                                    if self.lsa_age is not None:
                                                        return True

                                                    if self.lsa_area_id is not None:
                                                        return True

                                                    if self.lsa_type is not None:
                                                        return True

                                                    if self.sequence_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                    return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType.LsaHeader']['meta_info']


                                            class LsaDetail(object):
                                                """
                                                Detailed LSA information
                                                
                                                .. attribute:: free_time
                                                
                                                	The amount of time since the last check was made to free this LSA (s)
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_acknowledged
                                                
                                                	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_advertising_router_reachable
                                                
                                                	If true, Advertising Router is reachable
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_deleted
                                                
                                                	If true, flag is set to delete this LSA 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_flood_pending
                                                
                                                	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_maximum_aged
                                                
                                                	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_neighbor_exchange
                                                
                                                	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_no_delete
                                                
                                                	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_nsr_ack_pending
                                                
                                                	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_partial_spf
                                                
                                                	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_routing_bit
                                                
                                                	If true, Routing Bit set on the LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_routing_table
                                                
                                                	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                	**type**\:  bool
                                                
                                                .. attribute:: lsa_flood_required_post_fail_over
                                                
                                                	LSA flood required after FO
                                                	**type**\:  bool
                                                
                                                .. attribute:: lsa_length
                                                
                                                	Length of the LSA
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_sync_state
                                                
                                                	State of LSA sync with active
                                                	**type**\:   :py:class:`OspfLsaSyncStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncStateEnum>`
                                                
                                                .. attribute:: minute_table_index
                                                
                                                	Minute table index
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: nsr_flood_required
                                                
                                                	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                	**type**\:  bool
                                                
                                                .. attribute:: rate_limit
                                                
                                                	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                	**type**\:  bool
                                                
                                                .. attribute:: second_table_index
                                                
                                                	Second table index
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.free_time = None
                                                    self.is_acknowledged = None
                                                    self.is_advertising_router_reachable = None
                                                    self.is_deleted = None
                                                    self.is_flood_pending = None
                                                    self.is_maximum_aged = None
                                                    self.is_neighbor_exchange = None
                                                    self.is_no_delete = None
                                                    self.is_nsr_ack_pending = None
                                                    self.is_partial_spf = None
                                                    self.is_routing_bit = None
                                                    self.is_routing_table = None
                                                    self.lsa_flood_required_post_fail_over = None
                                                    self.lsa_length = None
                                                    self.lsa_sync_state = None
                                                    self.minute_table_index = None
                                                    self.nsr_flood_required = None
                                                    self.rate_limit = None
                                                    self.second_table_index = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-detail'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.free_time is not None:
                                                        return True

                                                    if self.is_acknowledged is not None:
                                                        return True

                                                    if self.is_advertising_router_reachable is not None:
                                                        return True

                                                    if self.is_deleted is not None:
                                                        return True

                                                    if self.is_flood_pending is not None:
                                                        return True

                                                    if self.is_maximum_aged is not None:
                                                        return True

                                                    if self.is_neighbor_exchange is not None:
                                                        return True

                                                    if self.is_no_delete is not None:
                                                        return True

                                                    if self.is_nsr_ack_pending is not None:
                                                        return True

                                                    if self.is_partial_spf is not None:
                                                        return True

                                                    if self.is_routing_bit is not None:
                                                        return True

                                                    if self.is_routing_table is not None:
                                                        return True

                                                    if self.lsa_flood_required_post_fail_over is not None:
                                                        return True

                                                    if self.lsa_length is not None:
                                                        return True

                                                    if self.lsa_sync_state is not None:
                                                        return True

                                                    if self.minute_table_index is not None:
                                                        return True

                                                    if self.nsr_flood_required is not None:
                                                        return True

                                                    if self.rate_limit is not None:
                                                        return True

                                                    if self.second_table_index is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                    return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType.LsaDetail']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:network-lsa-type'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.lsa_detail is not None and self.lsa_detail._has_data():
                                                    return True

                                                if self.lsa_header is not None and self.lsa_header._has_data():
                                                    return True

                                                if self.neighbor_router is not None:
                                                    for child in self.neighbor_router:
                                                        if child is not None:
                                                            return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType']['meta_info']


                                        class InterAreaPrefixLsaType(object):
                                            """
                                            Inter Area Prefix LSA
                                            
                                            .. attribute:: lsa_detail
                                            
                                            	Detailed LSA Information
                                            	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaDetail>`
                                            
                                            .. attribute:: lsa_header
                                            
                                            	Header information 
                                            	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaHeader>`
                                            
                                            .. attribute:: prefix
                                            
                                            	LSA address prefix 
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: prefix_length
                                            
                                            	Prefix length 
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: priority
                                            
                                            	Prefix priority
                                            	**type**\:   :py:class:`PrefixPriorityEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.PrefixPriorityEnum>`
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaDetail()
                                                self.lsa_detail.parent = self
                                                self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaHeader()
                                                self.lsa_header.parent = self
                                                self.prefix = None
                                                self.prefix_length = None
                                                self.priority = None


                                            class LsaHeader(object):
                                                """
                                                Header information 
                                                
                                                .. attribute:: advertising_router
                                                
                                                	Router ID of Advertising Router
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: checksum
                                                
                                                	Checksum value
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: is_do_not_age_lsa
                                                
                                                	If true, Do Not Age this LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_graceful_restart_active
                                                
                                                	If true, if grace restart is active 
                                                	**type**\:  bool
                                                
                                                .. attribute:: ls_id
                                                
                                                	LS ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: lsa_age
                                                
                                                	LSA's Age (s)
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_area_id
                                                
                                                	Area ID in decimal or dotted\-decimal format
                                                	**type**\:  str
                                                
                                                	**length:** 0..16
                                                
                                                .. attribute:: lsa_type
                                                
                                                	LSA type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: sequence_number
                                                
                                                	Current Sequence number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.advertising_router = None
                                                    self.checksum = None
                                                    self.is_do_not_age_lsa = None
                                                    self.is_graceful_restart_active = None
                                                    self.ls_id = None
                                                    self.lsa_age = None
                                                    self.lsa_area_id = None
                                                    self.lsa_type = None
                                                    self.sequence_number = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-header'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.advertising_router is not None:
                                                        return True

                                                    if self.checksum is not None:
                                                        return True

                                                    if self.is_do_not_age_lsa is not None:
                                                        return True

                                                    if self.is_graceful_restart_active is not None:
                                                        return True

                                                    if self.ls_id is not None:
                                                        return True

                                                    if self.lsa_age is not None:
                                                        return True

                                                    if self.lsa_area_id is not None:
                                                        return True

                                                    if self.lsa_type is not None:
                                                        return True

                                                    if self.sequence_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                    return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaHeader']['meta_info']


                                            class LsaDetail(object):
                                                """
                                                Detailed LSA Information
                                                
                                                .. attribute:: free_time
                                                
                                                	The amount of time since the last check was made to free this LSA (s)
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_acknowledged
                                                
                                                	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_advertising_router_reachable
                                                
                                                	If true, Advertising Router is reachable
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_deleted
                                                
                                                	If true, flag is set to delete this LSA 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_flood_pending
                                                
                                                	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_maximum_aged
                                                
                                                	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_neighbor_exchange
                                                
                                                	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_no_delete
                                                
                                                	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_nsr_ack_pending
                                                
                                                	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_partial_spf
                                                
                                                	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_routing_bit
                                                
                                                	If true, Routing Bit set on the LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_routing_table
                                                
                                                	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                	**type**\:  bool
                                                
                                                .. attribute:: lsa_flood_required_post_fail_over
                                                
                                                	LSA flood required after FO
                                                	**type**\:  bool
                                                
                                                .. attribute:: lsa_length
                                                
                                                	Length of the LSA
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_sync_state
                                                
                                                	State of LSA sync with active
                                                	**type**\:   :py:class:`OspfLsaSyncStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncStateEnum>`
                                                
                                                .. attribute:: minute_table_index
                                                
                                                	Minute table index
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: nsr_flood_required
                                                
                                                	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                	**type**\:  bool
                                                
                                                .. attribute:: rate_limit
                                                
                                                	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                	**type**\:  bool
                                                
                                                .. attribute:: second_table_index
                                                
                                                	Second table index
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.free_time = None
                                                    self.is_acknowledged = None
                                                    self.is_advertising_router_reachable = None
                                                    self.is_deleted = None
                                                    self.is_flood_pending = None
                                                    self.is_maximum_aged = None
                                                    self.is_neighbor_exchange = None
                                                    self.is_no_delete = None
                                                    self.is_nsr_ack_pending = None
                                                    self.is_partial_spf = None
                                                    self.is_routing_bit = None
                                                    self.is_routing_table = None
                                                    self.lsa_flood_required_post_fail_over = None
                                                    self.lsa_length = None
                                                    self.lsa_sync_state = None
                                                    self.minute_table_index = None
                                                    self.nsr_flood_required = None
                                                    self.rate_limit = None
                                                    self.second_table_index = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-detail'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.free_time is not None:
                                                        return True

                                                    if self.is_acknowledged is not None:
                                                        return True

                                                    if self.is_advertising_router_reachable is not None:
                                                        return True

                                                    if self.is_deleted is not None:
                                                        return True

                                                    if self.is_flood_pending is not None:
                                                        return True

                                                    if self.is_maximum_aged is not None:
                                                        return True

                                                    if self.is_neighbor_exchange is not None:
                                                        return True

                                                    if self.is_no_delete is not None:
                                                        return True

                                                    if self.is_nsr_ack_pending is not None:
                                                        return True

                                                    if self.is_partial_spf is not None:
                                                        return True

                                                    if self.is_routing_bit is not None:
                                                        return True

                                                    if self.is_routing_table is not None:
                                                        return True

                                                    if self.lsa_flood_required_post_fail_over is not None:
                                                        return True

                                                    if self.lsa_length is not None:
                                                        return True

                                                    if self.lsa_sync_state is not None:
                                                        return True

                                                    if self.minute_table_index is not None:
                                                        return True

                                                    if self.nsr_flood_required is not None:
                                                        return True

                                                    if self.rate_limit is not None:
                                                        return True

                                                    if self.second_table_index is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                    return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaDetail']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:inter-area-prefix-lsa-type'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.lsa_detail is not None and self.lsa_detail._has_data():
                                                    return True

                                                if self.lsa_header is not None and self.lsa_header._has_data():
                                                    return True

                                                if self.prefix is not None:
                                                    return True

                                                if self.prefix_length is not None:
                                                    return True

                                                if self.priority is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType']['meta_info']


                                        class InterAreaRouterLsaType(object):
                                            """
                                            Inter Area Router LSA
                                            
                                            .. attribute:: lsa_detail
                                            
                                            	Detailed LSA information
                                            	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaDetail>`
                                            
                                            .. attribute:: lsa_header
                                            
                                            	Header information 
                                            	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaHeader>`
                                            
                                            .. attribute:: lsa_router_id
                                            
                                            	LSA router ID 
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaDetail()
                                                self.lsa_detail.parent = self
                                                self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaHeader()
                                                self.lsa_header.parent = self
                                                self.lsa_router_id = None


                                            class LsaHeader(object):
                                                """
                                                Header information 
                                                
                                                .. attribute:: advertising_router
                                                
                                                	Router ID of Advertising Router
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: checksum
                                                
                                                	Checksum value
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: is_do_not_age_lsa
                                                
                                                	If true, Do Not Age this LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_graceful_restart_active
                                                
                                                	If true, if grace restart is active 
                                                	**type**\:  bool
                                                
                                                .. attribute:: ls_id
                                                
                                                	LS ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: lsa_age
                                                
                                                	LSA's Age (s)
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_area_id
                                                
                                                	Area ID in decimal or dotted\-decimal format
                                                	**type**\:  str
                                                
                                                	**length:** 0..16
                                                
                                                .. attribute:: lsa_type
                                                
                                                	LSA type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: sequence_number
                                                
                                                	Current Sequence number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.advertising_router = None
                                                    self.checksum = None
                                                    self.is_do_not_age_lsa = None
                                                    self.is_graceful_restart_active = None
                                                    self.ls_id = None
                                                    self.lsa_age = None
                                                    self.lsa_area_id = None
                                                    self.lsa_type = None
                                                    self.sequence_number = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-header'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.advertising_router is not None:
                                                        return True

                                                    if self.checksum is not None:
                                                        return True

                                                    if self.is_do_not_age_lsa is not None:
                                                        return True

                                                    if self.is_graceful_restart_active is not None:
                                                        return True

                                                    if self.ls_id is not None:
                                                        return True

                                                    if self.lsa_age is not None:
                                                        return True

                                                    if self.lsa_area_id is not None:
                                                        return True

                                                    if self.lsa_type is not None:
                                                        return True

                                                    if self.sequence_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                    return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaHeader']['meta_info']


                                            class LsaDetail(object):
                                                """
                                                Detailed LSA information
                                                
                                                .. attribute:: free_time
                                                
                                                	The amount of time since the last check was made to free this LSA (s)
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_acknowledged
                                                
                                                	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_advertising_router_reachable
                                                
                                                	If true, Advertising Router is reachable
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_deleted
                                                
                                                	If true, flag is set to delete this LSA 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_flood_pending
                                                
                                                	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_maximum_aged
                                                
                                                	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_neighbor_exchange
                                                
                                                	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_no_delete
                                                
                                                	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_nsr_ack_pending
                                                
                                                	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_partial_spf
                                                
                                                	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_routing_bit
                                                
                                                	If true, Routing Bit set on the LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_routing_table
                                                
                                                	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                	**type**\:  bool
                                                
                                                .. attribute:: lsa_flood_required_post_fail_over
                                                
                                                	LSA flood required after FO
                                                	**type**\:  bool
                                                
                                                .. attribute:: lsa_length
                                                
                                                	Length of the LSA
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_sync_state
                                                
                                                	State of LSA sync with active
                                                	**type**\:   :py:class:`OspfLsaSyncStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncStateEnum>`
                                                
                                                .. attribute:: minute_table_index
                                                
                                                	Minute table index
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: nsr_flood_required
                                                
                                                	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                	**type**\:  bool
                                                
                                                .. attribute:: rate_limit
                                                
                                                	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                	**type**\:  bool
                                                
                                                .. attribute:: second_table_index
                                                
                                                	Second table index
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.free_time = None
                                                    self.is_acknowledged = None
                                                    self.is_advertising_router_reachable = None
                                                    self.is_deleted = None
                                                    self.is_flood_pending = None
                                                    self.is_maximum_aged = None
                                                    self.is_neighbor_exchange = None
                                                    self.is_no_delete = None
                                                    self.is_nsr_ack_pending = None
                                                    self.is_partial_spf = None
                                                    self.is_routing_bit = None
                                                    self.is_routing_table = None
                                                    self.lsa_flood_required_post_fail_over = None
                                                    self.lsa_length = None
                                                    self.lsa_sync_state = None
                                                    self.minute_table_index = None
                                                    self.nsr_flood_required = None
                                                    self.rate_limit = None
                                                    self.second_table_index = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-detail'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.free_time is not None:
                                                        return True

                                                    if self.is_acknowledged is not None:
                                                        return True

                                                    if self.is_advertising_router_reachable is not None:
                                                        return True

                                                    if self.is_deleted is not None:
                                                        return True

                                                    if self.is_flood_pending is not None:
                                                        return True

                                                    if self.is_maximum_aged is not None:
                                                        return True

                                                    if self.is_neighbor_exchange is not None:
                                                        return True

                                                    if self.is_no_delete is not None:
                                                        return True

                                                    if self.is_nsr_ack_pending is not None:
                                                        return True

                                                    if self.is_partial_spf is not None:
                                                        return True

                                                    if self.is_routing_bit is not None:
                                                        return True

                                                    if self.is_routing_table is not None:
                                                        return True

                                                    if self.lsa_flood_required_post_fail_over is not None:
                                                        return True

                                                    if self.lsa_length is not None:
                                                        return True

                                                    if self.lsa_sync_state is not None:
                                                        return True

                                                    if self.minute_table_index is not None:
                                                        return True

                                                    if self.nsr_flood_required is not None:
                                                        return True

                                                    if self.rate_limit is not None:
                                                        return True

                                                    if self.second_table_index is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                    return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaDetail']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:inter-area-router-lsa-type'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.lsa_detail is not None and self.lsa_detail._has_data():
                                                    return True

                                                if self.lsa_header is not None and self.lsa_header._has_data():
                                                    return True

                                                if self.lsa_router_id is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType']['meta_info']


                                        class ExternalLsaType(object):
                                            """
                                            External LSA
                                            
                                            .. attribute:: external_tag
                                            
                                            	Route Tag
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: forwarding_address
                                            
                                            	Forwarding Address
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: is_forwarding_address_set
                                            
                                            	If true, forwarding address is set 
                                            	**type**\:  bool
                                            
                                            .. attribute:: lsa_detail
                                            
                                            	Detailed LSA Information
                                            	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType.LsaDetail>`
                                            
                                            .. attribute:: lsa_header
                                            
                                            	Header information 
                                            	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType.LsaHeader>`
                                            
                                            .. attribute:: metric_type
                                            
                                            	Metric type 
                                            	**type**\:   :py:class:`Ospfv3DefaultMetricEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3DefaultMetricEnum>`
                                            
                                            .. attribute:: prefix
                                            
                                            	IPV6 address prefix 
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: prefix_length
                                            
                                            	Prefix length 
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: priority
                                            
                                            	Prefix priority
                                            	**type**\:   :py:class:`PrefixPriorityEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.PrefixPriorityEnum>`
                                            
                                            .. attribute:: tos_cost
                                            
                                            	Type of service cost metric 
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.external_tag = None
                                                self.forwarding_address = None
                                                self.is_forwarding_address_set = None
                                                self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType.LsaDetail()
                                                self.lsa_detail.parent = self
                                                self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType.LsaHeader()
                                                self.lsa_header.parent = self
                                                self.metric_type = None
                                                self.prefix = None
                                                self.prefix_length = None
                                                self.priority = None
                                                self.tos_cost = None


                                            class LsaHeader(object):
                                                """
                                                Header information 
                                                
                                                .. attribute:: advertising_router
                                                
                                                	Router ID of Advertising Router
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: checksum
                                                
                                                	Checksum value
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: is_do_not_age_lsa
                                                
                                                	If true, Do Not Age this LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_graceful_restart_active
                                                
                                                	If true, if grace restart is active 
                                                	**type**\:  bool
                                                
                                                .. attribute:: ls_id
                                                
                                                	LS ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: lsa_age
                                                
                                                	LSA's Age (s)
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_area_id
                                                
                                                	Area ID in decimal or dotted\-decimal format
                                                	**type**\:  str
                                                
                                                	**length:** 0..16
                                                
                                                .. attribute:: lsa_type
                                                
                                                	LSA type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: sequence_number
                                                
                                                	Current Sequence number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.advertising_router = None
                                                    self.checksum = None
                                                    self.is_do_not_age_lsa = None
                                                    self.is_graceful_restart_active = None
                                                    self.ls_id = None
                                                    self.lsa_age = None
                                                    self.lsa_area_id = None
                                                    self.lsa_type = None
                                                    self.sequence_number = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-header'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.advertising_router is not None:
                                                        return True

                                                    if self.checksum is not None:
                                                        return True

                                                    if self.is_do_not_age_lsa is not None:
                                                        return True

                                                    if self.is_graceful_restart_active is not None:
                                                        return True

                                                    if self.ls_id is not None:
                                                        return True

                                                    if self.lsa_age is not None:
                                                        return True

                                                    if self.lsa_area_id is not None:
                                                        return True

                                                    if self.lsa_type is not None:
                                                        return True

                                                    if self.sequence_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                    return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType.LsaHeader']['meta_info']


                                            class LsaDetail(object):
                                                """
                                                Detailed LSA Information
                                                
                                                .. attribute:: free_time
                                                
                                                	The amount of time since the last check was made to free this LSA (s)
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_acknowledged
                                                
                                                	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_advertising_router_reachable
                                                
                                                	If true, Advertising Router is reachable
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_deleted
                                                
                                                	If true, flag is set to delete this LSA 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_flood_pending
                                                
                                                	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_maximum_aged
                                                
                                                	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_neighbor_exchange
                                                
                                                	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_no_delete
                                                
                                                	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_nsr_ack_pending
                                                
                                                	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_partial_spf
                                                
                                                	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_routing_bit
                                                
                                                	If true, Routing Bit set on the LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_routing_table
                                                
                                                	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                	**type**\:  bool
                                                
                                                .. attribute:: lsa_flood_required_post_fail_over
                                                
                                                	LSA flood required after FO
                                                	**type**\:  bool
                                                
                                                .. attribute:: lsa_length
                                                
                                                	Length of the LSA
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_sync_state
                                                
                                                	State of LSA sync with active
                                                	**type**\:   :py:class:`OspfLsaSyncStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncStateEnum>`
                                                
                                                .. attribute:: minute_table_index
                                                
                                                	Minute table index
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: nsr_flood_required
                                                
                                                	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                	**type**\:  bool
                                                
                                                .. attribute:: rate_limit
                                                
                                                	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                	**type**\:  bool
                                                
                                                .. attribute:: second_table_index
                                                
                                                	Second table index
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.free_time = None
                                                    self.is_acknowledged = None
                                                    self.is_advertising_router_reachable = None
                                                    self.is_deleted = None
                                                    self.is_flood_pending = None
                                                    self.is_maximum_aged = None
                                                    self.is_neighbor_exchange = None
                                                    self.is_no_delete = None
                                                    self.is_nsr_ack_pending = None
                                                    self.is_partial_spf = None
                                                    self.is_routing_bit = None
                                                    self.is_routing_table = None
                                                    self.lsa_flood_required_post_fail_over = None
                                                    self.lsa_length = None
                                                    self.lsa_sync_state = None
                                                    self.minute_table_index = None
                                                    self.nsr_flood_required = None
                                                    self.rate_limit = None
                                                    self.second_table_index = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-detail'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.free_time is not None:
                                                        return True

                                                    if self.is_acknowledged is not None:
                                                        return True

                                                    if self.is_advertising_router_reachable is not None:
                                                        return True

                                                    if self.is_deleted is not None:
                                                        return True

                                                    if self.is_flood_pending is not None:
                                                        return True

                                                    if self.is_maximum_aged is not None:
                                                        return True

                                                    if self.is_neighbor_exchange is not None:
                                                        return True

                                                    if self.is_no_delete is not None:
                                                        return True

                                                    if self.is_nsr_ack_pending is not None:
                                                        return True

                                                    if self.is_partial_spf is not None:
                                                        return True

                                                    if self.is_routing_bit is not None:
                                                        return True

                                                    if self.is_routing_table is not None:
                                                        return True

                                                    if self.lsa_flood_required_post_fail_over is not None:
                                                        return True

                                                    if self.lsa_length is not None:
                                                        return True

                                                    if self.lsa_sync_state is not None:
                                                        return True

                                                    if self.minute_table_index is not None:
                                                        return True

                                                    if self.nsr_flood_required is not None:
                                                        return True

                                                    if self.rate_limit is not None:
                                                        return True

                                                    if self.second_table_index is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                    return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType.LsaDetail']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:external-lsa-type'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.external_tag is not None:
                                                    return True

                                                if self.forwarding_address is not None:
                                                    return True

                                                if self.is_forwarding_address_set is not None:
                                                    return True

                                                if self.lsa_detail is not None and self.lsa_detail._has_data():
                                                    return True

                                                if self.lsa_header is not None and self.lsa_header._has_data():
                                                    return True

                                                if self.metric_type is not None:
                                                    return True

                                                if self.prefix is not None:
                                                    return True

                                                if self.prefix_length is not None:
                                                    return True

                                                if self.priority is not None:
                                                    return True

                                                if self.tos_cost is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType']['meta_info']


                                        class NssalsaType(object):
                                            """
                                            NSSA External LSA
                                            
                                            .. attribute:: external_tag
                                            
                                            	Route Tag
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: forwarding_address
                                            
                                            	Forwarding Address
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: is_forwarding_address_set
                                            
                                            	If true, forwarding address is set 
                                            	**type**\:  bool
                                            
                                            .. attribute:: lsa_detail
                                            
                                            	Detailed LSA Information
                                            	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType.LsaDetail>`
                                            
                                            .. attribute:: lsa_header
                                            
                                            	Header information 
                                            	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType.LsaHeader>`
                                            
                                            .. attribute:: metric_type
                                            
                                            	Metric type 
                                            	**type**\:   :py:class:`Ospfv3DefaultMetricEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3DefaultMetricEnum>`
                                            
                                            .. attribute:: prefix
                                            
                                            	IPV6 address prefix 
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: prefix_length
                                            
                                            	Prefix length 
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: priority
                                            
                                            	Prefix priority
                                            	**type**\:   :py:class:`PrefixPriorityEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.PrefixPriorityEnum>`
                                            
                                            .. attribute:: tos_cost
                                            
                                            	Type of service cost metric 
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.external_tag = None
                                                self.forwarding_address = None
                                                self.is_forwarding_address_set = None
                                                self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType.LsaDetail()
                                                self.lsa_detail.parent = self
                                                self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType.LsaHeader()
                                                self.lsa_header.parent = self
                                                self.metric_type = None
                                                self.prefix = None
                                                self.prefix_length = None
                                                self.priority = None
                                                self.tos_cost = None


                                            class LsaHeader(object):
                                                """
                                                Header information 
                                                
                                                .. attribute:: advertising_router
                                                
                                                	Router ID of Advertising Router
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: checksum
                                                
                                                	Checksum value
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: is_do_not_age_lsa
                                                
                                                	If true, Do Not Age this LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_graceful_restart_active
                                                
                                                	If true, if grace restart is active 
                                                	**type**\:  bool
                                                
                                                .. attribute:: ls_id
                                                
                                                	LS ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: lsa_age
                                                
                                                	LSA's Age (s)
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_area_id
                                                
                                                	Area ID in decimal or dotted\-decimal format
                                                	**type**\:  str
                                                
                                                	**length:** 0..16
                                                
                                                .. attribute:: lsa_type
                                                
                                                	LSA type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: sequence_number
                                                
                                                	Current Sequence number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.advertising_router = None
                                                    self.checksum = None
                                                    self.is_do_not_age_lsa = None
                                                    self.is_graceful_restart_active = None
                                                    self.ls_id = None
                                                    self.lsa_age = None
                                                    self.lsa_area_id = None
                                                    self.lsa_type = None
                                                    self.sequence_number = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-header'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.advertising_router is not None:
                                                        return True

                                                    if self.checksum is not None:
                                                        return True

                                                    if self.is_do_not_age_lsa is not None:
                                                        return True

                                                    if self.is_graceful_restart_active is not None:
                                                        return True

                                                    if self.ls_id is not None:
                                                        return True

                                                    if self.lsa_age is not None:
                                                        return True

                                                    if self.lsa_area_id is not None:
                                                        return True

                                                    if self.lsa_type is not None:
                                                        return True

                                                    if self.sequence_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                    return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType.LsaHeader']['meta_info']


                                            class LsaDetail(object):
                                                """
                                                Detailed LSA Information
                                                
                                                .. attribute:: free_time
                                                
                                                	The amount of time since the last check was made to free this LSA (s)
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_acknowledged
                                                
                                                	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_advertising_router_reachable
                                                
                                                	If true, Advertising Router is reachable
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_deleted
                                                
                                                	If true, flag is set to delete this LSA 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_flood_pending
                                                
                                                	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_maximum_aged
                                                
                                                	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_neighbor_exchange
                                                
                                                	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_no_delete
                                                
                                                	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_nsr_ack_pending
                                                
                                                	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_partial_spf
                                                
                                                	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_routing_bit
                                                
                                                	If true, Routing Bit set on the LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_routing_table
                                                
                                                	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                	**type**\:  bool
                                                
                                                .. attribute:: lsa_flood_required_post_fail_over
                                                
                                                	LSA flood required after FO
                                                	**type**\:  bool
                                                
                                                .. attribute:: lsa_length
                                                
                                                	Length of the LSA
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_sync_state
                                                
                                                	State of LSA sync with active
                                                	**type**\:   :py:class:`OspfLsaSyncStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncStateEnum>`
                                                
                                                .. attribute:: minute_table_index
                                                
                                                	Minute table index
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: nsr_flood_required
                                                
                                                	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                	**type**\:  bool
                                                
                                                .. attribute:: rate_limit
                                                
                                                	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                	**type**\:  bool
                                                
                                                .. attribute:: second_table_index
                                                
                                                	Second table index
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.free_time = None
                                                    self.is_acknowledged = None
                                                    self.is_advertising_router_reachable = None
                                                    self.is_deleted = None
                                                    self.is_flood_pending = None
                                                    self.is_maximum_aged = None
                                                    self.is_neighbor_exchange = None
                                                    self.is_no_delete = None
                                                    self.is_nsr_ack_pending = None
                                                    self.is_partial_spf = None
                                                    self.is_routing_bit = None
                                                    self.is_routing_table = None
                                                    self.lsa_flood_required_post_fail_over = None
                                                    self.lsa_length = None
                                                    self.lsa_sync_state = None
                                                    self.minute_table_index = None
                                                    self.nsr_flood_required = None
                                                    self.rate_limit = None
                                                    self.second_table_index = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-detail'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.free_time is not None:
                                                        return True

                                                    if self.is_acknowledged is not None:
                                                        return True

                                                    if self.is_advertising_router_reachable is not None:
                                                        return True

                                                    if self.is_deleted is not None:
                                                        return True

                                                    if self.is_flood_pending is not None:
                                                        return True

                                                    if self.is_maximum_aged is not None:
                                                        return True

                                                    if self.is_neighbor_exchange is not None:
                                                        return True

                                                    if self.is_no_delete is not None:
                                                        return True

                                                    if self.is_nsr_ack_pending is not None:
                                                        return True

                                                    if self.is_partial_spf is not None:
                                                        return True

                                                    if self.is_routing_bit is not None:
                                                        return True

                                                    if self.is_routing_table is not None:
                                                        return True

                                                    if self.lsa_flood_required_post_fail_over is not None:
                                                        return True

                                                    if self.lsa_length is not None:
                                                        return True

                                                    if self.lsa_sync_state is not None:
                                                        return True

                                                    if self.minute_table_index is not None:
                                                        return True

                                                    if self.nsr_flood_required is not None:
                                                        return True

                                                    if self.rate_limit is not None:
                                                        return True

                                                    if self.second_table_index is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                    return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType.LsaDetail']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:nssalsa-type'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.external_tag is not None:
                                                    return True

                                                if self.forwarding_address is not None:
                                                    return True

                                                if self.is_forwarding_address_set is not None:
                                                    return True

                                                if self.lsa_detail is not None and self.lsa_detail._has_data():
                                                    return True

                                                if self.lsa_header is not None and self.lsa_header._has_data():
                                                    return True

                                                if self.metric_type is not None:
                                                    return True

                                                if self.prefix is not None:
                                                    return True

                                                if self.prefix_length is not None:
                                                    return True

                                                if self.priority is not None:
                                                    return True

                                                if self.tos_cost is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType']['meta_info']


                                        class LinkLsaType(object):
                                            """
                                            Link LSA
                                            
                                            .. attribute:: interface_name
                                            
                                            	LSA interface handle
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                            
                                            .. attribute:: is_sham_link
                                            
                                            	If true, it is a sham link
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_virtual_link
                                            
                                            	If true, it is a virtual link
                                            	**type**\:  bool
                                            
                                            .. attribute:: lsa_detail
                                            
                                            	Detailed LSA information
                                            	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType.LsaDetail>`
                                            
                                            .. attribute:: lsa_header
                                            
                                            	Header information 
                                            	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType.LsaHeader>`
                                            
                                            .. attribute:: lsa_link_local
                                            
                                            	LSA link local 
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: prefix
                                            
                                            	OSPFv3 prefix 
                                            	**type**\: list of    :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType.Prefix>`
                                            
                                            .. attribute:: router_priority
                                            
                                            	Router priority 
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: sham_link_id
                                            
                                            	Sham link ID 
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: virtual_link_id
                                            
                                            	Virtual link ID 
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface_name = None
                                                self.is_sham_link = None
                                                self.is_virtual_link = None
                                                self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType.LsaDetail()
                                                self.lsa_detail.parent = self
                                                self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType.LsaHeader()
                                                self.lsa_header.parent = self
                                                self.lsa_link_local = None
                                                self.prefix = YList()
                                                self.prefix.parent = self
                                                self.prefix.name = 'prefix'
                                                self.router_priority = None
                                                self.sham_link_id = None
                                                self.virtual_link_id = None


                                            class LsaHeader(object):
                                                """
                                                Header information 
                                                
                                                .. attribute:: advertising_router
                                                
                                                	Router ID of Advertising Router
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: checksum
                                                
                                                	Checksum value
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: is_do_not_age_lsa
                                                
                                                	If true, Do Not Age this LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_graceful_restart_active
                                                
                                                	If true, if grace restart is active 
                                                	**type**\:  bool
                                                
                                                .. attribute:: ls_id
                                                
                                                	LS ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: lsa_age
                                                
                                                	LSA's Age (s)
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_area_id
                                                
                                                	Area ID in decimal or dotted\-decimal format
                                                	**type**\:  str
                                                
                                                	**length:** 0..16
                                                
                                                .. attribute:: lsa_type
                                                
                                                	LSA type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: sequence_number
                                                
                                                	Current Sequence number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.advertising_router = None
                                                    self.checksum = None
                                                    self.is_do_not_age_lsa = None
                                                    self.is_graceful_restart_active = None
                                                    self.ls_id = None
                                                    self.lsa_age = None
                                                    self.lsa_area_id = None
                                                    self.lsa_type = None
                                                    self.sequence_number = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-header'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.advertising_router is not None:
                                                        return True

                                                    if self.checksum is not None:
                                                        return True

                                                    if self.is_do_not_age_lsa is not None:
                                                        return True

                                                    if self.is_graceful_restart_active is not None:
                                                        return True

                                                    if self.ls_id is not None:
                                                        return True

                                                    if self.lsa_age is not None:
                                                        return True

                                                    if self.lsa_area_id is not None:
                                                        return True

                                                    if self.lsa_type is not None:
                                                        return True

                                                    if self.sequence_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                    return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType.LsaHeader']['meta_info']


                                            class LsaDetail(object):
                                                """
                                                Detailed LSA information
                                                
                                                .. attribute:: free_time
                                                
                                                	The amount of time since the last check was made to free this LSA (s)
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_acknowledged
                                                
                                                	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_advertising_router_reachable
                                                
                                                	If true, Advertising Router is reachable
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_deleted
                                                
                                                	If true, flag is set to delete this LSA 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_flood_pending
                                                
                                                	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_maximum_aged
                                                
                                                	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_neighbor_exchange
                                                
                                                	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_no_delete
                                                
                                                	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_nsr_ack_pending
                                                
                                                	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_partial_spf
                                                
                                                	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_routing_bit
                                                
                                                	If true, Routing Bit set on the LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_routing_table
                                                
                                                	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                	**type**\:  bool
                                                
                                                .. attribute:: lsa_flood_required_post_fail_over
                                                
                                                	LSA flood required after FO
                                                	**type**\:  bool
                                                
                                                .. attribute:: lsa_length
                                                
                                                	Length of the LSA
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_sync_state
                                                
                                                	State of LSA sync with active
                                                	**type**\:   :py:class:`OspfLsaSyncStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncStateEnum>`
                                                
                                                .. attribute:: minute_table_index
                                                
                                                	Minute table index
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: nsr_flood_required
                                                
                                                	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                	**type**\:  bool
                                                
                                                .. attribute:: rate_limit
                                                
                                                	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                	**type**\:  bool
                                                
                                                .. attribute:: second_table_index
                                                
                                                	Second table index
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.free_time = None
                                                    self.is_acknowledged = None
                                                    self.is_advertising_router_reachable = None
                                                    self.is_deleted = None
                                                    self.is_flood_pending = None
                                                    self.is_maximum_aged = None
                                                    self.is_neighbor_exchange = None
                                                    self.is_no_delete = None
                                                    self.is_nsr_ack_pending = None
                                                    self.is_partial_spf = None
                                                    self.is_routing_bit = None
                                                    self.is_routing_table = None
                                                    self.lsa_flood_required_post_fail_over = None
                                                    self.lsa_length = None
                                                    self.lsa_sync_state = None
                                                    self.minute_table_index = None
                                                    self.nsr_flood_required = None
                                                    self.rate_limit = None
                                                    self.second_table_index = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-detail'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.free_time is not None:
                                                        return True

                                                    if self.is_acknowledged is not None:
                                                        return True

                                                    if self.is_advertising_router_reachable is not None:
                                                        return True

                                                    if self.is_deleted is not None:
                                                        return True

                                                    if self.is_flood_pending is not None:
                                                        return True

                                                    if self.is_maximum_aged is not None:
                                                        return True

                                                    if self.is_neighbor_exchange is not None:
                                                        return True

                                                    if self.is_no_delete is not None:
                                                        return True

                                                    if self.is_nsr_ack_pending is not None:
                                                        return True

                                                    if self.is_partial_spf is not None:
                                                        return True

                                                    if self.is_routing_bit is not None:
                                                        return True

                                                    if self.is_routing_table is not None:
                                                        return True

                                                    if self.lsa_flood_required_post_fail_over is not None:
                                                        return True

                                                    if self.lsa_length is not None:
                                                        return True

                                                    if self.lsa_sync_state is not None:
                                                        return True

                                                    if self.minute_table_index is not None:
                                                        return True

                                                    if self.nsr_flood_required is not None:
                                                        return True

                                                    if self.rate_limit is not None:
                                                        return True

                                                    if self.second_table_index is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                    return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType.LsaDetail']['meta_info']


                                            class Prefix(object):
                                                """
                                                OSPFv3 prefix 
                                                
                                                .. attribute:: ospfv3_prefix_length
                                                
                                                	OSPFv3 prefix length 
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: ospfv3_prefix_metric
                                                
                                                	OSPFv3 prefix metric 
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: ospfv3_prefix_options
                                                
                                                	OSPFv3 prefix options 
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: prefix
                                                
                                                	OSPFv3 prefix 
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: priority
                                                
                                                	Prefix priority
                                                	**type**\:   :py:class:`PrefixPriorityEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.PrefixPriorityEnum>`
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ospfv3_prefix_length = None
                                                    self.ospfv3_prefix_metric = None
                                                    self.ospfv3_prefix_options = None
                                                    self.prefix = None
                                                    self.priority = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:prefix'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ospfv3_prefix_length is not None:
                                                        return True

                                                    if self.ospfv3_prefix_metric is not None:
                                                        return True

                                                    if self.ospfv3_prefix_options is not None:
                                                        return True

                                                    if self.prefix is not None:
                                                        return True

                                                    if self.priority is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                    return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType.Prefix']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:link-lsa-type'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface_name is not None:
                                                    return True

                                                if self.is_sham_link is not None:
                                                    return True

                                                if self.is_virtual_link is not None:
                                                    return True

                                                if self.lsa_detail is not None and self.lsa_detail._has_data():
                                                    return True

                                                if self.lsa_header is not None and self.lsa_header._has_data():
                                                    return True

                                                if self.lsa_link_local is not None:
                                                    return True

                                                if self.prefix is not None:
                                                    for child_ref in self.prefix:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.router_priority is not None:
                                                    return True

                                                if self.sham_link_id is not None:
                                                    return True

                                                if self.virtual_link_id is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType']['meta_info']


                                        class IntraAreaPrefixLsaType(object):
                                            """
                                            Intra Area Prefix LSA
                                            
                                            .. attribute:: lsa_detail
                                            
                                            	Detailed LSA information
                                            	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaDetail>`
                                            
                                            .. attribute:: lsa_header
                                            
                                            	Header information 
                                            	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaHeader>`
                                            
                                            .. attribute:: prefix
                                            
                                            	OSPFv3 prefix 
                                            	**type**\: list of    :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.Prefix>`
                                            
                                            .. attribute:: reference_advertised_router
                                            
                                            	Reference advertised router 
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: reference_lsa_id
                                            
                                            	Reference LSA ID 
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: reference_type
                                            
                                            	Reference type 
                                            	**type**\:   :py:class:`Ospfv3Lsa1Enum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Lsa1Enum>`
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaDetail()
                                                self.lsa_detail.parent = self
                                                self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaHeader()
                                                self.lsa_header.parent = self
                                                self.prefix = YList()
                                                self.prefix.parent = self
                                                self.prefix.name = 'prefix'
                                                self.reference_advertised_router = None
                                                self.reference_lsa_id = None
                                                self.reference_type = None


                                            class LsaHeader(object):
                                                """
                                                Header information 
                                                
                                                .. attribute:: advertising_router
                                                
                                                	Router ID of Advertising Router
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: checksum
                                                
                                                	Checksum value
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: is_do_not_age_lsa
                                                
                                                	If true, Do Not Age this LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_graceful_restart_active
                                                
                                                	If true, if grace restart is active 
                                                	**type**\:  bool
                                                
                                                .. attribute:: ls_id
                                                
                                                	LS ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: lsa_age
                                                
                                                	LSA's Age (s)
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_area_id
                                                
                                                	Area ID in decimal or dotted\-decimal format
                                                	**type**\:  str
                                                
                                                	**length:** 0..16
                                                
                                                .. attribute:: lsa_type
                                                
                                                	LSA type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: sequence_number
                                                
                                                	Current Sequence number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.advertising_router = None
                                                    self.checksum = None
                                                    self.is_do_not_age_lsa = None
                                                    self.is_graceful_restart_active = None
                                                    self.ls_id = None
                                                    self.lsa_age = None
                                                    self.lsa_area_id = None
                                                    self.lsa_type = None
                                                    self.sequence_number = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-header'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.advertising_router is not None:
                                                        return True

                                                    if self.checksum is not None:
                                                        return True

                                                    if self.is_do_not_age_lsa is not None:
                                                        return True

                                                    if self.is_graceful_restart_active is not None:
                                                        return True

                                                    if self.ls_id is not None:
                                                        return True

                                                    if self.lsa_age is not None:
                                                        return True

                                                    if self.lsa_area_id is not None:
                                                        return True

                                                    if self.lsa_type is not None:
                                                        return True

                                                    if self.sequence_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                    return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaHeader']['meta_info']


                                            class LsaDetail(object):
                                                """
                                                Detailed LSA information
                                                
                                                .. attribute:: free_time
                                                
                                                	The amount of time since the last check was made to free this LSA (s)
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_acknowledged
                                                
                                                	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_advertising_router_reachable
                                                
                                                	If true, Advertising Router is reachable
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_deleted
                                                
                                                	If true, flag is set to delete this LSA 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_flood_pending
                                                
                                                	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_maximum_aged
                                                
                                                	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_neighbor_exchange
                                                
                                                	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_no_delete
                                                
                                                	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_nsr_ack_pending
                                                
                                                	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_partial_spf
                                                
                                                	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_routing_bit
                                                
                                                	If true, Routing Bit set on the LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_routing_table
                                                
                                                	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                	**type**\:  bool
                                                
                                                .. attribute:: lsa_flood_required_post_fail_over
                                                
                                                	LSA flood required after FO
                                                	**type**\:  bool
                                                
                                                .. attribute:: lsa_length
                                                
                                                	Length of the LSA
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_sync_state
                                                
                                                	State of LSA sync with active
                                                	**type**\:   :py:class:`OspfLsaSyncStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncStateEnum>`
                                                
                                                .. attribute:: minute_table_index
                                                
                                                	Minute table index
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: nsr_flood_required
                                                
                                                	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                	**type**\:  bool
                                                
                                                .. attribute:: rate_limit
                                                
                                                	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                	**type**\:  bool
                                                
                                                .. attribute:: second_table_index
                                                
                                                	Second table index
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.free_time = None
                                                    self.is_acknowledged = None
                                                    self.is_advertising_router_reachable = None
                                                    self.is_deleted = None
                                                    self.is_flood_pending = None
                                                    self.is_maximum_aged = None
                                                    self.is_neighbor_exchange = None
                                                    self.is_no_delete = None
                                                    self.is_nsr_ack_pending = None
                                                    self.is_partial_spf = None
                                                    self.is_routing_bit = None
                                                    self.is_routing_table = None
                                                    self.lsa_flood_required_post_fail_over = None
                                                    self.lsa_length = None
                                                    self.lsa_sync_state = None
                                                    self.minute_table_index = None
                                                    self.nsr_flood_required = None
                                                    self.rate_limit = None
                                                    self.second_table_index = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-detail'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.free_time is not None:
                                                        return True

                                                    if self.is_acknowledged is not None:
                                                        return True

                                                    if self.is_advertising_router_reachable is not None:
                                                        return True

                                                    if self.is_deleted is not None:
                                                        return True

                                                    if self.is_flood_pending is not None:
                                                        return True

                                                    if self.is_maximum_aged is not None:
                                                        return True

                                                    if self.is_neighbor_exchange is not None:
                                                        return True

                                                    if self.is_no_delete is not None:
                                                        return True

                                                    if self.is_nsr_ack_pending is not None:
                                                        return True

                                                    if self.is_partial_spf is not None:
                                                        return True

                                                    if self.is_routing_bit is not None:
                                                        return True

                                                    if self.is_routing_table is not None:
                                                        return True

                                                    if self.lsa_flood_required_post_fail_over is not None:
                                                        return True

                                                    if self.lsa_length is not None:
                                                        return True

                                                    if self.lsa_sync_state is not None:
                                                        return True

                                                    if self.minute_table_index is not None:
                                                        return True

                                                    if self.nsr_flood_required is not None:
                                                        return True

                                                    if self.rate_limit is not None:
                                                        return True

                                                    if self.second_table_index is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                    return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaDetail']['meta_info']


                                            class Prefix(object):
                                                """
                                                OSPFv3 prefix 
                                                
                                                .. attribute:: ospfv3_prefix_length
                                                
                                                	OSPFv3 prefix length 
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: ospfv3_prefix_metric
                                                
                                                	OSPFv3 prefix metric 
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: ospfv3_prefix_options
                                                
                                                	OSPFv3 prefix options 
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: prefix
                                                
                                                	OSPFv3 prefix 
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: priority
                                                
                                                	Prefix priority
                                                	**type**\:   :py:class:`PrefixPriorityEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.PrefixPriorityEnum>`
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ospfv3_prefix_length = None
                                                    self.ospfv3_prefix_metric = None
                                                    self.ospfv3_prefix_options = None
                                                    self.prefix = None
                                                    self.priority = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:prefix'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ospfv3_prefix_length is not None:
                                                        return True

                                                    if self.ospfv3_prefix_metric is not None:
                                                        return True

                                                    if self.ospfv3_prefix_options is not None:
                                                        return True

                                                    if self.prefix is not None:
                                                        return True

                                                    if self.priority is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                    return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.Prefix']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:intra-area-prefix-lsa-type'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.lsa_detail is not None and self.lsa_detail._has_data():
                                                    return True

                                                if self.lsa_header is not None and self.lsa_header._has_data():
                                                    return True

                                                if self.prefix is not None:
                                                    for child_ref in self.prefix:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.reference_advertised_router is not None:
                                                    return True

                                                if self.reference_lsa_id is not None:
                                                    return True

                                                if self.reference_type is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType']['meta_info']


                                        class GraceLsa(object):
                                            """
                                            Grace LSA
                                            
                                            .. attribute:: grace_period
                                            
                                            	The grace periord where helper routers should wait before advertising it fully adjacent(s) 
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: grace_reason
                                            
                                            	Reason for router restart
                                            	**type**\:   :py:class:`Ospfv3GracefulRestartReasonEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3GracefulRestartReasonEnum>`
                                            
                                            .. attribute:: lsa_detail
                                            
                                            	Detailed LSA information
                                            	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa.LsaDetail>`
                                            
                                            .. attribute:: lsa_header
                                            
                                            	Header information 
                                            	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa.LsaHeader>`
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.grace_period = None
                                                self.grace_reason = None
                                                self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa.LsaDetail()
                                                self.lsa_detail.parent = self
                                                self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa.LsaHeader()
                                                self.lsa_header.parent = self


                                            class LsaHeader(object):
                                                """
                                                Header information 
                                                
                                                .. attribute:: advertising_router
                                                
                                                	Router ID of Advertising Router
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: checksum
                                                
                                                	Checksum value
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: is_do_not_age_lsa
                                                
                                                	If true, Do Not Age this LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_graceful_restart_active
                                                
                                                	If true, if grace restart is active 
                                                	**type**\:  bool
                                                
                                                .. attribute:: ls_id
                                                
                                                	LS ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: lsa_age
                                                
                                                	LSA's Age (s)
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_area_id
                                                
                                                	Area ID in decimal or dotted\-decimal format
                                                	**type**\:  str
                                                
                                                	**length:** 0..16
                                                
                                                .. attribute:: lsa_type
                                                
                                                	LSA type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: sequence_number
                                                
                                                	Current Sequence number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.advertising_router = None
                                                    self.checksum = None
                                                    self.is_do_not_age_lsa = None
                                                    self.is_graceful_restart_active = None
                                                    self.ls_id = None
                                                    self.lsa_age = None
                                                    self.lsa_area_id = None
                                                    self.lsa_type = None
                                                    self.sequence_number = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-header'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.advertising_router is not None:
                                                        return True

                                                    if self.checksum is not None:
                                                        return True

                                                    if self.is_do_not_age_lsa is not None:
                                                        return True

                                                    if self.is_graceful_restart_active is not None:
                                                        return True

                                                    if self.ls_id is not None:
                                                        return True

                                                    if self.lsa_age is not None:
                                                        return True

                                                    if self.lsa_area_id is not None:
                                                        return True

                                                    if self.lsa_type is not None:
                                                        return True

                                                    if self.sequence_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                    return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa.LsaHeader']['meta_info']


                                            class LsaDetail(object):
                                                """
                                                Detailed LSA information
                                                
                                                .. attribute:: free_time
                                                
                                                	The amount of time since the last check was made to free this LSA (s)
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_acknowledged
                                                
                                                	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_advertising_router_reachable
                                                
                                                	If true, Advertising Router is reachable
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_deleted
                                                
                                                	If true, flag is set to delete this LSA 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_flood_pending
                                                
                                                	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_maximum_aged
                                                
                                                	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_neighbor_exchange
                                                
                                                	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_no_delete
                                                
                                                	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_nsr_ack_pending
                                                
                                                	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_partial_spf
                                                
                                                	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_routing_bit
                                                
                                                	If true, Routing Bit set on the LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_routing_table
                                                
                                                	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                	**type**\:  bool
                                                
                                                .. attribute:: lsa_flood_required_post_fail_over
                                                
                                                	LSA flood required after FO
                                                	**type**\:  bool
                                                
                                                .. attribute:: lsa_length
                                                
                                                	Length of the LSA
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_sync_state
                                                
                                                	State of LSA sync with active
                                                	**type**\:   :py:class:`OspfLsaSyncStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncStateEnum>`
                                                
                                                .. attribute:: minute_table_index
                                                
                                                	Minute table index
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: nsr_flood_required
                                                
                                                	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                	**type**\:  bool
                                                
                                                .. attribute:: rate_limit
                                                
                                                	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                	**type**\:  bool
                                                
                                                .. attribute:: second_table_index
                                                
                                                	Second table index
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.free_time = None
                                                    self.is_acknowledged = None
                                                    self.is_advertising_router_reachable = None
                                                    self.is_deleted = None
                                                    self.is_flood_pending = None
                                                    self.is_maximum_aged = None
                                                    self.is_neighbor_exchange = None
                                                    self.is_no_delete = None
                                                    self.is_nsr_ack_pending = None
                                                    self.is_partial_spf = None
                                                    self.is_routing_bit = None
                                                    self.is_routing_table = None
                                                    self.lsa_flood_required_post_fail_over = None
                                                    self.lsa_length = None
                                                    self.lsa_sync_state = None
                                                    self.minute_table_index = None
                                                    self.nsr_flood_required = None
                                                    self.rate_limit = None
                                                    self.second_table_index = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-detail'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.free_time is not None:
                                                        return True

                                                    if self.is_acknowledged is not None:
                                                        return True

                                                    if self.is_advertising_router_reachable is not None:
                                                        return True

                                                    if self.is_deleted is not None:
                                                        return True

                                                    if self.is_flood_pending is not None:
                                                        return True

                                                    if self.is_maximum_aged is not None:
                                                        return True

                                                    if self.is_neighbor_exchange is not None:
                                                        return True

                                                    if self.is_no_delete is not None:
                                                        return True

                                                    if self.is_nsr_ack_pending is not None:
                                                        return True

                                                    if self.is_partial_spf is not None:
                                                        return True

                                                    if self.is_routing_bit is not None:
                                                        return True

                                                    if self.is_routing_table is not None:
                                                        return True

                                                    if self.lsa_flood_required_post_fail_over is not None:
                                                        return True

                                                    if self.lsa_length is not None:
                                                        return True

                                                    if self.lsa_sync_state is not None:
                                                        return True

                                                    if self.minute_table_index is not None:
                                                        return True

                                                    if self.nsr_flood_required is not None:
                                                        return True

                                                    if self.rate_limit is not None:
                                                        return True

                                                    if self.second_table_index is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                    return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa.LsaDetail']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:grace-lsa'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.grace_period is not None:
                                                    return True

                                                if self.grace_reason is not None:
                                                    return True

                                                if self.lsa_detail is not None and self.lsa_detail._has_data():
                                                    return True

                                                if self.lsa_header is not None and self.lsa_header._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa']['meta_info']


                                        class UnknownLinkLsaType(object):
                                            """
                                            Unknown Link Scope LSA
                                            
                                            .. attribute:: interface_name
                                            
                                            	LSA interface name 
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                            
                                            .. attribute:: is_sham_link
                                            
                                            	If true, it is a sham link 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_virtual_link
                                            
                                            	If true, it is a virtual link 
                                            	**type**\:  bool
                                            
                                            .. attribute:: lsa_detail
                                            
                                            	Detailed LSA information
                                            	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaDetail>`
                                            
                                            .. attribute:: lsa_header
                                            
                                            	Header information 
                                            	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaHeader>`
                                            
                                            .. attribute:: sham_link_id
                                            
                                            	Shamlink ID 
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: virtual_link_id
                                            
                                            	Virtual link ID 
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface_name = None
                                                self.is_sham_link = None
                                                self.is_virtual_link = None
                                                self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaDetail()
                                                self.lsa_detail.parent = self
                                                self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaHeader()
                                                self.lsa_header.parent = self
                                                self.sham_link_id = None
                                                self.virtual_link_id = None


                                            class LsaHeader(object):
                                                """
                                                Header information 
                                                
                                                .. attribute:: advertising_router
                                                
                                                	Router ID of Advertising Router
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: checksum
                                                
                                                	Checksum value
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: is_do_not_age_lsa
                                                
                                                	If true, Do Not Age this LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_graceful_restart_active
                                                
                                                	If true, if grace restart is active 
                                                	**type**\:  bool
                                                
                                                .. attribute:: ls_id
                                                
                                                	LS ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: lsa_age
                                                
                                                	LSA's Age (s)
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_area_id
                                                
                                                	Area ID in decimal or dotted\-decimal format
                                                	**type**\:  str
                                                
                                                	**length:** 0..16
                                                
                                                .. attribute:: lsa_type
                                                
                                                	LSA type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: sequence_number
                                                
                                                	Current Sequence number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.advertising_router = None
                                                    self.checksum = None
                                                    self.is_do_not_age_lsa = None
                                                    self.is_graceful_restart_active = None
                                                    self.ls_id = None
                                                    self.lsa_age = None
                                                    self.lsa_area_id = None
                                                    self.lsa_type = None
                                                    self.sequence_number = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-header'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.advertising_router is not None:
                                                        return True

                                                    if self.checksum is not None:
                                                        return True

                                                    if self.is_do_not_age_lsa is not None:
                                                        return True

                                                    if self.is_graceful_restart_active is not None:
                                                        return True

                                                    if self.ls_id is not None:
                                                        return True

                                                    if self.lsa_age is not None:
                                                        return True

                                                    if self.lsa_area_id is not None:
                                                        return True

                                                    if self.lsa_type is not None:
                                                        return True

                                                    if self.sequence_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                    return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaHeader']['meta_info']


                                            class LsaDetail(object):
                                                """
                                                Detailed LSA information
                                                
                                                .. attribute:: free_time
                                                
                                                	The amount of time since the last check was made to free this LSA (s)
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_acknowledged
                                                
                                                	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_advertising_router_reachable
                                                
                                                	If true, Advertising Router is reachable
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_deleted
                                                
                                                	If true, flag is set to delete this LSA 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_flood_pending
                                                
                                                	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_maximum_aged
                                                
                                                	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_neighbor_exchange
                                                
                                                	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_no_delete
                                                
                                                	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_nsr_ack_pending
                                                
                                                	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_partial_spf
                                                
                                                	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_routing_bit
                                                
                                                	If true, Routing Bit set on the LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_routing_table
                                                
                                                	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                	**type**\:  bool
                                                
                                                .. attribute:: lsa_flood_required_post_fail_over
                                                
                                                	LSA flood required after FO
                                                	**type**\:  bool
                                                
                                                .. attribute:: lsa_length
                                                
                                                	Length of the LSA
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_sync_state
                                                
                                                	State of LSA sync with active
                                                	**type**\:   :py:class:`OspfLsaSyncStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncStateEnum>`
                                                
                                                .. attribute:: minute_table_index
                                                
                                                	Minute table index
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: nsr_flood_required
                                                
                                                	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                	**type**\:  bool
                                                
                                                .. attribute:: rate_limit
                                                
                                                	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                	**type**\:  bool
                                                
                                                .. attribute:: second_table_index
                                                
                                                	Second table index
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.free_time = None
                                                    self.is_acknowledged = None
                                                    self.is_advertising_router_reachable = None
                                                    self.is_deleted = None
                                                    self.is_flood_pending = None
                                                    self.is_maximum_aged = None
                                                    self.is_neighbor_exchange = None
                                                    self.is_no_delete = None
                                                    self.is_nsr_ack_pending = None
                                                    self.is_partial_spf = None
                                                    self.is_routing_bit = None
                                                    self.is_routing_table = None
                                                    self.lsa_flood_required_post_fail_over = None
                                                    self.lsa_length = None
                                                    self.lsa_sync_state = None
                                                    self.minute_table_index = None
                                                    self.nsr_flood_required = None
                                                    self.rate_limit = None
                                                    self.second_table_index = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-detail'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.free_time is not None:
                                                        return True

                                                    if self.is_acknowledged is not None:
                                                        return True

                                                    if self.is_advertising_router_reachable is not None:
                                                        return True

                                                    if self.is_deleted is not None:
                                                        return True

                                                    if self.is_flood_pending is not None:
                                                        return True

                                                    if self.is_maximum_aged is not None:
                                                        return True

                                                    if self.is_neighbor_exchange is not None:
                                                        return True

                                                    if self.is_no_delete is not None:
                                                        return True

                                                    if self.is_nsr_ack_pending is not None:
                                                        return True

                                                    if self.is_partial_spf is not None:
                                                        return True

                                                    if self.is_routing_bit is not None:
                                                        return True

                                                    if self.is_routing_table is not None:
                                                        return True

                                                    if self.lsa_flood_required_post_fail_over is not None:
                                                        return True

                                                    if self.lsa_length is not None:
                                                        return True

                                                    if self.lsa_sync_state is not None:
                                                        return True

                                                    if self.minute_table_index is not None:
                                                        return True

                                                    if self.nsr_flood_required is not None:
                                                        return True

                                                    if self.rate_limit is not None:
                                                        return True

                                                    if self.second_table_index is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                    return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaDetail']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:unknown-link-lsa-type'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface_name is not None:
                                                    return True

                                                if self.is_sham_link is not None:
                                                    return True

                                                if self.is_virtual_link is not None:
                                                    return True

                                                if self.lsa_detail is not None and self.lsa_detail._has_data():
                                                    return True

                                                if self.lsa_header is not None and self.lsa_header._has_data():
                                                    return True

                                                if self.sham_link_id is not None:
                                                    return True

                                                if self.virtual_link_id is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType']['meta_info']


                                        class UnknownAreaLsaType(object):
                                            """
                                            Unknown\-Area scope LSA
                                            
                                            .. attribute:: interface_name
                                            
                                            	LSA interface name 
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                            
                                            .. attribute:: is_sham_link
                                            
                                            	If true, it is a sham link 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_virtual_link
                                            
                                            	If true, it is a virtual link 
                                            	**type**\:  bool
                                            
                                            .. attribute:: lsa_detail
                                            
                                            	Detailed LSA information
                                            	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaDetail>`
                                            
                                            .. attribute:: lsa_header
                                            
                                            	Header information 
                                            	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaHeader>`
                                            
                                            .. attribute:: sham_link_id
                                            
                                            	Shamlink ID 
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: virtual_link_id
                                            
                                            	Virtual link ID 
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface_name = None
                                                self.is_sham_link = None
                                                self.is_virtual_link = None
                                                self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaDetail()
                                                self.lsa_detail.parent = self
                                                self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaHeader()
                                                self.lsa_header.parent = self
                                                self.sham_link_id = None
                                                self.virtual_link_id = None


                                            class LsaHeader(object):
                                                """
                                                Header information 
                                                
                                                .. attribute:: advertising_router
                                                
                                                	Router ID of Advertising Router
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: checksum
                                                
                                                	Checksum value
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: is_do_not_age_lsa
                                                
                                                	If true, Do Not Age this LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_graceful_restart_active
                                                
                                                	If true, if grace restart is active 
                                                	**type**\:  bool
                                                
                                                .. attribute:: ls_id
                                                
                                                	LS ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: lsa_age
                                                
                                                	LSA's Age (s)
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_area_id
                                                
                                                	Area ID in decimal or dotted\-decimal format
                                                	**type**\:  str
                                                
                                                	**length:** 0..16
                                                
                                                .. attribute:: lsa_type
                                                
                                                	LSA type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: sequence_number
                                                
                                                	Current Sequence number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.advertising_router = None
                                                    self.checksum = None
                                                    self.is_do_not_age_lsa = None
                                                    self.is_graceful_restart_active = None
                                                    self.ls_id = None
                                                    self.lsa_age = None
                                                    self.lsa_area_id = None
                                                    self.lsa_type = None
                                                    self.sequence_number = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-header'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.advertising_router is not None:
                                                        return True

                                                    if self.checksum is not None:
                                                        return True

                                                    if self.is_do_not_age_lsa is not None:
                                                        return True

                                                    if self.is_graceful_restart_active is not None:
                                                        return True

                                                    if self.ls_id is not None:
                                                        return True

                                                    if self.lsa_age is not None:
                                                        return True

                                                    if self.lsa_area_id is not None:
                                                        return True

                                                    if self.lsa_type is not None:
                                                        return True

                                                    if self.sequence_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                    return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaHeader']['meta_info']


                                            class LsaDetail(object):
                                                """
                                                Detailed LSA information
                                                
                                                .. attribute:: free_time
                                                
                                                	The amount of time since the last check was made to free this LSA (s)
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_acknowledged
                                                
                                                	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_advertising_router_reachable
                                                
                                                	If true, Advertising Router is reachable
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_deleted
                                                
                                                	If true, flag is set to delete this LSA 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_flood_pending
                                                
                                                	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_maximum_aged
                                                
                                                	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_neighbor_exchange
                                                
                                                	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_no_delete
                                                
                                                	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_nsr_ack_pending
                                                
                                                	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_partial_spf
                                                
                                                	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_routing_bit
                                                
                                                	If true, Routing Bit set on the LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_routing_table
                                                
                                                	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                	**type**\:  bool
                                                
                                                .. attribute:: lsa_flood_required_post_fail_over
                                                
                                                	LSA flood required after FO
                                                	**type**\:  bool
                                                
                                                .. attribute:: lsa_length
                                                
                                                	Length of the LSA
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_sync_state
                                                
                                                	State of LSA sync with active
                                                	**type**\:   :py:class:`OspfLsaSyncStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncStateEnum>`
                                                
                                                .. attribute:: minute_table_index
                                                
                                                	Minute table index
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: nsr_flood_required
                                                
                                                	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                	**type**\:  bool
                                                
                                                .. attribute:: rate_limit
                                                
                                                	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                	**type**\:  bool
                                                
                                                .. attribute:: second_table_index
                                                
                                                	Second table index
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.free_time = None
                                                    self.is_acknowledged = None
                                                    self.is_advertising_router_reachable = None
                                                    self.is_deleted = None
                                                    self.is_flood_pending = None
                                                    self.is_maximum_aged = None
                                                    self.is_neighbor_exchange = None
                                                    self.is_no_delete = None
                                                    self.is_nsr_ack_pending = None
                                                    self.is_partial_spf = None
                                                    self.is_routing_bit = None
                                                    self.is_routing_table = None
                                                    self.lsa_flood_required_post_fail_over = None
                                                    self.lsa_length = None
                                                    self.lsa_sync_state = None
                                                    self.minute_table_index = None
                                                    self.nsr_flood_required = None
                                                    self.rate_limit = None
                                                    self.second_table_index = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-detail'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.free_time is not None:
                                                        return True

                                                    if self.is_acknowledged is not None:
                                                        return True

                                                    if self.is_advertising_router_reachable is not None:
                                                        return True

                                                    if self.is_deleted is not None:
                                                        return True

                                                    if self.is_flood_pending is not None:
                                                        return True

                                                    if self.is_maximum_aged is not None:
                                                        return True

                                                    if self.is_neighbor_exchange is not None:
                                                        return True

                                                    if self.is_no_delete is not None:
                                                        return True

                                                    if self.is_nsr_ack_pending is not None:
                                                        return True

                                                    if self.is_partial_spf is not None:
                                                        return True

                                                    if self.is_routing_bit is not None:
                                                        return True

                                                    if self.is_routing_table is not None:
                                                        return True

                                                    if self.lsa_flood_required_post_fail_over is not None:
                                                        return True

                                                    if self.lsa_length is not None:
                                                        return True

                                                    if self.lsa_sync_state is not None:
                                                        return True

                                                    if self.minute_table_index is not None:
                                                        return True

                                                    if self.nsr_flood_required is not None:
                                                        return True

                                                    if self.rate_limit is not None:
                                                        return True

                                                    if self.second_table_index is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                    return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaDetail']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:unknown-area-lsa-type'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface_name is not None:
                                                    return True

                                                if self.is_sham_link is not None:
                                                    return True

                                                if self.is_virtual_link is not None:
                                                    return True

                                                if self.lsa_detail is not None and self.lsa_detail._has_data():
                                                    return True

                                                if self.lsa_header is not None and self.lsa_header._has_data():
                                                    return True

                                                if self.sham_link_id is not None:
                                                    return True

                                                if self.virtual_link_id is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType']['meta_info']


                                        class UnknownAslsaType(object):
                                            """
                                            Unknown\-AS scope LSA
                                            
                                            .. attribute:: interface_name
                                            
                                            	LSA interface name 
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                            
                                            .. attribute:: is_sham_link
                                            
                                            	If true, it is a sham link 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_virtual_link
                                            
                                            	If true, it is a virtual link 
                                            	**type**\:  bool
                                            
                                            .. attribute:: lsa_detail
                                            
                                            	Detailed LSA information
                                            	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType.LsaDetail>`
                                            
                                            .. attribute:: lsa_header
                                            
                                            	Header information 
                                            	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType.LsaHeader>`
                                            
                                            .. attribute:: sham_link_id
                                            
                                            	Shamlink ID 
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: virtual_link_id
                                            
                                            	Virtual link ID 
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface_name = None
                                                self.is_sham_link = None
                                                self.is_virtual_link = None
                                                self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType.LsaDetail()
                                                self.lsa_detail.parent = self
                                                self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType.LsaHeader()
                                                self.lsa_header.parent = self
                                                self.sham_link_id = None
                                                self.virtual_link_id = None


                                            class LsaHeader(object):
                                                """
                                                Header information 
                                                
                                                .. attribute:: advertising_router
                                                
                                                	Router ID of Advertising Router
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: checksum
                                                
                                                	Checksum value
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: is_do_not_age_lsa
                                                
                                                	If true, Do Not Age this LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_graceful_restart_active
                                                
                                                	If true, if grace restart is active 
                                                	**type**\:  bool
                                                
                                                .. attribute:: ls_id
                                                
                                                	LS ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: lsa_age
                                                
                                                	LSA's Age (s)
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_area_id
                                                
                                                	Area ID in decimal or dotted\-decimal format
                                                	**type**\:  str
                                                
                                                	**length:** 0..16
                                                
                                                .. attribute:: lsa_type
                                                
                                                	LSA type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: sequence_number
                                                
                                                	Current Sequence number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.advertising_router = None
                                                    self.checksum = None
                                                    self.is_do_not_age_lsa = None
                                                    self.is_graceful_restart_active = None
                                                    self.ls_id = None
                                                    self.lsa_age = None
                                                    self.lsa_area_id = None
                                                    self.lsa_type = None
                                                    self.sequence_number = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-header'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.advertising_router is not None:
                                                        return True

                                                    if self.checksum is not None:
                                                        return True

                                                    if self.is_do_not_age_lsa is not None:
                                                        return True

                                                    if self.is_graceful_restart_active is not None:
                                                        return True

                                                    if self.ls_id is not None:
                                                        return True

                                                    if self.lsa_age is not None:
                                                        return True

                                                    if self.lsa_area_id is not None:
                                                        return True

                                                    if self.lsa_type is not None:
                                                        return True

                                                    if self.sequence_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                    return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType.LsaHeader']['meta_info']


                                            class LsaDetail(object):
                                                """
                                                Detailed LSA information
                                                
                                                .. attribute:: free_time
                                                
                                                	The amount of time since the last check was made to free this LSA (s)
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_acknowledged
                                                
                                                	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_advertising_router_reachable
                                                
                                                	If true, Advertising Router is reachable
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_deleted
                                                
                                                	If true, flag is set to delete this LSA 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_flood_pending
                                                
                                                	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_maximum_aged
                                                
                                                	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_neighbor_exchange
                                                
                                                	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_no_delete
                                                
                                                	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_nsr_ack_pending
                                                
                                                	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_partial_spf
                                                
                                                	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_routing_bit
                                                
                                                	If true, Routing Bit set on the LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_routing_table
                                                
                                                	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                	**type**\:  bool
                                                
                                                .. attribute:: lsa_flood_required_post_fail_over
                                                
                                                	LSA flood required after FO
                                                	**type**\:  bool
                                                
                                                .. attribute:: lsa_length
                                                
                                                	Length of the LSA
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_sync_state
                                                
                                                	State of LSA sync with active
                                                	**type**\:   :py:class:`OspfLsaSyncStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncStateEnum>`
                                                
                                                .. attribute:: minute_table_index
                                                
                                                	Minute table index
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: nsr_flood_required
                                                
                                                	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                	**type**\:  bool
                                                
                                                .. attribute:: rate_limit
                                                
                                                	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                	**type**\:  bool
                                                
                                                .. attribute:: second_table_index
                                                
                                                	Second table index
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.free_time = None
                                                    self.is_acknowledged = None
                                                    self.is_advertising_router_reachable = None
                                                    self.is_deleted = None
                                                    self.is_flood_pending = None
                                                    self.is_maximum_aged = None
                                                    self.is_neighbor_exchange = None
                                                    self.is_no_delete = None
                                                    self.is_nsr_ack_pending = None
                                                    self.is_partial_spf = None
                                                    self.is_routing_bit = None
                                                    self.is_routing_table = None
                                                    self.lsa_flood_required_post_fail_over = None
                                                    self.lsa_length = None
                                                    self.lsa_sync_state = None
                                                    self.minute_table_index = None
                                                    self.nsr_flood_required = None
                                                    self.rate_limit = None
                                                    self.second_table_index = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-detail'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.free_time is not None:
                                                        return True

                                                    if self.is_acknowledged is not None:
                                                        return True

                                                    if self.is_advertising_router_reachable is not None:
                                                        return True

                                                    if self.is_deleted is not None:
                                                        return True

                                                    if self.is_flood_pending is not None:
                                                        return True

                                                    if self.is_maximum_aged is not None:
                                                        return True

                                                    if self.is_neighbor_exchange is not None:
                                                        return True

                                                    if self.is_no_delete is not None:
                                                        return True

                                                    if self.is_nsr_ack_pending is not None:
                                                        return True

                                                    if self.is_partial_spf is not None:
                                                        return True

                                                    if self.is_routing_bit is not None:
                                                        return True

                                                    if self.is_routing_table is not None:
                                                        return True

                                                    if self.lsa_flood_required_post_fail_over is not None:
                                                        return True

                                                    if self.lsa_length is not None:
                                                        return True

                                                    if self.lsa_sync_state is not None:
                                                        return True

                                                    if self.minute_table_index is not None:
                                                        return True

                                                    if self.nsr_flood_required is not None:
                                                        return True

                                                    if self.rate_limit is not None:
                                                        return True

                                                    if self.second_table_index is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                    return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType.LsaDetail']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:unknown-aslsa-type'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface_name is not None:
                                                    return True

                                                if self.is_sham_link is not None:
                                                    return True

                                                if self.is_virtual_link is not None:
                                                    return True

                                                if self.lsa_detail is not None and self.lsa_detail._has_data():
                                                    return True

                                                if self.lsa_header is not None and self.lsa_header._has_data():
                                                    return True

                                                if self.sham_link_id is not None:
                                                    return True

                                                if self.virtual_link_id is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType']['meta_info']


                                        class UnknownLsaType(object):
                                            """
                                            Unknown LSA
                                            
                                            .. attribute:: interface_name
                                            
                                            	LSA interface name 
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                            
                                            .. attribute:: is_sham_link
                                            
                                            	If true, it is a sham link 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_virtual_link
                                            
                                            	If true, it is a virtual link 
                                            	**type**\:  bool
                                            
                                            .. attribute:: lsa_detail
                                            
                                            	Detailed LSA information
                                            	**type**\:   :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType.LsaDetail>`
                                            
                                            .. attribute:: lsa_header
                                            
                                            	Header information 
                                            	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType.LsaHeader>`
                                            
                                            .. attribute:: sham_link_id
                                            
                                            	Shamlink ID 
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: virtual_link_id
                                            
                                            	Virtual link ID 
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface_name = None
                                                self.is_sham_link = None
                                                self.is_virtual_link = None
                                                self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType.LsaDetail()
                                                self.lsa_detail.parent = self
                                                self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType.LsaHeader()
                                                self.lsa_header.parent = self
                                                self.sham_link_id = None
                                                self.virtual_link_id = None


                                            class LsaHeader(object):
                                                """
                                                Header information 
                                                
                                                .. attribute:: advertising_router
                                                
                                                	Router ID of Advertising Router
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: checksum
                                                
                                                	Checksum value
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: is_do_not_age_lsa
                                                
                                                	If true, Do Not Age this LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_graceful_restart_active
                                                
                                                	If true, if grace restart is active 
                                                	**type**\:  bool
                                                
                                                .. attribute:: ls_id
                                                
                                                	LS ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: lsa_age
                                                
                                                	LSA's Age (s)
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_area_id
                                                
                                                	Area ID in decimal or dotted\-decimal format
                                                	**type**\:  str
                                                
                                                	**length:** 0..16
                                                
                                                .. attribute:: lsa_type
                                                
                                                	LSA type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: sequence_number
                                                
                                                	Current Sequence number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.advertising_router = None
                                                    self.checksum = None
                                                    self.is_do_not_age_lsa = None
                                                    self.is_graceful_restart_active = None
                                                    self.ls_id = None
                                                    self.lsa_age = None
                                                    self.lsa_area_id = None
                                                    self.lsa_type = None
                                                    self.sequence_number = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-header'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.advertising_router is not None:
                                                        return True

                                                    if self.checksum is not None:
                                                        return True

                                                    if self.is_do_not_age_lsa is not None:
                                                        return True

                                                    if self.is_graceful_restart_active is not None:
                                                        return True

                                                    if self.ls_id is not None:
                                                        return True

                                                    if self.lsa_age is not None:
                                                        return True

                                                    if self.lsa_area_id is not None:
                                                        return True

                                                    if self.lsa_type is not None:
                                                        return True

                                                    if self.sequence_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                    return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType.LsaHeader']['meta_info']


                                            class LsaDetail(object):
                                                """
                                                Detailed LSA information
                                                
                                                .. attribute:: free_time
                                                
                                                	The amount of time since the last check was made to free this LSA (s)
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_acknowledged
                                                
                                                	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_advertising_router_reachable
                                                
                                                	If true, Advertising Router is reachable
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_deleted
                                                
                                                	If true, flag is set to delete this LSA 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_flood_pending
                                                
                                                	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_maximum_aged
                                                
                                                	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_neighbor_exchange
                                                
                                                	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_no_delete
                                                
                                                	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_nsr_ack_pending
                                                
                                                	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_partial_spf
                                                
                                                	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_routing_bit
                                                
                                                	If true, Routing Bit set on the LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_routing_table
                                                
                                                	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                	**type**\:  bool
                                                
                                                .. attribute:: lsa_flood_required_post_fail_over
                                                
                                                	LSA flood required after FO
                                                	**type**\:  bool
                                                
                                                .. attribute:: lsa_length
                                                
                                                	Length of the LSA
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_sync_state
                                                
                                                	State of LSA sync with active
                                                	**type**\:   :py:class:`OspfLsaSyncStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncStateEnum>`
                                                
                                                .. attribute:: minute_table_index
                                                
                                                	Minute table index
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: nsr_flood_required
                                                
                                                	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                	**type**\:  bool
                                                
                                                .. attribute:: rate_limit
                                                
                                                	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                	**type**\:  bool
                                                
                                                .. attribute:: second_table_index
                                                
                                                	Second table index
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.free_time = None
                                                    self.is_acknowledged = None
                                                    self.is_advertising_router_reachable = None
                                                    self.is_deleted = None
                                                    self.is_flood_pending = None
                                                    self.is_maximum_aged = None
                                                    self.is_neighbor_exchange = None
                                                    self.is_no_delete = None
                                                    self.is_nsr_ack_pending = None
                                                    self.is_partial_spf = None
                                                    self.is_routing_bit = None
                                                    self.is_routing_table = None
                                                    self.lsa_flood_required_post_fail_over = None
                                                    self.lsa_length = None
                                                    self.lsa_sync_state = None
                                                    self.minute_table_index = None
                                                    self.nsr_flood_required = None
                                                    self.rate_limit = None
                                                    self.second_table_index = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-detail'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.free_time is not None:
                                                        return True

                                                    if self.is_acknowledged is not None:
                                                        return True

                                                    if self.is_advertising_router_reachable is not None:
                                                        return True

                                                    if self.is_deleted is not None:
                                                        return True

                                                    if self.is_flood_pending is not None:
                                                        return True

                                                    if self.is_maximum_aged is not None:
                                                        return True

                                                    if self.is_neighbor_exchange is not None:
                                                        return True

                                                    if self.is_no_delete is not None:
                                                        return True

                                                    if self.is_nsr_ack_pending is not None:
                                                        return True

                                                    if self.is_partial_spf is not None:
                                                        return True

                                                    if self.is_routing_bit is not None:
                                                        return True

                                                    if self.is_routing_table is not None:
                                                        return True

                                                    if self.lsa_flood_required_post_fail_over is not None:
                                                        return True

                                                    if self.lsa_length is not None:
                                                        return True

                                                    if self.lsa_sync_state is not None:
                                                        return True

                                                    if self.minute_table_index is not None:
                                                        return True

                                                    if self.nsr_flood_required is not None:
                                                        return True

                                                    if self.rate_limit is not None:
                                                        return True

                                                    if self.second_table_index is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                    return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType.LsaDetail']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:unknown-lsa-type'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface_name is not None:
                                                    return True

                                                if self.is_sham_link is not None:
                                                    return True

                                                if self.is_virtual_link is not None:
                                                    return True

                                                if self.lsa_detail is not None and self.lsa_detail._has_data():
                                                    return True

                                                if self.lsa_header is not None and self.lsa_header._has_data():
                                                    return True

                                                if self.sham_link_id is not None:
                                                    return True

                                                if self.virtual_link_id is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                                return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-info'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.external_lsa_type is not None and self.external_lsa_type._has_data():
                                                return True

                                            if self.grace_lsa is not None and self.grace_lsa._has_data():
                                                return True

                                            if self.inter_area_prefix_lsa_type is not None and self.inter_area_prefix_lsa_type._has_data():
                                                return True

                                            if self.inter_area_router_lsa_type is not None and self.inter_area_router_lsa_type._has_data():
                                                return True

                                            if self.intra_area_prefix_lsa_type is not None and self.intra_area_prefix_lsa_type._has_data():
                                                return True

                                            if self.link_lsa_type is not None and self.link_lsa_type._has_data():
                                                return True

                                            if self.lsa_info_type is not None:
                                                return True

                                            if self.lsa_summary_info is not None and self.lsa_summary_info._has_data():
                                                return True

                                            if self.network_lsa_type is not None and self.network_lsa_type._has_data():
                                                return True

                                            if self.nssalsa_type is not None and self.nssalsa_type._has_data():
                                                return True

                                            if self.router_lsa_type is not None and self.router_lsa_type._has_data():
                                                return True

                                            if self.unknown_area_lsa_type is not None and self.unknown_area_lsa_type._has_data():
                                                return True

                                            if self.unknown_aslsa_type is not None and self.unknown_aslsa_type._has_data():
                                                return True

                                            if self.unknown_link_lsa_type is not None and self.unknown_link_lsa_type._has_data():
                                                return True

                                            if self.unknown_lsa_type is not None and self.unknown_lsa_type._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.advertising_router is not None:
                                            return True

                                        if self.area_id is not None:
                                            return True

                                        if self.interface_name is not None:
                                            return True

                                        if self.ls_id is not None:
                                            return True

                                        if self.ls_type is not None:
                                            return True

                                        if self.lsa_info is not None and self.lsa_info._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                        return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa-internal-table'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.lsa is not None:
                                        for child_ref in self.lsa:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                    return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:database-table'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.lsa_internal_table is not None and self.lsa_internal_table._has_data():
                                    return True

                                if self.lsa_table is not None and self.lsa_table._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable']['meta_info']


                        class DatabaseSummaryTable(object):
                            """
                            Database summary table
                            
                            .. attribute:: database_summary
                            
                            	Database Summary information
                            	**type**\:   :py:class:`DatabaseSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseSummaryTable.DatabaseSummary>`
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.database_summary = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseSummaryTable.DatabaseSummary()
                                self.database_summary.parent = self


                            class DatabaseSummary(object):
                                """
                                Database Summary information
                                
                                .. attribute:: area_database
                                
                                	OSPFv3 Area Database list 
                                	**type**\: list of    :py:class:`AreaDatabase <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseSummaryTable.DatabaseSummary.AreaDatabase>`
                                
                                .. attribute:: database_counters
                                
                                	OSPFv3 database counters 
                                	**type**\:   :py:class:`DatabaseCounters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseSummaryTable.DatabaseSummary.DatabaseCounters>`
                                
                                .. attribute:: database_router_id
                                
                                	Database router ID 
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: is_opaque_database_capable
                                
                                	If true, opaque database is capable 
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.area_database = YList()
                                    self.area_database.parent = self
                                    self.area_database.name = 'area_database'
                                    self.database_counters = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseSummaryTable.DatabaseSummary.DatabaseCounters()
                                    self.database_counters.parent = self
                                    self.database_router_id = None
                                    self.is_opaque_database_capable = None


                                class DatabaseCounters(object):
                                    """
                                    OSPFv3 database counters 
                                    
                                    .. attribute:: deleted_lsa
                                    
                                    	deleted lsa
                                    	**type**\:  list of int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: lsa
                                    
                                    	lsa
                                    	**type**\:  list of int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: lsa_checksum
                                    
                                    	lsa checksum
                                    	**type**\:  list of int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: max_age_lsa
                                    
                                    	max age lsa
                                    	**type**\:  list of int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.deleted_lsa = YLeafList()
                                        self.deleted_lsa.parent = self
                                        self.deleted_lsa.name = 'deleted_lsa'
                                        self.lsa = YLeafList()
                                        self.lsa.parent = self
                                        self.lsa.name = 'lsa'
                                        self.lsa_checksum = YLeafList()
                                        self.lsa_checksum.parent = self
                                        self.lsa_checksum.name = 'lsa_checksum'
                                        self.max_age_lsa = YLeafList()
                                        self.max_age_lsa.parent = self
                                        self.max_age_lsa.name = 'max_age_lsa'

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:database-counters'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.deleted_lsa is not None:
                                            for child in self.deleted_lsa:
                                                if child is not None:
                                                    return True

                                        if self.lsa is not None:
                                            for child in self.lsa:
                                                if child is not None:
                                                    return True

                                        if self.lsa_checksum is not None:
                                            for child in self.lsa_checksum:
                                                if child is not None:
                                                    return True

                                        if self.max_age_lsa is not None:
                                            for child in self.max_age_lsa:
                                                if child is not None:
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                        return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseSummaryTable.DatabaseSummary.DatabaseCounters']['meta_info']


                                class AreaDatabase(object):
                                    """
                                    OSPFv3 Area Database list 
                                    
                                    .. attribute:: area_database_summary
                                    
                                    	Area database summary 
                                    	**type**\:   :py:class:`AreaDatabaseSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseSummaryTable.DatabaseSummary.AreaDatabase.AreaDatabaseSummary>`
                                    
                                    .. attribute:: lsa_area_id
                                    
                                    	Area ID in decimal or dotted\-decimal format
                                    	**type**\:  str
                                    
                                    	**length:** 0..16
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.area_database_summary = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseSummaryTable.DatabaseSummary.AreaDatabase.AreaDatabaseSummary()
                                        self.area_database_summary.parent = self
                                        self.lsa_area_id = None


                                    class AreaDatabaseSummary(object):
                                        """
                                        Area database summary 
                                        
                                        .. attribute:: deleted_lsa
                                        
                                        	deleted lsa
                                        	**type**\:  list of int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: lsa
                                        
                                        	lsa
                                        	**type**\:  list of int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: lsa_checksum
                                        
                                        	lsa checksum
                                        	**type**\:  list of int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: max_age_lsa
                                        
                                        	max age lsa
                                        	**type**\:  list of int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.deleted_lsa = YLeafList()
                                            self.deleted_lsa.parent = self
                                            self.deleted_lsa.name = 'deleted_lsa'
                                            self.lsa = YLeafList()
                                            self.lsa.parent = self
                                            self.lsa.name = 'lsa'
                                            self.lsa_checksum = YLeafList()
                                            self.lsa_checksum.parent = self
                                            self.lsa_checksum.name = 'lsa_checksum'
                                            self.max_age_lsa = YLeafList()
                                            self.max_age_lsa.parent = self
                                            self.max_age_lsa.name = 'max_age_lsa'

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:area-database-summary'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.deleted_lsa is not None:
                                                for child in self.deleted_lsa:
                                                    if child is not None:
                                                        return True

                                            if self.lsa is not None:
                                                for child in self.lsa:
                                                    if child is not None:
                                                        return True

                                            if self.lsa_checksum is not None:
                                                for child in self.lsa_checksum:
                                                    if child is not None:
                                                        return True

                                            if self.max_age_lsa is not None:
                                                for child in self.max_age_lsa:
                                                    if child is not None:
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                            return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseSummaryTable.DatabaseSummary.AreaDatabase.AreaDatabaseSummary']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:area-database'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.area_database_summary is not None and self.area_database_summary._has_data():
                                            return True

                                        if self.lsa_area_id is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                        return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseSummaryTable.DatabaseSummary.AreaDatabase']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:database-summary'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.area_database is not None:
                                        for child_ref in self.area_database:
                                            if child_ref._has_data():
                                                return True

                                    if self.database_counters is not None and self.database_counters._has_data():
                                        return True

                                    if self.database_router_id is not None:
                                        return True

                                    if self.is_opaque_database_capable is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                    return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseSummaryTable.DatabaseSummary']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:database-summary-table'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.database_summary is not None and self.database_summary._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseSummaryTable']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')
                            if self.area_id is None:
                                raise YPYModelError('Key property area_id is None')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:area[Cisco-IOS-XR-ipv6-ospfv3-oper:area-id = ' + str(self.area_id) + ']'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.area_id is not None:
                                return True

                            if self.database_summary_table is not None and self.database_summary_table._has_data():
                                return True

                            if self.database_table is not None and self.database_table._has_data():
                                return True

                            if self.flood_list_table is not None and self.flood_list_table._has_data():
                                return True

                            if self.interface_brief_table is not None and self.interface_brief_table._has_data():
                                return True

                            if self.interface_table is not None and self.interface_table._has_data():
                                return True

                            if self.neighbor_detail_table is not None and self.neighbor_detail_table._has_data():
                                return True

                            if self.neighbor_table is not None and self.neighbor_table._has_data():
                                return True

                            if self.request_list_table is not None and self.request_list_table._has_data():
                                return True

                            if self.retransmission_list_table is not None and self.retransmission_list_table._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                            return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Areas.Area']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:areas'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.area is not None:
                            for child_ref in self.area:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                        return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Areas']['meta_info']


                class InternalRoutes(object):
                    """
                    OSPFv3 internal route information table
                    
                    .. attribute:: internal_route
                    
                    	OSPFv3 internal route information
                    	**type**\: list of    :py:class:`InternalRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.InternalRoutes.InternalRoute>`
                    
                    

                    """

                    _prefix = 'ipv6-ospfv3-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.internal_route = YList()
                        self.internal_route.parent = self
                        self.internal_route.name = 'internal_route'


                    class InternalRoute(object):
                        """
                        OSPFv3 internal route information
                        
                        .. attribute:: prefix
                        
                        	Route prefix
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: prefix_length
                        
                        	Prefix length
                        	**type**\:  int
                        
                        	**range:** 0..128
                        
                        .. attribute:: route_area_id
                        
                        	Route area ID 
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: route_path
                        
                        	List of paths to this route
                        	**type**\: list of    :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.InternalRoutes.InternalRoute.RoutePath>`
                        
                        .. attribute:: route_source
                        
                        	List of topology source information
                        	**type**\: list of    :py:class:`RouteSource <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.InternalRoutes.InternalRoute.RouteSource>`
                        
                        .. attribute:: route_topology
                        
                        	Common Route topology information
                        	**type**\:   :py:class:`RouteTopology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.InternalRoutes.InternalRoute.RouteTopology>`
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.prefix = None
                            self.prefix_length = None
                            self.route_area_id = None
                            self.route_path = YList()
                            self.route_path.parent = self
                            self.route_path.name = 'route_path'
                            self.route_source = YList()
                            self.route_source.parent = self
                            self.route_source.name = 'route_source'
                            self.route_topology = Ospfv3.Processes.Process.DefaultVrf.InternalRoutes.InternalRoute.RouteTopology()
                            self.route_topology.parent = self


                        class RouteTopology(object):
                            """
                            Common Route topology information
                            
                            .. attribute:: route_cost
                            
                            	Route cost 
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: route_distance
                            
                            	Route distance 
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: route_id
                            
                            	Route ID 
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: route_type
                            
                            	Route type
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.route_cost = None
                                self.route_distance = None
                                self.route_id = None
                                self.route_type = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:route-topology'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.route_cost is not None:
                                    return True

                                if self.route_distance is not None:
                                    return True

                                if self.route_id is not None:
                                    return True

                                if self.route_type is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.InternalRoutes.InternalRoute.RouteTopology']['meta_info']


                        class RouteSource(object):
                            """
                            List of topology source information
                            
                            .. attribute:: route_source_adversting_router
                            
                            	Route source of the advertising router 
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: route_source_id
                            
                            	Route source ID 
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: route_source_lsa_type
                            
                            	Type of LSA advertising the prefix, see RFC5340
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.route_source_adversting_router = None
                                self.route_source_id = None
                                self.route_source_lsa_type = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:route-source'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.route_source_adversting_router is not None:
                                    return True

                                if self.route_source_id is not None:
                                    return True

                                if self.route_source_lsa_type is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.InternalRoutes.InternalRoute.RouteSource']['meta_info']


                        class RoutePath(object):
                            """
                            List of paths to this route
                            
                            .. attribute:: interface_name
                            
                            	Route path interface name 
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: route_backup_path
                            
                            	Backup Path Info
                            	**type**\:   :py:class:`RouteBackupPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.InternalRoutes.InternalRoute.RoutePath.RouteBackupPath>`
                            
                            .. attribute:: route_path_id
                            
                            	Path ID of path
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: route_path_next_hop
                            
                            	Route path next hop 
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.interface_name = None
                                self.route_backup_path = Ospfv3.Processes.Process.DefaultVrf.InternalRoutes.InternalRoute.RoutePath.RouteBackupPath()
                                self.route_backup_path.parent = self
                                self.route_path_id = None
                                self.route_path_next_hop = None


                            class RouteBackupPath(object):
                                """
                                Backup Path Info
                                
                                .. attribute:: backup_metric
                                
                                	Metric
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: backup_route_interface_name
                                
                                	Next hop Interface
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: backup_route_next_hop_address
                                
                                	Nexthop IP address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: backup_route_source
                                
                                	IP address of source of route
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: downstream
                                
                                	Downstream
                                	**type**\:  bool
                                
                                .. attribute:: line_card_disjoint
                                
                                	Line Card Disjoint
                                	**type**\:  bool
                                
                                .. attribute:: node_protect
                                
                                	Node Protect
                                	**type**\:  bool
                                
                                .. attribute:: primary_path
                                
                                	Primary Path
                                	**type**\:  bool
                                
                                .. attribute:: srlg_disjoint
                                
                                	SRLG Disjoint
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.backup_metric = None
                                    self.backup_route_interface_name = None
                                    self.backup_route_next_hop_address = None
                                    self.backup_route_source = None
                                    self.downstream = None
                                    self.line_card_disjoint = None
                                    self.node_protect = None
                                    self.primary_path = None
                                    self.srlg_disjoint = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:route-backup-path'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.backup_metric is not None:
                                        return True

                                    if self.backup_route_interface_name is not None:
                                        return True

                                    if self.backup_route_next_hop_address is not None:
                                        return True

                                    if self.backup_route_source is not None:
                                        return True

                                    if self.downstream is not None:
                                        return True

                                    if self.line_card_disjoint is not None:
                                        return True

                                    if self.node_protect is not None:
                                        return True

                                    if self.primary_path is not None:
                                        return True

                                    if self.srlg_disjoint is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                    return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.InternalRoutes.InternalRoute.RoutePath.RouteBackupPath']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:route-path'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.interface_name is not None:
                                    return True

                                if self.route_backup_path is not None and self.route_backup_path._has_data():
                                    return True

                                if self.route_path_id is not None:
                                    return True

                                if self.route_path_next_hop is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.InternalRoutes.InternalRoute.RoutePath']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:internal-route'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.prefix is not None:
                                return True

                            if self.prefix_length is not None:
                                return True

                            if self.route_area_id is not None:
                                return True

                            if self.route_path is not None:
                                for child_ref in self.route_path:
                                    if child_ref._has_data():
                                        return True

                            if self.route_source is not None:
                                for child_ref in self.route_source:
                                    if child_ref._has_data():
                                        return True

                            if self.route_topology is not None and self.route_topology._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                            return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.InternalRoutes.InternalRoute']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:internal-routes'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.internal_route is not None:
                            for child_ref in self.internal_route:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                        return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.InternalRoutes']['meta_info']


                class ProtocolAreas(object):
                    """
                    Protocol area table 
                    
                    .. attribute:: protocol_area
                    
                    	Area information 
                    	**type**\: list of    :py:class:`ProtocolArea <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.ProtocolAreas.ProtocolArea>`
                    
                    

                    """

                    _prefix = 'ipv6-ospfv3-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.protocol_area = YList()
                        self.protocol_area.parent = self
                        self.protocol_area.name = 'protocol_area'


                    class ProtocolArea(object):
                        """
                        Area information 
                        
                        .. attribute:: area_id  <key>
                        
                        	Area ID
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: distribute_list_in
                        
                        	Distribute List In
                        	**type**\:  str
                        
                        .. attribute:: protocol_area_id
                        
                        	Area ID string in decimal and dotted\-decimal format
                        	**type**\:  str
                        
                        	**length:** 0..16
                        
                        .. attribute:: protocol_interface
                        
                        	Interface list
                        	**type**\: list of    :py:class:`ProtocolInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.ProtocolAreas.ProtocolArea.ProtocolInterface>`
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.area_id = None
                            self.distribute_list_in = None
                            self.protocol_area_id = None
                            self.protocol_interface = YList()
                            self.protocol_interface.parent = self
                            self.protocol_interface.name = 'protocol_interface'


                        class ProtocolInterface(object):
                            """
                            Interface list
                            
                            .. attribute:: distribute_list_in
                            
                            	Distribute List In
                            	**type**\:  str
                            
                            .. attribute:: interface_name
                            
                            	Protocol interface name 
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.distribute_list_in = None
                                self.interface_name = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:protocol-interface'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.distribute_list_in is not None:
                                    return True

                                if self.interface_name is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.ProtocolAreas.ProtocolArea.ProtocolInterface']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')
                            if self.area_id is None:
                                raise YPYModelError('Key property area_id is None')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:protocol-area[Cisco-IOS-XR-ipv6-ospfv3-oper:area-id = ' + str(self.area_id) + ']'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.area_id is not None:
                                return True

                            if self.distribute_list_in is not None:
                                return True

                            if self.protocol_area_id is not None:
                                return True

                            if self.protocol_interface is not None:
                                for child_ref in self.protocol_interface:
                                    if child_ref._has_data():
                                        return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                            return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.ProtocolAreas.ProtocolArea']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:protocol-areas'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.protocol_area is not None:
                            for child_ref in self.protocol_area:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                        return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.ProtocolAreas']['meta_info']


                class ConnectedRoutes(object):
                    """
                    OSPFv3 connected route information table
                    
                    .. attribute:: connected_route
                    
                    	OSPFv3 connected route information
                    	**type**\: list of    :py:class:`ConnectedRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.ConnectedRoutes.ConnectedRoute>`
                    
                    

                    """

                    _prefix = 'ipv6-ospfv3-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.connected_route = YList()
                        self.connected_route.parent = self
                        self.connected_route.name = 'connected_route'


                    class ConnectedRoute(object):
                        """
                        OSPFv3 connected route information
                        
                        .. attribute:: prefix
                        
                        	Route prefix
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: prefix_length
                        
                        	Prefix length
                        	**type**\:  int
                        
                        	**range:** 0..128
                        
                        .. attribute:: route_path
                        
                        	List of paths to this route
                        	**type**\: list of    :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.ConnectedRoutes.ConnectedRoute.RoutePath>`
                        
                        .. attribute:: route_topology
                        
                        	Common Route topology information
                        	**type**\:   :py:class:`RouteTopology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.ConnectedRoutes.ConnectedRoute.RouteTopology>`
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.prefix = None
                            self.prefix_length = None
                            self.route_path = YList()
                            self.route_path.parent = self
                            self.route_path.name = 'route_path'
                            self.route_topology = Ospfv3.Processes.Process.DefaultVrf.ConnectedRoutes.ConnectedRoute.RouteTopology()
                            self.route_topology.parent = self


                        class RouteTopology(object):
                            """
                            Common Route topology information
                            
                            .. attribute:: route_cost
                            
                            	Route cost 
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: route_distance
                            
                            	Route distance 
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: route_id
                            
                            	Route ID 
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: route_type
                            
                            	Route type
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.route_cost = None
                                self.route_distance = None
                                self.route_id = None
                                self.route_type = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:route-topology'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.route_cost is not None:
                                    return True

                                if self.route_distance is not None:
                                    return True

                                if self.route_id is not None:
                                    return True

                                if self.route_type is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.ConnectedRoutes.ConnectedRoute.RouteTopology']['meta_info']


                        class RoutePath(object):
                            """
                            List of paths to this route
                            
                            .. attribute:: interface_name
                            
                            	Route path interface name 
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: route_backup_path
                            
                            	Backup Path Info
                            	**type**\:   :py:class:`RouteBackupPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.ConnectedRoutes.ConnectedRoute.RoutePath.RouteBackupPath>`
                            
                            .. attribute:: route_path_id
                            
                            	Path ID of path
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: route_path_next_hop
                            
                            	Route path next hop 
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.interface_name = None
                                self.route_backup_path = Ospfv3.Processes.Process.DefaultVrf.ConnectedRoutes.ConnectedRoute.RoutePath.RouteBackupPath()
                                self.route_backup_path.parent = self
                                self.route_path_id = None
                                self.route_path_next_hop = None


                            class RouteBackupPath(object):
                                """
                                Backup Path Info
                                
                                .. attribute:: backup_metric
                                
                                	Metric
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: backup_route_interface_name
                                
                                	Next hop Interface
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: backup_route_next_hop_address
                                
                                	Nexthop IP address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: backup_route_source
                                
                                	IP address of source of route
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: downstream
                                
                                	Downstream
                                	**type**\:  bool
                                
                                .. attribute:: line_card_disjoint
                                
                                	Line Card Disjoint
                                	**type**\:  bool
                                
                                .. attribute:: node_protect
                                
                                	Node Protect
                                	**type**\:  bool
                                
                                .. attribute:: primary_path
                                
                                	Primary Path
                                	**type**\:  bool
                                
                                .. attribute:: srlg_disjoint
                                
                                	SRLG Disjoint
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.backup_metric = None
                                    self.backup_route_interface_name = None
                                    self.backup_route_next_hop_address = None
                                    self.backup_route_source = None
                                    self.downstream = None
                                    self.line_card_disjoint = None
                                    self.node_protect = None
                                    self.primary_path = None
                                    self.srlg_disjoint = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:route-backup-path'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.backup_metric is not None:
                                        return True

                                    if self.backup_route_interface_name is not None:
                                        return True

                                    if self.backup_route_next_hop_address is not None:
                                        return True

                                    if self.backup_route_source is not None:
                                        return True

                                    if self.downstream is not None:
                                        return True

                                    if self.line_card_disjoint is not None:
                                        return True

                                    if self.node_protect is not None:
                                        return True

                                    if self.primary_path is not None:
                                        return True

                                    if self.srlg_disjoint is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                    return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.ConnectedRoutes.ConnectedRoute.RoutePath.RouteBackupPath']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:route-path'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.interface_name is not None:
                                    return True

                                if self.route_backup_path is not None and self.route_backup_path._has_data():
                                    return True

                                if self.route_path_id is not None:
                                    return True

                                if self.route_path_next_hop is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.ConnectedRoutes.ConnectedRoute.RoutePath']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:connected-route'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.prefix is not None:
                                return True

                            if self.prefix_length is not None:
                                return True

                            if self.route_path is not None:
                                for child_ref in self.route_path:
                                    if child_ref._has_data():
                                        return True

                            if self.route_topology is not None and self.route_topology._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                            return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.ConnectedRoutes.ConnectedRoute']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:connected-routes'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.connected_route is not None:
                            for child_ref in self.connected_route:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                        return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.ConnectedRoutes']['meta_info']


                class VrfStatistics(object):
                    """
                    Container for Statistics
                    
                    .. attribute:: prefix_priority_stats
                    
                    	OSPF Prefix SPF Prioritization statistics
                    	**type**\:   :py:class:`PrefixPriorityStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.VrfStatistics.PrefixPriorityStats>`
                    
                    .. attribute:: protocol_stats
                    
                    	Protocol table
                    	**type**\:   :py:class:`ProtocolStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.VrfStatistics.ProtocolStats>`
                    
                    .. attribute:: rawio_stats
                    
                    	OSPF Prefix SPF Prioritization statistics
                    	**type**\:   :py:class:`RawioStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.VrfStatistics.RawioStats>`
                    
                    .. attribute:: spf_stats
                    
                    	OSPFv3 RIB batch statistics
                    	**type**\:   :py:class:`SpfStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.VrfStatistics.SpfStats>`
                    
                    .. attribute:: vrf_rib_batch_stats
                    
                    	OSPFv3 RIB batch statistics
                    	**type**\:   :py:class:`VrfRibBatchStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.VrfStatistics.VrfRibBatchStats>`
                    
                    

                    """

                    _prefix = 'ipv6-ospfv3-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.prefix_priority_stats = Ospfv3.Processes.Process.DefaultVrf.VrfStatistics.PrefixPriorityStats()
                        self.prefix_priority_stats.parent = self
                        self.protocol_stats = Ospfv3.Processes.Process.DefaultVrf.VrfStatistics.ProtocolStats()
                        self.protocol_stats.parent = self
                        self.rawio_stats = Ospfv3.Processes.Process.DefaultVrf.VrfStatistics.RawioStats()
                        self.rawio_stats.parent = self
                        self.spf_stats = Ospfv3.Processes.Process.DefaultVrf.VrfStatistics.SpfStats()
                        self.spf_stats.parent = self
                        self.vrf_rib_batch_stats = Ospfv3.Processes.Process.DefaultVrf.VrfStatistics.VrfRibBatchStats()
                        self.vrf_rib_batch_stats.parent = self


                    class ProtocolStats(object):
                        """
                        Protocol table
                        
                        .. attribute:: protocol_stat
                        
                        	Protocol statistics for an interface
                        	**type**\: list of    :py:class:`ProtocolStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.VrfStatistics.ProtocolStats.ProtocolStat>`
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.protocol_stat = YList()
                            self.protocol_stat.parent = self
                            self.protocol_stat.name = 'protocol_stat'


                        class ProtocolStat(object):
                            """
                            Protocol statistics for an interface
                            
                            .. attribute:: interface_name  <key>
                            
                            	Interface name
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: checksum_err
                            
                            	Checksum Errors
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: dbdes_in_ls_as
                            
                            	Database Description LSAs in
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: dbdes_in_packets
                            
                            	Database Description Packets in
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: dbdes_out_ls_as
                            
                            	Database Description LSAs out
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: dbdes_out_packets
                            
                            	Database Description Packets out
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: dropped_in_gs
                            
                            	Dropped in GS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: hello_in_packets
                            
                            	Hello packets in
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: hello_out_packets
                            
                            	Hello Out Packets
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: ls_ack_in_ls_as
                            
                            	LS Ack LSAs in
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: ls_ack_in_packets
                            
                            	LS Acks Packets in
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: ls_ack_out_ls_as
                            
                            	LS Ack LSAs out
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: ls_ack_out_packets
                            
                            	LS Ack Packets out
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: ls_req_in_ls_as
                            
                            	LS Requests in
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: ls_req_in_packets
                            
                            	LSA Requests in
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: ls_req_out_ls_as
                            
                            	LS Reuqests LSAs out
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: ls_req_out_packets
                            
                            	LS Request Packets out
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: ls_upd_in_ignored
                            
                            	LS Updates ignored
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: ls_upd_in_ls_as
                            
                            	LS Updates LSAs in
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: ls_upd_in_packets
                            
                            	LS Updates Packets in
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: ls_upd_out_ls_as
                            
                            	LS Update LSAs out
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: ls_upd_out_packets
                            
                            	LS Update Packets out
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: total_in_packets
                            
                            	Total inputs packets
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: total_out_packets
                            
                            	Total Out Packets
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.interface_name = None
                                self.checksum_err = None
                                self.dbdes_in_ls_as = None
                                self.dbdes_in_packets = None
                                self.dbdes_out_ls_as = None
                                self.dbdes_out_packets = None
                                self.dropped_in_gs = None
                                self.hello_in_packets = None
                                self.hello_out_packets = None
                                self.ls_ack_in_ls_as = None
                                self.ls_ack_in_packets = None
                                self.ls_ack_out_ls_as = None
                                self.ls_ack_out_packets = None
                                self.ls_req_in_ls_as = None
                                self.ls_req_in_packets = None
                                self.ls_req_out_ls_as = None
                                self.ls_req_out_packets = None
                                self.ls_upd_in_ignored = None
                                self.ls_upd_in_ls_as = None
                                self.ls_upd_in_packets = None
                                self.ls_upd_out_ls_as = None
                                self.ls_upd_out_packets = None
                                self.total_in_packets = None
                                self.total_out_packets = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')
                                if self.interface_name is None:
                                    raise YPYModelError('Key property interface_name is None')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:protocol-stat[Cisco-IOS-XR-ipv6-ospfv3-oper:interface-name = ' + str(self.interface_name) + ']'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.interface_name is not None:
                                    return True

                                if self.checksum_err is not None:
                                    return True

                                if self.dbdes_in_ls_as is not None:
                                    return True

                                if self.dbdes_in_packets is not None:
                                    return True

                                if self.dbdes_out_ls_as is not None:
                                    return True

                                if self.dbdes_out_packets is not None:
                                    return True

                                if self.dropped_in_gs is not None:
                                    return True

                                if self.hello_in_packets is not None:
                                    return True

                                if self.hello_out_packets is not None:
                                    return True

                                if self.ls_ack_in_ls_as is not None:
                                    return True

                                if self.ls_ack_in_packets is not None:
                                    return True

                                if self.ls_ack_out_ls_as is not None:
                                    return True

                                if self.ls_ack_out_packets is not None:
                                    return True

                                if self.ls_req_in_ls_as is not None:
                                    return True

                                if self.ls_req_in_packets is not None:
                                    return True

                                if self.ls_req_out_ls_as is not None:
                                    return True

                                if self.ls_req_out_packets is not None:
                                    return True

                                if self.ls_upd_in_ignored is not None:
                                    return True

                                if self.ls_upd_in_ls_as is not None:
                                    return True

                                if self.ls_upd_in_packets is not None:
                                    return True

                                if self.ls_upd_out_ls_as is not None:
                                    return True

                                if self.ls_upd_out_packets is not None:
                                    return True

                                if self.total_in_packets is not None:
                                    return True

                                if self.total_out_packets is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.VrfStatistics.ProtocolStats.ProtocolStat']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:protocol-stats'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.protocol_stat is not None:
                                for child_ref in self.protocol_stat:
                                    if child_ref._has_data():
                                        return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                            return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.VrfStatistics.ProtocolStats']['meta_info']


                    class SpfStats(object):
                        """
                        OSPFv3 RIB batch statistics
                        
                        .. attribute:: spf_header
                        
                        	SPF statistics header
                        	**type**\:   :py:class:`SpfHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.VrfStatistics.SpfStats.SpfHeader>`
                        
                        .. attribute:: spf_runtime
                        
                        	List of SPF run\-time statistics
                        	**type**\: list of    :py:class:`SpfRuntime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.VrfStatistics.SpfStats.SpfRuntime>`
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.spf_header = Ospfv3.Processes.Process.DefaultVrf.VrfStatistics.SpfStats.SpfHeader()
                            self.spf_header.parent = self
                            self.spf_runtime = YList()
                            self.spf_runtime.parent = self
                            self.spf_runtime.name = 'spf_runtime'


                        class SpfHeader(object):
                            """
                            SPF statistics header
                            
                            .. attribute:: area_summary
                            
                            	List of Areas with SPF statistics
                            	**type**\: list of    :py:class:`AreaSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.VrfStatistics.SpfStats.SpfHeader.AreaSummary>`
                            
                            .. attribute:: header_router_id
                            
                            	Router ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: header_sp_fs
                            
                            	Number of SPF calculations
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.area_summary = YList()
                                self.area_summary.parent = self
                                self.area_summary.name = 'area_summary'
                                self.header_router_id = None
                                self.header_sp_fs = None


                            class AreaSummary(object):
                                """
                                List of Areas with SPF statistics
                                
                                .. attribute:: area_id
                                
                                	Area ID of the area SPF statistics
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sp_fs
                                
                                	Number of SPF calculations
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.area_id = None
                                    self.sp_fs = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:area-summary'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.area_id is not None:
                                        return True

                                    if self.sp_fs is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                    return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.VrfStatistics.SpfStats.SpfHeader.AreaSummary']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:spf-header'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.area_summary is not None:
                                    for child_ref in self.area_summary:
                                        if child_ref._has_data():
                                            return True

                                if self.header_router_id is not None:
                                    return True

                                if self.header_sp_fs is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.VrfStatistics.SpfStats.SpfHeader']['meta_info']


                        class SpfRuntime(object):
                            """
                            List of SPF run\-time statistics
                            
                            .. attribute:: area_stat
                            
                            	List of per\-area SPF statistics
                            	**type**\: list of    :py:class:`AreaStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.VrfStatistics.SpfStats.SpfRuntime.AreaStat>`
                            
                            .. attribute:: global_time
                            
                            	Global SPF times
                            	**type**\:   :py:class:`GlobalTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.VrfStatistics.SpfStats.SpfRuntime.GlobalTime>`
                            
                            .. attribute:: lsa
                            
                            	List of LSAs triggering the SPF calculation
                            	**type**\: list of    :py:class:`Lsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.VrfStatistics.SpfStats.SpfRuntime.Lsa>`
                            
                            .. attribute:: lsa_changes
                            
                            	Number of LSA changes triggering an SPF calculation
                            	**type**\:  int
                            
                            	**range:** \-32768..32767
                            
                            .. attribute:: reason_flags
                            
                            	Reasons for triggering an SPF calculation Bit 1 \- Router LSA update Bit 2 \- Network LSA update Bit 3 \- Inter\-Area Prefix LSA update Bit 4 \- Inter\-Area Router LSA update Bit 5 \- AS External LSA update Bit 6 \- MOSPF LSA update Bit 7 \- Type 7 AS External LSA update Bit 8 \- Link LSA update Bit 9 \- Prefix LSA update
                            	**type**\:  str
                            
                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                            
                            .. attribute:: rib_add_routes
                            
                            	Number of routes added to RIB
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: rib_delete_routes
                            
                            	Number of routes deleted from RIB
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: start_time
                            
                            	SPF calculation start time
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.area_stat = YList()
                                self.area_stat.parent = self
                                self.area_stat.name = 'area_stat'
                                self.global_time = Ospfv3.Processes.Process.DefaultVrf.VrfStatistics.SpfStats.SpfRuntime.GlobalTime()
                                self.global_time.parent = self
                                self.lsa = YList()
                                self.lsa.parent = self
                                self.lsa.name = 'lsa'
                                self.lsa_changes = None
                                self.reason_flags = None
                                self.rib_add_routes = None
                                self.rib_delete_routes = None
                                self.start_time = None


                            class GlobalTime(object):
                                """
                                Global SPF times
                                
                                .. attribute:: dijkstra
                                
                                	Dijkstra time in msec
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: external_prefix
                                
                                	External prefix processing time in msec
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: external_prefix_del
                                
                                	External prefix deletion time in msec
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: inter_prefix
                                
                                	Inter\-prefix processing time in msec
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: inter_prefix_del
                                
                                	Intra\-prefix deletion time in msec
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: intra_prefix
                                
                                	Intra\-prefix processing time in msec
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: intra_prefix_del
                                
                                	Intra\-prefix deletion time in msec
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rib_add
                                
                                	RIB add processing time in msec
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rib_del
                                
                                	RIB deletion time in msec
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.dijkstra = None
                                    self.external_prefix = None
                                    self.external_prefix_del = None
                                    self.inter_prefix = None
                                    self.inter_prefix_del = None
                                    self.intra_prefix = None
                                    self.intra_prefix_del = None
                                    self.rib_add = None
                                    self.rib_del = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:global-time'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.dijkstra is not None:
                                        return True

                                    if self.external_prefix is not None:
                                        return True

                                    if self.external_prefix_del is not None:
                                        return True

                                    if self.inter_prefix is not None:
                                        return True

                                    if self.inter_prefix_del is not None:
                                        return True

                                    if self.intra_prefix is not None:
                                        return True

                                    if self.intra_prefix_del is not None:
                                        return True

                                    if self.rib_add is not None:
                                        return True

                                    if self.rib_del is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                    return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.VrfStatistics.SpfStats.SpfRuntime.GlobalTime']['meta_info']


                            class Lsa(object):
                                """
                                List of LSAs triggering the SPF calculation
                                
                                .. attribute:: lsa_advertising_router
                                
                                	Advertising router ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: lsa_area_id
                                
                                	Area ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: lsa_flush
                                
                                	If true, the LSA change is a flush
                                	**type**\:  bool
                                
                                .. attribute:: lsa_id
                                
                                	LSA ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: lsa_type
                                
                                	LSA type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.lsa_advertising_router = None
                                    self.lsa_area_id = None
                                    self.lsa_flush = None
                                    self.lsa_id = None
                                    self.lsa_type = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:lsa'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.lsa_advertising_router is not None:
                                        return True

                                    if self.lsa_area_id is not None:
                                        return True

                                    if self.lsa_flush is not None:
                                        return True

                                    if self.lsa_id is not None:
                                        return True

                                    if self.lsa_type is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                    return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.VrfStatistics.SpfStats.SpfRuntime.Lsa']['meta_info']


                            class AreaStat(object):
                                """
                                List of per\-area SPF statistics
                                
                                .. attribute:: spf_stat_area_id
                                
                                	Area ID for area of these SPF statistics
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: spf_stat_lsa_type_count
                                
                                	Counts of LSA types triggering an SPF calculation
                                	**type**\:  list of int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: spf_stat_time
                                
                                	SPF time calculations
                                	**type**\:   :py:class:`SpfStatTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.VrfStatistics.SpfStats.SpfRuntime.AreaStat.SpfStatTime>`
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.spf_stat_area_id = None
                                    self.spf_stat_lsa_type_count = YLeafList()
                                    self.spf_stat_lsa_type_count.parent = self
                                    self.spf_stat_lsa_type_count.name = 'spf_stat_lsa_type_count'
                                    self.spf_stat_time = Ospfv3.Processes.Process.DefaultVrf.VrfStatistics.SpfStats.SpfRuntime.AreaStat.SpfStatTime()
                                    self.spf_stat_time.parent = self


                                class SpfStatTime(object):
                                    """
                                    SPF time calculations
                                    
                                    .. attribute:: dijkstra
                                    
                                    	Dijkstra time in msec
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: external_prefix
                                    
                                    	External prefix processing time in msec
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: external_prefix_del
                                    
                                    	External prefix deletion time in msec
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: inter_prefix
                                    
                                    	Inter\-prefix processing time in msec
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: inter_prefix_del
                                    
                                    	Intra\-prefix deletion time in msec
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: intra_prefix
                                    
                                    	Intra\-prefix processing time in msec
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: intra_prefix_del
                                    
                                    	Intra\-prefix deletion time in msec
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rib_add
                                    
                                    	RIB add processing time in msec
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rib_del
                                    
                                    	RIB deletion time in msec
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.dijkstra = None
                                        self.external_prefix = None
                                        self.external_prefix_del = None
                                        self.inter_prefix = None
                                        self.inter_prefix_del = None
                                        self.intra_prefix = None
                                        self.intra_prefix_del = None
                                        self.rib_add = None
                                        self.rib_del = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:spf-stat-time'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.dijkstra is not None:
                                            return True

                                        if self.external_prefix is not None:
                                            return True

                                        if self.external_prefix_del is not None:
                                            return True

                                        if self.inter_prefix is not None:
                                            return True

                                        if self.inter_prefix_del is not None:
                                            return True

                                        if self.intra_prefix is not None:
                                            return True

                                        if self.intra_prefix_del is not None:
                                            return True

                                        if self.rib_add is not None:
                                            return True

                                        if self.rib_del is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                        return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.VrfStatistics.SpfStats.SpfRuntime.AreaStat.SpfStatTime']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:area-stat'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.spf_stat_area_id is not None:
                                        return True

                                    if self.spf_stat_lsa_type_count is not None:
                                        for child in self.spf_stat_lsa_type_count:
                                            if child is not None:
                                                return True

                                    if self.spf_stat_time is not None and self.spf_stat_time._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                    return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.VrfStatistics.SpfStats.SpfRuntime.AreaStat']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:spf-runtime'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.area_stat is not None:
                                    for child_ref in self.area_stat:
                                        if child_ref._has_data():
                                            return True

                                if self.global_time is not None and self.global_time._has_data():
                                    return True

                                if self.lsa is not None:
                                    for child_ref in self.lsa:
                                        if child_ref._has_data():
                                            return True

                                if self.lsa_changes is not None:
                                    return True

                                if self.reason_flags is not None:
                                    return True

                                if self.rib_add_routes is not None:
                                    return True

                                if self.rib_delete_routes is not None:
                                    return True

                                if self.start_time is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.VrfStatistics.SpfStats.SpfRuntime']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:spf-stats'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.spf_header is not None and self.spf_header._has_data():
                                return True

                            if self.spf_runtime is not None:
                                for child_ref in self.spf_runtime:
                                    if child_ref._has_data():
                                        return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                            return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.VrfStatistics.SpfStats']['meta_info']


                    class RawioStats(object):
                        """
                        OSPF Prefix SPF Prioritization statistics
                        
                        .. attribute:: in_bytes
                        
                        	Received Bytes
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: byte
                        
                        .. attribute:: in_error_drops
                        
                        	In Error Drops
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: in_handle_drops
                        
                        	In Handle Drops
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: in_ipsec_drops
                        
                        	In IPSEC Drops
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: in_long_packets
                        
                        	Received Long Packets
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: in_malloc_drops
                        
                        	In Malloc Drops
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: in_packets
                        
                        	Received Packets
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: in_queue_drops
                        
                        	In Queue Drops
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: in_short_drops
                        
                        	In Short Drops
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: out_bytes
                        
                        	Sent Bytes
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: byte
                        
                        .. attribute:: out_error_drops
                        
                        	Error Drops
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: out_ipsec_drops
                        
                        	Out IPSEC Drops
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: out_nofd_drops
                        
                        	No FileDescriptor Drops
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: out_nopak_drops
                        
                        	No Packet Buffers
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: out_packets
                        
                        	Packets Sent
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: out_pakapi_errors
                        
                        	PAK API Errors
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: raw_conn_close
                        
                        	Raw Connections Close
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: raw_conn_error
                        
                        	Raw Connections Error
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: raw_conn_open
                        
                        	Raw Connections Open
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: raw_conn_state
                        
                        	Raw Connection State
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.in_bytes = None
                            self.in_error_drops = None
                            self.in_handle_drops = None
                            self.in_ipsec_drops = None
                            self.in_long_packets = None
                            self.in_malloc_drops = None
                            self.in_packets = None
                            self.in_queue_drops = None
                            self.in_short_drops = None
                            self.out_bytes = None
                            self.out_error_drops = None
                            self.out_ipsec_drops = None
                            self.out_nofd_drops = None
                            self.out_nopak_drops = None
                            self.out_packets = None
                            self.out_pakapi_errors = None
                            self.raw_conn_close = None
                            self.raw_conn_error = None
                            self.raw_conn_open = None
                            self.raw_conn_state = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:rawio-stats'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.in_bytes is not None:
                                return True

                            if self.in_error_drops is not None:
                                return True

                            if self.in_handle_drops is not None:
                                return True

                            if self.in_ipsec_drops is not None:
                                return True

                            if self.in_long_packets is not None:
                                return True

                            if self.in_malloc_drops is not None:
                                return True

                            if self.in_packets is not None:
                                return True

                            if self.in_queue_drops is not None:
                                return True

                            if self.in_short_drops is not None:
                                return True

                            if self.out_bytes is not None:
                                return True

                            if self.out_error_drops is not None:
                                return True

                            if self.out_ipsec_drops is not None:
                                return True

                            if self.out_nofd_drops is not None:
                                return True

                            if self.out_nopak_drops is not None:
                                return True

                            if self.out_packets is not None:
                                return True

                            if self.out_pakapi_errors is not None:
                                return True

                            if self.raw_conn_close is not None:
                                return True

                            if self.raw_conn_error is not None:
                                return True

                            if self.raw_conn_open is not None:
                                return True

                            if self.raw_conn_state is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                            return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.VrfStatistics.RawioStats']['meta_info']


                    class PrefixPriorityStats(object):
                        """
                        OSPF Prefix SPF Prioritization statistics
                        
                        .. attribute:: critical
                        
                        	Critical priority classifications
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: high
                        
                        	High priority classifications
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: low
                        
                        	Low priority classifications
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: medium
                        
                        	Medium priority classifications
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.critical = None
                            self.high = None
                            self.low = None
                            self.medium = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:prefix-priority-stats'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.critical is not None:
                                return True

                            if self.high is not None:
                                return True

                            if self.low is not None:
                                return True

                            if self.medium is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                            return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.VrfStatistics.PrefixPriorityStats']['meta_info']


                    class VrfRibBatchStats(object):
                        """
                        OSPFv3 RIB batch statistics
                        
                        .. attribute:: batches_sent
                        
                        	No. of RIB batches sent
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: max_routes
                        
                        	Max No. of Routes in a batch
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: paths_add
                        
                        	No. of paths added to RIB
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: paths_add_errs
                        
                        	No. of paths add errors
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: paths_del
                        
                        	No. of paths del sent to RIB
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: paths_del_errs
                        
                        	No. of Paths del errors
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: paths_pending
                        
                        	No. of paths waiting to be sent to RIB
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: paths_sent
                        
                        	No. of Paths sent to RIB
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: routes_pending
                        
                        	No of Pending Routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: routes_sent
                        
                        	No. of Routes sent to RIB
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.batches_sent = None
                            self.max_routes = None
                            self.paths_add = None
                            self.paths_add_errs = None
                            self.paths_del = None
                            self.paths_del_errs = None
                            self.paths_pending = None
                            self.paths_sent = None
                            self.routes_pending = None
                            self.routes_sent = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:vrf-rib-batch-stats'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.batches_sent is not None:
                                return True

                            if self.max_routes is not None:
                                return True

                            if self.paths_add is not None:
                                return True

                            if self.paths_add_errs is not None:
                                return True

                            if self.paths_del is not None:
                                return True

                            if self.paths_del_errs is not None:
                                return True

                            if self.paths_pending is not None:
                                return True

                            if self.paths_sent is not None:
                                return True

                            if self.routes_pending is not None:
                                return True

                            if self.routes_sent is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                            return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.VrfStatistics.VrfRibBatchStats']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:vrf-statistics'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.prefix_priority_stats is not None and self.prefix_priority_stats._has_data():
                            return True

                        if self.protocol_stats is not None and self.protocol_stats._has_data():
                            return True

                        if self.rawio_stats is not None and self.rawio_stats._has_data():
                            return True

                        if self.spf_stats is not None and self.spf_stats._has_data():
                            return True

                        if self.vrf_rib_batch_stats is not None and self.vrf_rib_batch_stats._has_data():
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                        return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.VrfStatistics']['meta_info']


                class Summary(object):
                    """
                    OSPFv3 summary
                    
                    .. attribute:: ospfv3
                    
                    	OSPFv3 summary
                    	**type**\:   :py:class:`Ospfv3_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Summary.Ospfv3_>`
                    
                    .. attribute:: protocol
                    
                    	OSPFv3 protocol summary
                    	**type**\:   :py:class:`Protocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Summary.Protocol>`
                    
                    .. attribute:: route
                    
                    	OSPFv3 route summary
                    	**type**\:   :py:class:`Route <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Summary.Route>`
                    
                    

                    """

                    _prefix = 'ipv6-ospfv3-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.ospfv3 = Ospfv3.Processes.Process.DefaultVrf.Summary.Ospfv3_()
                        self.ospfv3.parent = self
                        self.protocol = Ospfv3.Processes.Process.DefaultVrf.Summary.Protocol()
                        self.protocol.parent = self
                        self.route = Ospfv3.Processes.Process.DefaultVrf.Summary.Route()
                        self.route.parent = self


                    class Protocol(object):
                        """
                        OSPFv3 protocol summary
                        
                        .. attribute:: administrative_distance
                        
                        	Administrative distance
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: administrative_distance_external
                        
                        	Administrative Distance for External routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: administrative_distance_inter_area
                        
                        	Administrative Distance for Inter Area routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: distribute_list_in
                        
                        	Distribute List In
                        	**type**\:  str
                        
                        .. attribute:: is_graceful_restart
                        
                        	If true, Graceful restart is enabled 
                        	**type**\:  bool
                        
                        .. attribute:: protocol_router_id
                        
                        	Protocol router ID
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.administrative_distance = None
                            self.administrative_distance_external = None
                            self.administrative_distance_inter_area = None
                            self.distribute_list_in = None
                            self.is_graceful_restart = None
                            self.protocol_router_id = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:protocol'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.administrative_distance is not None:
                                return True

                            if self.administrative_distance_external is not None:
                                return True

                            if self.administrative_distance_inter_area is not None:
                                return True

                            if self.distribute_list_in is not None:
                                return True

                            if self.is_graceful_restart is not None:
                                return True

                            if self.protocol_router_id is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                            return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Summary.Protocol']['meta_info']


                    class Ospfv3_(object):
                        """
                        OSPFv3 summary
                        
                        .. attribute:: areas
                        
                        	Number of areas
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: as_dc_bitless_ls_as
                        
                        	Number of external and AS opaque LSAs with demand circut bit not set
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: as_do_not_age_ls_as
                        
                        	Number of external and AS opaque LSAs with do not age set 
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: as_ls_as
                        
                        	Number of AS scope LSAs
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: as_lsa_flood_list_length
                        
                        	Length of AS LSAs flood list
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: context_name
                        
                        	Context name
                        	**type**\:  str
                        
                        	**length:** 0..32
                        
                        .. attribute:: default_metric
                        
                        	Default metric 
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: default_metric_type
                        
                        	Default metric type 
                        	**type**\:   :py:class:`Ospfv3DefaultMetricEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3DefaultMetricEnum>`
                        
                        .. attribute:: default_policy_name
                        
                        	Default policy name 
                        	**type**\:  str
                        
                        .. attribute:: default_tag
                        
                        	Default tag 
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: domain_id
                        
                        	Domain ID information
                        	**type**\:   :py:class:`DomainId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Summary.Ospfv3_.DomainId>`
                        
                        .. attribute:: grace_resync_time
                        
                        	Grace time to resync 
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: graceful_shutdown_state
                        
                        	Graceful shutdown state
                        	**type**\:   :py:class:`Ospfv3GracefulShutdownStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3GracefulShutdownStateEnum>`
                        
                        .. attribute:: ipfrr_tiebreakers
                        
                        	IPFRR\-Tiebreakers list
                        	**type**\: list of    :py:class:`IpfrrTiebreakers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Summary.Ospfv3_.IpfrrTiebreakers>`
                        
                        .. attribute:: is_area_border_router
                        
                        	If true, is an area border router
                        	**type**\:  bool
                        
                        .. attribute:: is_as_border_router
                        
                        	If true, is an AS border router
                        	**type**\:  bool
                        
                        .. attribute:: is_auto_cost
                        
                        	If true, auto cost is enabled
                        	**type**\:  bool
                        
                        .. attribute:: is_default_always
                        
                        	If true, default always 
                        	**type**\:  bool
                        
                        .. attribute:: is_default_originated
                        
                        	If true, origin is by default 
                        	**type**\:  bool
                        
                        .. attribute:: is_default_policy
                        
                        	If true, is a default policy 
                        	**type**\:  bool
                        
                        .. attribute:: is_grace_restart_enabled
                        
                        	If true, grace restart is enabled 
                        	**type**\:  bool
                        
                        .. attribute:: is_nsr_enabled
                        
                        	If true, NSR is enabled
                        	**type**\:  bool
                        
                        .. attribute:: is_nsr_switchover_on_restart
                        
                        	Trigger RP Switchover on detectable process restart
                        	**type**\:  bool
                        
                        .. attribute:: is_opaque_capable
                        
                        	Opaque LSA capable 
                        	**type**\:  bool
                        
                        .. attribute:: is_role_standby
                        
                        	If true, the process is running as stanby role
                        	**type**\:  bool
                        
                        .. attribute:: is_router_id_stalled
                        
                        	Stalled Router ID 
                        	**type**\:  bool
                        
                        .. attribute:: last_nsf_time
                        
                        	 Length of time since the last NSF (s)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: lsa_flood_pacing_interval
                        
                        	LSA flood pacing timer (ms)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: lsa_group_interval
                        
                        	LSA refresh interval (sec)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: lsa_hold_time
                        
                        	Second delay before generating next LSA (ms)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: lsa_maximum_time
                        
                        	Maximum delay before generating an LSA (ms)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: lsa_retransmission_pacing_interval
                        
                        	LSA retransmission pacing timer (ms)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: lsa_start_time
                        
                        	Initial LSA throttle delay (ms)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: maximum_interfaces
                        
                        	Maximum number of interfaces
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: maximum_paths
                        
                        	Maximum number of paths
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: metric
                        
                        	Redistribution metric 
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: minimum_lsa_interval
                        
                        	Minimum time between LSA regeneration (ms)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: normal_areas
                        
                        	Number of normal areas
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: nssa_areas
                        
                        	Number of NSSA areas
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: opaque_lsa_checksum
                        
                        	Sum of opaque LSA checksum
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: opaque_lsas
                        
                        	Number of opaque LSAs
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: redistribution_limit
                        
                        	The number of redistributed prefixes allowed
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: redistribution_threshold
                        
                        	When the number of redistributed prefixes reaches this threshold, a warning message is issued 
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: reference_bandwidth
                        
                        	Reference Bandwdith
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: role
                        
                        	Role, V1/V2 Active/Standby
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: router_id
                        
                        	Router ID
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: snmp_trap_enabled
                        
                        	If true, snmp trap is enabled
                        	**type**\:  bool
                        
                        .. attribute:: spf_hold_time
                        
                        	Minimum delay time between SPF runs (ms)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: spf_maximum_time
                        
                        	Maximum delay time between SPF runs (ms)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: spf_start_time
                        
                        	Scheduling delay for SPF (ms)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: stub_areas
                        
                        	Number of stub and total stub areas
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: stub_router
                        
                        	Stub Router Information
                        	**type**\: list of    :py:class:`StubRouter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Summary.Ospfv3_.StubRouter>`
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.areas = None
                            self.as_dc_bitless_ls_as = None
                            self.as_do_not_age_ls_as = None
                            self.as_ls_as = None
                            self.as_lsa_flood_list_length = None
                            self.context_name = None
                            self.default_metric = None
                            self.default_metric_type = None
                            self.default_policy_name = None
                            self.default_tag = None
                            self.domain_id = Ospfv3.Processes.Process.DefaultVrf.Summary.Ospfv3_.DomainId()
                            self.domain_id.parent = self
                            self.grace_resync_time = None
                            self.graceful_shutdown_state = None
                            self.ipfrr_tiebreakers = YList()
                            self.ipfrr_tiebreakers.parent = self
                            self.ipfrr_tiebreakers.name = 'ipfrr_tiebreakers'
                            self.is_area_border_router = None
                            self.is_as_border_router = None
                            self.is_auto_cost = None
                            self.is_default_always = None
                            self.is_default_originated = None
                            self.is_default_policy = None
                            self.is_grace_restart_enabled = None
                            self.is_nsr_enabled = None
                            self.is_nsr_switchover_on_restart = None
                            self.is_opaque_capable = None
                            self.is_role_standby = None
                            self.is_router_id_stalled = None
                            self.last_nsf_time = None
                            self.lsa_flood_pacing_interval = None
                            self.lsa_group_interval = None
                            self.lsa_hold_time = None
                            self.lsa_maximum_time = None
                            self.lsa_retransmission_pacing_interval = None
                            self.lsa_start_time = None
                            self.maximum_interfaces = None
                            self.maximum_paths = None
                            self.metric = None
                            self.minimum_lsa_interval = None
                            self.normal_areas = None
                            self.nssa_areas = None
                            self.opaque_lsa_checksum = None
                            self.opaque_lsas = None
                            self.redistribution_limit = None
                            self.redistribution_threshold = None
                            self.reference_bandwidth = None
                            self.role = None
                            self.router_id = None
                            self.snmp_trap_enabled = None
                            self.spf_hold_time = None
                            self.spf_maximum_time = None
                            self.spf_start_time = None
                            self.stub_areas = None
                            self.stub_router = YList()
                            self.stub_router.parent = self
                            self.stub_router.name = 'stub_router'


                        class DomainId(object):
                            """
                            Domain ID information
                            
                            .. attribute:: primary_domain_id
                            
                            	Primary Domain ID
                            	**type**\:   :py:class:`PrimaryDomainId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Summary.Ospfv3_.DomainId.PrimaryDomainId>`
                            
                            .. attribute:: secondary_domain_id
                            
                            	List of secondary domain IDs
                            	**type**\: list of    :py:class:`SecondaryDomainId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Summary.Ospfv3_.DomainId.SecondaryDomainId>`
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.primary_domain_id = Ospfv3.Processes.Process.DefaultVrf.Summary.Ospfv3_.DomainId.PrimaryDomainId()
                                self.primary_domain_id.parent = self
                                self.secondary_domain_id = YList()
                                self.secondary_domain_id.parent = self
                                self.secondary_domain_id.name = 'secondary_domain_id'


                            class PrimaryDomainId(object):
                                """
                                Primary Domain ID
                                
                                .. attribute:: domain_id_type
                                
                                	Domain ID Type
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: domain_id_value
                                
                                	Domain ID value
                                	**type**\:  str
                                
                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.domain_id_type = None
                                    self.domain_id_value = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:primary-domain-id'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.domain_id_type is not None:
                                        return True

                                    if self.domain_id_value is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                    return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Summary.Ospfv3_.DomainId.PrimaryDomainId']['meta_info']


                            class SecondaryDomainId(object):
                                """
                                List of secondary domain IDs
                                
                                .. attribute:: domain_id_type
                                
                                	Domain ID Type
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: domain_id_value
                                
                                	Domain ID value
                                	**type**\:  str
                                
                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.domain_id_type = None
                                    self.domain_id_value = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:secondary-domain-id'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.domain_id_type is not None:
                                        return True

                                    if self.domain_id_value is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                    return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Summary.Ospfv3_.DomainId.SecondaryDomainId']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:domain-id'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.primary_domain_id is not None and self.primary_domain_id._has_data():
                                    return True

                                if self.secondary_domain_id is not None:
                                    for child_ref in self.secondary_domain_id:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Summary.Ospfv3_.DomainId']['meta_info']


                        class StubRouter(object):
                            """
                            Stub Router Information
                            
                            .. attribute:: abr_off_reason
                            
                            	Reason for being in ABR off mode
                            	**type**\:   :py:class:`StubRouterAbrOffReasonEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.StubRouterAbrOffReasonEnum>`
                            
                            .. attribute:: abr_resume_time
                            
                            	Timestamp (relative to 1970/1/1 00\:00) when ABR duties were resumed
                            	**type**\:   :py:class:`AbrResumeTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Summary.Ospfv3_.StubRouter.AbrResumeTime>`
                            
                            .. attribute:: active
                            
                            	If true, stub router mode is active
                            	**type**\:  bool
                            
                            .. attribute:: external_lsa_metric
                            
                            	Metric for external LSAs in max\-metric mode
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: include_stub_links
                            
                            	If true, advertise maximum metric for stub links
                            	**type**\:  bool
                            
                            .. attribute:: mode
                            
                            	Stub router mode
                            	**type**\:   :py:class:`StubRouterModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.StubRouterModeEnum>`
                            
                            .. attribute:: remaining_time
                            
                            	Remaining time (in seconds) in stub router mode
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: set_reason
                            
                            	Reason for entering stub router mode
                            	**type**\:   :py:class:`StubRouterTriggerEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.StubRouterTriggerEnum>`
                            
                            .. attribute:: start_time
                            
                            	Timestamp (relative to 1970/1/1 00\:00) when stub router mode was activated
                            	**type**\:   :py:class:`StartTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Summary.Ospfv3_.StubRouter.StartTime>`
                            
                            .. attribute:: summary_lsa_metric
                            
                            	Metric for summary LSAs in max\-metric mode
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: trigger
                            
                            	Triggers for entering stub router mode
                            	**type**\: list of    :py:class:`Trigger <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Summary.Ospfv3_.StubRouter.Trigger>`
                            
                            .. attribute:: unset_reason
                            
                            	Reason for clearing stub router condition
                            	**type**\:   :py:class:`StubRouterExitReasonEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.StubRouterExitReasonEnum>`
                            
                            .. attribute:: unset_time
                            
                            	Timestamp (relative to 1970/1/1 00\:00) when stub router condition was cleared
                            	**type**\:   :py:class:`UnsetTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Summary.Ospfv3_.StubRouter.UnsetTime>`
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.abr_off_reason = None
                                self.abr_resume_time = Ospfv3.Processes.Process.DefaultVrf.Summary.Ospfv3_.StubRouter.AbrResumeTime()
                                self.abr_resume_time.parent = self
                                self.active = None
                                self.external_lsa_metric = None
                                self.include_stub_links = None
                                self.mode = None
                                self.remaining_time = None
                                self.set_reason = None
                                self.start_time = Ospfv3.Processes.Process.DefaultVrf.Summary.Ospfv3_.StubRouter.StartTime()
                                self.start_time.parent = self
                                self.summary_lsa_metric = None
                                self.trigger = YList()
                                self.trigger.parent = self
                                self.trigger.name = 'trigger'
                                self.unset_reason = None
                                self.unset_time = Ospfv3.Processes.Process.DefaultVrf.Summary.Ospfv3_.StubRouter.UnsetTime()
                                self.unset_time.parent = self


                            class UnsetTime(object):
                                """
                                Timestamp (relative to 1970/1/1 00\:00) when stub
                                router condition was cleared
                                
                                .. attribute:: nanosecond
                                
                                	Nano seconds 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: nanosecond
                                
                                .. attribute:: second
                                
                                	Seconds 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.nanosecond = None
                                    self.second = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:unset-time'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.nanosecond is not None:
                                        return True

                                    if self.second is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                    return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Summary.Ospfv3_.StubRouter.UnsetTime']['meta_info']


                            class StartTime(object):
                                """
                                Timestamp (relative to 1970/1/1 00\:00) when stub
                                router mode was activated
                                
                                .. attribute:: nanosecond
                                
                                	Nano seconds 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: nanosecond
                                
                                .. attribute:: second
                                
                                	Seconds 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.nanosecond = None
                                    self.second = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:start-time'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.nanosecond is not None:
                                        return True

                                    if self.second is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                    return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Summary.Ospfv3_.StubRouter.StartTime']['meta_info']


                            class AbrResumeTime(object):
                                """
                                Timestamp (relative to 1970/1/1 00\:00) when ABR
                                duties were resumed
                                
                                .. attribute:: nanosecond
                                
                                	Nano seconds 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: nanosecond
                                
                                .. attribute:: second
                                
                                	Seconds 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.nanosecond = None
                                    self.second = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:abr-resume-time'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.nanosecond is not None:
                                        return True

                                    if self.second is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                    return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Summary.Ospfv3_.StubRouter.AbrResumeTime']['meta_info']


                            class Trigger(object):
                                """
                                Triggers for entering stub router mode
                                
                                .. attribute:: start_time
                                
                                	Timestamp (relative to 1970/1/1 00\:00) when stub router mode was activated
                                	**type**\:   :py:class:`StartTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Summary.Ospfv3_.StubRouter.Trigger.StartTime>`
                                
                                .. attribute:: time
                                
                                	Time (in seconds) to stay in stub router mode
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: trigger
                                
                                	Stub Router Trigger type
                                	**type**\:   :py:class:`StubRouterTriggerEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.StubRouterTriggerEnum>`
                                
                                .. attribute:: unset_reason
                                
                                	Reason for clearing stub router condition
                                	**type**\:   :py:class:`StubRouterExitReasonEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.StubRouterExitReasonEnum>`
                                
                                .. attribute:: unset_time
                                
                                	Timestamp (relative to 1970/1/1 00\:00) when stub router condition was cleared
                                	**type**\:   :py:class:`UnsetTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Summary.Ospfv3_.StubRouter.Trigger.UnsetTime>`
                                
                                .. attribute:: wait_for_bgp
                                
                                	If true, stub router is terminated when BGP converges
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.start_time = Ospfv3.Processes.Process.DefaultVrf.Summary.Ospfv3_.StubRouter.Trigger.StartTime()
                                    self.start_time.parent = self
                                    self.time = None
                                    self.trigger = None
                                    self.unset_reason = None
                                    self.unset_time = Ospfv3.Processes.Process.DefaultVrf.Summary.Ospfv3_.StubRouter.Trigger.UnsetTime()
                                    self.unset_time.parent = self
                                    self.wait_for_bgp = None


                                class UnsetTime(object):
                                    """
                                    Timestamp (relative to 1970/1/1 00\:00) when stub
                                    router condition was cleared
                                    
                                    .. attribute:: nanosecond
                                    
                                    	Nano seconds 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: nanosecond
                                    
                                    .. attribute:: second
                                    
                                    	Seconds 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.nanosecond = None
                                        self.second = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:unset-time'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.nanosecond is not None:
                                            return True

                                        if self.second is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                        return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Summary.Ospfv3_.StubRouter.Trigger.UnsetTime']['meta_info']


                                class StartTime(object):
                                    """
                                    Timestamp (relative to 1970/1/1 00\:00) when stub
                                    router mode was activated
                                    
                                    .. attribute:: nanosecond
                                    
                                    	Nano seconds 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: nanosecond
                                    
                                    .. attribute:: second
                                    
                                    	Seconds 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.nanosecond = None
                                        self.second = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:start-time'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.nanosecond is not None:
                                            return True

                                        if self.second is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                        return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Summary.Ospfv3_.StubRouter.Trigger.StartTime']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:trigger'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.start_time is not None and self.start_time._has_data():
                                        return True

                                    if self.time is not None:
                                        return True

                                    if self.trigger is not None:
                                        return True

                                    if self.unset_reason is not None:
                                        return True

                                    if self.unset_time is not None and self.unset_time._has_data():
                                        return True

                                    if self.wait_for_bgp is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                    return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Summary.Ospfv3_.StubRouter.Trigger']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:stub-router'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.abr_off_reason is not None:
                                    return True

                                if self.abr_resume_time is not None and self.abr_resume_time._has_data():
                                    return True

                                if self.active is not None:
                                    return True

                                if self.external_lsa_metric is not None:
                                    return True

                                if self.include_stub_links is not None:
                                    return True

                                if self.mode is not None:
                                    return True

                                if self.remaining_time is not None:
                                    return True

                                if self.set_reason is not None:
                                    return True

                                if self.start_time is not None and self.start_time._has_data():
                                    return True

                                if self.summary_lsa_metric is not None:
                                    return True

                                if self.trigger is not None:
                                    for child_ref in self.trigger:
                                        if child_ref._has_data():
                                            return True

                                if self.unset_reason is not None:
                                    return True

                                if self.unset_time is not None and self.unset_time._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Summary.Ospfv3_.StubRouter']['meta_info']


                        class IpfrrTiebreakers(object):
                            """
                            IPFRR\-Tiebreakers list
                            
                            .. attribute:: tiebreaker_index
                            
                            	Tiebreaker Index
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: tiebreaker_type
                            
                            	Tiebreaker Type
                            	**type**\:   :py:class:`IpfrrTbrkrEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.IpfrrTbrkrEnum>`
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.tiebreaker_index = None
                                self.tiebreaker_type = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:ipfrr-tiebreakers'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.tiebreaker_index is not None:
                                    return True

                                if self.tiebreaker_type is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Summary.Ospfv3_.IpfrrTiebreakers']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:ospfv3'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.areas is not None:
                                return True

                            if self.as_dc_bitless_ls_as is not None:
                                return True

                            if self.as_do_not_age_ls_as is not None:
                                return True

                            if self.as_ls_as is not None:
                                return True

                            if self.as_lsa_flood_list_length is not None:
                                return True

                            if self.context_name is not None:
                                return True

                            if self.default_metric is not None:
                                return True

                            if self.default_metric_type is not None:
                                return True

                            if self.default_policy_name is not None:
                                return True

                            if self.default_tag is not None:
                                return True

                            if self.domain_id is not None and self.domain_id._has_data():
                                return True

                            if self.grace_resync_time is not None:
                                return True

                            if self.graceful_shutdown_state is not None:
                                return True

                            if self.ipfrr_tiebreakers is not None:
                                for child_ref in self.ipfrr_tiebreakers:
                                    if child_ref._has_data():
                                        return True

                            if self.is_area_border_router is not None:
                                return True

                            if self.is_as_border_router is not None:
                                return True

                            if self.is_auto_cost is not None:
                                return True

                            if self.is_default_always is not None:
                                return True

                            if self.is_default_originated is not None:
                                return True

                            if self.is_default_policy is not None:
                                return True

                            if self.is_grace_restart_enabled is not None:
                                return True

                            if self.is_nsr_enabled is not None:
                                return True

                            if self.is_nsr_switchover_on_restart is not None:
                                return True

                            if self.is_opaque_capable is not None:
                                return True

                            if self.is_role_standby is not None:
                                return True

                            if self.is_router_id_stalled is not None:
                                return True

                            if self.last_nsf_time is not None:
                                return True

                            if self.lsa_flood_pacing_interval is not None:
                                return True

                            if self.lsa_group_interval is not None:
                                return True

                            if self.lsa_hold_time is not None:
                                return True

                            if self.lsa_maximum_time is not None:
                                return True

                            if self.lsa_retransmission_pacing_interval is not None:
                                return True

                            if self.lsa_start_time is not None:
                                return True

                            if self.maximum_interfaces is not None:
                                return True

                            if self.maximum_paths is not None:
                                return True

                            if self.metric is not None:
                                return True

                            if self.minimum_lsa_interval is not None:
                                return True

                            if self.normal_areas is not None:
                                return True

                            if self.nssa_areas is not None:
                                return True

                            if self.opaque_lsa_checksum is not None:
                                return True

                            if self.opaque_lsas is not None:
                                return True

                            if self.redistribution_limit is not None:
                                return True

                            if self.redistribution_threshold is not None:
                                return True

                            if self.reference_bandwidth is not None:
                                return True

                            if self.role is not None:
                                return True

                            if self.router_id is not None:
                                return True

                            if self.snmp_trap_enabled is not None:
                                return True

                            if self.spf_hold_time is not None:
                                return True

                            if self.spf_maximum_time is not None:
                                return True

                            if self.spf_start_time is not None:
                                return True

                            if self.stub_areas is not None:
                                return True

                            if self.stub_router is not None:
                                for child_ref in self.stub_router:
                                    if child_ref._has_data():
                                        return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                            return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Summary.Ospfv3_']['meta_info']


                    class Route(object):
                        """
                        OSPFv3 route summary
                        
                        .. attribute:: extern_one_route
                        
                        	Extern 1 route summary 
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: extern_two_route
                        
                        	Extern 2 route summary 
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: inter_area_route
                        
                        	Inter route summary 
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: intra_area_route
                        
                        	Intra route summary 
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: nssa_one_route
                        
                        	NSSA 1 route summary 
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: nssa_two_route
                        
                        	NSSA 2 route summary 
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: redistribution_route
                        
                        	Redistribution route summary 
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: route_connected
                        
                        	Route connected 
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: route_id
                        
                        	Route summary of a route ID 
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: total_received_route
                        
                        	Total route received summary
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: total_sent_route
                        
                        	Total route summary 
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.extern_one_route = None
                            self.extern_two_route = None
                            self.inter_area_route = None
                            self.intra_area_route = None
                            self.nssa_one_route = None
                            self.nssa_two_route = None
                            self.redistribution_route = None
                            self.route_connected = None
                            self.route_id = None
                            self.total_received_route = None
                            self.total_sent_route = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:route'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.extern_one_route is not None:
                                return True

                            if self.extern_two_route is not None:
                                return True

                            if self.inter_area_route is not None:
                                return True

                            if self.intra_area_route is not None:
                                return True

                            if self.nssa_one_route is not None:
                                return True

                            if self.nssa_two_route is not None:
                                return True

                            if self.redistribution_route is not None:
                                return True

                            if self.route_connected is not None:
                                return True

                            if self.route_id is not None:
                                return True

                            if self.total_received_route is not None:
                                return True

                            if self.total_sent_route is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                            return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Summary.Route']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:summary'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.ospfv3 is not None and self.ospfv3._has_data():
                            return True

                        if self.protocol is not None and self.protocol._has_data():
                            return True

                        if self.route is not None and self.route._has_data():
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                        return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.Summary']['meta_info']


                class RetransmissionListProcessTable(object):
                    """
                    OSPFv3 retransmission list information table for
                    all areas
                    
                    .. attribute:: retransmission
                    
                    	OSPFv3 retransmission list information
                    	**type**\: list of    :py:class:`Retransmission <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.RetransmissionListProcessTable.Retransmission>`
                    
                    

                    """

                    _prefix = 'ipv6-ospfv3-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.retransmission = YList()
                        self.retransmission.parent = self
                        self.retransmission.name = 'retransmission'


                    class Retransmission(object):
                        """
                        OSPFv3 retransmission list information
                        
                        .. attribute:: interface_name
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: is_retransmission_sham_link
                        
                        	If true, sham link is retransmitted 
                        	**type**\:  bool
                        
                        .. attribute:: is_retransmissionvirtual_link
                        
                        	If true, virtual link is retransmitted 
                        	**type**\:  bool
                        
                        .. attribute:: neighbor_address
                        
                        	Neighbor address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: retransmission_area_db
                        
                        	List of area scope entries
                        	**type**\: list of    :py:class:`RetransmissionAreaDb <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.RetransmissionListProcessTable.Retransmission.RetransmissionAreaDb>`
                        
                        .. attribute:: retransmission_asdb
                        
                        	List of AS scope entries
                        	**type**\: list of    :py:class:`RetransmissionAsdb <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.RetransmissionListProcessTable.Retransmission.RetransmissionAsdb>`
                        
                        .. attribute:: retransmission_length
                        
                        	Retransmission queue length
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: retransmission_neighbor_address
                        
                        	Neighbor IP address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: retransmission_sham_link_id
                        
                        	Retransmission sham link ID 
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: retransmission_timer
                        
                        	Amount of time remaining on retransmission timer (ms)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: retransmissionvirtual_link_db
                        
                        	List of virtual link scope entries 
                        	**type**\: list of    :py:class:`RetransmissionvirtualLinkDb <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.RetransmissionListProcessTable.Retransmission.RetransmissionvirtualLinkDb>`
                        
                        .. attribute:: retransmissionvirtual_link_id
                        
                        	Retransmission virtual link ID 
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.interface_name = None
                            self.is_retransmission_sham_link = None
                            self.is_retransmissionvirtual_link = None
                            self.neighbor_address = None
                            self.retransmission_area_db = YList()
                            self.retransmission_area_db.parent = self
                            self.retransmission_area_db.name = 'retransmission_area_db'
                            self.retransmission_asdb = YList()
                            self.retransmission_asdb.parent = self
                            self.retransmission_asdb.name = 'retransmission_asdb'
                            self.retransmission_length = None
                            self.retransmission_neighbor_address = None
                            self.retransmission_sham_link_id = None
                            self.retransmission_timer = None
                            self.retransmissionvirtual_link_db = YList()
                            self.retransmissionvirtual_link_db.parent = self
                            self.retransmissionvirtual_link_db.name = 'retransmissionvirtual_link_db'
                            self.retransmissionvirtual_link_id = None


                        class RetransmissionvirtualLinkDb(object):
                            """
                            List of virtual link scope entries 
                            
                            .. attribute:: header_advertising_router
                            
                            	Router ID of the advertising router
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: header_lsa_age
                            
                            	Age of the LSA (seconds)
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: second
                            
                            .. attribute:: header_lsa_id
                            
                            	LSA ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: header_lsa_type
                            
                            	LSA type
                            	**type**\:   :py:class:`Ospfv3Lsa1Enum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Lsa1Enum>`
                            
                            .. attribute:: header_sequence_number
                            
                            	Current LSA sequence number
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.header_advertising_router = None
                                self.header_lsa_age = None
                                self.header_lsa_id = None
                                self.header_lsa_type = None
                                self.header_sequence_number = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:retransmissionvirtual-link-db'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.header_advertising_router is not None:
                                    return True

                                if self.header_lsa_age is not None:
                                    return True

                                if self.header_lsa_id is not None:
                                    return True

                                if self.header_lsa_type is not None:
                                    return True

                                if self.header_sequence_number is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.RetransmissionListProcessTable.Retransmission.RetransmissionvirtualLinkDb']['meta_info']


                        class RetransmissionAreaDb(object):
                            """
                            List of area scope entries
                            
                            .. attribute:: header_advertising_router
                            
                            	Router ID of the advertising router
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: header_lsa_age
                            
                            	Age of the LSA (seconds)
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: second
                            
                            .. attribute:: header_lsa_id
                            
                            	LSA ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: header_lsa_type
                            
                            	LSA type
                            	**type**\:   :py:class:`Ospfv3Lsa1Enum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Lsa1Enum>`
                            
                            .. attribute:: header_sequence_number
                            
                            	Current LSA sequence number
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.header_advertising_router = None
                                self.header_lsa_age = None
                                self.header_lsa_id = None
                                self.header_lsa_type = None
                                self.header_sequence_number = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:retransmission-area-db'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.header_advertising_router is not None:
                                    return True

                                if self.header_lsa_age is not None:
                                    return True

                                if self.header_lsa_id is not None:
                                    return True

                                if self.header_lsa_type is not None:
                                    return True

                                if self.header_sequence_number is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.RetransmissionListProcessTable.Retransmission.RetransmissionAreaDb']['meta_info']


                        class RetransmissionAsdb(object):
                            """
                            List of AS scope entries
                            
                            .. attribute:: header_advertising_router
                            
                            	Router ID of the advertising router
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: header_lsa_age
                            
                            	Age of the LSA (seconds)
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: second
                            
                            .. attribute:: header_lsa_id
                            
                            	LSA ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: header_lsa_type
                            
                            	LSA type
                            	**type**\:   :py:class:`Ospfv3Lsa1Enum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Lsa1Enum>`
                            
                            .. attribute:: header_sequence_number
                            
                            	Current LSA sequence number
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.header_advertising_router = None
                                self.header_lsa_age = None
                                self.header_lsa_id = None
                                self.header_lsa_type = None
                                self.header_sequence_number = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:retransmission-asdb'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.header_advertising_router is not None:
                                    return True

                                if self.header_lsa_age is not None:
                                    return True

                                if self.header_lsa_id is not None:
                                    return True

                                if self.header_lsa_type is not None:
                                    return True

                                if self.header_sequence_number is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.RetransmissionListProcessTable.Retransmission.RetransmissionAsdb']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:retransmission'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.interface_name is not None:
                                return True

                            if self.is_retransmission_sham_link is not None:
                                return True

                            if self.is_retransmissionvirtual_link is not None:
                                return True

                            if self.neighbor_address is not None:
                                return True

                            if self.retransmission_area_db is not None:
                                for child_ref in self.retransmission_area_db:
                                    if child_ref._has_data():
                                        return True

                            if self.retransmission_asdb is not None:
                                for child_ref in self.retransmission_asdb:
                                    if child_ref._has_data():
                                        return True

                            if self.retransmission_length is not None:
                                return True

                            if self.retransmission_neighbor_address is not None:
                                return True

                            if self.retransmission_sham_link_id is not None:
                                return True

                            if self.retransmission_timer is not None:
                                return True

                            if self.retransmissionvirtual_link_db is not None:
                                for child_ref in self.retransmissionvirtual_link_db:
                                    if child_ref._has_data():
                                        return True

                            if self.retransmissionvirtual_link_id is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                            return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.RetransmissionListProcessTable.Retransmission']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:retransmission-list-process-table'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.retransmission is not None:
                            for child_ref in self.retransmission:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                        return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.RetransmissionListProcessTable']['meta_info']


                class BadChecksums(object):
                    """
                    Bad Checksum Packets information table
                    
                    .. attribute:: bad_checksum
                    
                    	Bad Checksum Packet information
                    	**type**\: list of    :py:class:`BadChecksum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.BadChecksums.BadChecksum>`
                    
                    

                    """

                    _prefix = 'ipv6-ospfv3-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.bad_checksum = YList()
                        self.bad_checksum.parent = self
                        self.bad_checksum.name = 'bad_checksum'


                    class BadChecksum(object):
                        """
                        Bad Checksum Packet information
                        
                        .. attribute:: packet_number  <key>
                        
                        	Bad Checksum Packets number
                        	**type**\:  int
                        
                        	**range:** 0..9
                        
                        .. attribute:: computed_checksum
                        
                        	Computed Checksum
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: received_checksum
                        
                        	Received Checksum
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: received_data
                        
                        	Received Hexadecimal Data
                        	**type**\:  str
                        
                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                        
                        .. attribute:: timestamp
                        
                        	Packet Timestamp (relative to 1970/1/1 00\:00)
                        	**type**\:   :py:class:`Timestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.BadChecksums.BadChecksum.Timestamp>`
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.packet_number = None
                            self.computed_checksum = None
                            self.received_checksum = None
                            self.received_data = None
                            self.timestamp = Ospfv3.Processes.Process.DefaultVrf.BadChecksums.BadChecksum.Timestamp()
                            self.timestamp.parent = self


                        class Timestamp(object):
                            """
                            Packet Timestamp (relative to 1970/1/1 00\:00)
                            
                            .. attribute:: nanosecond
                            
                            	Nano seconds 
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: nanosecond
                            
                            .. attribute:: second
                            
                            	Seconds 
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.nanosecond = None
                                self.second = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:timestamp'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.nanosecond is not None:
                                    return True

                                if self.second is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.BadChecksums.BadChecksum.Timestamp']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')
                            if self.packet_number is None:
                                raise YPYModelError('Key property packet_number is None')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:bad-checksum[Cisco-IOS-XR-ipv6-ospfv3-oper:packet-number = ' + str(self.packet_number) + ']'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.packet_number is not None:
                                return True

                            if self.computed_checksum is not None:
                                return True

                            if self.received_checksum is not None:
                                return True

                            if self.received_data is not None:
                                return True

                            if self.timestamp is not None and self.timestamp._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                            return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.BadChecksums.BadChecksum']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:bad-checksums'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.bad_checksum is not None:
                            for child_ref in self.bad_checksum:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                        return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.BadChecksums']['meta_info']


                class DatabaseSummaryTable(object):
                    """
                    Database summary table
                    
                    .. attribute:: database_summary
                    
                    	Database Summary information
                    	**type**\:   :py:class:`DatabaseSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseSummaryTable.DatabaseSummary>`
                    
                    

                    """

                    _prefix = 'ipv6-ospfv3-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.database_summary = Ospfv3.Processes.Process.DefaultVrf.DatabaseSummaryTable.DatabaseSummary()
                        self.database_summary.parent = self


                    class DatabaseSummary(object):
                        """
                        Database Summary information
                        
                        .. attribute:: area_database
                        
                        	OSPFv3 Area Database list 
                        	**type**\: list of    :py:class:`AreaDatabase <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseSummaryTable.DatabaseSummary.AreaDatabase>`
                        
                        .. attribute:: database_counters
                        
                        	OSPFv3 database counters 
                        	**type**\:   :py:class:`DatabaseCounters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseSummaryTable.DatabaseSummary.DatabaseCounters>`
                        
                        .. attribute:: database_router_id
                        
                        	Database router ID 
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: is_opaque_database_capable
                        
                        	If true, opaque database is capable 
                        	**type**\:  bool
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.area_database = YList()
                            self.area_database.parent = self
                            self.area_database.name = 'area_database'
                            self.database_counters = Ospfv3.Processes.Process.DefaultVrf.DatabaseSummaryTable.DatabaseSummary.DatabaseCounters()
                            self.database_counters.parent = self
                            self.database_router_id = None
                            self.is_opaque_database_capable = None


                        class DatabaseCounters(object):
                            """
                            OSPFv3 database counters 
                            
                            .. attribute:: deleted_lsa
                            
                            	deleted lsa
                            	**type**\:  list of int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: lsa
                            
                            	lsa
                            	**type**\:  list of int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: lsa_checksum
                            
                            	lsa checksum
                            	**type**\:  list of int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: max_age_lsa
                            
                            	max age lsa
                            	**type**\:  list of int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.deleted_lsa = YLeafList()
                                self.deleted_lsa.parent = self
                                self.deleted_lsa.name = 'deleted_lsa'
                                self.lsa = YLeafList()
                                self.lsa.parent = self
                                self.lsa.name = 'lsa'
                                self.lsa_checksum = YLeafList()
                                self.lsa_checksum.parent = self
                                self.lsa_checksum.name = 'lsa_checksum'
                                self.max_age_lsa = YLeafList()
                                self.max_age_lsa.parent = self
                                self.max_age_lsa.name = 'max_age_lsa'

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:database-counters'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.deleted_lsa is not None:
                                    for child in self.deleted_lsa:
                                        if child is not None:
                                            return True

                                if self.lsa is not None:
                                    for child in self.lsa:
                                        if child is not None:
                                            return True

                                if self.lsa_checksum is not None:
                                    for child in self.lsa_checksum:
                                        if child is not None:
                                            return True

                                if self.max_age_lsa is not None:
                                    for child in self.max_age_lsa:
                                        if child is not None:
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.DatabaseSummaryTable.DatabaseSummary.DatabaseCounters']['meta_info']


                        class AreaDatabase(object):
                            """
                            OSPFv3 Area Database list 
                            
                            .. attribute:: area_database_summary
                            
                            	Area database summary 
                            	**type**\:   :py:class:`AreaDatabaseSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseSummaryTable.DatabaseSummary.AreaDatabase.AreaDatabaseSummary>`
                            
                            .. attribute:: lsa_area_id
                            
                            	Area ID in decimal or dotted\-decimal format
                            	**type**\:  str
                            
                            	**length:** 0..16
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.area_database_summary = Ospfv3.Processes.Process.DefaultVrf.DatabaseSummaryTable.DatabaseSummary.AreaDatabase.AreaDatabaseSummary()
                                self.area_database_summary.parent = self
                                self.lsa_area_id = None


                            class AreaDatabaseSummary(object):
                                """
                                Area database summary 
                                
                                .. attribute:: deleted_lsa
                                
                                	deleted lsa
                                	**type**\:  list of int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: lsa
                                
                                	lsa
                                	**type**\:  list of int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: lsa_checksum
                                
                                	lsa checksum
                                	**type**\:  list of int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: max_age_lsa
                                
                                	max age lsa
                                	**type**\:  list of int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.deleted_lsa = YLeafList()
                                    self.deleted_lsa.parent = self
                                    self.deleted_lsa.name = 'deleted_lsa'
                                    self.lsa = YLeafList()
                                    self.lsa.parent = self
                                    self.lsa.name = 'lsa'
                                    self.lsa_checksum = YLeafList()
                                    self.lsa_checksum.parent = self
                                    self.lsa_checksum.name = 'lsa_checksum'
                                    self.max_age_lsa = YLeafList()
                                    self.max_age_lsa.parent = self
                                    self.max_age_lsa.name = 'max_age_lsa'

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:area-database-summary'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.deleted_lsa is not None:
                                        for child in self.deleted_lsa:
                                            if child is not None:
                                                return True

                                    if self.lsa is not None:
                                        for child in self.lsa:
                                            if child is not None:
                                                return True

                                    if self.lsa_checksum is not None:
                                        for child in self.lsa_checksum:
                                            if child is not None:
                                                return True

                                    if self.max_age_lsa is not None:
                                        for child in self.max_age_lsa:
                                            if child is not None:
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                    return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.DatabaseSummaryTable.DatabaseSummary.AreaDatabase.AreaDatabaseSummary']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:area-database'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.area_database_summary is not None and self.area_database_summary._has_data():
                                    return True

                                if self.lsa_area_id is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.DatabaseSummaryTable.DatabaseSummary.AreaDatabase']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:database-summary'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.area_database is not None:
                                for child_ref in self.area_database:
                                    if child_ref._has_data():
                                        return True

                            if self.database_counters is not None and self.database_counters._has_data():
                                return True

                            if self.database_router_id is not None:
                                return True

                            if self.is_opaque_database_capable is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                            return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.DatabaseSummaryTable.DatabaseSummary']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:database-summary-table'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.database_summary is not None and self.database_summary._has_data():
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                        return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.DatabaseSummaryTable']['meta_info']


                class NeighborProcessTable(object):
                    """
                    OSPFv3 neighbor information table for all areas
                    
                    .. attribute:: neighbor
                    
                    	OSPFv3 neighbor detail information
                    	**type**\: list of    :py:class:`Neighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.NeighborProcessTable.Neighbor>`
                    
                    

                    """

                    _prefix = 'ipv6-ospfv3-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.neighbor = YList()
                        self.neighbor.parent = self
                        self.neighbor.name = 'neighbor'


                    class Neighbor(object):
                        """
                        OSPFv3 neighbor detail information
                        
                        .. attribute:: interface_name
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: is_neighbor_sham_link
                        
                        	If true, neighbor is on a sham link 
                        	**type**\:  bool
                        
                        .. attribute:: is_neighbor_virtual_link
                        
                        	If true, neighbor is on a virtual link 
                        	**type**\:  bool
                        
                        .. attribute:: neighbor_address
                        
                        	Neighbor ID
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: neighbor_address_xr
                        
                        	Neighbor IP Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: neighbor_bfd_info
                        
                        	Neighbor BFD information
                        	**type**\:   :py:class:`NeighborBfdInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.NeighborProcessTable.Neighbor.NeighborBfdInfo>`
                        
                        .. attribute:: neighbor_dead_timer
                        
                        	Time until neighbor's dead timer expires (seconds)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: neighbor_designated_router
                        
                        	Designated router 
                        	**type**\:  str
                        
                        	**length:** 0..9
                        
                        .. attribute:: neighbor_detail
                        
                        	Detailed OSPFv3 neighbor information 
                        	**type**\:   :py:class:`NeighborDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.NeighborProcessTable.Neighbor.NeighborDetail>`
                        
                        .. attribute:: neighbor_dr_priority
                        
                        	Neighbor's DR priority
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: neighbor_interface_id
                        
                        	Neighbor interface ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: neighbor_sham_link_id
                        
                        	Neighbor sham link id 
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: neighbor_state
                        
                        	Neighbor's state
                        	**type**\:   :py:class:`Ospfv3NeighborStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3NeighborStateEnum>`
                        
                        .. attribute:: neighbor_up_time
                        
                        	Amount of time since the adjacency is up (seconds)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: neighbor_virtual_link_id
                        
                        	Neighbor virtual link id 
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.interface_name = None
                            self.is_neighbor_sham_link = None
                            self.is_neighbor_virtual_link = None
                            self.neighbor_address = None
                            self.neighbor_address_xr = None
                            self.neighbor_bfd_info = Ospfv3.Processes.Process.DefaultVrf.NeighborProcessTable.Neighbor.NeighborBfdInfo()
                            self.neighbor_bfd_info.parent = self
                            self.neighbor_dead_timer = None
                            self.neighbor_designated_router = None
                            self.neighbor_detail = Ospfv3.Processes.Process.DefaultVrf.NeighborProcessTable.Neighbor.NeighborDetail()
                            self.neighbor_detail.parent = self
                            self.neighbor_dr_priority = None
                            self.neighbor_interface_id = None
                            self.neighbor_sham_link_id = None
                            self.neighbor_state = None
                            self.neighbor_up_time = None
                            self.neighbor_virtual_link_id = None


                        class NeighborDetail(object):
                            """
                            Detailed OSPFv3 neighbor information 
                            
                            .. attribute:: interface_type
                            
                            	Interface type
                            	**type**\:   :py:class:`Ospfv3InterfaceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3InterfaceEnum>`
                            
                            .. attribute:: is_neighbor_filtered
                            
                            	If true, filter outgoing LSAs 
                            	**type**\:  bool
                            
                            .. attribute:: neighbor_backup_designated_router_address
                            
                            	Address of backup designated router
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: neighbor_cost
                            
                            	Cost of path to this neighbor 
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: neighbor_designated_router_address
                            
                            	Address of designated router
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: neighbor_ignore_timer
                            
                            	Remaining time when ignore timer is running 
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: neighbor_option
                            
                            	 This is bitmask of neighbor's option field received 
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: neighbor_retransmission
                            
                            	Retransmission information with this neighbor
                            	**type**\:   :py:class:`NeighborRetransmission <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.NeighborProcessTable.Neighbor.NeighborDetail.NeighborRetransmission>`
                            
                            .. attribute:: next_poll_interval
                            
                            	For NBMA networks, amount of time remaining in seconds before the next poll interval expires and Hello is sent (s)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: pending_events
                            
                            	Number of pending events 
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: poll_interval
                            
                            	Poll interval (s)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: state_changes
                            
                            	Number of state changes 
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.interface_type = None
                                self.is_neighbor_filtered = None
                                self.neighbor_backup_designated_router_address = None
                                self.neighbor_cost = None
                                self.neighbor_designated_router_address = None
                                self.neighbor_ignore_timer = None
                                self.neighbor_option = None
                                self.neighbor_retransmission = Ospfv3.Processes.Process.DefaultVrf.NeighborProcessTable.Neighbor.NeighborDetail.NeighborRetransmission()
                                self.neighbor_retransmission.parent = self
                                self.next_poll_interval = None
                                self.pending_events = None
                                self.poll_interval = None
                                self.state_changes = None


                            class NeighborRetransmission(object):
                                """
                                Retransmission information with this neighbor
                                
                                .. attribute:: area_first_flood
                                
                                	First flood item for area scope LSAs
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: area_first_flood_index
                                
                                	Index of the first flood item for area scope LSAs
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: area_flood_index
                                
                                	Area scope LSA's flood index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: area_next_flood
                                
                                	Next flood item for area scope LSAs
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: area_next_flood_index
                                
                                	Index of next flood item for Area scope LSAs
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: as_first_flood
                                
                                	First flood item for AS scope LSAs
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: as_first_flood_index
                                
                                	Index for first flood item for AS scope LSAs
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: as_flood_index
                                
                                	AS scope LSA's flood index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: as_next_flood
                                
                                	Next flood item for AS scope LSAs
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: as_next_flood_index
                                
                                	Index of next flood item for AS scope LSAs
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: database_descriptor_retransmissions
                                
                                	Number of database descriptor retransmissions during last exchange
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: last_retransmission_length
                                
                                	Number of LSAs sent in last retransmission
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: last_retransmission_time
                                
                                	Last retransmission scan time (ms)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: link_first_flood
                                
                                	Link first flood information 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: link_first_flood_index
                                
                                	Link first flood information index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: link_flood_index
                                
                                	Link flood index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: link_next_flood
                                
                                	Link next flood information 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: link_next_flood_index
                                
                                	Link next flood information index 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: lsa_retransmission_timer
                                
                                	Time until next LSA retransmission (ms)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: maximum_retransmission_length
                                
                                	Maximum number of LSAs sent in a retransmission
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: maximum_retransmission_time
                                
                                	Maximum retransmission scan time (ms)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: neighbor_retransmissions
                                
                                	Number of neighbor retransmissions 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: retransmissions
                                
                                	Number of retransmissions for this neighbor
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.area_first_flood = None
                                    self.area_first_flood_index = None
                                    self.area_flood_index = None
                                    self.area_next_flood = None
                                    self.area_next_flood_index = None
                                    self.as_first_flood = None
                                    self.as_first_flood_index = None
                                    self.as_flood_index = None
                                    self.as_next_flood = None
                                    self.as_next_flood_index = None
                                    self.database_descriptor_retransmissions = None
                                    self.last_retransmission_length = None
                                    self.last_retransmission_time = None
                                    self.link_first_flood = None
                                    self.link_first_flood_index = None
                                    self.link_flood_index = None
                                    self.link_next_flood = None
                                    self.link_next_flood_index = None
                                    self.lsa_retransmission_timer = None
                                    self.maximum_retransmission_length = None
                                    self.maximum_retransmission_time = None
                                    self.neighbor_retransmissions = None
                                    self.retransmissions = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:neighbor-retransmission'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.area_first_flood is not None:
                                        return True

                                    if self.area_first_flood_index is not None:
                                        return True

                                    if self.area_flood_index is not None:
                                        return True

                                    if self.area_next_flood is not None:
                                        return True

                                    if self.area_next_flood_index is not None:
                                        return True

                                    if self.as_first_flood is not None:
                                        return True

                                    if self.as_first_flood_index is not None:
                                        return True

                                    if self.as_flood_index is not None:
                                        return True

                                    if self.as_next_flood is not None:
                                        return True

                                    if self.as_next_flood_index is not None:
                                        return True

                                    if self.database_descriptor_retransmissions is not None:
                                        return True

                                    if self.last_retransmission_length is not None:
                                        return True

                                    if self.last_retransmission_time is not None:
                                        return True

                                    if self.link_first_flood is not None:
                                        return True

                                    if self.link_first_flood_index is not None:
                                        return True

                                    if self.link_flood_index is not None:
                                        return True

                                    if self.link_next_flood is not None:
                                        return True

                                    if self.link_next_flood_index is not None:
                                        return True

                                    if self.lsa_retransmission_timer is not None:
                                        return True

                                    if self.maximum_retransmission_length is not None:
                                        return True

                                    if self.maximum_retransmission_time is not None:
                                        return True

                                    if self.neighbor_retransmissions is not None:
                                        return True

                                    if self.retransmissions is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                    return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.NeighborProcessTable.Neighbor.NeighborDetail.NeighborRetransmission']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:neighbor-detail'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.interface_type is not None:
                                    return True

                                if self.is_neighbor_filtered is not None:
                                    return True

                                if self.neighbor_backup_designated_router_address is not None:
                                    return True

                                if self.neighbor_cost is not None:
                                    return True

                                if self.neighbor_designated_router_address is not None:
                                    return True

                                if self.neighbor_ignore_timer is not None:
                                    return True

                                if self.neighbor_option is not None:
                                    return True

                                if self.neighbor_retransmission is not None and self.neighbor_retransmission._has_data():
                                    return True

                                if self.next_poll_interval is not None:
                                    return True

                                if self.pending_events is not None:
                                    return True

                                if self.poll_interval is not None:
                                    return True

                                if self.state_changes is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.NeighborProcessTable.Neighbor.NeighborDetail']['meta_info']


                        class NeighborBfdInfo(object):
                            """
                            Neighbor BFD information
                            
                            .. attribute:: bfd_intf_enable_mode
                            
                            	BFD enable mode \- Default/Strict
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: bfd_status_flag
                            
                            	Status of the BFD Session
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.bfd_intf_enable_mode = None
                                self.bfd_status_flag = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:neighbor-bfd-info'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.bfd_intf_enable_mode is not None:
                                    return True

                                if self.bfd_status_flag is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.NeighborProcessTable.Neighbor.NeighborBfdInfo']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:neighbor'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.interface_name is not None:
                                return True

                            if self.is_neighbor_sham_link is not None:
                                return True

                            if self.is_neighbor_virtual_link is not None:
                                return True

                            if self.neighbor_address is not None:
                                return True

                            if self.neighbor_address_xr is not None:
                                return True

                            if self.neighbor_bfd_info is not None and self.neighbor_bfd_info._has_data():
                                return True

                            if self.neighbor_dead_timer is not None:
                                return True

                            if self.neighbor_designated_router is not None:
                                return True

                            if self.neighbor_detail is not None and self.neighbor_detail._has_data():
                                return True

                            if self.neighbor_dr_priority is not None:
                                return True

                            if self.neighbor_interface_id is not None:
                                return True

                            if self.neighbor_sham_link_id is not None:
                                return True

                            if self.neighbor_state is not None:
                                return True

                            if self.neighbor_up_time is not None:
                                return True

                            if self.neighbor_virtual_link_id is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                            return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.NeighborProcessTable.Neighbor']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:neighbor-process-table'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.neighbor is not None:
                            for child_ref in self.neighbor:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                        return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.NeighborProcessTable']['meta_info']


                class FastReroutes(object):
                    """
                    OSPFv3 fast reroute topology information table
                    
                    .. attribute:: fast_reroute
                    
                    	OSPFv3 fast reroute topology information
                    	**type**\: list of    :py:class:`FastReroute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.FastReroutes.FastReroute>`
                    
                    

                    """

                    _prefix = 'ipv6-ospfv3-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.fast_reroute = YList()
                        self.fast_reroute.parent = self
                        self.fast_reroute.name = 'fast_reroute'


                    class FastReroute(object):
                        """
                        OSPFv3 fast reroute topology information
                        
                        .. attribute:: area_id
                        
                        	AreaID
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: ipfrr_area_revision
                        
                        	IPFRR Topology Revision
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: ipfrr_router_id
                        
                        	OSPF Router ID
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipfrr_topo
                        
                        	IPFRR Topology entries
                        	**type**\: list of    :py:class:`IpfrrTopo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.FastReroutes.FastReroute.IpfrrTopo>`
                        
                        .. attribute:: ipfrr_topo_area_id
                        
                        	Area ID string in decimal or dotted decimal format
                        	**type**\:  str
                        
                        	**length:** 0..16
                        
                        .. attribute:: router_id
                        
                        	Router ID
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.area_id = None
                            self.ipfrr_area_revision = None
                            self.ipfrr_router_id = None
                            self.ipfrr_topo = YList()
                            self.ipfrr_topo.parent = self
                            self.ipfrr_topo.name = 'ipfrr_topo'
                            self.ipfrr_topo_area_id = None
                            self.router_id = None


                        class IpfrrTopo(object):
                            """
                            IPFRR Topology entries
                            
                            .. attribute:: distance
                            
                            	IPFRR Topology Distance
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: dr
                            
                            	IPFRR Topology DR entry
                            	**type**\:  bool
                            
                            .. attribute:: lsaid
                            
                            	IPFRR Topology LSA ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: neighbor_sourced
                            
                            	IPFRR Topology Neighbor Sourced
                            	**type**\:  bool
                            
                            .. attribute:: node_id
                            
                            	IPFRR Topology Node ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: revision
                            
                            	IPFRR Topology Revision
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: type4
                            
                            	IPFRR Topoogy Type\-4 entry
                            	**type**\:  bool
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.distance = None
                                self.dr = None
                                self.lsaid = None
                                self.neighbor_sourced = None
                                self.node_id = None
                                self.revision = None
                                self.type4 = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:ipfrr-topo'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.distance is not None:
                                    return True

                                if self.dr is not None:
                                    return True

                                if self.lsaid is not None:
                                    return True

                                if self.neighbor_sourced is not None:
                                    return True

                                if self.node_id is not None:
                                    return True

                                if self.revision is not None:
                                    return True

                                if self.type4 is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.FastReroutes.FastReroute.IpfrrTopo']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:fast-reroute'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.area_id is not None:
                                return True

                            if self.ipfrr_area_revision is not None:
                                return True

                            if self.ipfrr_router_id is not None:
                                return True

                            if self.ipfrr_topo is not None:
                                for child_ref in self.ipfrr_topo:
                                    if child_ref._has_data():
                                        return True

                            if self.ipfrr_topo_area_id is not None:
                                return True

                            if self.router_id is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                            return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.FastReroutes.FastReroute']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:fast-reroutes'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.fast_reroute is not None:
                            for child_ref in self.fast_reroute:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                        return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.FastReroutes']['meta_info']


                class InterfaceBriefProcessTable(object):
                    """
                    OSPFv3 interface brief information table for all
                    areas
                    
                    .. attribute:: interface_brief
                    
                    	Interface brief information
                    	**type**\: list of    :py:class:`InterfaceBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.InterfaceBriefProcessTable.InterfaceBrief>`
                    
                    

                    """

                    _prefix = 'ipv6-ospfv3-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.interface_brief = YList()
                        self.interface_brief.parent = self
                        self.interface_brief.name = 'interface_brief'


                    class InterfaceBrief(object):
                        """
                        Interface brief information
                        
                        .. attribute:: interface_name  <key>
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: interface_address
                        
                        	Interface IP address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: interface_adjacent_neighbors
                        
                        	Total number of adjacent neighbors
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: interface_link_cost
                        
                        	Interface link cost
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: interface_neighbors
                        
                        	Total number of neighbors 
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: network_type
                        
                        	Network type
                        	**type**\:   :py:class:`Ospfv3InterfaceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3InterfaceEnum>`
                        
                        .. attribute:: ospf_interface_state
                        
                        	Interface OSPF state
                        	**type**\:   :py:class:`Ospfv3InterfaceStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3InterfaceStateEnum>`
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.interface_name = None
                            self.interface_address = None
                            self.interface_adjacent_neighbors = None
                            self.interface_link_cost = None
                            self.interface_neighbors = None
                            self.network_type = None
                            self.ospf_interface_state = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')
                            if self.interface_name is None:
                                raise YPYModelError('Key property interface_name is None')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:interface-brief[Cisco-IOS-XR-ipv6-ospfv3-oper:interface-name = ' + str(self.interface_name) + ']'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.interface_name is not None:
                                return True

                            if self.interface_address is not None:
                                return True

                            if self.interface_adjacent_neighbors is not None:
                                return True

                            if self.interface_link_cost is not None:
                                return True

                            if self.interface_neighbors is not None:
                                return True

                            if self.network_type is not None:
                                return True

                            if self.ospf_interface_state is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                            return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.InterfaceBriefProcessTable.InterfaceBrief']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:interface-brief-process-table'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.interface_brief is not None:
                            for child_ref in self.interface_brief:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                        return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.InterfaceBriefProcessTable']['meta_info']


                class NeighborDetailProcessTable(object):
                    """
                    OSPFv3 neighbor information table for all areas
                    
                    .. attribute:: neighbor_detail
                    
                    	OSPFv3 neighbor detail information
                    	**type**\: list of    :py:class:`NeighborDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.NeighborDetailProcessTable.NeighborDetail>`
                    
                    

                    """

                    _prefix = 'ipv6-ospfv3-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.neighbor_detail = YList()
                        self.neighbor_detail.parent = self
                        self.neighbor_detail.name = 'neighbor_detail'


                    class NeighborDetail(object):
                        """
                        OSPFv3 neighbor detail information
                        
                        .. attribute:: interface_name
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: is_neighbor_sham_link
                        
                        	If true, neighbor is on a sham link 
                        	**type**\:  bool
                        
                        .. attribute:: is_neighbor_virtual_link
                        
                        	If true, neighbor is on a virtual link 
                        	**type**\:  bool
                        
                        .. attribute:: neighbor_address
                        
                        	Neighbor ID
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: neighbor_address_xr
                        
                        	Neighbor IP Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: neighbor_bfd_info
                        
                        	Neighbor BFD information
                        	**type**\:   :py:class:`NeighborBfdInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.NeighborDetailProcessTable.NeighborDetail.NeighborBfdInfo>`
                        
                        .. attribute:: neighbor_dead_timer
                        
                        	Time until neighbor's dead timer expires (seconds)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: neighbor_designated_router
                        
                        	Designated router 
                        	**type**\:  str
                        
                        	**length:** 0..9
                        
                        .. attribute:: neighbor_detail
                        
                        	Detailed OSPFv3 neighbor information 
                        	**type**\:   :py:class:`NeighborDetail_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.NeighborDetailProcessTable.NeighborDetail.NeighborDetail_>`
                        
                        .. attribute:: neighbor_dr_priority
                        
                        	Neighbor's DR priority
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: neighbor_interface_id
                        
                        	Neighbor interface ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: neighbor_sham_link_id
                        
                        	Neighbor sham link id 
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: neighbor_state
                        
                        	Neighbor's state
                        	**type**\:   :py:class:`Ospfv3NeighborStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3NeighborStateEnum>`
                        
                        .. attribute:: neighbor_up_time
                        
                        	Amount of time since the adjacency is up (seconds)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: neighbor_virtual_link_id
                        
                        	Neighbor virtual link id 
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.interface_name = None
                            self.is_neighbor_sham_link = None
                            self.is_neighbor_virtual_link = None
                            self.neighbor_address = None
                            self.neighbor_address_xr = None
                            self.neighbor_bfd_info = Ospfv3.Processes.Process.DefaultVrf.NeighborDetailProcessTable.NeighborDetail.NeighborBfdInfo()
                            self.neighbor_bfd_info.parent = self
                            self.neighbor_dead_timer = None
                            self.neighbor_designated_router = None
                            self.neighbor_detail = Ospfv3.Processes.Process.DefaultVrf.NeighborDetailProcessTable.NeighborDetail.NeighborDetail_()
                            self.neighbor_detail.parent = self
                            self.neighbor_dr_priority = None
                            self.neighbor_interface_id = None
                            self.neighbor_sham_link_id = None
                            self.neighbor_state = None
                            self.neighbor_up_time = None
                            self.neighbor_virtual_link_id = None


                        class NeighborDetail_(object):
                            """
                            Detailed OSPFv3 neighbor information 
                            
                            .. attribute:: interface_type
                            
                            	Interface type
                            	**type**\:   :py:class:`Ospfv3InterfaceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3InterfaceEnum>`
                            
                            .. attribute:: is_neighbor_filtered
                            
                            	If true, filter outgoing LSAs 
                            	**type**\:  bool
                            
                            .. attribute:: neighbor_backup_designated_router_address
                            
                            	Address of backup designated router
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: neighbor_cost
                            
                            	Cost of path to this neighbor 
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: neighbor_designated_router_address
                            
                            	Address of designated router
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: neighbor_ignore_timer
                            
                            	Remaining time when ignore timer is running 
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: neighbor_option
                            
                            	 This is bitmask of neighbor's option field received 
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: neighbor_retransmission
                            
                            	Retransmission information with this neighbor
                            	**type**\:   :py:class:`NeighborRetransmission <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.NeighborDetailProcessTable.NeighborDetail.NeighborDetail_.NeighborRetransmission>`
                            
                            .. attribute:: next_poll_interval
                            
                            	For NBMA networks, amount of time remaining in seconds before the next poll interval expires and Hello is sent (s)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: pending_events
                            
                            	Number of pending events 
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: poll_interval
                            
                            	Poll interval (s)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: state_changes
                            
                            	Number of state changes 
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.interface_type = None
                                self.is_neighbor_filtered = None
                                self.neighbor_backup_designated_router_address = None
                                self.neighbor_cost = None
                                self.neighbor_designated_router_address = None
                                self.neighbor_ignore_timer = None
                                self.neighbor_option = None
                                self.neighbor_retransmission = Ospfv3.Processes.Process.DefaultVrf.NeighborDetailProcessTable.NeighborDetail.NeighborDetail_.NeighborRetransmission()
                                self.neighbor_retransmission.parent = self
                                self.next_poll_interval = None
                                self.pending_events = None
                                self.poll_interval = None
                                self.state_changes = None


                            class NeighborRetransmission(object):
                                """
                                Retransmission information with this neighbor
                                
                                .. attribute:: area_first_flood
                                
                                	First flood item for area scope LSAs
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: area_first_flood_index
                                
                                	Index of the first flood item for area scope LSAs
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: area_flood_index
                                
                                	Area scope LSA's flood index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: area_next_flood
                                
                                	Next flood item for area scope LSAs
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: area_next_flood_index
                                
                                	Index of next flood item for Area scope LSAs
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: as_first_flood
                                
                                	First flood item for AS scope LSAs
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: as_first_flood_index
                                
                                	Index for first flood item for AS scope LSAs
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: as_flood_index
                                
                                	AS scope LSA's flood index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: as_next_flood
                                
                                	Next flood item for AS scope LSAs
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: as_next_flood_index
                                
                                	Index of next flood item for AS scope LSAs
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: database_descriptor_retransmissions
                                
                                	Number of database descriptor retransmissions during last exchange
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: last_retransmission_length
                                
                                	Number of LSAs sent in last retransmission
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: last_retransmission_time
                                
                                	Last retransmission scan time (ms)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: link_first_flood
                                
                                	Link first flood information 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: link_first_flood_index
                                
                                	Link first flood information index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: link_flood_index
                                
                                	Link flood index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: link_next_flood
                                
                                	Link next flood information 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: link_next_flood_index
                                
                                	Link next flood information index 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: lsa_retransmission_timer
                                
                                	Time until next LSA retransmission (ms)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: maximum_retransmission_length
                                
                                	Maximum number of LSAs sent in a retransmission
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: maximum_retransmission_time
                                
                                	Maximum retransmission scan time (ms)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: neighbor_retransmissions
                                
                                	Number of neighbor retransmissions 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: retransmissions
                                
                                	Number of retransmissions for this neighbor
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.area_first_flood = None
                                    self.area_first_flood_index = None
                                    self.area_flood_index = None
                                    self.area_next_flood = None
                                    self.area_next_flood_index = None
                                    self.as_first_flood = None
                                    self.as_first_flood_index = None
                                    self.as_flood_index = None
                                    self.as_next_flood = None
                                    self.as_next_flood_index = None
                                    self.database_descriptor_retransmissions = None
                                    self.last_retransmission_length = None
                                    self.last_retransmission_time = None
                                    self.link_first_flood = None
                                    self.link_first_flood_index = None
                                    self.link_flood_index = None
                                    self.link_next_flood = None
                                    self.link_next_flood_index = None
                                    self.lsa_retransmission_timer = None
                                    self.maximum_retransmission_length = None
                                    self.maximum_retransmission_time = None
                                    self.neighbor_retransmissions = None
                                    self.retransmissions = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:neighbor-retransmission'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.area_first_flood is not None:
                                        return True

                                    if self.area_first_flood_index is not None:
                                        return True

                                    if self.area_flood_index is not None:
                                        return True

                                    if self.area_next_flood is not None:
                                        return True

                                    if self.area_next_flood_index is not None:
                                        return True

                                    if self.as_first_flood is not None:
                                        return True

                                    if self.as_first_flood_index is not None:
                                        return True

                                    if self.as_flood_index is not None:
                                        return True

                                    if self.as_next_flood is not None:
                                        return True

                                    if self.as_next_flood_index is not None:
                                        return True

                                    if self.database_descriptor_retransmissions is not None:
                                        return True

                                    if self.last_retransmission_length is not None:
                                        return True

                                    if self.last_retransmission_time is not None:
                                        return True

                                    if self.link_first_flood is not None:
                                        return True

                                    if self.link_first_flood_index is not None:
                                        return True

                                    if self.link_flood_index is not None:
                                        return True

                                    if self.link_next_flood is not None:
                                        return True

                                    if self.link_next_flood_index is not None:
                                        return True

                                    if self.lsa_retransmission_timer is not None:
                                        return True

                                    if self.maximum_retransmission_length is not None:
                                        return True

                                    if self.maximum_retransmission_time is not None:
                                        return True

                                    if self.neighbor_retransmissions is not None:
                                        return True

                                    if self.retransmissions is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                    return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.NeighborDetailProcessTable.NeighborDetail.NeighborDetail_.NeighborRetransmission']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:neighbor-detail'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.interface_type is not None:
                                    return True

                                if self.is_neighbor_filtered is not None:
                                    return True

                                if self.neighbor_backup_designated_router_address is not None:
                                    return True

                                if self.neighbor_cost is not None:
                                    return True

                                if self.neighbor_designated_router_address is not None:
                                    return True

                                if self.neighbor_ignore_timer is not None:
                                    return True

                                if self.neighbor_option is not None:
                                    return True

                                if self.neighbor_retransmission is not None and self.neighbor_retransmission._has_data():
                                    return True

                                if self.next_poll_interval is not None:
                                    return True

                                if self.pending_events is not None:
                                    return True

                                if self.poll_interval is not None:
                                    return True

                                if self.state_changes is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.NeighborDetailProcessTable.NeighborDetail.NeighborDetail_']['meta_info']


                        class NeighborBfdInfo(object):
                            """
                            Neighbor BFD information
                            
                            .. attribute:: bfd_intf_enable_mode
                            
                            	BFD enable mode \- Default/Strict
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: bfd_status_flag
                            
                            	Status of the BFD Session
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.bfd_intf_enable_mode = None
                                self.bfd_status_flag = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:neighbor-bfd-info'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.bfd_intf_enable_mode is not None:
                                    return True

                                if self.bfd_status_flag is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                                return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.NeighborDetailProcessTable.NeighborDetail.NeighborBfdInfo']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:neighbor-detail'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.interface_name is not None:
                                return True

                            if self.is_neighbor_sham_link is not None:
                                return True

                            if self.is_neighbor_virtual_link is not None:
                                return True

                            if self.neighbor_address is not None:
                                return True

                            if self.neighbor_address_xr is not None:
                                return True

                            if self.neighbor_bfd_info is not None and self.neighbor_bfd_info._has_data():
                                return True

                            if self.neighbor_dead_timer is not None:
                                return True

                            if self.neighbor_designated_router is not None:
                                return True

                            if self.neighbor_detail is not None and self.neighbor_detail._has_data():
                                return True

                            if self.neighbor_dr_priority is not None:
                                return True

                            if self.neighbor_interface_id is not None:
                                return True

                            if self.neighbor_sham_link_id is not None:
                                return True

                            if self.neighbor_state is not None:
                                return True

                            if self.neighbor_up_time is not None:
                                return True

                            if self.neighbor_virtual_link_id is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                            return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.NeighborDetailProcessTable.NeighborDetail']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:neighbor-detail-process-table'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.neighbor_detail is not None:
                            for child_ref in self.neighbor_detail:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                        return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf.NeighborDetailProcessTable']['meta_info']

                @property
                def _common_path(self):
                    if self.parent is None:
                        raise YPYModelError('parent is not set . Cannot derive path.')

                    return self.parent._common_path +'/Cisco-IOS-XR-ipv6-ospfv3-oper:default-vrf'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.area_informations is not None and self.area_informations._has_data():
                        return True

                    if self.areas is not None and self.areas._has_data():
                        return True

                    if self.bad_checksums is not None and self.bad_checksums._has_data():
                        return True

                    if self.border_routers is not None and self.border_routers._has_data():
                        return True

                    if self.connected_routes is not None and self.connected_routes._has_data():
                        return True

                    if self.database_summary_table is not None and self.database_summary_table._has_data():
                        return True

                    if self.database_table is not None and self.database_table._has_data():
                        return True

                    if self.external_routes is not None and self.external_routes._has_data():
                        return True

                    if self.fast_reroutes is not None and self.fast_reroutes._has_data():
                        return True

                    if self.flood_list_process_table is not None and self.flood_list_process_table._has_data():
                        return True

                    if self.interface_brief_process_table is not None and self.interface_brief_process_table._has_data():
                        return True

                    if self.interface_process_table is not None and self.interface_process_table._has_data():
                        return True

                    if self.internal_routes is not None and self.internal_routes._has_data():
                        return True

                    if self.neighbor_detail_process_table is not None and self.neighbor_detail_process_table._has_data():
                        return True

                    if self.neighbor_process_table is not None and self.neighbor_process_table._has_data():
                        return True

                    if self.protocol_areas is not None and self.protocol_areas._has_data():
                        return True

                    if self.redistributions is not None and self.redistributions._has_data():
                        return True

                    if self.request_list_process_table is not None and self.request_list_process_table._has_data():
                        return True

                    if self.retransmission_list_process_table is not None and self.retransmission_list_process_table._has_data():
                        return True

                    if self.route_summary is not None and self.route_summary._has_data():
                        return True

                    if self.sham_link_table is not None and self.sham_link_table._has_data():
                        return True

                    if self.summary is not None and self.summary._has_data():
                        return True

                    if self.summary_prefixes is not None and self.summary_prefixes._has_data():
                        return True

                    if self.virtual_link is not None and self.virtual_link._has_data():
                        return True

                    if self.vrf_statistics is not None and self.vrf_statistics._has_data():
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                    return meta._meta_table['Ospfv3.Processes.Process.DefaultVrf']['meta_info']

            @property
            def _common_path(self):
                if self.process_name is None:
                    raise YPYModelError('Key property process_name is None')

                return '/Cisco-IOS-XR-ipv6-ospfv3-oper:ospfv3/Cisco-IOS-XR-ipv6-ospfv3-oper:processes/Cisco-IOS-XR-ipv6-ospfv3-oper:process[Cisco-IOS-XR-ipv6-ospfv3-oper:process-name = ' + str(self.process_name) + ']'

            def is_config(self):
                ''' Returns True if this instance represents config data else returns False '''
                return False

            def _has_data(self):
                if not self.is_config():
                    return False
                if self.process_name is not None:
                    return True

                if self.default_vrf is not None and self.default_vrf._has_data():
                    return True

                if self.statistics is not None and self.statistics._has_data():
                    return True

                if self.vrfs is not None and self.vrfs._has_data():
                    return True

                return False

            @staticmethod
            def _meta_info():
                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
                return meta._meta_table['Ospfv3.Processes.Process']['meta_info']

        @property
        def _common_path(self):

            return '/Cisco-IOS-XR-ipv6-ospfv3-oper:ospfv3/Cisco-IOS-XR-ipv6-ospfv3-oper:processes'

        def is_config(self):
            ''' Returns True if this instance represents config data else returns False '''
            return False

        def _has_data(self):
            if not self.is_config():
                return False
            if self.process is not None:
                for child_ref in self.process:
                    if child_ref._has_data():
                        return True

            return False

        @staticmethod
        def _meta_info():
            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
            return meta._meta_table['Ospfv3.Processes']['meta_info']

    @property
    def _common_path(self):

        return '/Cisco-IOS-XR-ipv6-ospfv3-oper:ospfv3'

    def is_config(self):
        ''' Returns True if this instance represents config data else returns False '''
        return False

    def _has_data(self):
        if not self.is_config():
            return False
        if self.processes is not None and self.processes._has_data():
            return True

        return False

    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv6_ospfv3_oper as meta
        return meta._meta_table['Ospfv3']['meta_info']


